# coding: utf8
from __future__ import unicode_literals


rules = {'ADJ': {"'": [('e', False)],
         '-motorede': [('-motorede', False)],
         '-ramt': [('-ramt', False)],
         '.': [('indelig', False)],
         '0.': [('0.', False)],
         '1.': [('1.', False)],
         '13.': [('13.', True)],
         '2.': [('2.', False)],
         '23.': [('23.', True)],
         '3': [('3.', True)],
         '3.': [('3', True), ('3.', True)],
         '4.': [('4.', True)],
         '5.': [('5.', False)],
         '6.': [('6.', False)],
         '7.': [('7.', False)],
         '8.': [('8.', False)],
         '9.': [('9.', False)],
         'abelt': [('abel', False)],
         'abet': [('abet', False)],
         'adbundet': [('adbundet', False)],
         'ade': [('ad', False)],
         'adent': [('aden', False)],
         'adet': [('adet', False)],
         'adne': [('aden', False)],
         'adt': [('ad', False)],
         'afaldet': [('afalden', False)],
         'afe': [('af', False)],
         'aft': [('af', False)],
         'age': [('ag', False)],
         'agent': [('agen', False)],
         'agest': [('agest', False)],
         'aget': [('aget', False)],
         'agne': [('agen', False)],
         'agt': [('ag', False)],
         'agte': [('agt', False)],
         'ake': [('ak', False)],
         'akke': [('ak', False)],
         'akt': [('ak', False)],
         'aldt': [('aldt', False)],
         'aldte': [('aldt', False)],
         'ale': [('al', False)],
         'alede': [('alet', False)],
         'alidt': [('alid', False)],
         'alige': [('alig', False)],
         'allerinderst': [('indre', True)],
         'alne': [('alen', False)],
         'alt': [('al', False)],
         'alært': [('alær', False)],
         'ame': [('am', False)],
         'amet': [('amet', False)],
         'amfulde': [('amfuld', False)],
         'amme': [('am', False)],
         'ammede': [('ammet', False)],
         'amt': [('am', False)],
         'an': [('an', False)],
         'ande': [('and', False)],
         'andede': [('andet', False)],
         'andet': [('anden', False)],
         'ane': [('an', False)],
         'anført': [('anført', False)],
         'ange': [('ange', False)],
         'anges': [('ange', False)],
         'angt': [('angen', False)],
         'ankt': [('ankt', False)],
         'anløbne': [('anløben', True), ('anløbet', True)],
         'annede': [('annet', False)],
         'anskrevet': [('anskreven', True), ('anskrevet', True)],
         'anskrevne': [('anskrevet', True), ('anskreven', True)],
         'ant': [('an', False)],
         'apt': [('ap', False)],
         'are': [('ar', False)],
         'arede': [('aret', False)],
         'arent': [('aren', False)],
         'aret': [('aret', False)],
         'arge': [('arg', True)],
         'arige': [('arig', False)],
         'arint': [('arin', False)],
         'arre': [('ar', False)],
         'art': [('ar', False)],
         'arte': [('arte', False)],
         'asalt': [('asal', False)],
         'aset': [('aset', False)],
         'ast': [('ast', False)],
         'astørre': [('astør', False)],
         'at': [('at', False)],
         'atalt': [('atal', False)],
         'ate': [('at', False)],
         'ative': [('ativ', False)],
         'atne': [('atten', False)],
         'atomdrevet': [('atomdrevet', True), ('atomdreven', True)],
         'atomdrevne': [('atomdreven', True), ('atomdrevet', True)],
         'atte': [('at', False)],
         'avalent': [('avalent', False)],
         'ave': [('av', False)],
         'avent': [('aven', False)],
         'aveste': [('av', False)],
         'avet': [('avet', False)],
         'avt': [('av', False)],
         'bagede': [('baget', False)],
         'baghjulstrukket': [('baghjulstrukken', True), ('baghjulstrukket', True)],
         'baghjulstrukne': [('baghjulstrukken', True), ('baghjulstrukket', True)],
         'bagt': [('bagt', False)],
         'bandet': [('bandet', False)],
         'batteridrevet': [('batteridreven', True), ('batteridrevet', True)],
         'batteridrevne': [('batteridrevet', True), ('batteridreven', True)],
         'bbet': [('bbet', False)],
         'bede': [('bet', False)],
         'bedre': [('god', True)],
         'bedst': [('god', True)],
         'bedste': [('god', True)],
         'belt': [('belt', False)],
         'benført': [('benfør', False)],
         'benzindrevet': [('benzindrevet', True), ('benzindreven', True)],
         'benzindrevne': [('benzindreven', True), ('benzindrevet', True)],
         'betalt': [('betalt', False)],
         'bette': [('bette', True)],
         'bevist': [('bevist', False)],
         'bidt': [('bidt', False)],
         'bitte': [('bitte', True)],
         'bjergtagede': [('bjergtagen', True), ('bjergtaget', True)],
         'bjergtaget': [('bjergtaget', True), ('bjergtagen', True)],
         'bjergtagne': [('bjergtagen', True), ('bjergtaget', True)],
         'blede': [('blet', False)],
         'blidt': [('blid', False)],
         'blinde': [('blind', False)],
         'blødstrøget': [('blødstrøget', True), ('blødstrøgen', True)],
         'blødstrøgne': [('blødstrøget', True), ('blødstrøgen', True)],
         'bne': [('ben', False)],
         'boldt': [('bold', True)],
         'bortløbet': [('bortløben', True), ('bortløbet', True)],
         'bortløbne': [('bortløben', True), ('bortløbet', True)],
         'brakt': [('brak', True)],
         'brede': [('bred', True)],
         'bredt': [('bred', False)],
         'bret': [('bret', False)],
         'bridt': [('brid', False)],
         'brige': [('brig', False)],
         'brugerdrevet': [('brugerdrevet', True), ('brugerdreven', True)],
         'brugerdrevne': [('brugerdrevet', True), ('brugerdreven', True)],
         'bset': [('bset', False)],
         'bt': [('bt', False)],
         'bte': [('bt', False)],
         'btilt': [('btil', False)],
         'budt': [('budt', False)],
         'bundet': [('bunden', True)],
         'bundne': [('bunden', False)],
         'bust': [('bust', False)],
         'bårne': [('båren', False)],
         'bæltedrevet': [('bæltedreven', True), ('bæltedrevet', True)],
         'bæltedrevne': [('bæltedrevet', True), ('bæltedreven', True)],
         'ce': [('ce', False)],
         'cent': [('cent', False)],
         'chede': [('chet', False)],
         'core': [('core', False)],
         'dagede': [('daget', False)],
         'dakt': [('dakt', False)],
         'dampdrevet': [('dampdrevet', True), ('dampdreven', True)],
         'dampdrevne': [('dampdrevet', True), ('dampdreven', True)],
         'dant': [('dant', False)],
         'date': [('date', False)],
         'dde': [('d', False)],
         'ddent': [('dden', False)],
         'ddet': [('ddet', False)],
         'debrede': [('debred', False)],
         'dede': [('det', False)],
         'delt': [('delt', False)],
         'dement': [('dement', False)],
         'dene': [('dene', False)],
         'dere': [('d', False)],
         'derne': [('derne', False)],
         'derst': [('derst', False)],
         'des': [('des', False)],
         'dfaldet': [('dfalden', False)],
         'dfrosne': [('dfrossen', False)],
         'dført': [('dfør', False)],
         'dgivet': [('dgiven', False)],
         'dgivne': [('dgiven', False)],
         'dhørt': [('dhør', False)],
         'dieseldrevet': [('dieseldreven', True), ('dieseldrevet', True)],
         'dieseldrevne': [('dieseldrevet', True), ('dieseldreven', True)],
         'digne': [('digen', False)],
         'digst': [('digst', False)],
         'dkede': [('dked', False)],
         'dkåren': [('dkåren', False)],
         'dlede': [('dlet', False)],
         'dlevet': [('dlevet', False)],
         'dlige': [('dlig', False)],
         'dløst': [('dløs', False)],
         'dnere': [('den', False)],
         'dnævnte': [('dnævnt', False)],
         'dobbeltslebet': [('dobbeltsleben', True), ('dobbeltslebet', True)],
         'dobbeltslebne': [('dobbeltslebet', True), ('dobbeltsleben', True)],
         'dre': [('dre', False)],
         'drede': [('dret', False)],
         'drene': [('drene', False)],
         'dret': [('dret', False)],
         'drevet': [('drevet', False)],
         'drevne': [('dreven', True), ('drevet', True)],
         'drige': [('drig', False)],
         'drukne': [('drukken', False)],
         'dsagte': [('dsagt', False)],
         'dse': [('ds', False)],
         'dset': [('dset', False)],
         'dsle': [('dsel', False)],
         'dt': [('dt', False)],
         'dtaget': [('dtaget', False)],
         'dte': [('dt', False)],
         'dtramt': [('dtramt', False)],
         'duløst': [('duløs', False)],
         'dvist': [('dvis', False)],
         'dvundet': [('dvunden', False)],
         'dædt': [('dædt', False)],
         'dækt': [('dækt', False)],
         'døde': [('død', False)],
         'dødfundet': [('dødfunden', True), ('dødfundet', True)],
         'dødfundne': [('dødfundet', True), ('dødfunden', True)],
         'dømt': [('dømt', False)],
         'døvblevet': [('døvbleven', True), ('døvblevet', True)],
         'døvblevne': [('døvbleven', True), ('døvblevet', True)],
         'e': [('', False)],
         'ebet': [('ebet', False)],
         'ebrede': [('ebret', False)],
         'edent': [('eden', False)],
         'edet': [('edet', False)],
         'edne': [('eden', False)],
         'edst': [('eds', False)],
         'edt': [('ed', False)],
         'ee': [('ee', False)],
         'eede': [('eet', False)],
         'efrosne': [('efrossen', False)],
         'ege': [('eg', False)],
         'egent': [('egen', False)],
         'eget': [('egen', True)],
         'egne': [('egen', False)],
         'egt': [('eg', False)],
         'egte': [('egt', False)],
         'eige': [('eige', False)],
         'eje': [('ej', False)],
         'eldrevet': [('eldreven', True), ('eldrevet', True)],
         'eldrevne': [('eldrevet', True), ('eldreven', True)],
         'eldt': [('eldt', False)],
         'ele': [('el', False)],
         'elede': [('elet', False)],
         'elige': [('elig', False)],
         'elinde': [('elinde', False)],
         'elkomne': [('elkommen', False)],
         'ellent': [('ellent', False)],
         'elment': [('elment', False)],
         'elt': [('el', False)],
         'elve': [('elve', False)],
         'elært': [('elær', False)],
         'eløbet': [('eløbet', False)],
         'eløst': [('eløs', False)],
         'eme': [('em', False)],
         'ement': [('emen', False)],
         'emere': [('emer', False)],
         'emert': [('emer', False)],
         'emet': [('emet', False)],
         'emme': [('em', False)],
         'emmede': [('emmet', False)],
         'emmest': [('em', False)],
         'emmeste': [('emmest', False)],
         'emst': [('emst', False)],
         'emste': [('emst', False)],
         'emt': [('em', False)],
         'emte': [('emte', False)],
         'en': [('en', False)],
         'endent': [('endent', False)],
         'endt': [('endt', False)],
         'ene': [('ene', True)],
         'eneste': [('eneste', True)],
         'enført': [('enført', False)],
         'enkelt': [('enkelt', True), ('enkel', True)],
         'ense': [('ense', False)],
         'enst': [('ens', False)],
         'ent': [('en', False)],
         'enævnte': [('enævnt', False)],
         'ept': [('ep', False)],
         'eramt': [('eramt', False)],
         'erde': [('erde', False)],
         'erdrevet': [('erdrevet', False)],
         'ere': [('er', False)],
         'erede': [('eret', False)],
         'erene': [('eren', False)],
         'erent': [('eren', False)],
         'eret': [('eret', False)],
         'ergent': [('ergent', False)],
         'erige': [('erig', False)],
         'erint': [('erin', False)],
         'erne': [('ern', False)],
         'ernede': [('ernet', False)],
         'erste': [('erst', False)],
         'ert': [('er', False)],
         'eset': [('eset', False)],
         'esidste': [('esidst', False)],
         'eskåret': [('skåren', False)],
         'eskårne': [('skåren', False)],
         'eslige': [('eslige', False)],
         'esmå': [('elille', False)],
         'est': [('est', False)],
         'este': [('', False)],
         'estramt': [('estramt', False)],
         'estre': [('estre', False)],
         'estridt': [('estridt', False)],
         'estørst': [('estørst', False)],
         'estørste': [('estørst', False)],
         'et': [('et', False)],
         'etalt': [('etal', False)],
         'ete': [('et', False)],
         'etive': [('etiv', False)],
         'etrukket': [('etrukket', False)],
         'ette': [('et', False)],
         'euse': [('euse', False)],
         'event': [('even', False)],
         'evist': [('evis', False)],
         'evorne': [('evorn', False)],
         'facetslebet': [('facetsleben', True), ('facetslebet', True)],
         'facetslebne': [('facetslebet', True), ('facetsleben', True)],
         'fake': [('fake', True)],
         'faldne': [('falden', False)],
         'fanget': [('fangen', True), ('fanget', True)],
         'fangne': [('fanget', True), ('fangen', True)],
         'faret': [('faren', False)],
         'fe': [('', False)],
         'fede': [('fed', False)],
         'fekte': [('fekt', False)],
         'fektive': [('fektiv', False)],
         'ferent': [('ferent', False)],
         'feste': [('fest', False)],
         'ffede': [('ffet', False)],
         'ffet': [('ffet', False)],
         'figne': [('figen', False)],
         'figurskåret': [('figurskåren', True), ('figurskåret', True)],
         'figurskårne': [('figurskåren', True), ('figurskåret', True)],
         'finskåret': [('finskåren', True), ('finskåret', True)],
         'finskårne': [('finskåren', True), ('finskåret', True)],
         'fintskåret': [('fintskåret', True), ('fintskåren', True)],
         'fintskårne': [('fintskåret', True), ('fintskåren', True)],
         'firehjulstrukket': [('firehjulstrukket', True), ('firehjulstrukken', True)],
         'firehjulstrukne': [('firehjulstrukket', True), ('firehjulstrukken', True)],
         'firhjulstrukket': [('firhjulstrukken', True), ('firhjulstrukket', True)],
         'firhjulstrukne': [('firhjulstrukken', True), ('firhjulstrukket', True)],
         'fladt': [('flad', True)],
         'flede': [('flet', False)],
         'fledt': [('fledt', False)],
         'flige': [('flig', False)],
         'floromvundne': [('floromvunden', True), ('floromvundet', True)],
         'fløjne': [('fløjet', False)],
         'fne': [('ffen', False)],
         'forede': [('foret', False)],
         'forhjulstrukket': [('forhjulstrukken', True), ('forhjulstrukket', True)],
         'forhjulstrukne': [('forhjulstrukken', True), ('forhjulstrukket', True)],
         'forne': [('forne', True)],
         'forrevne': [('forrevet', True), ('forreven', True)],
         'forskåret': [('forskåren', True), ('forskåret', True)],
         'forskårne': [('forskåren', True), ('forskåret', True)],
         'frede': [('fret', False)],
         'frelst': [('frels', True), ('frelst', True)],
         'frene': [('fren', False)],
         'frent': [('fren', False)],
         'fret': [('fret', False)],
         'frosne': [('frossen', True)],
         'frosset': [('frossen', False)],
         'fside': [('fside', False)],
         'fte': [('ft', False)],
         'ftramt': [('ftramt', False)],
         'fulde': [('fuld', False)],
         'fuløst': [('fuløs', False)],
         'født': [('født', False)],
         'fødte': [('født', False)],
         'føgede': [('føget', False)],
         'føgne': [('føget', False)],
         'føje': [('føje', True)],
         'først': [('først', False)],
         'første': [('første', True)],
         'ført': [('før', True)],
         'gangne': [('gangen', False)],
         'gant': [('gant', False)],
         'gasdrevet': [('gasdreven', True), ('gasdrevet', True)],
         'gasdrevne': [('gasdreven', True), ('gasdrevet', True)],
         'gede': [('get', False)],
         'gemt': [('gemt', False)],
         'gemte': [('gemt', False)],
         'gene': [('gen', False)],
         'gentagede': [('gentagen', True), ('gentaget', True)],
         'gentaget': [('gentaget', True), ('gentagen', True)],
         'gentagne': [('gentagen', True), ('gentaget', True)],
         'gere': [('g', False)],
         'gerst': [('gerst', False)],
         'ges': [('ges', False)],
         'gest': [('g', False)],
         'geste': [('gest', False)],
         'gge': [('g', False)],
         'ggent': [('ggen', False)],
         'gget': [('gget', False)],
         'ght': [('gh', False)],
         'ghørt': [('ghør', False)],
         'gift': [('gift', True)],
         'gistent': [('gisten', True)],
         'givet': [('givet', True)],
         'givne': [('givet', True), ('given', True)],
         'gl.': [('ongelig', False)],
         'glatslebet': [('glatslebet', True), ('glatsleben', True)],
         'glatslebne': [('glatsleben', True), ('glatslebet', True)],
         'glede': [('glet', False)],
         'glige': [('glig', False)],
         'gløst': [('gløs', False)],
         'gn': [('gn', False)],
         'gnt': [('gn', False)],
         'goldt': [('gold', True)],
         'gramt': [('gram', True)],
         'grede': [('gret', False)],
         'gret': [('gret', False)],
         'gridt': [('grid', False)],
         'groftskåret': [('groftskåren', True), ('groftskåret', True)],
         'groftskårne': [('groftskåren', True), ('groftskåret', True)],
         'grovskåret': [('grovskåret', True), ('grovskåren', True)],
         'grovskårne': [('grovskåret', True), ('grovskåren', True)],
         'gse': [('gs', False)],
         'gst': [('gst', False)],
         'gt': [('gt', False)],
         'gte': [('gte', False)],
         'gtramt': [('gtramt', False)],
         'gtrukket': [('gtrukket', False)],
         'gvalt': [('gval', False)],
         'gvist': [('gvis', False)],
         'gvorne': [('gvorn', False)],
         'gældbundet': [('gældbundet', True), ('gældbunden', True)],
         'gældbundne': [('gældbunden', True), ('gældbundet', True)],
         'hadt': [('hadt', False)],
         'halt': [('halt', True)],
         'hede': [('hed', False)],
         'hestetrukket': [('hestetrukket', True), ('hestetrukken', True)],
         'hestetrukne': [('hestetrukket', True), ('hestetrukken', True)],
         'hore': [('hore', False)],
         'hulde': [('huld', True)],
         'hv.': [('orhenværende', False)],
         'hyre': [('hyre', False)],
         'håndbåret': [('håndbåren', True), ('håndbåret', True)],
         'håndbårne': [('håndbåren', True), ('håndbåret', True)],
         'håndskrevet': [('håndskreven', True), ('håndskrevet', True)],
         'håndskrevne': [('håndskreven', True), ('håndskrevet', True)],
         'håndskåret': [('håndskåret', True), ('håndskåren', True)],
         'håndskårne': [('håndskåret', True), ('håndskåren', True)],
         'håndstrøget': [('håndstrøget', True), ('håndstrøgen', True)],
         'håndstrøgne': [('håndstrøget', True), ('håndstrøgen', True)],
         'hårede': [('håret', False)],
         'hårtrukne': [('hårtrukket', True), ('hårtrukken', True)],
         'hæst': [('hæs', True)],
         'højeste': [('høj', True)],
         'højtbesunget': [('højtbesunget', True), ('højtbesungen', True)],
         'højtbesungne': [('højtbesungen', True), ('højtbesunget', True)],
         'hørt': [('hørt', False)],
         'i.': [('i.', False)],
         'iant': [('iant', False)],
         'ibelt': [('ibel', False)],
         'ibet': [('ibet', False)],
         'ibevist': [('ibevis', False)],
         'ibrede': [('ibret', False)],
         'ide': [('id', False)],
         'idelt': [('idel', False)],
         'ident': [('iden', False)],
         'idet': [('idet', False)],
         'idne': [('iden', False)],
         'idst': [('ids', False)],
         'idste': [('idst', False)],
         'idt': [('id', False)],
         'ie': [('ie', False)],
         'iede': [('iet', False)],
         'ient': [('ient', False)],
         'ift': [('iv', False)],
         'ige': [('ig', False)],
         'igent': [('igen', False)],
         'iges': [('ig', False)],
         'igeste': [('ig', False)],
         'iget': [('iget', False)],
         'ight': [('ight', False)],
         'igne': [('ign', False)],
         'igst': [('ig', False)],
         'igste': [('igst', False)],
         'igt': [('ig', False)],
         'ike': [('ike', False)],
         'ikke': [('ik', False)],
         'ikket': [('ikken', False)],
         'ikne': [('ikken', False)],
         'ikt': [('ik', False)],
         'ilanddrevet': [('ilanddreven', True), ('ilanddrevet', True)],
         'ilanddrevne': [('ilanddreven', True), ('ilanddrevet', True)],
         'ilde': [('ilde', False)],
         'ile': [('il', False)],
         'ilede': [('ilet', False)],
         'ilige': [('ilig', False)],
         'ille': [('ille', False)],
         'illigste': [('illig', False)],
         'illært': [('illært', False)],
         'ilt': [('il', False)],
         'iløst': [('iløs', False)],
         'ime': [('im', False)],
         'imet': [('imet', False)],
         'imme': [('im', False)],
         'immede': [('immet', False)],
         'imt': [('im', False)],
         'in': [('in', False)],
         'inde': [('ind', False)],
         'indede': [('indet', False)],
         'indre': [('indre', True)],
         'indsunkne': [('indsunket', True), ('indsunken', True)],
         'ine': [('in', False)],
         'ineste': [('in', False)],
         'inge': [('inge', False)],
         'ingent': [('ingent', False)],
         'inkt': [('inkt', False)],
         'innede': [('innet', False)],
         'int': [('in', False)],
         'ipne': [('ippen', False)],
         'ipt': [('ip', False)],
         'irede': [('iret', False)],
         'irekte': [('irekte', False)],
         'iret': [('iret', False)],
         'irige': [('irig', False)],
         'ise': [('is', False)],
         'iset': [('iset', True)],
         'ist': [('is', False)],
         'istent': [('istent', False)],
         'it': [('it', False)],
         'italt': [('ital', False)],
         'ite': [('ite', False)],
         'itive': [('itiv', False)],
         'itne': [('itten', False)],
         'itre': [('itter', False)],
         'itte': [('it', False)],
         'iturevet': [('iturevet', True), ('itureven', True)],
         'iturevne': [('iturevet', True), ('itureven', True)],
         'ivalent': [('ivalent', False)],
         'ive': [('iv', False)],
         'ivent': [('iven', False)],
         'iverse': [('iverse', False)],
         'ives': [('iv', False)],
         'iveste': [('iv', False)],
         'ivet': [('ivet', False)],
         'ivrede': [('ivret', False)],
         'ivt': [('iv', False)],
         'jagede': [('jaget', False)],
         'jdet': [('jdet', False)],
         'je': [('je', False)],
         'jede': [('jet', False)],
         'jektive': [('jektiv', False)],
         'jent': [('jent', False)],
         'jere': [('j', False)],
         'jle': [('jl', False)],
         'jlede': [('jlet', False)],
         'jlige': [('jlig', False)],
         'jlt': [('jl', False)],
         'jn': [('jn', False)],
         'jne': [('jn', False)],
         'jnt': [('jn', False)],
         'jordbundne': [('jordbunden', True), ('jordbundet', True)],
         'jort': [('jort', False)],
         'jrbidt': [('jrbidt', False)],
         'jre': [('jre', False)],
         'jrede': [('jret', False)],
         'jret': [('jret', False)],
         'jse': [('js', False)],
         'jset': [('jset', False)],
         'jst': [('jst', False)],
         'jævnt': [('jævn', False)],
         'kadent': [('kadent', False)],
         'kadt': [('kadt', False)],
         'kaldet': [('kaldet', False)],
         'kant': [('kant', False)],
         'kbundet': [('kbundet', False)],
         'kdrevne': [('kdreven', False)],
         'kede': [('ked', True)],
         'kere': [('', False)],
         'kert': [('kert', False)],
         'keste': [('', False)],
         'kfanget': [('kfanget', False)],
         'kide': [('kide', False)],
         'kidt': [('kidt', False)],
         'kikket': [('kikket', False)],
         'kilt': [('kilt', False)],
         'kkede': [('kket', False)],
         'kkert': [('kker', False)],
         'kket': [('kket', False)],
         'klede': [('klet', False)],
         'klere': [('kel', False)],
         'knebne': [('kneben', True)],
         'knyt': [('knyt', False)],
         'kogt': [('kogt', False)],
         'koldt': [('kold', False)],
         'komne': [('kommen', False)],
         'kort': [('kort', False)],
         'kre': [('kker', False)],
         'krede': [('kret', False)],
         'kret': [('kret', False)],
         'krint': [('krin', False)],
         'kræsent': [('kræsen', True)],
         'ksalt': [('ksal', False)],
         'kse': [('ks', False)],
         'ksent': [('ksen', False)],
         'kset': [('kset', False)],
         'ksne': [('ksen', False)],
         'kst': [('ks', False)],
         'kt': [('kt', False)],
         'ktalt': [('ktal', False)],
         'kte': [('kt', False)],
         'ktilt': [('ktil', False)],
         'ktive': [('ktiv', False)],
         'ktramt': [('ktramt', False)],
         'kudt': [('kudt', False)],
         'kult': [('kult', False)],
         'kuløst': [('kuløs', False)],
         'kvist': [('kvis', False)],
         'kårede': [('kåret', False)],
         'kåret': [('kåren', False)],
         'kårne': [('kåren', False)],
         'kæreste': [('kær', True)],
         'kørt': [('kørt', False)],
         'ladt': [('lad', True)],
         'lagede': [('laget', False)],
         'laget': [('lagen', False)],
         'lagt': [('lagt', False)],
         'landet': [('landet', False)],
         'lange': [('lang', False)],
         'langes': [('lang', True)],
         'langt': [('lang', False)],
         'langtrukne': [('langtrukken', True), ('langtrukket', True)],
         'lankt': [('lank', False)],
         'lant': [('lant', False)],
         'large': [('large', True)],
         'ldbårne': [('ldbåren', False)],
         'lde': [('ld', False)],
         'ldent': [('lden', False)],
         'ldet': [('ldet', False)],
         'ldne': [('lden', False)],
         'ldste': [('ldst', False)],
         'ldt': [('ld', False)],
         'le': [('el', False)],
         'lede': [('led', True)],
         'ledigblevet': [('ledigbleven', True), ('ledigblevet', True)],
         'ledigblevne': [('ledigbleven', True), ('ledigblevet', True)],
         'ledt': [('led', True)],
         'leget': [('leget', False)],
         'lektive': [('lektiv', False)],
         'lemt': [('lemt', False)],
         'lemte': [('lemt', False)],
         'lent': [('lent', False)],
         'lere': [('lere', False)],
         'lergent': [('lergen', False)],
         'lert': [('lert', False)],
         'les': [('les', False)],
         'leste': [('lest', False)],
         'levne': [('leven', False)],
         'lget': [('lget', False)],
         'lgte': [('lgt', False)],
         'lidet': [('liden', True)],
         'lidt': [('lidt', False)],
         'lige': [('lige', False)],
         'ligent': [('ligent', False)],
         'ligst': [('ligst', False)],
         'ligste': [('lig', False)],
         'likket': [('likket', False)],
         'linde': [('lind', True)],
         'lindt': [('lind', False)],
         'line': [('line', False)],
         'linkt': [('link', False)],
         'linnede': [('linned', True)],
         'live': [('live', True)],
         'lkede': [('lket', False)],
         'lket': [('lket', False)],
         'lle': [('l', False)],
         'llede': [('llet', False)],
         'llent': [('llen', False)],
         'llige': [('llig', False)],
         'lligste': [('lligst', False)],
         'llært': [('llær', False)],
         'lløst': [('lløs', False)],
         'lme': [('lm', False)],
         'lment': [('lmen', False)],
         'lmet': [('lmet', False)],
         'lmfulde': [('lmfuld', False)],
         'lmt': [('lm', False)],
         'lne': [('llen', False)],
         'lodne': [('lodden', True)],
         'lommet': [('lommet', False)],
         'lorne': [('loren', True)],
         'lorrige': [('lorrig', False)],
         'losset': [('losset', False)],
         'lost': [('lost', True)],
         'lovbundet': [('lovbunden', True), ('lovbundet', True)],
         'lovbundne': [('lovbundet', True), ('lovbunden', True)],
         'lpint': [('lpin', False)],
         'lrede': [('lret', False)],
         'lret': [('lret', False)],
         'lrige': [('lrig', False)],
         'lse': [('ls', False)],
         'lset': [('lset', False)],
         'lt': [('lt', False)],
         'ltant': [('ltan', False)],
         'lte': [('lt', False)],
         'ltent': [('lten', False)],
         'ltes': [('lt', False)],
         'ltre': [('lter', False)],
         'luftbåret': [('luftbåren', True), ('luftbåret', True)],
         'luftbårne': [('luftbåren', True), ('luftbåret', True)],
         'lugne': [('lugen', False)],
         'lukket': [('lukket', False)],
         'lukt': [('lukt', False)],
         'lunde': [('lunde', False)],
         'lunkne': [('lunken', False)],
         'lvandet': [('lvanden', False)],
         'lve': [('lv', False)],
         'lvet': [('lvet', False)],
         'lvist': [('lvis', False)],
         'lvorne': [('lvorn', False)],
         'lvt': [('lv', False)],
         'lyst': [('lys', True)],
         'lædt': [('lædt', False)],
         'lært': [('lært', False)],
         'læste': [('læst', False)],
         'løbet': [('løben', False)],
         'løbne': [('løben', False)],
         'løde': [('lød', False)],
         'lørt': [('lørt', False)],
         'løsslupne': [('løssluppet', True), ('løssluppen', True)],
         'løst': [('løs', True)],
         'made': [('made', False)],
         'mage': [('mage', True)],
         'mandet': [('mandet', False)],
         'mange': [('mangen', True), ('mange', True)],
         'mant': [('mant', False)],
         'mart': [('mart', False)],
         'marte': [('mart', False)],
         'maskindrevet': [('maskindrevet', True), ('maskindreven', True)],
         'maskindrevne': [('maskindreven', True), ('maskindrevet', True)],
         'matslebet': [('matsleben', True), ('matslebet', True)],
         'matslebne': [('matslebet', True), ('matsleben', True)],
         'mbet': [('mbet', False)],
         'mede': [('met', False)],
         'medtagede': [('medtagen', True), ('medtaget', True)],
         'medtaget': [('medtaget', True), ('medtagen', True)],
         'medtagne': [('medtagen', True), ('medtaget', True)],
         'meget': [('megen', True)],
         'meldte': [('meldte', False)],
         'mene': [('men', False)],
         'mere': [('mere', True)],
         'mert': [('mert', False)],
         'mes': [('mes', False)],
         'mest': [('mest', True)],
         'meste': [('mest', True)],
         'milde': [('mild', True)],
         'mindede': [('minded', True)],
         'mindre': [('lidt', True), ('lille', True)],
         'mindst': [('lidt', True), ('lille', True)],
         'mindste': [('lille', True)],
         'mle': [('mmel', False)],
         'mlede': [('mlet', False)],
         'mlige': [('mlig', False)],
         'mløst': [('mløs', False)],
         'mment': [('mmen', False)],
         'mmere': [('m', False)],
         'mmert': [('mmer', False)],
         'mmet': [('mmet', False)],
         'mosset': [('mosset', False)],
         'motordrevet': [('motordreven', True), ('motordrevet', True)],
         'motordrevne': [('motordreven', True), ('motordrevet', True)],
         'motorede': [('motoret', False)],
         'mpe': [('mp', False)],
         'mpre': [('mper', False)],
         'mpt': [('mp', False)],
         'mpte': [('mpte', False)],
         'mre': [('mmer', False)],
         'mrede': [('mret', False)],
         'mret': [('mret', False)],
         'mrøget': [('mrøget', False)],
         'mse': [('ms', False)],
         'mset': [('mset', False)],
         'mst': [('ms', False)],
         'mstridt': [('mstridt', False)],
         'mt': [('mt', False)],
         'mte': [('mt', False)],
         'mtive': [('mtiv', False)],
         'mtlige': [('mtlige', False)],
         'mulige': [('mulig', False)],
         'mult': [('mult', False)],
         'mundet': [('mundet', False)],
         'murt': [('murt', False)],
         'mædt': [('mædt', False)],
         'mælt': [('mælt', False)],
         'møgede': [('møget', False)],
         'nant': [('nant', False)],
         'navngivne': [('navngivet', True)],
         'nde': [('nde', False)],
         'ndede': [('nded', False)],
         'ndent': [('nden', False)],
         'ndet': [('ndet', False)],
         'ndne': [('nden', False)],
         'ndre': [('nder', False)],
         'ndt': [('nd', False)],
         'ndtagede': [('ndtaget', False)],
         'ndtagne': [('ndtaget', False)],
         'nede': [('net', False)],
         'nedsunkne': [('nedsunket', True), ('nedsunken', True)],
         'nektive': [('nektiv', False)],
         'nemmeste': [('nem', True)],
         'nemst': [('nem', False)],
         'nemste': [('nem', False)],
         'nent': [('nent', False)],
         'nere': [('n', False)],
         'nert': [('nert', False)],
         'nes': [('nes', False)],
         'neste': [('', False)],
         'nfaldet': [('nfalden', False)],
         'nge': [('ng', False)],
         'ngent': [('ngen', False)],
         'nges': [('ng', False)],
         'nget': [('nget', False)],
         'ngivne': [('ngiven', False)],
         'ngste': [('ngst', False)],
         'ngt': [('ng', False)],
         'ngte': [('ngt', False)],
         'nilde': [('nild', False)],
         'nke': [('nk', False)],
         'nkede': [('nket', False)],
         'nkelt': [('nkel', False)],
         'nket': [('nket', False)],
         'nkommet': [('nkommen', False)],
         'nlige': [('nlig', False)],
         'nløbet': [('nløbet', False)],
         'nløst': [('nløs', False)],
         'nmeldte': [('nmeldt', False)],
         'nne': [('n', False)],
         'nnævnte': [('nnævnt', False)],
         'nrige': [('nrig', False)],
         'ns.': [('nservativ', False)],
         'nset': [('nset', False)],
         'nsidste': [('nsidst', False)],
         'nst': [('nst', False)],
         'nstre': [('nstre', False)],
         'nstrengt': [('nstrengt', False)],
         'nstørst': [('nstørst', False)],
         'nstørste': [('nstørst', False)],
         'ntalt': [('ntal', False)],
         'ntant': [('ntan', False)],
         'nte': [('nt', False)],
         'ntent': [('nten', False)],
         'ntilt': [('ntil', False)],
         'ntive': [('ntiv', False)],
         'ntre': [('nter', False)],
         'nuløst': [('nuløs', False)],
         'nverst': [('nvers', False)],
         'nyfaldet': [('nyfaldet', True), ('nyfalden', True)],
         'nyfaldne': [('nyfalden', True), ('nyfaldet', True)],
         'nyfundet': [('nyfundet', True), ('nyfunden', True)],
         'nyfundne': [('nyfunden', True), ('nyfundet', True)],
         'nystrøgede': [('nystrøget', True), ('nystrøgen', True)],
         'nystrøget': [('nystrøget', True), ('nystrøgen', True)],
         'nystrøgne': [('nystrøget', True), ('nystrøgen', True)],
         'nyt': [('ny', False)],
         'nytilkommet': [('nytilkommen', True), ('nytilkommet', True)],
         'nytilkomne': [('nytilkommet', True), ('nytilkommen', True)],
         'nærest': [('nær', True)],
         'nævnte': [('nævnt', True)],
         'nødt': [('nødt', True)],
         'nøje': [('nøje', True)],
         'obelt': [('obel', False)],
         'obevist': [('obevis', False)],
         'obt': [('ob', False)],
         'ode': [('od', False)],
         'odent': [('oden', False)],
         'odet': [('odet', False)],
         'odne': [('oden', False)],
         'odt': [('od', False)],
         'oede': [('oet', False)],
         'oge': [('og', False)],
         'ogent': [('ogen', False)],
         'ogeste': [('og', False)],
         'oget': [('oget', False)],
         'ogt': [('og', False)],
         'ogte': [('ogt', False)],
         'oket': [('oket', False)],
         'okke': [('ok', False)],
         'okne': [('okken', False)],
         'okt': [('ok', False)],
         'oldt': [('oldt', False)],
         'oldte': [('oldt', False)],
         'ole': [('ol', False)],
         'olede': [('olet', False)],
         'olidt': [('olid', False)],
         'olige': [('olig', False)],
         'olt': [('ol', False)],
         'olært': [('olær', False)],
         'oløst': [('oløs', False)],
         'omant': [('oman', False)],
         'omart': [('omar', False)],
         'ome': [('om', False)],
         'omere': [('omer', False)],
         'omert': [('omer', False)],
         'omme': [('om', False)],
         'ommede': [('ommet', False)],
         'omst': [('om', False)],
         'omt': [('om', False)],
         'on': [('on', False)],
         'onde': [('ond', False)],
         'one': [('on', False)],
         'ont': [('on', False)],
         'ontant': [('ontant', False)],
         'opakt': [('opak', True)],
         'opdrevet': [('opdrevet', True), ('opdreven', True)],
         'opdrevne': [('opdrevet', True), ('opdreven', True)],
         'ope': [('op', False)],
         'opre': [('oper', False)],
         'opt': [('op', False)],
         'oramt': [('oramt', False)],
         'orange': [('orange', True)],
         'ore': [('or', False)],
         'orent': [('oren', False)],
         'oret': [('oret', False)],
         'orlige': [('orlige', False)],
         'orløst': [('orløst', False)],
         'ornede': [('ornet', False)],
         'orrige': [('orrige', False)],
         'ort': [('or', False)],
         'ose': [('os', False)],
         'oset': [('oset', False)],
         'ospektive': [('ospektiv', False)],
         'ost': [('os', False)],
         'ot': [('ot', False)],
         'otalt': [('otal', False)],
         'ote': [('ot', False)],
         'otive': [('otiv', False)],
         'otne': [('otten', False)],
         'otte': [('ot', False)],
         'ovalent': [('ovalent', False)],
         'ovalt': [('oval', True)],
         'ove': [('ov', False)],
         'ovedet': [('ovedet', False)],
         'ovent': [('oven', False)],
         'overdrevne': [('overdrevet', True), ('overdreven', True)],
         'ovet': [('ovet', False)],
         'ovt': [('ov', False)],
         'pakt': [('pakt', False)],
         'pandet': [('pandet', False)],
         'pant': [('pant', False)],
         'parent': [('parent', False)],
         'pe': [('', False)],
         'pede': [('pet', False)],
         'peget': [('peget', False)],
         'pekte': [('pekt', False)],
         'perst': [('perst', False)],
         'pint': [('pint', False)],
         'pist': [('pist', False)],
         'pladt': [('pladt', False)],
         'plaget': [('plaget', False)],
         'plant': [('plan', True)],
         'plede': [('plet', False)],
         'plevet': [('plevet', False)],
         'plyst': [('plyst', False)],
         'pne': [('pen', False)],
         'pontant': [('pontan', False)],
         'porede': [('poret', False)],
         'porlige': [('porlig', False)],
         'porløst': [('porløs', False)],
         'pre': [('pper', False)],
         'prede': [('pret', False)],
         'prest': [('pres', False)],
         'pret': [('pret', False)],
         'prevet': [('prevet', False)],
         'prevne': [('prevet', False)],
         'proft': [('prof', True)],
         'propeldrevet': [('propeldreven', True), ('propeldrevet', True)],
         'propeldrevne': [('propeldreven', True), ('propeldrevet', True)],
         'prudt': [('prud', True)],
         'prukne': [('prukken', False)],
         'psagte': [('psagt', False)],
         'pset': [('pset', False)],
         'pt': [('pt', False)],
         'ptaget': [('ptaget', False)],
         'pte': [('pt', False)],
         'ptive': [('ptiv', False)],
         'ptskåret': [('ptskåret', False)],
         'puløst': [('puløs', False)],
         'pure': [('pure', True), ('pur', True)],
         'pvist': [('pvis', False)],
         'påtaget': [('påtagen', True), ('påtaget', True)],
         'ragede': [('raget', False)],
         'ragt': [('ragt', False)],
         'rakt': [('rakt', False)],
         'ramt': [('ram', True)],
         'randet': [('randet', False)],
         'range': [('rang', False)],
         'rangt': [('rang', False)],
         'rankt': [('rank', True)],
         'rant': [('rant', False)],
         'rast': [('ras', False)],
         'rbedst': [('rbedst', False)],
         'rbedste': [('rbedst', False)],
         'rbidt': [('rbid', False)],
         'rbt': [('rb', False)],
         'rbundet': [('rbundet', False)],
         'rdbundet': [('rdbundet', False)],
         'rde': [('rd', False)],
         'rdet': [('rdet', False)],
         'rdt': [('rd', False)],
         're': [('er', False)],
         'reaktionsdrevet': [('reaktionsdreven', True), ('reaktionsdrevet', True)],
         'reaktionsdrevne': [('reaktionsdreven', True), ('reaktionsdrevet', True)],
         'rede': [('rede', True)],
         'redet': [('reden', False)],
         'redt': [('redt', False)],
         'regelbundet': [('regelbundet', True), ('regelbunden', True)],
         'regelbundne': [('regelbundet', True), ('regelbunden', True)],
         'reget': [('reget', False)],
         'rekomne': [('rekommen', False)],
         'rekte': [('rekt', False)],
         'remmede': [('remmed', False)],
         'remmest': [('remmest', False)],
         'ren': [('ren', True)],
         'rene': [('ren', True)],
         'rent': [('ren', True)],
         'rere': [('r', False)],
         'res': [('res', False)],
         'reste': [('ter', False)],
         'ret': [('ret', True)],
         'revne': [('reven', False)],
         'rfangne': [('rfangen', False)],
         'rfe': [('rf', False)],
         'rfløjne': [('rfløjen', False)],
         'rfrosne': [('rfrossen', False)],
         'rft': [('rf', False)],
         'rførste': [('rførst', False)],
         'rgent': [('rgen', False)],
         'rget': [('rget', False)],
         'rgivet': [('rgiven', False)],
         'rgivne': [('rgiven', False)],
         'rgne': [('rgen', False)],
         'rgt': [('rg', False)],
         'rgte': [('rgt', False)],
         'rhøjeste': [('rhøjest', False)],
         'rie': [('ri', False)],
         'rige': [('rig', True)],
         'rikket': [('rikket', False)],
         'rikt': [('rikt', False)],
         'rindt': [('rind', False)],
         'rint': [('rint', False)],
         'rise': [('rise', False)],
         'rist': [('rist', False)],
         'ristent': [('risten', False)],
         'rit': [('ri', False)],
         'rke': [('rk', False)],
         'rkede': [('rket', False)],
         'rkere': [('rk', False)],
         'rkeste': [('rk', False)],
         'rket': [('rket', False)],
         'rkt': [('rk', False)],
         'rkæreste': [('rkærest', False)],
         'rladt': [('rladt', False)],
         'rle': [('rle', False)],
         'rlige': [('rlig', False)],
         'rløst': [('rløs', False)],
         'rme': [('rm', False)],
         'rmere': [('rm', False)],
         'rmest': [('r', False)],
         'rmeste': [('r', False)],
         'rmet': [('rmet', False)],
         'rmfulde': [('rmfuld', False)],
         'rmindst': [('rmindst', False)],
         'rmindste': [('rmindst', False)],
         'rmt': [('rm', False)],
         'rn': [('rn', False)],
         'rne': [('ren', False)],
         'rnt': [('rn', False)],
         'rnævnte': [('rnævnt', False)],
         'rodne': [('rodden', False)],
         'roft': [('rov', False)],
         'rosset': [('rosset', False)],
         'rpe': [('rp', False)],
         'rpskåret': [('rpskåret', False)],
         'rpt': [('rp', False)],
         'rrant': [('rran', False)],
         'rrede': [('rret', False)],
         'rrest': [('rrest', False)],
         'rreste': [('rrest', False)],
         'rret': [('rret', False)],
         'rrevet': [('rrevet', False)],
         'rrige': [('rrig', False)],
         'rsagte': [('rsagt', False)],
         'rsalt': [('rsal', False)],
         'rskårne': [('rskåren', False)],
         'rst': [('rst', False)],
         'rstilt': [('rstilt', False)],
         'rstørst': [('rstørst', False)],
         'rstørste': [('rstørst', False)],
         'rte': [('rt', False)],
         'rtere': [('rt', False)],
         'rtilt': [('rtil', False)],
         'rtive': [('rtiv', False)],
         'rtoiremæssige': [('toiremæssig', False)],
         'rtrukket': [('rtrukket', False)],
         'rudt': [('rudt', False)],
         'rukket': [('rukket', False)],
         'rundet': [('rundet', False)],
         'rundskåret': [('rundskåret', True), ('rundskåren', True)],
         'rundskårne': [('rundskåret', True), ('rundskåren', True)],
         'runget': [('runget', False)],
         'runkne': [('runken', True)],
         'runkt': [('runk', False)],
         'rust': [('rust', False)],
         'rutalt': [('rutal', False)],
         'rve': [('rv', False)],
         'rverst': [('rvers', False)],
         'rvet': [('rvet', False)],
         'rvist': [('rvis', False)],
         'rvorne': [('rvorn', False)],
         'rvt': [('rv', False)],
         'rvænt': [('rvænt', False)],
         'rykt': [('rykt', False)],
         'rådt': [('rådt', False)],
         'rædt': [('rædt', False)],
         'ræsent': [('ræsent', False)],
         'røde': [('rød', False)],
         'røgede': [('røget', False)],
         'røget': [('røget', True)],
         'rømt': [('rømt', False)],
         'rørt': [('rørt', False)],
         's.': [('simal', False)],
         'sagede': [('saget', False)],
         'sagnomspundet': [('sagnomspunden', True), ('sagnomspundet', True)],
         'sagnomspundne': [('sagnomspundet', True), ('sagnomspunden', True)],
         'sagt': [('sagt', False)],
         'sagte': [('sagte', True)],
         'sakt': [('sakt', False)],
         'salt': [('salt', True)],
         'samfulde': [('samfulde', True)],
         'samme': [('samme', True)],
         'sammenknebne': [('sammenknebet', True), ('sammenkneben', True)],
         'sammenkrøbet': [('sammenkrøbet', True), ('sammenkrøben', True)],
         'sammenkrøbne': [('sammenkrøbet', True), ('sammenkrøben', True)],
         'sammensunkne': [('sammensunken', True), ('sammensunket', True)],
         'sandet': [('sandet', True)],
         'sant': [('sant', False)],
         'sart': [('sart', True)],
         'sarte': [('sart', True)],
         'sede': [('set', False)],
         'selvhjulpne': [('selvhjulpen', True), ('selvhjulpet', True)],
         'selvopfundet': [('selvopfundet', True), ('selvopfunden', True)],
         'selvopfundne': [('selvopfunden', True), ('selvopfundet', True)],
         'selvskrevet': [('selvskreven', True), ('selvskrevet', True)],
         'selvskrevne': [('selvskreven', True), ('selvskrevet', True)],
         'sene': [('sen', True)],
         'seneste': [('sen', True)],
         'sent': [('sen', True)],
         'sert': [('sert', False)],
         'ses': [('ses', False)],
         'sgent': [('sgen', False)],
         'side': [('sid', True)],
         'sident': [('sident', False)],
         'sidst': [('sidst', False)],
         'sidste': [('sidste', True)],
         'sikke': [('sikken', True)],
         'skarpskårne': [('skarpskåren', True), ('skarpskåret', True)],
         'skarpslebet': [('skarpsleben', True), ('skarpslebet', True)],
         'skarpslebne': [('skarpslebet', True), ('skarpsleben', True)],
         'skarptskårne': [('skarptskåret', True), ('skarptskåren', True)],
         'skarptslebet': [('skarptslebet', True), ('skarptsleben', True)],
         'skarptslebne': [('skarptsleben', True), ('skarptslebet', True)],
         'ske': [('sk', False)],
         'skede': [('sket', False)],
         'skemabundet': [('skemabunden', True), ('skemabundet', True)],
         'skemabundne': [('skemabundet', True), ('skemabunden', True)],
         'sket': [('sket', False)],
         'skrevet': [('skreven', False)],
         'skrevne': [('skreven', False)],
         'skt': [('sk', False)],
         'skårede': [('skåret', True)],
         'skåren': [('skåren', False)],
         'skåret': [('skåret', False)],
         'skårne': [('skåret', False)],
         'skørt': [('skør', False)],
         'sle': [('ssel', False)],
         'slebne': [('sleben', True)],
         'slede': [('slet', False)],
         'slemt': [('slem', True)],
         'slige': [('slig', False)],
         'sløst': [('sløs', False)],
         'små': [('lille', True), ('små', True)],
         'små bitte': [('lille bitte', True)],
         'småbitte': [('lillebitte', True)],
         'småtskåret': [('småtskåret', True), ('småtskåren', True)],
         'småtskårne': [('småtskåret', True), ('småtskåren', True)],
         'snavngivet': [('snavngivet', False)],
         'sne': [('ssen', False)],
         'snævnte': [('snævnt', False)],
         'soldrevet': [('soldreven', True), ('soldrevet', True)],
         'soldrevne': [('soldreven', True), ('soldrevet', True)],
         'solsvedet': [('solsveden', True), ('solsvedet', True)],
         'solsvedne': [('solsvedet', True), ('solsveden', True)],
         'sorne': [('soren', False)],
         'sort': [('sort', False)],
         'spektive': [('spektive', False)],
         'sramt': [('sramt', False)],
         'srede': [('sret', False)],
         'srige': [('srig', False)],
         'ssalt': [('ssal', False)],
         'sse': [('s', False)],
         'ssent': [('ssen', False)],
         'sset': [('sset', False)],
         'stalt': [('stal', False)],
         'standet': [('standen', False)],
         'ste': [('st', False)],
         'stedbundet': [('stedbundet', True), ('stedbunden', True)],
         'stedbundne': [('stedbunden', True), ('stedbundet', True)],
         'stedfundet': [('stedfundet', True), ('stedfunden', True)],
         'stedfundne': [('stedfunden', True), ('stedfundet', True)],
         'stent': [('sten', False)],
         'stilt': [('stil', False)],
         'stive': [('stiv', False)],
         'stramt': [('stram', True)],
         'stre': [('ster', False)],
         'strengt': [('streng', True)],
         'stridt': [('strid', True)],
         'strøgede': [('strøget', False)],
         'strøget': [('strøget', False)],
         'strøgne': [('strøget', False)],
         'større': [('stor', True)],
         'størst': [('stor', True)],
         'største': [('stor', True)],
         'sust': [('sust', False)],
         'svalt': [('sval', True)],
         'svart': [('svar', True)],
         'svedne': [('sveden', False)],
         'svindt': [('svindt', False)],
         'svist': [('svis', False)],
         'svunget': [('svungen', True), ('svunget', True)],
         'svungne': [('svunget', True), ('svungen', True)],
         'søbåret': [('søbåren', True), ('søbåret', True)],
         'søbårne': [('søbåren', True), ('søbåret', True)],
         'søde': [('sød', False)],
         't': [('', False)],
         'tagede': [('taget', False)],
         'tagne': [('taget', False)],
         'takt': [('takt', False)],
         'talt': [('talt', False)],
         'tandet': [('tandet', False)],
         'tant': [('tant', False)],
         'tbedst': [('tbedst', False)],
         'tbedste': [('tbedst', False)],
         'tbundet': [('tbundet', False)],
         'tede': [('tet', False)],
         'tedt': [('tedt', False)],
         'tegt': [('tegt', False)],
         'temt': [('temt', False)],
         'temte': [('temt', False)],
         'tense': [('tens', False)],
         'tent': [('tent', False)],
         'tere': [('', False)],
         'terst': [('terst', False)],
         'tes': [('tes', False)],
         'test': [('t', False)],
         'tfødte': [('tfødte', False)],
         'tgivne': [('tgivne', False)],
         'thøjeste': [('thøjest', False)],
         'tidsbundet': [('tidsbunden', True), ('tidsbundet', True)],
         'tidsbundne': [('tidsbunden', True), ('tidsbundet', True)],
         'tigste': [('tig', False)],
         'tilbageblevet': [('tilbagebleven', True), ('tilbageblevet', True)],
         'tilbageblevne': [('tilbagebleven', True), ('tilbageblevet', True)],
         'tilbagetrukne': [('tilbagetrukket', True), ('tilbagetrukken', True)],
         'tilfangetagede': [('tilfangetaget', True), ('tilfangetagen', True)],
         'tilfangetaget': [('tilfangetagen', True), ('tilfangetaget', True)],
         'tilfangetagne': [('tilfangetaget', True), ('tilfangetagen', True)],
         'tilfrosne': [('tilfrosset', True), ('tilfrossen', True)],
         'tilfrosset': [('tilfrosset', True), ('tilfrossen', True)],
         'tilløbet': [('tilløbet', True), ('tilløben', True)],
         'tilløbne': [('tilløbet', True), ('tilløben', True)],
         'tiloversblevet': [('tiloversblevet', True), ('tiloversbleven', True)],
         'tiloversblevne': [('tiloversblevet', True), ('tiloversbleven', True)],
         'tilskadekommet': [('tilskadekommet', True), ('tilskadekommen', True)],
         'tilskadekomne': [('tilskadekommen', True), ('tilskadekommet', True)],
         'tlede': [('tlet', False)],
         'tlige': [('tlig', False)],
         'tløbet': [('tløbet', False)],
         'tløst': [('tløs', False)],
         'tne': [('ten', False)],
         'tnævnte': [('tnævnte', False)],
         'tolt': [('tolt', False)],
         'tosset': [('tosset', False)],
         'tovt': [('tovt', False)],
         'traditionsbundet': [('traditionsbunden', True), ('traditionsbundet', True)],
         'traditionsbundne': [('traditionsbunden', True), ('traditionsbundet', True)],
         'trede': [('tret', False)],
         'tret': [('tret', False)],
         'tsidste': [('tsidst', False)],
         'tskårede': [('tskåret', False)],
         'tstørst': [('tstørst', False)],
         'tstørste': [('tstørst', False)],
         'ttent': [('tten', False)],
         'ttes': [('t', False)],
         'tunget': [('tunget', False)],
         'tvist': [('tvis', False)],
         'tvunget': [('tvungen', False)],
         'tyngst': [('tyngst', False)],
         'tækt': [('tækt', False)],
         'tældst': [('tældst', False)],
         'tætskrevet': [('tætskrevet', True), ('tætskreven', True)],
         'tætskrevne': [('tætskrevet', True), ('tætskreven', True)],
         'tødt': [('tødt', False)],
         'tødte': [('tødt', False)],
         'tørre': [('tør', True)],
         'uant': [('uant', False)],
         'ubeskrevet': [('ubeskrevet', True), ('ubeskreven', True)],
         'ubeskrevne': [('ubeskrevet', True), ('ubeskreven', True)],
         'ubeskårede': [('ubeskåren', True), ('ubeskåret', True)],
         'ubeskåret': [('ubeskåret', True), ('ubeskåren', True)],
         'ubeskårne': [('ubeskåret', True), ('ubeskåren', True)],
         'ubrede': [('ubret', False)],
         'ubundet': [('ubundet', True), ('ubunden', True)],
         'ubundne': [('ubundet', True), ('ubunden', True)],
         'ude': [('ud', False)],
         'udent': [('uden', False)],
         'udet': [('udet', False)],
         'udne': [('uden', False)],
         'udsprungne': [('udsprungen', True), ('udsprunget', True)],
         'udst': [('uds', False)],
         'uede': [('uet', False)],
         'uent': [('uent', False)],
         'uert': [('uert', False)],
         'ugent': [('ugen', False)],
         'ugne': [('uggen', False)],
         'ugte': [('ugt', False)],
         'uindbundet': [('uindbundet', True), ('uindbunden', True)],
         'uindbundne': [('uindbunden', True), ('uindbundet', True)],
         'ukke': [('uk', False)],
         'ukket': [('ukken', False)],
         'ukne': [('ukken', False)],
         'ukt': [('uk', False)],
         'ule': [('ul', False)],
         'ulede': [('ulet', False)],
         'ulige': [('ulige', True)],
         'uline': [('ulin', False)],
         'ult': [('ul', False)],
         'ulært': [('ulær', False)],
         'uløst': [('uløst', True)],
         'umant': [('uman', False)],
         'ume': [('um', False)],
         'umme': [('um', False)],
         'umt': [('um', False)],
         'un': [('un', False)],
         'unavngivet': [('unavngivet', True), ('unavngiven', True)],
         'unavngivne': [('unavngiven', True), ('unavngivet', True)],
         'unde': [('und', False)],
         'undede': [('undet', False)],
         'underdrevne': [('underdreven', True), ('underdrevet', True)],
         'une': [('un', False)],
         'unkt': [('unkt', False)],
         'unt': [('un', False)],
         'uomskårede': [('uomskåret', True), ('uomskåren', True)],
         'uomskåren': [('uomskåret', True), ('uomskåren', True)],
         'uopskårede': [('uopskåret', True), ('uopskåren', True)],
         'uopskåret': [('uopskåren', True), ('uopskåret', True)],
         'uopskårne': [('uopskåren', True), ('uopskåret', True)],
         'uovertruffet': [('uovertruffet', True), ('uovertruffen', True)],
         'uovertrufne': [('uovertruffen', True), ('uovertruffet', True)],
         'ure': [('ur', False)],
         'urede': [('uret', False)],
         'uren': [('uren', True)],
         'urene': [('uren', True)],
         'uret': [('uret', False)],
         'urgt': [('urgt', False)],
         'urmættede': [('rumættet', False)],
         'urt': [('ur', False)],
         'usagte': [('usagt', True)],
         'usalt': [('usal', False)],
         'use': [('us', False)],
         'uset': [('uset', False)],
         'uslebet': [('usleben', True), ('uslebet', True)],
         'uslebne': [('uslebet', True), ('usleben', True)],
         'ust': [('us', False)],
         'ut': [('ut', False)],
         'utalt': [('utalt', True)],
         'utant': [('utan', False)],
         'utilt': [('util', False)],
         'utive': [('utiv', False)],
         'utte': [('ut', False)],
         'uvant': [('uvan', True), ('uvant', True)],
         'uvert': [('uver', False)],
         'uvet': [('uvet', False)],
         'uvorne': [('uvorn', True)],
         'uvre': [('uver', False)],
         'v.': [('verse', False)],
         'vakt': [('vakt', False)],
         'valent': [('valen', True), ('valent', True)],
         'valt': [('valt', False)],
         'vandet': [('vandet', False)],
         'vanført': [('vanfør', True)],
         'vant': [('vant', False)],
         'vart': [('vart', False)],
         'varte': [('vart', False)],
         'vast': [('vas', False)],
         'vede': [('vet', False)],
         'vedt': [('vedt', False)],
         'veget': [('veget', False)],
         'velanskrevet': [('velanskrevet', True), ('velanskreven', True)],
         'velanskrevne': [('velanskrevet', True), ('velanskreven', True)],
         'velbeskrevet': [('velbeskrevet', True), ('velbeskreven', True)],
         'velbeskrevne': [('velbeskrevet', True), ('velbeskreven', True)],
         'veldrevet': [('veldrevet', True), ('veldreven', True)],
         'veldrevne': [('veldrevet', True), ('veldreven', True)],
         'velskrevet': [('velskrevet', True), ('velskreven', True)],
         'velskrevne': [('velskrevet', True), ('velskreven', True)],
         'vent': [('vent', False)],
         'vere': [('v', False)],
         'verse': [('vers', False)],
         'verst': [('verst', False)],
         'vert': [('vert', False)],
         'ves': [('ves', False)],
         'vest': [('v', False)],
         'veste': [('veste', False)],
         'vident': [('vident', False)],
         'vidst': [('vidst', False)],
         'vidtdrevet': [('vidtdrevet', True), ('vidtdreven', True)],
         'vidtdrevne': [('vidtdreven', True), ('vidtdrevet', True)],
         'vilde': [('vild', True)],
         'vindbåret': [('vindbåren', True), ('vindbåret', True)],
         'vindbårne': [('vindbåren', True), ('vindbåret', True)],
         'vinddrevet': [('vinddrevet', True), ('vinddreven', True)],
         'vinddrevne': [('vinddrevet', True), ('vinddreven', True)],
         'vindt': [('vind', True)],
         'vist': [('vis', True)],
         'vle': [('vl', False)],
         'vlede': [('vlet', False)],
         'vlige': [('vlig', False)],
         'vlt': [('vl', False)],
         'vløst': [('vløs', False)],
         'vn': [('vn', False)],
         'vne': [('ven', False)],
         'vommet': [('vommet', True)],
         'voret': [('voren', False)],
         'vorlige': [('vorlig', False)],
         'vorne': [('voren', False)],
         'vornede': [('vorned', True)],
         'vre': [('vre', False)],
         'vrede': [('vred', True)],
         'vredt': [('vred', True)],
         'vret': [('vret', False)],
         'vrige': [('vrig', False)],
         'vsagte': [('vsagt', False)],
         'vse': [('vs', False)],
         'vset': [('vset', False)],
         'vst': [('vs', False)],
         'vte': [('vt', False)],
         'vundet': [('vundet', False)],
         'vundne': [('vunden', False)],
         'vungne': [('vungen', False)],
         'vænt': [('væn', True)],
         'værre': [('værre', True)],
         'xede': [('xet', False)],
         'yant': [('yant', False)],
         'ybt': [('yb', False)],
         'yede': [('yet', False)],
         'yere': [('y', False)],
         'yfe': [('yf', False)],
         'yft': [('yf', False)],
         'yge': [('yg', False)],
         'yget': [('yget', False)],
         'ygst': [('yg', False)],
         'ygt': [('yg', False)],
         'ykke': [('yk', False)],
         'ykt': [('yk', False)],
         'ykåret': [('ykåret', False)],
         'yldt': [('yldt', False)],
         'yldte': [('yldt', False)],
         'ylige': [('ylig', False)],
         'ylært': [('ylær', False)],
         'yme': [('ym', False)],
         'ymere': [('ymer', False)],
         'ymert': [('ymer', False)],
         'ymt': [('ym', False)],
         'yn': [('yn', False)],
         'ynde': [('ynd', False)],
         'yndede': [('yndet', False)],
         'yne': [('yn', False)],
         'yngre': [('ung', True)],
         'yngst': [('ung', True)],
         'ynt': [('yn', False)],
         'ype': [('yp', False)],
         'ypt': [('yp', False)],
         'yre': [('yr', False)],
         'yrede': [('yret', False)],
         'yreste': [('yr', False)],
         'yret': [('yret', False)],
         'yrige': [('yrig', False)],
         'yrt': [('yr', False)],
         'yse': [('ys', False)],
         'yst': [('yst', False)],
         'ytte': [('yt', False)],
         'yvalent': [('yvalent', False)],
         'zede': [('zet', False)],
         'åbevist': [('åbevis', False)],
         'ådant': [('ådan', False)],
         'åde': [('åd', False)],
         'ådet': [('ådet', False)],
         'ådlige': [('ådlige', False)],
         'ådne': [('ådden', False)],
         'ådt': [('åd', False)],
         'åede': [('ået', False)],
         'åene': [('åen', False)],
         'ågent': [('ågen', False)],
         'åget': [('åget', False)],
         'ågne': [('ågen', False)],
         'ålent': [('ålen', False)],
         'ålige': [('ålig', False)],
         'ålne': [('ålen', False)],
         'åndede': [('åndet', False)],
         'årede': [('året', True)],
         'åren': [('åren', False)],
         'årent': [('åren', False)],
         'året': [('året', False)],
         'årige': [('årig', False)],
         'årnede': [('årnet', False)],
         'åset': [('åset', False)],
         'åst': [('åst', False)],
         'åtagne': [('åtagen', False)],
         'æbet': [('æbet', False)],
         'æde': [('æd', False)],
         'ædelt': [('ædel', True)],
         'ædet': [('ædet', False)],
         'ædt': [('æd', False)],
         'æede': [('æet', False)],
         'æge': [('æg', False)],
         'æget': [('æget', False)],
         'ægt': [('æg', False)],
         'ækelt': [('ækel', True)],
         'ække': [('æk', False)],
         'ækt': [('æk', False)],
         'ældre': [('gammel', True)],
         'ældres': [('gammel', True)],
         'ældst': [('gammel', True)],
         'ældt': [('ældt', False)],
         'ældte': [('ældt', False)],
         'æle': [('æl', False)],
         'ælede': [('ælet', False)],
         'ælent': [('ælen', False)],
         'ælige': [('ælig', False)],
         'ælne': [('ælen', False)],
         'ælst': [('æls', False)],
         'ælt': [('æl', False)],
         'æløst': [('æløs', False)],
         'æmmede': [('æmmet', False)],
         'æmpe': [('æmpe', False)],
         'æn': [('æn', False)],
         'ændede': [('ændet', False)],
         'ændt': [('ændt', False)],
         'æne': [('æn', False)],
         'ængere': [('ang', False)],
         'ængst': [('ang', False)],
         'ængt': [('ængt', False)],
         'ænkt': [('ænkt', False)],
         'ænt': [('æn', False)],
         'ære': [('ær', False)],
         'ærede': [('æret', False)],
         'ærent': [('ærent', False)],
         'ærest': [('ærest', False)],
         'æreste': [('ær', False)],
         'æret': [('æret', False)],
         'ærmere': [('ær', False)],
         'ærre': [('å', False)],
         'ærrest': [('å', False)],
         'ærreste': [('å', False)],
         'ærste': [('ærst', False)],
         'ært': [('ær', False)],
         'æse': [('æs', False)],
         'æset': [('æset', False)],
         'æsne': [('æsen', False)],
         'æst': [('æst', False)],
         'æste': [('æste', False)],
         'æt': [('æt', False)],
         'æte': [('æt', False)],
         'æterbåret': [('æterbåren', True), ('æterbåret', True)],
         'æterbårne': [('æterbåren', True), ('æterbåret', True)],
         'ætte': [('æt', False)],
         'ævalt': [('æval', False)],
         'æve': [('æv', False)],
         'ævert': [('æver', False)],
         'ævet': [('ævet', False)],
         'ævne': [('ævn', False)],
         'ævnt': [('ævnt', False)],
         'ævnte': [('ævnt', False)],
         'ævre': [('æver', False)],
         'ævt': [('æv', False)],
         'øde': [('øde', True)],
         'ødent': [('øden', False)],
         'ødes': [('ød', False)],
         'ødet': [('ødet', False)],
         'ødne': [('øden', False)],
         'ødt': [('ød', False)],
         'øede': [('øet', False)],
         'øgent': [('øgen', False)],
         'øget': [('øget', False)],
         'øgne': [('øgen', False)],
         'øgte': [('øgt', False)],
         'øje': [('øj', False)],
         'øjent': [('øjen', False)],
         'øjst': [('øjs', False)],
         'ølede': [('ølet', False)],
         'ølige': [('ølig', False)],
         'ølle': [('ølle', False)],
         'ømme': [('øm', True)],
         'ømmede': [('ømmet', False)],
         'ømt': [('øm', True)],
         'øn': [('øn', False)],
         'øndre': [('øndre', False)],
         'øne': [('øn', False)],
         'ønnede': [('ønnet', False)],
         'ønt': [('øn', False)],
         'øre': [('ør', False)],
         'ørede': [('øret', False)],
         'øret': [('øret', False)],
         'ørige': [('ørig', False)],
         'ørt': [('ør', False)],
         'øse': [('øs', False)],
         'øset': [('øset', False)],
         'øst': [('øs', False)],
         'østre': [('østre', False)],
         'øt': [('øt', False)],
         'øtte': [('øt', False)],
         'øve': [('øv', False)],
         'øvet': [('øvet', False)],
         'øvt': [('øv', False)]},
 'ADJ_ADJ': {'små': [('lille', True)]},
 'ADJ_NOUN': {'-': [('program', False)],
              'ager': [('ager', False)],
              'anker': [('anke', False)],
              'arter': [('arter', False)],
              'banker': [('bank', True)],
              'der': [('de', False)],
              'dser': [('ds', False)],
              'e': [('', False)],
              'eker': [('ek', False)],
              'ers': [('', False)],
              'es': [('es', False)],
              'ger': [('ge', False)],
              'gs': [('gs', False)],
              'is': [('is', False)],
              'kser': [('kser', False)],
              'lager': [('lage', False)],
              'mer': [('me', False)],
              'n': [('', False)],
              'ner': [('ne', False)],
              'os': [('os', False)],
              'ps': [('ps', False)],
              'rer': [('rer', False)],
              'rs': [('rs', False)],
              'rter': [('rte', False)],
              's': [('', False)],
              'se': [('se', False)],
              'ser': [('sus', False)],
              'ster': [('st', False)],
              'tanke': [('tank', True), ('tanke', True)],
              'ter': [('ter', False)],
              'us': [('us', False)],
              've': [('ve', False)],
              'ys': [('ys', False)]},
 'ADJ_VERB': {'ank': [('ynke', False)], 'ar': [('ære', False)], 'r': [('re', False)]},
 'ADP': {'.': [('andt', False)],
         'er': [('er', False)],
         'ga.': [('å_grund_af', False)],
         'mere': [('', False)],
         'mest': [('', False)],
         'or': [('or', False)],
         'r': [('er', False)],
         'r.': [('er', False)],
         'ær': [('ær', False)],
         'ør': [('ør', False)]},
 'ADP_ADJ': {'mindre': [('lille', True)], 'ne': [('met', False)], 'små': [('lille', True)]},
 'ADP_NOUN': {'-': [('ministerium', False)],
              'anken': [('anke', False)],
              'aterne': [('at', False)],
              'banken': [('bank', True)],
              'den': [('de', False)],
              'dens': [('den', False)],
              'derne': [('de', False)],
              'en': [('', False)],
              'erne': [('', False)],
              'et': [('', False)],
              'ger': [('ge', False)],
              'jderne': [('jder', False)],
              'jorden': [('jorden', True), ('jord', True)],
              'ken': [('ke', False)],
              'kens': [('ke', False)],
              'men': [('me', False)],
              'merne': [('me', False)],
              'nden': [('nd', False)],
              'nes': [('', False)],
              'nkens': [('nk', False)],
              'ren': [('re', False)],
              'ret': [('er', False)],
              'ser': [('se', False)],
              'serne': [('ser', False)],
              'ster': [('st', False)],
              'ten': [('te', False)],
              'ter': [('ter', False)],
              'terne': [('', False)],
              'tet': [('', False)],
              'ænderne': [('and', False)],
              'øret': [('ør', False)]},
 'ADP_PROPN': {'øst-': [('øst-', True), ('østeuropa', True)]},
 'ADP_VERB': {'ar': [('ære', False)]},
 'ADV': {'.a': [('andt_andet', False)],
         '.a.': [('andt_andet', False)],
         '.eks.': [('or_eksempel', False)],
         '.fl.': [('ed_flere', False)],
         '.h.': [('il_højre', False)],
         '.s.v': [('g_så_videre', False)],
         '.s.v.': [('g_så_videre', False)],
         '.t.': [('ro_tempore', False)],
         '.v.': [('ed_videre', False)],
         '.v.s.': [('et_vil_sige', False)],
         'a': [('irka', False)],
         'a.': [('irka', False)],
         'are': [('are', False)],
         'ast': [('ast', False)],
         'at': [('at', False)],
         'bort': [('bort', True)],
         'bt': [('bt', False)],
         'da': [('da', False)],
         'dre': [('dre', False)],
         'dst': [('dst', False)],
         'dt': [('dt', False)],
         'ere': [('ere', False)],
         'est': [('est', False)],
         'et': [('et', False)],
         'fort': [('fort', True)],
         'ft': [('ft', False)],
         'gere': [('ge', False)],
         'gst': [('gst', False)],
         'gt': [('gt', False)],
         'hv.': [('enholdsvis', False)],
         'ia': [('ia', False)],
         'igere': [('igere', False)],
         'ire': [('ire', False)],
         'ist': [('ist', False)],
         'it': [('it', False)],
         'jort': [('jort', False)],
         'jst': [('jst', False)],
         'jt': [('jt', False)],
         'ka': [('ka', False)],
         'kort': [('kort', True)],
         'kt': [('kt', False)],
         'la': [('la', False)],
         'lst': [('lst', False)],
         'lt': [('lt', False)],
         'længst': [('længe', True)],
         'mt': [('mt', False)],
         'na': [('na', False)],
         'nst': [('nst', False)],
         'nt': [('nt', False)],
         'ore': [('ore', False)],
         'ost': [('ost', False)],
         'ot': [('ot', False)],
         'pt': [('pt', False)],
         'ra': [('ra', False)],
         'rlængst': [('rlængst', False)],
         'rre': [('rre', False)],
         'rst': [('rst', False)],
         'rt': [('rt', False)],
         'sa': [('sa', False)],
         'stort': [('stor', True), ('stort', True)],
         'sv.': [('g_så_videre', False)],
         'ta': [('ta', False)],
         'test': [('te', False)],
         'ure': [('ure', False)],
         'ust': [('ust', False)],
         'ut': [('ut', False)],
         'vre': [('vre', False)],
         'vs.': [('et_vil_sige', False)],
         'vt': [('vt', False)],
         'x': [('or_eksempel', False)],
         'yre': [('yre', False)],
         'yst': [('yst', False)],
         'yt': [('yt', True)],
         'åre': [('åre', False)],
         'åt': [('åt', False)],
         'æst': [('æst', False)],
         'æt': [('æt', False)],
         'ér': [('er', False)],
         'øst': [('øst', False)]},
 'ADV_ADJ': {'mindre': [('lille', True)], 'ne': [('et', False)], 'små': [('lille', True)], 't': [('', False)]},
 'ADV_ADV': {'t': [('', False)]},
 'ADV_NOUN': {'erne': [('', False)], 'rs': [('', False)], 't': [('', False)]},
 'ADV_VERB': {'ad': [('ede', False)],
              'al': [('ulle', False)],
              'alte': [('ælle', False)],
              'ap': [('ippe', False)],
              'ar': [('ære', False)],
              'eg': [('ige', False)],
              'er': [('e', False)],
              'es': [('es', False)],
              'od': [('ade', False)],
              'or': [('o', False)],
              'r': [('re', False)],
              'rtalt': [('rtælle', False)],
              'ses': [('se', True), ('ses', True)],
              'talt': [('tale', True)],
              'tod': [('tå', False)],
              'undet': [('inde', False)],
              'å': [('e', False)],
              'ås': [('ås', False)]},
 'AUX': {"'": [('nne', False)],
         "'r": [('ve', False)],
         "a'": [('unne', False)],
         'al': [('ulle', False)],
         'an': [('unne', False)],
         'ar': [('ave', False)],
         'de': [('e', False)],
         'er': [('være', True)],
         'ev': [('ive', False)],
         'evet': [('ive', False)],
         'l': [('lle', False)],
         'nde': [('', False)],
         'rde': [('rde', False)],
         't': [('', False)],
         'v': [('ve', False)],
         'var': [('være', True)],
         'ver': [('ve', False)],
         'å': [('åtte', False)],
         'ør': [('urde', False)]},
 'AUX_ADV': {'stort': [('stor', True), ('stort', True)]},
 'AUX_NOUN': {'en': [('', False)],
              'erne': [('', False)],
              'jorden': [('jord', True), ('jorden', True)],
              'rserne': [('rs', False)],
              'serne': [('ser', False)],
              'yden': [('yd', False)]},
 'AUX_VERB': {'es': [('es', False)],
              'et': [('e', False)],
              'kes': [('ke', False)],
              'rtalt': [('rtælle', False)],
              'ses': [('se', True)],
              'talt': [('tale', True)],
              'tes': [('te', False)],
              'undet': [('inde', False)],
              'ås': [('ås', False)],
              'ør': [('urde', False)]},
 'CCONJ_ADJ': {'mindre': [('lille', True)], 'ne': [('fet', False)], 'små': [('lille', True)]},
 'CCONJ_NOUN': {'er': [('', False)],
                'n': [('', False)],
                'ne': [('', False)],
                's': [('', False)],
                'vs': [('vs', False)],
                'ænger': [('ang', False)]},
 'CCONJ_VERB': {'alte': [('ælle', False)],
                'ar': [('ære', False)],
                'g': [('ge', False)],
                'od': [('ade', False)],
                'r': [('', False)],
                'te': [('me', False)],
                'å': [('e', False)],
                'øget': [('yge', False)]},
 'DET': {'.': [('en', False)],
         'de': [('den', True)],
         'den': [('den', False)],
         'dens': [('dens', True)],
         'een': [('en', True)],
         'en': [('en', True)],
         'ens': [('en', True)],
         'er': [('er', False)],
         'eres': [('eres', False)],
         'ert': [('er', False)],
         'es': [('es', False)],
         'ge': [('ge', False)],
         'gen': [('gen', False)],
         'isse': [('enne', False)],
         'le': [('en', False)],
         'me': [('me', False)],
         'ne': [('n', False)],
         'nes': [('ne', False)],
         'nne': [('nne', False)],
         'ns': [('ns', False)],
         'ore': [('ores', False)],
         'ores': [('ores', False)],
         'r': [('res', False)],
         're': [('en', False)],
         'res': [('en', False)],
         'rt': [('res', False)],
         's.': [('enne', False)],
         't': [('n', False)],
         'tet': [('gen', False)],
         'thvert': [('nhver', False)],
         'ts': [('ts', False)],
         'tte': [('nne', False)],
         'én': [('en', False)],
         'ét': [('en', True)]},
 'DET_ADJ': {'mindre': [('lille', True)], 'små': [('lille', True)]},
 'DET_ADV': {'t': [('', False)]},
 'DET_NOUN': {'anker': [('anke', False)],
              'banker': [('bank', True)],
              'der': [('de', False)],
              'e': [('', False)],
              'er': [('', False)],
              'es': [('es', False)],
              'gs': [('gs', False)],
              'is': [('is', False)],
              'ke': [('ke', False)],
              'ler': [('ler', False)],
              'ls': [('ls', False)],
              'os': [('os', False)],
              's': [('', False)],
              'se': [('se', False)],
              'ter': [('ter', False)],
              'us': [('us', False)],
              've': [('ve', False)]},
 'NOUN': {' age': [(' age', False)],
          ' ages': [(' age', False)],
          ' lattens': [(' latte', False)],
          ' latter': [(' latte', False)],
          ' latters': [(' latte', False)],
          ' morter': [(' morte', False)],
          ' morterne': [(' morte', False)],
          ' morternes': [(' morte', False)],
          ' morters': [(' morte', False)],
          ' summer': [(' summer', False)],
          ' summers': [(' summer', False)],
          ' toiletter': [(' toilette', False)],
          ' toiletterne': [(' toilette', False)],
          ' toiletternes': [(' toilette', False)],
          ' toiletters': [(' toilette', False)],
          ' verts': [(' verts', False)],
          '"bog-til-tiden"-princippet': [('bog-til-tiden-princip', True)],
          '"jump"-nummer': [('jump-nummer', True)],
          '"mellem-os"-læserne': [('mellem-os-læser', True)],
          "'": [('', False)],
          "'alben": [("'albe", False)],
          "'albens": [("'albe", False)],
          "'en": [('', False)],
          "'ene": [('', False)],
          "'enes": [('', False)],
          "'ens": [('', False)],
          "'er": [('', False)],
          "'erne": [("'er", False)],
          "'ernes": [('', False)],
          "'ers": [('', False)],
          "'et": [('', False)],
          "'ets": [('', False)],
          "'rne": [("'r", False)],
          "'rollen": [("'roll", False)],
          "'s": [('', False)],
          "'s'": [('', False)],
          '-': [('-butik', False)],
          '-a': [('-a', False)],
          '-anklagerne': [('-anklage', False)],
          '-arbejder': [('-arbejder', False)],
          '-bogen': [('-bog', False)],
          '-bomber': [('-bombe', False)],
          '-bomberne': [('-bombe', False)],
          '-bombernes': [('-bombe', False)],
          '-bombers': [('-bombe', False)],
          '-bremser': [('-bremser', False)],
          '-bremserne': [('-bremser', False)],
          '-bremsernes': [('-bremser', False)],
          '-bremsers': [('-bremser', False)],
          '-byen': [('-byen', False)],
          '-center': [('-center', False)],
          '-centre': [('-center', False)],
          '-centrene': [('-center', False)],
          '-centrenes': [('-center', False)],
          '-centres': [('-center', False)],
          '-centret': [('-center', False)],
          '-centrets': [('-center', False)],
          '-chis': [('-chi', False)],
          '-cyklen': [('-cykel', False)],
          '-cyklens': [('-cykel', False)],
          '-cykler': [('-cykel', False)],
          '-cyklerne': [('-cykel', False)],
          '-cyklernes': [('-cykel', False)],
          '-cyklers': [('-cykel', False)],
          '-dage': [('-dag', False)],
          '-dagen': [('-dag', False)],
          '-dagene': [('-dag', False)],
          '-dagenes': [('-dag', False)],
          '-dages': [('-dag', False)],
          '-eleverne': [('-elev', False)],
          '-elevernes': [('-elev', False)],
          '-eller': [('-eller', False)],
          '-ellers': [('-eller', False)],
          '-ener': [('-ener', False)],
          '-enerne': [('-ener', False)],
          '-enernes': [('-ener', False)],
          '-eners': [('-ener', False)],
          '-fanger': [('-fange', False)],
          '-fangerne': [('-fange', False)],
          '-fangernes': [('-fange', False)],
          '-fangers': [('-fange', False)],
          '-feriens': [('-ferie', False)],
          '-fis': [('-fi', False)],
          "-gas'": [('-gas', False)],
          '-gassernes': [('-gas', False)],
          '-gener': [('-gen', False)],
          '-hallen': [('-hal', False)],
          '-handler': [('-handel', False)],
          '-handlerne': [('-handel', False)],
          '-handlernes': [('-handel', False)],
          '-handlers': [('-handel', False)],
          '-hus': [('-hus', False)],
          '-kagen': [('-kage', False)],
          '-kagens': [('-kage', False)],
          '-kilder': [('-kilde', False)],
          '-kollegiet': [('-kollegium', False)],
          '-krater': [('-krater', False)],
          '-lime': [('-lime', False)],
          '-lys': [('-lys', False)],
          '-lægernes': [('-læge', False)],
          '-lærer': [('-lærer', False)],
          '-lærerne': [('-lærer', False)],
          '-lærernes': [('-lærer', False)],
          '-lærers': [('-lærer', False)],
          '-markerne': [('-mark', False)],
          '-meter': [('-meter', False)],
          '-mænd': [('-mand', False)],
          '-mødernes': [('-møde', False)],
          '-nummers': [('-nummer', False)],
          '-parken': [('-parken', False)],
          '-pigernes': [('-pige', False)],
          '-pladerne': [('-plade', False)],
          '-porter': [('-porter', False)],
          '-porters': [('-porter', False)],
          '-regningerne': [('regning', False)],
          '-rens': [('-rens', False)],
          '-renten': [('-rente', False)],
          '-rentens': [('-rente', False)],
          '-renternes': [('-rente', False)],
          '-ret': [('-ret', False)],
          '-retter': [('-ret', False)],
          '-rummet': [('-rum', False)],
          '-rummets': [('-rum', False)],
          '-røret': [('-rør', False)],
          '-rørets': [('-rør', False)],
          '-sagen': [('-sag', False)],
          '-sagers': [('-sag', False)],
          '-seerne': [('-seer', False)],
          '-spalten': [('-spalte', False)],
          '-spaltens': [('-spalte', False)],
          '-stave': [('-stav', False)],
          '-staven': [('-stav', False)],
          '-stavens': [('-stav', False)],
          '-staves': [('-stav', False)],
          '-teter': [('-tete', False)],
          '-teters': [('-tete', False)],
          '-tider': [('-tid', False)],
          '-tidernes': [('-tid', False)],
          '-tids': [('-tid', False)],
          '-timer': [('-time', False)],
          '-timerne': [('-time', False)],
          '-timernes': [('-time', False)],
          '-timers': [('-time', False)],
          '-tribunen': [('-tribune', False)],
          "-tv'et": [('-tv', False)],
          "-tv'ets": [('-tv', False)],
          '-tvs': [('-tv', False)],
          '-tys': [('-tys', False)],
          '-uge': [('-uge', False)],
          '-uret': [('-ur', False)],
          '-urets': [('-ur', False)],
          '-urs': [('-ur', False)],
          '-veksler': [('-veksel', False)],
          '-vekslerne': [('-veksel', False)],
          '-vekslernes': [('-veksel', False)],
          '-vekslers': [('-veksel', False)],
          '-vinder': [('-vinder', False)],
          '-vuer': [('-vu', False)],
          '-vuerne': [('-vu', False)],
          '-vuernes': [('-vu', False)],
          '-vuers': [('-vu', False)],
          '-vuet': [('-vu', False)],
          '-vuets': [('-vu', False)],
          '-årene': [('-årene', True)],
          '-årenes': [('-årene', True)],
          '-æbler': [('-æble', False)],
          '.s': [('.', False)],
          '/s': [('ktieselskab', False)],
          '/s-fællesskaberne': [('nteressentskab-fællesskab', False)],
          "0'er": [("0'er", False)],
          "0'ernes": [("0'er", False)],
          '0erne': [('0er', False)],
          '0ernes': [('0er', False)],
          "A'erne": [('A', False)],
          "AD'ernes": [('AD', True)],
          "B'erne": [('B', False)],
          "BH'ers": [('BH', False)],
          "C'erne": [('C', False)],
          "CD'er": [('CD', True)],
          "CD'ernes": [('CD', True)],
          "D'er": [('D', True)],
          "D'erne": [('D', False)],
          "D'ernes": [('D', True)],
          "D'ers": [('D', True)],
          "E'erne": [('E', True)],
          "EP'er": [('EP', True)],
          "EP'ernes": [('EP', True)],
          "EP'ers": [('EP', True)],
          "F'er": [('F', True)],
          "F'erne": [('F', False)],
          "F'ernes": [('F', True)],
          "F'ers": [('F', True)],
          "FG'er": [("FG'er", False)],
          "FG'erne": [("FG'er", False)],
          "FG'ernes": [("FG'er", False)],
          "FG'ers": [("FG'er", False)],
          "G'er": [('G', True)],
          "G'erne": [('G', True)],
          "G'ernes": [('G', True)],
          "G'ers": [('G', True)],
          "H'er": [('H', True)],
          "H'erne": [('H', False)],
          "H'ernes": [('H', True)],
          "H'ers": [('H', True)],
          "HD'er": [("HD'er", True)],
          "HD'erne": [("HD'er", True)],
          "HD'ernes": [("HD'er", True)],
          "HD'ers": [("HD'er", True)],
          "HF'er": [("HF'er", True)],
          "HF'erne": [("HF'er", True)],
          "HF'ernes": [("HF'er", True)],
          "HF'ers": [("HF'er", True)],
          "HH'er": [("HH'er", True)],
          "HH'erne": [("HH'er", True)],
          "HH'ernes": [("HH'er", True)],
          "HH'ers": [("HH'er", True)],
          "HX'er": [("HX'er", False)],
          "HX'erne": [("HX'er", False)],
          "HX'ernes": [("HX'er", False)],
          "HX'ers": [("HX'er", False)],
          "I'erne": [('I', True)],
          "ID'er": [('ID', True)],
          "ID'ernes": [('ID', False)],
          "IP'er": [('IP', False)],
          "IP'ernes": [('IP', False)],
          "IP'ers": [('IP', False)],
          "J'erne": [('J', True)],
          "K'erne": [('K', True)],
          "L'erne": [('L', True)],
          "LP'er": [('LP', True)],
          "M'erne": [('M', True)],
          "MF'er": [('MF', True)],
          "MF'ernes": [('MF', True)],
          "MF'ers": [('MF', True)],
          "N'erne": [('N', True)],
          "O'erne": [('O', False)],
          "P'er": [('P', True)],
          "P'erne": [('P', False)],
          "P'ernes": [('P', True)],
          "P'ers": [('P', True)],
          "Q'erne": [('Q', True)],
          "R'erne": [('R', True)],
          'Rs': [('R', False)],
          "S'erne": [('S', False)],
          "T'erne": [('T', False)],
          "TP'er": [("TP'er", False)],
          "TP'erne": [("TP'er", False)],
          "TP'ernes": [("TP'er", False)],
          "TP'ers": [("TP'er", False)],
          "TX'er": [("TX'er", False)],
          "TX'erne": [("TX'er", False)],
          "TX'ernes": [("TX'er", False)],
          "TX'ers": [("TX'er", False)],
          "U'erne": [('U', True)],
          "UG'er": [('UG', True)],
          "V'erne": [('V', False)],
          'Vs': [('V', False)],
          "W'erne": [('W', True)],
          "X'er": [('X', True)],
          "X'erne": [('X', True)],
          "X'ernes": [('X', True)],
          "X'ers": [('X', True)],
          "Y'erne": [('Y', True)],
          "Z'erne": [('Z', True)],
          'a': [('a', True)],
          "a'erne": [('a', False)],
          'a.': [('lliard', False)],
          'aagenser': [('aagenser', False)],
          'aagenserne': [('aagenser', False)],
          'aagensernes': [('aagenser', False)],
          'aagensers': [('aagenser', False)],
          'aalen': [('aal', False)],
          'aalens': [('aal', False)],
          'aaltens': [('aalt', False)],
          'aalter': [('aalt', False)],
          'aalterne': [('aalt', False)],
          'aalternes': [('aalt', False)],
          'aalters': [('aalt', False)],
          'aaner': [('aaner', False)],
          'aanerne': [('aaner', False)],
          'aanernes': [('aaner', False)],
          'aaners': [('aaner', False)],
          'aans': [('aans', False)],
          "aans'": [('aans', False)],
          'aarbejder': [('aarbejder', False)],
          'aarbejderne': [('aarbejder', False)],
          'aarbejdernes': [('aarbejder', False)],
          'aarbejders': [('aarbejder', False)],
          'abalder': [('abalder', False)],
          'abalders': [('abalder', False)],
          'abanen': [('aban', False)],
          'abanens': [('aban', False)],
          'abaner': [('aban', False)],
          'abanerne': [('aban', False)],
          'abanernes': [('aban', False)],
          'abaners': [('aban', False)],
          'abanken': [('abank', False)],
          'abankens': [('abank', False)],
          'abanker': [('abank', False)],
          'abankerne': [('abank', False)],
          'abankernes': [('abank', False)],
          'abankers': [('abank', False)],
          'abarber': [('abarber', False)],
          'abarberne': [('abarber', False)],
          'abarbernes': [('abarber', False)],
          'abarbers': [('abarber', False)],
          'abas': [('abas', False)],
          'abasen': [('abas', False)],
          'abasens': [('abas', False)],
          'abaser': [('abas', False)],
          'abaserne': [('abas', False)],
          'abasernes': [('abas', False)],
          'abasers': [('abase', False)],
          'abasker': [('abask', False)],
          'abaskerne': [('abask', False)],
          'abaskernes': [('abask', False)],
          'abaskers': [('abask', False)],
          'abassen': [('abas', False)],
          'abassens': [('abas', False)],
          'abasser': [('abas', False)],
          'abasserne': [('abas', False)],
          'abassernes': [('abas', False)],
          'abassers': [('abas', False)],
          'abbe': [('abbe', False)],
          'abben': [('ab', False)],
          'abbens': [('abbe', False)],
          'abber': [('abbe', False)],
          'abberne': [('ab', False)],
          'abbernes': [('abbe', False)],
          'abbers': [('abbe', False)],
          'abbes': [('abbe', False)],
          'abe': [('abe', True)],
          'abeler': [('abel', False)],
          'abelers': [('abel', False)],
          'abellens': [('abel', False)],
          'abellerne': [('abel', False)],
          'abellernes': [('abel', False)],
          'aben': [('abe', True)],
          'abenderne': [('abend', False)],
          'abene': [('ab', False)],
          'abener': [('aben', False)],
          'abenerne': [('abene', False)],
          'abenernes': [('abene', False)],
          'abeners': [('aben', False)],
          'abenes': [('ab', False)],
          'abenet': [('abene', False)],
          'abenets': [('abene', False)],
          'abens': [('abe', True)],
          'aber': [('abe', False)],
          'aberiers': [('aberi', False)],
          'aberne': [('abe', True)],
          'abernes': [('abe', True)],
          'abers': [('abe', True)],
          'abes': [('abe', True)],
          'abet': [('abet', False)],
          'abets': [('ab', False)],
          'abilens': [('abil', False)],
          'abilernes': [('abil', False)],
          'abilet': [('abil', False)],
          'abilier': [('abil', False)],
          'abiliers': [('abilier', False)],
          'abinen': [('abin', False)],
          'abinens': [('abin', False)],
          'abiner': [('abine', False)],
          'abinerne': [('abin', False)],
          'abinernes': [('abin', False)],
          'abiners': [('abine', False)],
          'abis': [('abis', False)],
          'abissen': [('abis', False)],
          'abissens': [('abis', False)],
          'abits': [('abit', False)],
          'abitter': [('abit', False)],
          'abitterne': [('abit', False)],
          'abitternes': [('abit', False)],
          'abitters': [('abit', False)],
          'able': [('abel', False)],
          'ablens': [('abel', False)],
          'ables': [('able', False)],
          'ablet': [('ablet', False)],
          'ablets': [('ablet', False)],
          'ablus': [('ablu', False)],
          'aboer': [('abo', False)],
          'aboerne': [('abo', False)],
          'aboernes': [('abo', False)],
          'aboers': [('abo', False)],
          'abolen': [('abol', False)],
          'abolens': [('abol', False)],
          'abolet': [('abol', False)],
          'abolets': [('abol', False)],
          'abonden': [('abond', False)],
          'abondens': [('abond', False)],
          'abras': [('abra', False)],
          'abres': [('aber', False)],
          'abriks': [('abrik', False)],
          'abringen': [('abring', False)],
          'abringens': [('abring', False)],
          'abringer': [('abring', False)],
          'abringerne': [('abring', False)],
          'abringernes': [('abring', False)],
          'abringers': [('abring', False)],
          'abs': [('abs', True)],
          "abs'": [('abs', True)],
          'abstinenser': [('abstinenser', True), ('abstinens', True)],
          'abstinenserne': [('abstinens', True), ('abstinenser', True)],
          'abstinensernes': [('abstinenser', True), ('abstinens', True)],
          'abstinensers': [('abstinenser', True), ('abstinens', True)],
          'abuds': [('abuds', False)],
          'abuen': [('abu', False)],
          'abuens': [('abu', False)],
          'abuer': [('abu', False)],
          'abuerne': [('abu', False)],
          'abuernes': [('abu', False)],
          'abuers': [('abu', False)],
          'aburet': [('aburet', False)],
          'aburets': [('aburet', False)],
          'aburetten': [('aburet', False)],
          'aburettens': [('aburet', False)],
          'aburetter': [('aburet', False)],
          'aburetterne': [('aburet', False)],
          'aburetternes': [('aburet', False)],
          'aburetters': [('aburet', False)],
          'abus': [('abu', False)],
          'abys': [('abys', False)],
          'abælter': [('abælte', False)],
          'abælterne': [('abælte', False)],
          'abælternes': [('abælte', False)],
          'abælters': [('abælte', False)],
          'abæltet': [('abælte', False)],
          'abæltets': [('abælte', False)],
          'abønnen': [('abønne', False)],
          'abønnens': [('abønne', False)],
          'abønner': [('abønne', False)],
          'abønnerne': [('abønne', False)],
          'abønnernes': [('abønne', False)],
          'abønners': [('abønne', False)],
          'acen': [('ac', False)],
          'acene': [('ace', False)],
          'acener': [('acener', False)],
          'acenerne': [('acener', False)],
          'acenernes': [('acener', False)],
          'aceners': [('acener', False)],
          'acenes': [('ace', False)],
          'acens': [('ac', False)],
          'acenter': [('acenter', False)],
          'acentre': [('acenter', False)],
          'acentrene': [('acenter', False)],
          'acentrenes': [('acenter', False)],
          'acentres': [('acenter', False)],
          'acentret': [('acenter', False)],
          'acentrets': [('acenter', False)],
          'acer': [('acer', False)],
          'acerne': [('acer', False)],
          'acernes': [('acer', False)],
          'acers': [('acer', False)],
          'aces': [('ace', False)],
          'acet': [('acet', False)],
          'acets': [('ace', False)],
          'acetylen': [('acetyl', True), ('acetylen', True)],
          'acetylens': [('acetyl', True), ('acetylen', True)],
          'ache': [('ache', False)],
          'achen': [('ache', False)],
          'achens': [('ache', False)],
          'acher': [('ache', False)],
          'acherne': [('ache', False)],
          'achers': [('ache', False)],
          'aches': [('ache', False)],
          'achis': [('achis', False)],
          'achos': [('acho', False)],
          'acien': [('acie', False)],
          'aciens': [('acie', False)],
          'acier': [('acie', False)],
          'aciers': [('acie', False)],
          'acies': [('acie', False)],
          'acillen': [('acille', False)],
          'aciller': [('acille', False)],
          'acillerne': [('acille', False)],
          'acis': [('acis', False)],
          'acisterne': [('acist', False)],
          'acisternes': [('acist', False)],
          'acits': [('acit', False)],
          'acittens': [('acit', False)],
          'acitter': [('acit', False)],
          'acitterne': [('acit', False)],
          'acker': [('ack', False)],
          'ackerne': [('acker', False)],
          'ackernes': [('ack', False)],
          'ackers': [('acker', False)],
          'acket': [('acket', False)],
          'ackets': [('acket', False)],
          'acks': [('acks', False)],
          "acks'": [('acks', False)],
          'acksene': [('acks', False)],
          'acksenes': [('acks', False)],
          'act.': [('act.', False)],
          'act.s': [('act.', False)],
          'acter': [('act', False)],
          'acters': [('acter', False)],
          'acts': [('acts', False)],
          "acts'": [('acts', False)],
          'ad': [('ad', False)],
          "ad'er": [('ad', True)],
          "ad'ers": [('ad', True)],
          'adage': [('adag', False)],
          'adagene': [('adag', False)],
          'adagenes': [('adag', False)],
          'adamme': [('adamme', False)],
          'adammen': [('adamme', False)],
          'adammens': [('adamme', False)],
          'adammer': [('adamme', False)],
          'adammerne': [('adamme', False)],
          'adammernes': [('adamme', False)],
          'adammers': [('adamme', False)],
          'adammes': [('adamme', False)],
          'adans': [('adan', False)],
          'adarer': [('adar', False)],
          'adarernes': [('adar', False)],
          'adas': [('ada', False)],
          "adas'": [('ada', False)],
          'adde': [('adde', False)],
          'adden': [('adde', False)],
          'addens': [('adde', False)],
          'adder': [('adde', False)],
          'adderne': [('adde', False)],
          'addernes': [('adde', False)],
          'addes': [('adde', False)],
          'ade': [('ad', False)],
          'adehandler': [('adehandler', False)],
          'adehandlers': [('adehandler', False)],
          'adellen': [('adelle', False)],
          'adellens': [('adel', False)],
          'adeller': [('adel', False)],
          'adellerne': [('adel', False)],
          'adellernes': [('adel', False)],
          'adellers': [('adel', False)],
          'adene': [('ad', False)],
          'adenes': [('ad', False)],
          'ader': [('ade', False)],
          'adere': [('ader', False)],
          'aderen': [('ader', False)],
          'aderens': [('ader', False)],
          'aderer': [('adere', False)],
          'adererne': [('ader', False)],
          'aderernes': [('ader', False)],
          'aderers': [('adere', False)],
          'aderes': [('ader', False)],
          'adernes': [('ade', False)],
          'aders': [('aders', False)],
          "aders'": [('ader', False)],
          'ades': [('ad', False)],
          'adesten': [('adesten', False)],
          'adet': [('ad', False)],
          'adets': [('ad', False)],
          'adget': [('adge', False)],
          'adgets': [('adge', False)],
          'adhandler': [('adhandler', False)],
          'adhandlernes': [('adhandler', False)],
          'adhandlers': [('adhandler', False)],
          'adices': [('adix', False)],
          "adices'": [('adix', False)],
          'adien': [('adius', False)],
          'adiens': [('adius', False)],
          'adier': [('adius', False)],
          'adierne': [('adier', False)],
          'adiernes': [('adier', False)],
          'adiers': [('adie', False)],
          'adies': [('ady', False)],
          "adies'": [('ady', False)],
          'adiet': [('adie', False)],
          'adiets': [('adie', False)],
          'adiner': [('adine', False)],
          'adinerne': [('adine', False)],
          'adiners': [('adine', False)],
          'adis': [('adi', False)],
          'adisen': [('adise', False)],
          'adisens': [('adise', False)],
          'adiset': [('adis', False)],
          'adisets': [('adis', False)],
          'adium': [('adium', False)],
          'adiums': [('adium', False)],
          'adlen': [('adel', True)],
          'adlens': [('adel', False)],
          'adlerne': [('addel', False)],
          'adlernes': [('addel', False)],
          'adoks': [('adoks', False)],
          'adonen': [('adon', False)],
          'adonens': [('adon', False)],
          'adoren': [('ador', False)],
          'adorens': [('ador', False)],
          'adorer': [('ador', False)],
          'adorerne': [('ador', False)],
          'adorernes': [('ador', False)],
          'adorers': [('ador', False)],
          'ados': [('ados', False)],
          "ados'": [('ados', False)],
          'adosen': [('ados', False)],
          'adosens': [('ados', False)],
          'adoser': [('ados', False)],
          'adoserne': [('ados', False)],
          'adosernes': [('ados', False)],
          'adosers': [('ados', False)],
          'adpakker': [('adpakke', False)],
          'adpakkernes': [('adpakke', False)],
          'adpakkers': [('adpakke', False)],
          'adre': [('adre', False)],
          'adrene': [('ader', False)],
          'adrenes': [('ader', False)],
          'adrens': [('adre', False)],
          'adrer': [('adre', False)],
          'adrerne': [('adre', False)],
          'adrernes': [('adre', False)],
          'adres': [('ader', False)],
          'adrille': [('adrille', False)],
          'adrillen': [('adrille', False)],
          'adrillens': [('adrille', False)],
          'adrillers': [('adrille', False)],
          'adrilles': [('adrille', False)],
          'adronen': [('adron', False)],
          'adronens': [('adron', False)],
          'adroner': [('adron', False)],
          'adronerne': [('adron', False)],
          'adronernes': [('adron', False)],
          'adroners': [('adron', False)],
          'ads': [('ad', False)],
          "ads'": [('ad', False)],
          'adser': [('adser', False)],
          'adserne': [('adser', False)],
          'adsernes': [('adser', False)],
          'adsers': [('adser', False)],
          'adset': [('adset', False)],
          'adsets': [('adset', False)],
          'adsøerne': [('adsø', False)],
          'adsøernes': [('adsø', False)],
          'adsøers': [('adsø', False)],
          'adtangen': [('adtang', False)],
          'adtangens': [('adtang', False)],
          'aduen': [('adue', False)],
          'aduens': [('adue', False)],
          'aduren': [('adur', False)],
          'adurens': [('adur', False)],
          'adurer': [('adur', False)],
          'adurerne': [('adur', False)],
          'adurernes': [('adur', False)],
          'adurers': [('adur', False)],
          'advande': [('advand', False)],
          'advandes': [('advand', False)],
          'advandet': [('advand', False)],
          'advandets': [('advand', False)],
          'advisernes': [('advis', True)],
          'advisers': [('advis', True)],
          'adører': [('adør', False)],
          'adørers': [('adør', False)],
          'ae': [('ae', False)],
          'aeder': [('aeder', False)],
          'aeders': [('aeder', False)],
          'aeet': [('ae', False)],
          'aeets': [('ae', False)],
          'aeler': [('aeler', False)],
          'aelerne': [('aeler', False)],
          'aelernes': [('aeler', False)],
          'aelers': [('aeler', False)],
          'aelsers': [('aelse', False)],
          'aene': [('um', False)],
          'aenes': [('um', False)],
          'aenserne': [('aenser', False)],
          'aer': [('aer', False)],
          'aerne': [('aer', False)],
          'aernes': [('aer', False)],
          'aers': [('aer', False)],
          'aes': [('ae', False)],
          'af': [('af', False)],
          'afarternes': [('afart', True)],
          'afejer': [('afej', False)],
          'afejerne': [('afej', False)],
          'afen': [('af', False)],
          'afens': [('af', False)],
          'afer': [('af', False)],
          'aferne': [('af', False)],
          'afernes': [('af', False)],
          'afers': [('af', False)],
          'afet': [('af', False)],
          'afets': [('af', False)],
          'affelis': [('affeli', False)],
          'affen': [('affe', False)],
          'affene': [('af', False)],
          'affens': [('af', False)],
          'afferens': [('affer', False)],
          'afferet': [('afferet', False)],
          'afferets': [('afferet', False)],
          'afferne': [('af', False)],
          'affes': [('affe', False)],
          'affets': [('af', False)],
          'afier': [('afium', False)],
          'afierne': [('afium', False)],
          'afiernes': [('afium', False)],
          'afiers': [('afium', False)],
          'afiet': [('afium', False)],
          'afiets': [('afium', False)],
          'afikkens': [('afik', False)],
          'afikker': [('afik', False)],
          'afikkernes': [('afik', False)],
          'afikkers': [('afik', False)],
          'afiks': [('afik', False)],
          'afirer': [('afir', False)],
          'afirerne': [('afir', False)],
          'afirernes': [('afir', False)],
          'afirers': [('afir', False)],
          'afis': [('afi', False)],
          'afladen': [('aflad', True)],
          'afladens': [('aflad', True)],
          'aflen': [('afel', False)],
          'aflens': [('afel', False)],
          'afler': [('afel', False)],
          'aflerne': [('afel', False)],
          'aflernes': [('afel', False)],
          'aflers': [('afel', False)],
          'aflet': [('affel', False)],
          'aflets': [('affel', False)],
          'aflipper': [('aflip', False)],
          'aflipperne': [('aflip', False)],
          'aflippernes': [('aflip', False)],
          'aflippers': [('aflip', False)],
          'aflæser': [('aflæser', True)],
          'aflæserne': [('aflæser', False)],
          'aflæsernes': [('aflæser', False)],
          'aflæsers': [('aflæser', True)],
          'afløsernes': [('afløser', False)],
          'afons': [('afon', False)],
          'afrans': [('afran', False)],
          'aftalen': [('aftale', False)],
          'aftalens': [('aftale', True)],
          'aften': [('aften', False)],
          'aftens': [('aften', True)],
          'after': [('aft', False)],
          'aftes': [('aftes', True)],
          'ag': [('ag', False)],
          'ag.': [('ag.', False)],
          'agas': [('aga', False)],
          'agaten': [('agat', True)],
          'agatens': [('agat', False)],
          'agder': [('agd', False)],
          'agderne': [('agd', False)],
          'age': [('ag', False)],
          'agels': [('agel', False)],
          "agels'": [('agel', False)],
          'agemoder': [('agemode', False)],
          'agen': [('ag', False)],
          'agene': [('ag', False)],
          'agener': [('agen', False)],
          'agenerne': [('agen', False)],
          'agenernes': [('agen', False)],
          'ageners': [('agen', False)],
          'agenes': [('ag', False)],
          'agenet': [('agen', False)],
          'agenets': [('agen', False)],
          'agens': [('agens', True)],
          'agenser': [('agens', True)],
          'agenserne': [('agens', True)],
          'agensernes': [('agens', True)],
          'agensers': [('agens', True)],
          'ager': [('ager', True)],
          'agere': [('ager', False)],
          'agerede': [('agerede', False)],
          'ageren': [('ager', False)],
          'agerens': [('ager', False)],
          'agerer': [('agere', False)],
          'agererne': [('ager', False)],
          'agerernes': [('ager', False)],
          'agerers': [('ager', False)],
          'ageres': [('ager', False)],
          'agerne': [('age', False)],
          'agernes': [('age', False)],
          'agers': [('ager', True)],
          'ages': [('ag', False)],
          "ages'": [('age', False)],
          'aget': [('ag', False)],
          'agets': [('ag', False)],
          'agetterne': [('agette', False)],
          'agetternes': [('agette', False)],
          'agetters': [('agette', False)],
          'agge': [('agge', False)],
          'aggenes': [('ag', False)],
          'agger': [('agge', False)],
          'aggerne': [('agger', False)],
          'aggernes': [('agger', False)],
          'aggers': [('agger', False)],
          'agges': [('agge', False)],
          'aggings': [('agging', False)],
          'aghedens': [('aghed', False)],
          'agien': [('agi', False)],
          'agiens': [('agi', False)],
          'agis': [('agi', False)],
          'agister': [('agist', False)],
          'agisters': [('agister', False)],
          'agklapper': [('agklap', False)],
          'agklappers': [('agklap', False)],
          'agladerne': [('aglader', False)],
          'agladers': [('aglader', False)],
          'aglans': [('aglan', False)],
          'agle': [('agle', False)],
          'aglen': [('agle', False)],
          'aglene': [('agel', False)],
          'aglenes': [('agel', False)],
          'aglens': [('agel', False)],
          'agler': [('agel', False)],
          'aglerne': [('agel', False)],
          'aglernes': [('agle', False)],
          'aglers': [('agle', False)],
          'agles': [('agle', False)],
          'aglet': [('agl', False)],
          'aglærerne': [('aglærer', False)],
          'aglærernes': [('aglærer', False)],
          'agne': [('agne', False)],
          'agnen': [('agn', True)],
          'agnens': [('agn', True)],
          'agner': [('agne', False)],
          'agnerne': [('agen', False)],
          'agnernes': [('agne', False)],
          'agners': [('agne', False)],
          'agnes': [('agne', False)],
          'agnet': [('agen', False)],
          'agnets': [('agen', False)],
          'agnier': [('agni', False)],
          'agnierne': [('agni', False)],
          'agniernes': [('agni', False)],
          'agniers': [('agni', False)],
          'agnummer': [('agnummer', False)],
          'agnummers': [('agnum', False)],
          'agogen': [('agog', False)],
          'agogens': [('agog', False)],
          'agoger': [('agog', False)],
          'agogerne': [('agog', False)],
          'agogernes': [('agog', False)],
          'agogers': [('agog', False)],
          'agordner': [('agorden', False)],
          'agordnerne': [('agorden', False)],
          'agordners': [('agorden', False)],
          'agpibers': [('agpibe', False)],
          'agrams': [('agram', False)],
          'agras': [('agra', False)],
          'agrene': [('ager', False)],
          'agrenes': [('ager', False)],
          'agres': [('ager', True)],
          'ags': [('ag', False)],
          "ags'": [('ag', False)],
          'agsarbejders': [('agsarbejde', False)],
          'agsene': [('ag', False)],
          'agsenes': [('ag', False)],
          'agskurs': [('agskurs', False)],
          'agsomkostningerne': [('agsomkostninger', False)],
          'agter': [('agter', False)],
          'agterne': [('agter', False)],
          'agternes': [('agter', False)],
          'agters': [('agt', False)],
          'agthaver': [('agthaver', False)],
          'agthaverne': [('agthaver', False)],
          'agthavernes': [('agthaver', False)],
          'agthavers': [('agthaver', False)],
          'aguaner': [('aguaner', False)],
          'aguanerne': [('aguaner', False)],
          'aguanernes': [('aguaner', False)],
          'aguaners': [('aguaner', False)],
          'agyder': [('agyder', False)],
          'agyderne': [('agyder', False)],
          'agydernes': [('agyder', False)],
          'agyders': [('agyder', False)],
          'agører': [('agør', False)],
          'agørernes': [('agør', False)],
          'agørers': [('agør', False)],
          'ah': [('ah', False)],
          'ahamanerne': [('ahamaner', False)],
          'ahamanernes': [('ahamaner', False)],
          'ahamaners': [('ahamaner', False)],
          'ahandler': [('ahandler', False)],
          'ahandlerne': [('ahandler', False)],
          'ahandlernes': [('ahandler', False)],
          'ahandlers': [('ahandler', False)],
          'ahans': [('ahan', False)],
          'ahas': [('aha', False)],
          'ahave': [('ahav', False)],
          'ahaves': [('ahav', False)],
          'ahen': [('ah', False)],
          'ahens': [('ah', False)],
          'ahenternes': [('ahent', False)],
          'aher': [('ah', False)],
          'aherne': [('ah', False)],
          'ahernes': [('ah', False)],
          'ahers': [('ah', False)],
          'ahus': [('ahus', False)],
          'ahytten': [('ahyt', False)],
          'ahyttens': [('ahyt', False)],
          'ahytter': [('ahyt', False)],
          'ahytterne': [('ahyt', False)],
          'ahytternes': [('ahyt', False)],
          'ahytters': [('ahyt', False)],
          'ai': [('ai', False)],
          'aichernes': [('aiche', False)],
          'aide': [('aide', False)],
          'aiden': [('aide', False)],
          'aidens': [('aid', False)],
          'aider': [('aide', False)],
          'aiderne': [('aide', False)],
          'aidernes': [('aide', False)],
          'aiders': [('aide', False)],
          'aides': [('aide', False)],
          'aids': [('aids', True)],
          "aids'": [('aids', True)],
          'aidsen': [('aids', True)],
          'aidsens': [('aids', True)],
          'aien': [('ai', False)],
          'aiene': [('ai', False)],
          'aienes': [('ai', False)],
          'aiens': [('ai', False)],
          'aier': [('ai', False)],
          'aierne': [('ai', False)],
          'aiernes': [('ai', False)],
          'aiers': [('ai', False)],
          'aiet': [('ai', False)],
          'aiets': [('ai', False)],
          'aigres': [('aigre', False)],
          'aigretten': [('aigrette', False)],
          'aigrettens': [('aigrette', False)],
          'aikken': [('aik', False)],
          'aikkerne': [('aik', False)],
          'aikus': [('aiku', False)],
          'ailets': [('ail', False)],
          'aillet': [('aillet', False)],
          'aillets': [('aillet', False)],
          'ailletten': [('aillet', False)],
          'ailletter': [('aillet', False)],
          'ailletterne': [('aillet', False)],
          'ailletternes': [('aillet', False)],
          'aillister': [('aillist', False)],
          'aillisternes': [('aillist', False)],
          'aillisters': [('aillist', False)],
          'aine': [('aine', False)],
          'ainen': [('aine', False)],
          'ainens': [('aine', False)],
          'ainerne': [('ainer', False)],
          'ainernes': [('ainer', False)],
          'ainers': [('ainer', False)],
          'aines': [('aine', False)],
          'airen': [('air', False)],
          'airer': [('air', False)],
          'airerne': [('air', False)],
          'airernes': [('airer', False)],
          'airers': [('air', False)],
          'ais': [('ais', True)],
          'aise': [('aise', False)],
          'aisen': [('aise', False)],
          'aisens': [('aise', False)],
          'aiser': [('aiser', False)],
          'aiserne': [('aise', False)],
          'aisernes': [('aise', False)],
          'aisers': [('aiser', False)],
          'aises': [('aise', False)],
          'aismen': [('aisme', False)],
          'aismens': [('aisme', False)],
          'aisser': [('ais', True)],
          'aisserne': [('ais', True)],
          'aissernes': [('ais', True)],
          'aissers': [('ais', True)],
          'aisten': [('aist', False)],
          'aistens': [('aist', False)],
          'aister': [('aist', False)],
          'aisterne': [('aist', False)],
          'aisternes': [('aist', False)],
          'aisters': [('aist', False)],
          'aita': [('aita', False)],
          'aitas': [('aita', False)],
          'aiter': [('ait', False)],
          'aiterne': [('aiter', False)],
          'aiternes': [('ait', False)],
          'aiters': [('ait', False)],
          'ajakken': [('ajak', False)],
          'ajakkens': [('ajak', False)],
          'ajakker': [('ajak', False)],
          'ajakkerne': [('ajak', False)],
          'ajakkernes': [('ajak', False)],
          'ajakkers': [('ajak', False)],
          'ajas': [('aja', False)],
          'ajen': [('aj', False)],
          'ajene': [('aj', False)],
          'ajens': [('aj', False)],
          'ajer': [('aj', False)],
          'ajerne': [('aj', False)],
          'ajernes': [('aj', False)],
          'ajers': [('aj', False)],
          'ajet': [('aj', False)],
          'ajets': [('aj', False)],
          'ajle': [('ajle', True)],
          'ajlen': [('ajle', True)],
          'ajlens': [('ajle', True)],
          'ajles': [('ajle', True)],
          'ajs': [('aj', False)],
          'ajserne': [('ajs', False)],
          'ajsers': [('ajs', False)],
          'ak': [('ak', False)],
          'aka': [('aka', False)],
          'akaene': [('akum', False)],
          'akaenes': [('akum', False)],
          'akaffer': [('akaffe', False)],
          'akafferne': [('akaffe', False)],
          'akaffernes': [('akaffe', False)],
          'akaffers': [('akaffe', False)],
          'akagen': [('akage', False)],
          'akagens': [('akage', False)],
          'akajen': [('akaj', False)],
          'akajens': [('akaj', False)],
          'akajer': [('akaj', False)],
          'akajerne': [('akaj', False)],
          'akajernes': [('akaj', False)],
          'akajers': [('akaj', False)],
          'akaler': [('akal', False)],
          'akalerne': [('akal', False)],
          'akalernes': [('akal', False)],
          'akalers': [('akal', False)],
          'akalken': [('akalk', False)],
          'akalkens': [('akalk', False)],
          'akanen': [('akan', False)],
          'akanens': [('akan', False)],
          'akans': [('akan', False)],
          'akaos': [('akao', False)],
          'akas': [('aka', False)],
          'akater': [('akat', False)],
          'akaterne': [('akat', False)],
          'akaternes': [('akater', False)],
          'akaters': [('akat', False)],
          'aken': [('ak', False)],
          'akene': [('ak', False)],
          'akenes': [('ak', False)],
          'akens': [('ak', False)],
          'aker': [('aker', False)],
          'akere': [('aker', False)],
          'akeren': [('aker', False)],
          'akerens': [('aker', False)],
          'akeres': [('aker', False)],
          'akerne': [('aker', False)],
          'akernes': [('aker', False)],
          'akers': [('aker', False)],
          'akes': [('akes', False)],
          "akes'": [('akes', False)],
          'akesene': [('akes', False)],
          'akesenes': [('akes', False)],
          'aket': [('aket', False)],
          'akets': [('aket', False)],
          'aketten': [('akette', False)],
          'akettens': [('akette', False)],
          'aketter': [('aket', False)],
          'aketterne': [('akette', False)],
          'aketternes': [('akette', False)],
          'aketters': [('akette', False)],
          'akher': [('akher', False)],
          'akhernes': [('akher', False)],
          'akhers': [('akher', False)],
          'akias': [('akia', False)],
          'akiler': [('akiler', False)],
          'akilerne': [('akiler', False)],
          'akilernes': [('akiler', False)],
          'akilers': [('akiler', False)],
          'akinen': [('akin', False)],
          'akinens': [('akin', False)],
          'akiner': [('akin', False)],
          'akinernes': [('akin', False)],
          'akis': [('aki', False)],
          'akisen': [('akis', False)],
          'akke': [('akke', False)],
          'akken': [('akke', False)],
          'akkens': [('ak', False)],
          'akker': [('ak', False)],
          'akkernes': [('ak', False)],
          'akkers': [('ak', False)],
          'akkes': [('akke', False)],
          'akket': [('ak', False)],
          'akkets': [('ak', False)],
          'aklen': [('akkel', False)],
          'aklens': [('akel', False)],
          'aklerne': [('akkel', False)],
          'aklernes': [('akkel', False)],
          'aklers': [('akkel', False)],
          'akles': [('akle', False)],
          'aklingen': [('akling', False)],
          'aklingens': [('akling', False)],
          'aklinger': [('akling', False)],
          'aklingerne': [('akling', False)],
          'aklingernes': [('akling', False)],
          'aklingers': [('akling', False)],
          'aklips': [('aklip', False)],
          'akoks': [('akok', False)],
          'akoksen': [('akokse', False)],
          'akoksens': [('akokse', False)],
          'akometer': [('akometer', False)],
          'akometers': [('akometer', False)],
          'akon': [('akon', False)],
          'akonen': [('akon', False)],
          'akonens': [('akon', False)],
          'akoner': [('akon', False)],
          'akonerne': [('akon', False)],
          'akonernes': [('akon', False)],
          'akoners': [('akon', False)],
          'akons': [('akon', False)],
          'akoten': [('akot', False)],
          'akotens': [('akot', False)],
          'akoter': [('akot', False)],
          'akoterne': [('akot', False)],
          'akoternes': [('akot', False)],
          'akoters': [('akot', False)],
          'akotter': [('akotta', False)],
          'akotternes': [('akotta', False)],
          'akre': [('akre', False)],
          'akres': [('akre', False)],
          'akrisen': [('akrise', False)],
          'akroer': [('akroer', False)],
          'akroerne': [('akroer', False)],
          'akroernes': [('akroer', False)],
          'akroers': [('akro', False)],
          'akronen': [('akron', False)],
          'akronens': [('akron', False)],
          'akroner': [('akron', False)],
          'akronerne': [('akron', False)],
          'akronernes': [('akron', False)],
          'akroners': [('akron', False)],
          'aks': [('aks', True)],
          "aks'": [('aks', True)],
          'akse': [('akse', False)],
          'aksen': [('akse', False)],
          'aksens': [('akse', False)],
          'akser': [('akse', False)],
          'akserne': [('akse', False)],
          'aksernes': [('akse', True)],
          'aksers': [('akse', False)],
          'akses': [('akse', False)],
          'akshandler': [('akshandler', False)],
          'akshandlerne': [('akshandel', False)],
          'akshandlernes': [('akshandel', False)],
          'akshandlers': [('akshandler', False)],
          'aksis': [('aksi', False)],
          'akslerne': [('aksel', True)],
          'akslernes': [('aksel', False)],
          'akslers': [('aksel', False)],
          'aksten': [('akst', False)],
          'akstens': [('akst', False)],
          'akster': [('akst', False)],
          'aksterne': [('akst', False)],
          'aksternes': [('akst', False)],
          'aksters': [('akst', False)],
          'akteater': [('akteat', False)],
          'akteaters': [('akteat', False)],
          'akter': [('akt', True)],
          'akterne': [('akt', True)],
          'akternes': [('akt', True)],
          'akters': [('akt', True)],
          'akture': [('aktur', False)],
          'akummet': [('akum', False)],
          'akummets': [('akum', False)],
          'akunerne': [('akune', False)],
          'akuners': [('akune', False)],
          'akurs': [('akurs', False)],
          'akurser': [('akurs', False)],
          'akurserne': [('akurs', False)],
          'akursernes': [('akurs', False)],
          'akursers': [('akurs', False)],
          'akvarter': [('akvarter', False)],
          'akvarters': [('akvarter', False)],
          'akøren': [('akør', False)],
          'akører': [('akør', False)],
          'akørerne': [('akør', False)],
          'akørernes': [('akør', False)],
          'akørers': [('akør', False)],
          'al': [('al', False)],
          'alabas': [('alabas', False)],
          'alads': [('alads', False)],
          'alaksen': [('alakse', False)],
          'alaksens': [('alakse', False)],
          'alancer': [('alance', False)],
          'alancerne': [('alance', False)],
          'alancernes': [('alance', False)],
          'alancers': [('alance', False)],
          'alanens': [('alan', False)],
          'alaner': [('alaner', False)],
          'alanerne': [('alaner', False)],
          'alanernes': [('alaner', False)],
          'alaners': [('alan', False)],
          'alans': [('alan', False)],
          'alarer': [('alar', False)],
          'alarernes': [('alar', False)],
          'alars': [('alar', False)],
          'alaser': [('alas', False)],
          'alaserne': [('alas', False)],
          'alasernes': [('alas', False)],
          'alasers': [('alas', False)],
          'alatens': [('alat', False)],
          'alats': [('alat', False)],
          'alaver': [('alaver', False)],
          'alaverne': [('alaver', False)],
          'alavernes': [('alaver', False)],
          'alavers': [('alaver', False)],
          'albas': [('alba', True)],
          'alben': [('alben', False)],
          'albens': [('alben', False)],
          'alboernes': [('alboer', False)],
          'alboers': [('alboer', False)],
          'alde': [('alde', False)],
          'alden': [('alde', False)],
          'aldene': [('ald', False)],
          'aldens': [('alde', False)],
          'alder': [('alder', False)],
          'alderne': [('alder', False)],
          'aldernes': [('alder', False)],
          'alders': [('alder', True)],
          'aldes': [('alde', False)],
          'aldestens': [('aldesten', False)],
          'aldre': [('alder', False)],
          'ale': [('ale', True)],
          'aleaser': [('alease', False)],
          'aleaserne': [('alease', False)],
          'aleasernes': [('alease', False)],
          'aleasers': [('alease', False)],
          'alegaver': [('alegaver', False)],
          'alegaverne': [('alegaver', False)],
          'alegavernes': [('alegaver', False)],
          'alegavers': [('alegaver', False)],
          'alejen': [('alej', False)],
          'alejens': [('alej', False)],
          'alejer': [('alej', False)],
          'alejerne': [('alej', False)],
          'alejernes': [('alej', False)],
          'alejers': [('alej', False)],
          'alejs': [('alej', False)],
          'alen': [('ale', True), ('alen', True), ('al', True)],
          'alene': [('ale', True)],
          'alenen': [('alen', True)],
          'alenens': [('alen', False)],
          'alenes': [('ale', True)],
          'alenet': [('alen', False)],
          'alenets': [('alen', False)],
          'alens': [('al', True), ('alen', True), ('ale', True)],
          'alenserne': [('alens', False)],
          'aleoner': [('aleoner', False)],
          'aleonerne': [('aleoner', False)],
          'aleonernes': [('aleoner', False)],
          'aleoners': [('aleoner', False)],
          'aler': [('al', False)],
          'alere': [('aler', False)],
          'aleren': [('aler', False)],
          'alerens': [('aler', False)],
          'alerer': [('aler', False)],
          'alererne': [('aler', False)],
          'alerernes': [('aler', False)],
          'alerers': [('aler', False)],
          'aleres': [('aler', False)],
          'aleret': [('aleret', False)],
          'alerets': [('aleret', False)],
          'alerne': [('al', False)],
          'alernes': [('al', False)],
          'alers': [('al', False)],
          'ales': [('ale', True)],
          'alet': [('al', False)],
          'alets': [('al', False)],
          'aletten': [('alet', False)],
          'alettens': [('alet', False)],
          'aletter': [('alet', False)],
          'aletterne': [('alet', False)],
          'aletternes': [('alet', False)],
          'aletters': [('alet', False)],
          'alfarter': [('alfart', False)],
          'alfarterne': [('alfart', False)],
          'alfarters': [('alfart', False)],
          'alfer': [('alf', True)],
          'alferne': [('alf', True)],
          'alfernes': [('alf', True)],
          'alflugterne': [('alflugt', False)],
          'alge': [('alge', False)],
          'algen': [('alge', False)],
          'algens': [('alge', True)],
          'alger': [('alge', True)],
          'alges': [('alge', False)],
          'algier': [('algi', False)],
          'algierne': [('algi', False)],
          'algiernes': [('algi', False)],
          'algiers': [('algi', False)],
          'alheden': [('alhede', True)],
          'alheder': [('alhede', True)],
          'alhederne': [('alhede', True)],
          'alhedernes': [('alhede', True)],
          'alheders': [('alhede', True)],
          'alias': [('alias', True)],
          'alicens': [('alice', False)],
          'aliden': [('alid', False)],
          'alider': [('alid', False)],
          'aliderne': [('alid', False)],
          'alidernes': [('alid', False)],
          'aliders': [('alid', False)],
          'alids': [('alid', False)],
          'alien': [('alien', True)],
          'aliens': [('alien', True)],
          'alier': [('alier', False)],
          'alierne': [('alier', False)],
          'aliers': [('alier', False)],
          'alies': [('alie', False)],
          'alinde': [('alinde', False)],
          'alinden': [('alinde', False)],
          'alindens': [('alinde', False)],
          'alindes': [('alinde', False)],
          'alinen': [('alin', False)],
          'alinens': [('alin', False)],
          'aliner': [('alin', False)],
          'alinerne': [('alin', False)],
          'alinernes': [('alin', False)],
          'aliners': [('alin', False)],
          'alinet': [('alin', False)],
          'alinets': [('alin', False)],
          'alingers': [('aling', False)],
          'alis': [('alis', False)],
          'aliser': [('aliser', False)],
          'aliserne': [('aliser', False)],
          'alisernes': [('aliser', False)],
          'alisers': [('alise', False)],
          'aliskens': [('alisk', False)],
          'alisker': [('alisk', False)],
          'aliskerne': [('alisk', False)],
          'aliskernes': [('alisk', False)],
          'aliskers': [('alisk', False)],
          'alismen': [('alisme', False)],
          'alisten': [('alist', False)],
          'alistens': [('alist', False)],
          'alister': [('alist', False)],
          'alisterne': [('alist', False)],
          'alisternes': [('alist', False)],
          'alisters': [('alist', False)],
          'aliternes': [('aliter', False)],
          'aliters': [('aliter', False)],
          'alits': [('alit', False)],
          'alitter': [('alit', False)],
          'alium': [('alium', False)],
          'aliums': [('alium', False)],
          'aljen': [('alje', False)],
          'alke': [('alk', True)],
          'alken': [('alk', True)],
          'alkens': [('alk', True)],
          'alker': [('alk', True)],
          'alkerne': [('alk', True)],
          'alkernes': [('alk', True)],
          'alkers': [('alk', True)],
          'alkes': [('alk', True)],
          'alkoner': [('alkoner', False)],
          'alkoners': [('alkoner', False)],
          'alkover': [('alkove', True)],
          'alkovers': [('alkove', True)],
          'allagen': [('allage', False)],
          'allagens': [('allage', False)],
          'alle': [('alle', False)],
          'allen': [('alle', False)],
          'allene': [('al', False)],
          'allenes': [('al', False)],
          'allens': [('all', False)],
          'aller': [('alle', False)],
          'allerne': [('al', False)],
          'allernes': [('al', False)],
          'allers': [('aller', False)],
          'alles': [('alle', False)],
          'allet': [('al', False)],
          'allets': [('al', False)],
          'allettens': [('allet', False)],
          'alletters': [('allet', False)],
          'alliker': [('allike', True)],
          'allikerne': [('allike', True)],
          'allikernes': [('allike', True)],
          'allinger': [('alling', False)],
          'allingerne': [('alling', False)],
          'allingernes': [('alling', False)],
          'allister': [('alliste', False)],
          'allisternes': [('alliste', False)],
          'allisters': [('alliste', False)],
          "allos'": [('allos', False)],
          'allys': [('ally', False)],
          'allærers': [('allære', False)],
          'alme': [('alme', False)],
          'almen': [('alme', False)],
          'almens': [('alme', False)],
          'almer': [('alme', False)],
          'almerne': [('alme', False)],
          'almernes': [('alme', False)],
          'almers': [('alme', False)],
          'almes': [('alme', False)],
          'alminen': [('almin', False)],
          'aloen': [('aloe', True)],
          'aloens': [('aloe', True)],
          'aloer': [('aloe', True)],
          'aloerne': [('aloe', True)],
          'aloernes': [('aloe', True)],
          'aloers': [('aloe', True)],
          'alogen': [('alog', False)],
          'alogens': [('alogen', False)],
          'aloger': [('alog', False)],
          'alogerne': [('alog', False)],
          'alogernes': [('alog', False)],
          'alogers': [('alog', False)],
          'aloget': [('alog', False)],
          'alommen': [('alom', False)],
          'alommens': [('alom', False)],
          'alonier': [('alonier', False)],
          'alopens': [('alope', False)],
          'alopers': [('alope', False)],
          'aloppen': [('alop', False)],
          'aloppens': [('alop', False)],
          'alopper': [('alop', False)],
          'alopperne': [('alop', False)],
          'aloppernes': [('alop', False)],
          'aloppers': [('alop', False)],
          'alos': [('alo', False)],
          'alotten': [('alot', False)],
          'alottens': [('alot', False)],
          'alotter': [('alot', False)],
          'alotterne': [('alot', False)],
          'alotternes': [('alot', False)],
          'alotters': [('alot', False)],
          'alower': [('alow', False)],
          'alowerne': [('alow', False)],
          'alowernes': [('alow', False)],
          'alowers': [('alow', False)],
          'alpe': [('alpe', False)],
          'alpen': [('alp', True)],
          'alpens': [('alp', True)],
          'alper': [('alp', True)],
          'alperne': [('alp', True)],
          'alpernes': [('alp', True)],
          'alpers': [('alp', True)],
          'alpes': [('alpe', False)],
          'als': [('al', False)],
          "als'": [('al', False)],
          'alser': [('alse', False)],
          'alserne': [('alse', False)],
          'alsernes': [('alse', False)],
          'alset': [('alset', False)],
          'alsets': [('alset', False)],
          'alsinger': [('alsing', True), ('alsinger', True)],
          'alsingerne': [('alsing', True), ('alsinger', True)],
          'alsingernes': [('alsing', True), ('alsinger', True)],
          'alsingers': [('alsinger', True), ('alsing', True)],
          'alstyrers': [('alstyre', False)],
          'alstyret': [('alstyre', False)],
          'alte': [('alte', False)],
          'alten': [('alt', True)],
          'altene': [('alt', False)],
          'altens': [('alt', True)],
          'alter': [('alt', True), ('alter', True)],
          'alterne': [('alt', True)],
          'alternes': [('alt', True)],
          'alters': [('alter', True), ('alt', True)],
          'altes': [('alte', False)],
          'alukker': [('aluk', False)],
          'alukkerne': [('aluk', False)],
          'alukkernes': [('aluk', False)],
          'alukkers': [('aluk', False)],
          'aluks': [('aluk', False)],
          'alunet': [('alun', True)],
          'alunets': [('alun', True)],
          'alunken': [('alunk', False)],
          'alunkens': [('alunk', False)],
          'alunker': [('alunk', False)],
          'alunkerne': [('alunk', False)],
          'alunkernes': [('alunk', False)],
          'alunkers': [('alunk', False)],
          'aluns': [('alun', True)],
          'aluten': [('alut', False)],
          'alutens': [('alut', False)],
          'alve': [('alve', False)],
          'alven': [('alve', False)],
          'alvens': [('alve', False)],
          'alves': [('alve', False)],
          'alyde': [('alyd', False)],
          'alyden': [('alyd', False)],
          'alydens': [('alyd', False)],
          'alydes': [('alyd', False)],
          'alæer': [('alæ', False)],
          'alæerne': [('alæ', False)],
          'alæernes': [('alæ', False)],
          'alæers': [('alæ', False)],
          'alænder': [('alænder', False)],
          'alænderne': [('alænder', False)],
          'alændernes': [('alænder', False)],
          'alænders': [('alænder', False)],
          'alærer': [('alær', False)],
          'alærerne': [('alær', False)],
          'alærernes': [('alær', False)],
          'alærers': [('alær', False)],
          'alæret': [('alær', False)],
          'alærets': [('alær', False)],
          'alæs': [('alæ', False)],
          'aløen': [('alø', False)],
          'aløens': [('alø', False)],
          'aløer': [('alø', False)],
          'aløernes': [('alø', False)],
          'aløers': [('alø', False)],
          'alører': [('alør', False)],
          'alørernes': [('alør', False)],
          'am': [('am', False)],
          'amachen': [('amache', False)],
          'amachens': [('amache', False)],
          'amaden': [('amad', False)],
          'amads': [('amad', False)],
          'amagens': [('amage', False)],
          'amager': [('amager', True)],
          'amagerne': [('amager', True)],
          'amagernes': [('amager', True)],
          'amagers': [('amager', True)],
          'amajs': [('amaj', False)],
          'aman': [('aman', False)],
          'amanden': [('amande', False)],
          'amandens': [('amande', False)],
          'amanderne': [('amander', False)],
          'amandernes': [('amander', False)],
          'amanders': [('amander', False)],
          'amanens': [('aman', False)],
          'amanerne': [('amaner', False)],
          'amanernes': [('amaner', False)],
          'amaners': [('amaner', False)],
          'amarinen': [('amarin', False)],
          'amarinens': [('amarin', False)],
          'amariner': [('amarin', False)],
          'amarinerne': [('amarin', False)],
          'amarinernes': [('amarin', False)],
          'amariners': [('amarin', False)],
          'amas': [('ama', False)],
          'amasker': [('amask', False)],
          'amaskerne': [('amask', False)],
          'amaskernes': [('amask', False)],
          'amaskers': [('amask', False)],
          'amassen': [('amas', False)],
          'amassens': [('amas', False)],
          'amasser': [('amas', False)],
          'amasserne': [('amas', False)],
          'amassernes': [('amas', False)],
          'amassers': [('amas', False)],
          'amben': [('amben', False)],
          'ambens': [('amben', False)],
          'ambers': [('ambe', False)],
          'ambier': [('ambier', False)],
          'ambierne': [('ambier', False)],
          'ambler': [('ambel', False)],
          'amblerne': [('ambel', False)],
          'amblernes': [('ambel', False)],
          'amblers': [('ambel', False)],
          'amburs': [('ambur', False)],
          'amediciner': [('amediciner', False)],
          'amedicinerne': [('amediciner', False)],
          'amedicinernes': [('amediciner', False)],
          'amediciners': [('amediciner', False)],
          'amene': [('ame', False)],
          'amener': [('amen', False)],
          'amenerne': [('amen', False)],
          'ameners': [('amen', False)],
          'amenes': [('am', False)],
          'amens': [('ame', False)],
          'amenternes': [('ament', False)],
          'amenters': [('ament', False)],
          'amer': [('am', False)],
          'amere': [('amer', False)],
          'ameren': [('amer', False)],
          'amerens': [('amer', False)],
          'ameres': [('amer', False)],
          'amerne': [('am', False)],
          'amernes': [('am', False)],
          'amers': [('ame', False)],
          'amet': [('am', False)],
          'ameter': [('ameter', False)],
          'ameterne': [('amet', False)],
          'ameternes': [('amet', False)],
          'ameters': [('ameter', False)],
          'ametre': [('ameter', False)],
          'ametrene': [('ameter', False)],
          'ametrenes': [('ameter', False)],
          'ametres': [('ameter', False)],
          'ametret': [('ameter', False)],
          'ametrets': [('ameter', False)],
          'amfers': [('amfer', False)],
          'amhus': [('amhus', False)],
          'amider': [('amid', True)],
          'amiderne': [('amid', True)],
          'amidernes': [('amid', False)],
          'amiders': [('amid', True)],
          'amier': [('amier', False)],
          'amierne': [('amier', False)],
          'amiernes': [('amier', False)],
          'amiers': [('amier', False)],
          'amiet': [('ami', False)],
          'amiks': [('amik', False)],
          'amilen': [('amil', False)],
          'amilens': [('amil', False)],
          'amilien': [('amilie', False)],
          'amiliens': [('amilie', False)],
          'aminen': [('amin', False)],
          'aminens': [('amin', False)],
          'aminet': [('amin', False)],
          'aminets': [('amin', False)],
          'aministers': [('aminister', False)],
          'amis': [('ami', False)],
          'amitten': [('amit', False)],
          'amittens': [('amit', False)],
          'amitter': [('amit', False)],
          'amitterne': [('amit', False)],
          'amitternes': [('amit', False)],
          'amitters': [('amit', False)],
          'amlejernes': [('amleje', False)],
          'amler': [('amler', False)],
          'amlerne': [('amler', False)],
          'amlernes': [('amler', False)],
          'amlers': [('amler', False)],
          'amme': [('amme', False)],
          'ammelsers': [('ammelse', False)],
          'ammen': [('amme', True)],
          'ammens': [('amme', True)],
          'ammer': [('amme', True)],
          'ammerne': [('amme', True)],
          'ammernes': [('amme', False)],
          'ammers': [('amme', True)],
          'ammes': [('amme', False)],
          'ammet': [('am', False)],
          'ammets': [('am', False)],
          'ammoder': [('ammor', False)],
          'amoralen': [('amoral', True)],
          'amoralens': [('amoral', True)],
          'amos': [('amo', False)],
          'amotten': [('amotte', False)],
          'amottens': [('amotte', False)],
          'ampe': [('ampe', False)],
          'ampels': [('ampel', True)],
          'ampelse': [('ampels', False)],
          'ampelsen': [('ampels', False)],
          'ampelsens': [('ampels', False)],
          'ampelses': [('ampels', False)],
          'ampen': [('ampe', False)],
          'ampens': [('ampe', False)],
          'amper': [('ampe', False)],
          'ampere': [('ampere', False)],
          'amperes': [('ampere', False)],
          'amperier': [('amperi', False)],
          'amperierne': [('amperi', False)],
          'amperiernes': [('amperi', False)],
          'amperiers': [('amperi', False)],
          'amperiet': [('amperi', False)],
          'amperiets': [('amperi', False)],
          'amperne': [('ampe', False)],
          'ampernes': [('amper', False)],
          'ampers': [('amper', False)],
          'ampes': [('ampe', False)],
          'ampet': [('ampet', False)],
          'ampets': [('ampet', False)],
          'ampler': [('ampel', True)],
          'amplerne': [('ampel', True)],
          'amplernes': [('ampel', True)],
          'amplers': [('ampel', True)],
          'amplet': [('amplet', False)],
          'amplets': [('amplet', False)],
          'amrådets': [('amråd', False)],
          'ams': [('am', False)],
          "ams'": [('am', False)],
          'amse': [('amse', False)],
          'amsen': [('amse', False)],
          'amsens': [('amse', False)],
          'amser': [('amse', False)],
          'amserne': [('amse', False)],
          'amsernes': [('amse', False)],
          'amsers': [('amse', False)],
          'amses': [('amse', False)],
          'amskifterne': [('amskifte', False)],
          'amskifternes': [('amskifte', False)],
          'amtiden': [('amtid', False)],
          'amus': [('amus', False)],
          'amæer': [('amæer', False)],
          'amæerne': [('amæer', False)],
          'amæernes': [('amæer', False)],
          'amælken': [('amælk', False)],
          'amælkens': [('amælk', False)],
          'amærkerne': [('amærke', False)],
          'amærkernes': [('amærke', False)],
          'amærkers': [('amærke', False)],
          'an': [('an', False)],
          'ana': [('anum', False)],
          'anader': [('anade', False)],
          'anaftalen': [('anaftale', False)],
          'anaftalens': [('anaftale', False)],
          'anager': [('anager', False)],
          'anagerne': [('anage', False)],
          'anagernes': [('anage', False)],
          'anagers': [('anage', False)],
          'anakken': [('anak', False)],
          'anakkens': [('anak', False)],
          'anakker': [('anak', False)],
          'anakkerne': [('anak', False)],
          'anakkernes': [('anak', False)],
          'anakkers': [('anak', False)],
          'analen': [('anal', False)],
          'analer': [('anal', False)],
          'analerne': [('anal', False)],
          'analernes': [('anal', False)],
          'analers': [('anal', False)],
          'anans': [('anan', False)],
          'anas': [('ana', False)],
          'anasser': [('anas', False)],
          'anasserne': [('anas', False)],
          'anassernes': [('anas', False)],
          'anassers': [('anas', False)],
          'anaster': [('anaster', False)],
          'anasters': [('anaster', False)],
          'anaten': [('anat', False)],
          'anatens': [('anat', False)],
          'anater': [('anat', False)],
          'anaterne': [('anat', False)],
          'anaters': [('anat', False)],
          'anatorierne': [('anatorie', False)],
          'anatoriers': [('anatorie', False)],
          'anatoriet': [('anatorie', False)],
          'anatoriets': [('anatorie', False)],
          'ancen': [('ance', False)],
          'ancene': [('anc', False)],
          'ancenes': [('anc', False)],
          'ancens': [('ance', False)],
          'ancer': [('ance', False)],
          'ancerne': [('ance', False)],
          'ancernes': [('ance', False)],
          'ancers': [('ance', False)],
          'ancher': [('anche', False)],
          'ancherne': [('anche', False)],
          'anchernes': [('anche', False)],
          'anchers': [('anche', False)],
          'anda': [('anda', False)],
          'andage': [('andage', False)],
          'andagen': [('andage', False)],
          'andagens': [('andag', False)],
          'andages': [('andage', False)],
          'andalen': [('andal', False)],
          'andalens': [('andal', False)],
          'andaler': [('andale', False)],
          'andalerne': [('andal', False)],
          'andalernes': [('andal', False)],
          'andalers': [('andale', False)],
          'andanten': [('andante', True)],
          'andantens': [('andante', True)],
          'andanter': [('andante', True)],
          'andanterne': [('andante', True)],
          'andanternes': [('andante', True)],
          'andanters': [('andante', True)],
          'andarbejder': [('andarbejder', False)],
          'andarbejderne': [('andarbejder', False)],
          'andas': [('anda', False)],
          'andbo': [('andboer', False)],
          'andbos': [('andboer', False)],
          'ande': [('ande', False)],
          'anden': [('and', True)],
          'andens': [('and', True)],
          'ander': [('and', False)],
          'anderne': [('ander', False)],
          'andernes': [('ander', False)],
          'anders': [('ander', False)],
          'andertalerne': [('andertaler', False)],
          'andertalers': [('andertaler', False)],
          'andes': [('ande', False)],
          'andis': [('andi', False)],
          'andlerne': [('andel', False)],
          'andlernes': [('andel', False)],
          'andolers': [('andoler', False)],
          'andpumper': [('andpumper', False)],
          'andpumperne': [('andpumper', False)],
          'andpumpernes': [('andpumper', False)],
          'andpumpers': [('andpumper', False)],
          'andre': [('ander', False)],
          'andten': [('andt', False)],
          'andtens': [('andt', False)],
          'anduer': [('andu', False)],
          'anduerne': [('andu', False)],
          'anduernes': [('andu', False)],
          'anduers': [('andu', False)],
          'andørerne': [('andør', False)],
          'andørernes': [('andør', False)],
          'ane': [('ane', True)],
          'anearbejder': [('anearbejder', False)],
          'anearbejderne': [('anearbejder', False)],
          'aneger': [('anege', False)],
          'anegerne': [('anege', False)],
          'anegernes': [('anege', False)],
          'anegers': [('anege', False)],
          'aneler': [('anel', False)],
          'anelers': [('anel', False)],
          'anellen': [('anelle', False)],
          'aneller': [('anelle', False)],
          'anellers': [('anelle', False)],
          'anen': [('ane', True)],
          'anene': [('an', False)],
          'anenes': [('an', False)],
          'anens': [('ane', True)],
          'anenserne': [('anens', False)],
          'aner': [('ane', True)],
          'anerier': [('aneri', False)],
          'anerierne': [('aneri', False)],
          'aneriernes': [('aneri', False)],
          'aneriers': [('aneri', False)],
          'anerne': [('ane', True)],
          'anernes': [('ane', True)],
          'aners': [('ane', True)],
          'anes': [('ane', True)],
          'aneser': [('aneser', False)],
          'aneserne': [('aneser', False)],
          'anesernes': [('aneser', False)],
          'anesierne': [('anesier', False)],
          'anesiernes': [('anesier', False)],
          'anesiers': [('anesier', False)],
          'anet': [('an', False)],
          'aneterne': [('anet', False)],
          'aneternes': [('anet', False)],
          'anets': [('an', False)],
          'anetter': [('anette', False)],
          'anetterne': [('anette', False)],
          'anetternes': [('anette', False)],
          'anetters': [('anette', False)],
          'anettet': [('anette', False)],
          'anettets': [('anette', False)],
          'anfluens': [('anflue', False)],
          'angarerne': [('angar', False)],
          'angarers': [('angar', False)],
          "angas'": [('angas', False)],
          'ange': [('ange', False)],
          'anger': [('anger', False)],
          'angerne': [('ange', False)],
          'angernes': [('anger', False)],
          'angers': [('anger', True)],
          'anges': [('ange', False)],
          'anglen': [('angel', False)],
          'anglens': [('angle', False)],
          'angler': [('angler', True)],
          'anglerne': [('angler', True)],
          'anglernes': [('angler', True)],
          'anglers': [('angler', True)],
          'angles': [('angle', False)],
          'anglisten': [('anglist', True)],
          'anglistens': [('anglist', True)],
          'anglister': [('anglist', True)],
          'anglisterne': [('anglist', True)],
          'anglisternes': [('anglist', True)],
          'anglisters': [('anglist', True)],
          'angordnernes': [('angorden', False)],
          'angrene': [('angren', False)],
          'angrenes': [('angren', False)],
          'angster': [('angster', False)],
          'angsterne': [('angster', False)],
          'angsternes': [('angster', False)],
          'angsters': [('angster', False)],
          'anider': [('anid', False)],
          'aniderne': [('anid', False)],
          'anidernes': [('anid', False)],
          'aniders': [('anid', False)],
          'anien': [('anie', False)],
          'aniens': [('anie', False)],
          'anier': [('anier', False)],
          'anierne': [('ani', False)],
          'aniernes': [('anier', False)],
          'aniers': [('ani', False)],
          'aniet': [('anie', False)],
          'aniets': [('anie', False)],
          'aniker': [('aniker', False)],
          'anikerne': [('aniker', False)],
          'anikernes': [('aniker', False)],
          'anikers': [('aniker', False)],
          'aniklens': [('anikel', False)],
          'aninen': [('anin', False)],
          'aninens': [('anin', False)],
          'aninernes': [('anin', False)],
          'aningers': [('aning', False)],
          'anis': [('anis', True)],
          "anis'": [('anis', True)],
          'anissen': [('anis', True)],
          'anissens': [('anis', True)],
          'anister': [('anister', False)],
          'anisters': [('anister', False)],
          'anitten': [('anit', False)],
          'anittens': [('anit', False)],
          'anitter': [('anit', False)],
          'anitterne': [('anit', False)],
          'anitternes': [('anit', False)],
          'anitters': [('anit', False)],
          'anium': [('anium', False)],
          'aniums': [('anium', False)],
          'anke': [('anke', False)],
          'anken': [('anke', False)],
          'ankens': [('anke', True)],
          'anker': [('anker', True), ('anke', True)],
          'ankerne': [('anke', True)],
          'ankernes': [('anke', True)],
          'ankers': [('anke', True), ('anker', True)],
          'ankes': [('anke', False)],
          'anket': [('ank', False)],
          'ankets': [('ank', False)],
          'ankier': [('ankier', False)],
          'ankiers': [('ankier', False)],
          'anklager': [('anklager', True), ('anklage', True)],
          'anklagerne': [('anklager', True), ('anklage', True)],
          'anklagernes': [('anklager', True), ('anklage', True)],
          'anklagers': [('anklager', True), ('anklage', True)],
          'anklerne': [('ankel', True)],
          'anklernes': [('ankel', True)],
          'anklers': [('ankel', True)],
          'ankret': [('anker', True)],
          'anks': [('anks', False)],
          "anks'": [('anks', False)],
          'annalens': [('annal', True)],
          'anne': [('anne', False)],
          'anner': [('anner', False)],
          'annerne': [('an', False)],
          'annernes': [('an', False)],
          'annes': [('anne', False)],
          'annier': [('anni', False)],
          'anniernes': [('anni', False)],
          'anniers': [('anni', False)],
          'anniet': [('anni', False)],
          'anniets': [('anni', False)],
          'annis': [('anni', False)],
          'anolinen': [('anolin', False)],
          'anolinens': [('anolin', False)],
          'anomen': [('anom', False)],
          'anomens': [('anom', False)],
          'anomer': [('anom', False)],
          'anomerne': [('anom', False)],
          'anomernes': [('anom', False)],
          'anomers': [('anom', False)],
          'anonen': [('anon', False)],
          'anonens': [('anon', False)],
          'anoner': [('anon', False)],
          'anonerne': [('anon', False)],
          'anonernes': [('anon', False)],
          'anonet': [('anon', False)],
          'anonets': [('anon', False)],
          'ans': [('an', False)],
          "ans'": [('an', False)],
          'ansagernes': [('ansager', False)],
          'ansagers': [('ansager', False)],
          'ansats': [('ansats', True)],
          'anse': [('anse', False)],
          'ansene': [('ans', False)],
          'ansenes': [('an', False)],
          'anserne': [('ans', False)],
          'ansernes': [('anse', False)],
          'anses': [('anse', False)],
          'ansier': [('ansier', False)],
          'ansions': [('ansion', False)],
          'ansker': [('ansker', False)],
          'anskerne': [('ansker', False)],
          'ansler': [('ansler', False)],
          'anslerne': [('ansel', False)],
          'anslernes': [('ansel', False)],
          'anslers': [('ansel', False)],
          'antage': [('antage', False)],
          'antagen': [('antage', False)],
          'antages': [('antage', False)],
          'antas': [('antum', False)],
          'antaten': [('antate', False)],
          'antatens': [('antate', False)],
          'antater': [('antat', False)],
          'antaterne': [('antate', False)],
          'antaternes': [('antat', False)],
          'antaters': [('antate', False)],
          'ante': [('ante', False)],
          'anten': [('ante', False)],
          'antens': [('ante', False)],
          'anter': [('ant', False)],
          'anteret': [('anteret', False)],
          'anterets': [('anteret', False)],
          'anterne': [('ante', False)],
          'anternes': [('ante', False)],
          'anternet': [('antern', False)],
          'anternets': [('antern', False)],
          'anters': [('ante', False)],
          'antes': [('ante', False)],
          'antet': [('ante', False)],
          'antets': [('ante', False)],
          'anti': [('anti', False)],
          'antier': [('anti', False)],
          'antiernes': [('anti', False)],
          'antiers': [('anti', False)],
          'antikvarboghandler': [('antikvarboghandel', True), ('antikvarboghandler', True)],
          'antikvarboghandlerne': [('antikvarboghandel', True), ('antikvarboghandler', True)],
          'antikvarboghandlernes': [('antikvarboghandel', True), ('antikvarboghandler', True)],
          'antikvarboghandlers': [('antikvarboghandler', True), ('antikvarboghandel', True)],
          'antinen': [('antine', False)],
          'antinens': [('antine', False)],
          'antiner': [('antine', False)],
          'antinerne': [('antiner', False)],
          'antinernes': [('antine', False)],
          'antiners': [('antiner', False)],
          'antis': [('anti', False)],
          'antissen': [('antis', False)],
          'antissens': [('antis', False)],
          'antisser': [('antis', False)],
          'antisserne': [('antis', False)],
          'antissernes': [('antis', False)],
          'antissers': [('antis', False)],
          "ants'": [('ants', False)],
          'antus': [('antus', False)],
          'anummers': [('anummer', False)],
          'anus': [('anus', False)],
          'anussernes': [('anus', False)],
          'anussers': [('anus', False)],
          'anzen': [('anze', False)],
          'anzens': [('anze', False)],
          'anzer': [('anz', False)],
          'anzerne': [('anze', False)],
          'anzernes': [('anze', False)],
          'anzers': [('anz', False)],
          'anæer': [('anæer', False)],
          'anæerne': [('anæer', False)],
          'anæernes': [('anæer', False)],
          'anæren': [('anære', False)],
          'anøren': [('anør', False)],
          'anører': [('anør', False)],
          'anørernes': [('anør', False)],
          'anørers': [('anør', False)],
          'aoen': [('ao', False)],
          'aoens': [('ao', False)],
          'aoer': [('ao', False)],
          'aoerne': [('ao', False)],
          'aoernes': [('ao', False)],
          'aoers': [('ao', False)],
          'aoliner': [('aolin', False)],
          'aoner': [('ao', False)],
          'aonerne': [('ao', False)],
          'aonernes': [('ao', False)],
          'aoners': [('ao', False)],
          'aordrer': [('aordre', False)],
          'aorien': [('aori', False)],
          'aoriens': [('aori', False)],
          'aorier': [('aori', False)],
          'aorierne': [('aori', False)],
          'aoriernes': [('aori', False)],
          'aoris': [('aori', False)],
          'aos': [('ao', False)],
          'aoste': [('aost', False)],
          'aosten': [('aost', False)],
          'aostens': [('aost', False)],
          'aostes': [('aost', False)],
          'apalmen': [('apalm', False)],
          'apalmens': [('apalm', False)],
          'apanden': [('apand', False)],
          'apandens': [('apand', False)],
          'apanerne': [('apaner', False)],
          'apanernes': [('apaner', False)],
          'apas': [('apas', False)],
          'apassager': [('apassage', False)],
          'apassagers': [('apassage', False)],
          'apatiens': [('apati', True)],
          'apellet': [('apel', False)],
          'apellets': [('apel', False)],
          'apels': [('apel', False)],
          'apen': [('ape', False)],
          'apens': [('ape', False)],
          'aper': [('aper', False)],
          'apere': [('aper', False)],
          'aperens': [('aper', False)],
          'aperes': [('aper', False)],
          'aperne': [('aper', False)],
          'apernes': [('ape', False)],
          'apers': [('ape', False)],
          'apersen': [('apers', False)],
          'apersens': [('apers', False)],
          'apes': [('ape', False)],
          'apet': [('apet', False)],
          'apeterne': [('apet', False)],
          'apeternes': [('apet', False)],
          'apets': [('apet', False)],
          'apien': [('api', False)],
          'apiens': [('apiens', False)],
          'apier': [('api', False)],
          'apierne': [('api', False)],
          'apiernes': [('api', False)],
          'apiers': [('api', False)],
          'apillen': [('apil', False)],
          'apillens': [('apil', False)],
          'apiller': [('apil', False)],
          'apillerne': [('apil', False)],
          'apillernes': [('apil', False)],
          'apillers': [('apil', False)],
          'apils': [('apil', False)],
          'apirens': [('apir', False)],
          'apirer': [('apir', False)],
          'apirerne': [('apir', False)],
          'apirernes': [('apir', False)],
          'apis': [('api', False)],
          'apisen': [('apis', False)],
          'apisens': [('apis', False)],
          'aplanter': [('aplante', False)],
          'aplanterne': [('aplante', False)],
          'aplanternes': [('aplante', False)],
          'aplanters': [('aplante', False)],
          'aplys': [('aply', False)],
          'apoet': [('apo', False)],
          'apoets': [('apo', False)],
          'apoteker': [('apotek', True), ('apoteker', True)],
          'apotekerne': [('apotek', True), ('apoteker', True)],
          'apotekernes': [('apotek', True), ('apoteker', True)],
          'apotekers': [('apotek', True), ('apoteker', True)],
          'appe': [('appe', False)],
          'appen': [('app', True)],
          'appendicitten': [('appendicitis', True), ('appendicit', True)],
          'appendicittens': [('appendicit', True), ('appendicitis', True)],
          'appendicitter': [('appendicit', True), ('appendicitis', True)],
          'appendicitterne': [('appendicit', True), ('appendicitis', True)],
          'appendicitternes': [('appendicitis', True), ('appendicit', True)],
          'appendicitters': [('appendicitis', True), ('appendicit', True)],
          'appens': [('app', True)],
          'apper': [('app', False)],
          'apperne': [('app', True)],
          'appernes': [('app', True)],
          'appers': [('app', True)],
          'appes': [('ap', False)],
          'appet': [('ap', False)],
          'appets': [('ap', False)],
          'apporter': [('apport', False)],
          'apporters': [('apport', False)],
          'apringer': [('apring', False)],
          'apringerne': [('apring', False)],
          'apringernes': [('apring', False)],
          'aprisen': [('apris', False)],
          'aprisens': [('apris', False)],
          'apriser': [('apris', False)],
          'apriserne': [('apris', False)],
          'aprisernes': [('apris', False)],
          'aprisers': [('apris', False)],
          'aps': [('ap', False)],
          "aps'": [('ap', False)],
          'apser': [('apse', False)],
          'apserne': [('apse', False)],
          'apsernes': [('apse', False)],
          'apsers': [('aps', False)],
          'apsis': [('apsis', True)],
          'apterne': [('apter', False)],
          'apternes': [('apter', False)],
          'apters': [('apter', False)],
          'apuner': [('apun', False)],
          'apænder': [('apand', False)],
          'apænderne': [('apand', False)],
          'apændernes': [('apand', False)],
          'ar': [('ar', False)],
          'arabens': [('araben', False)],
          'araberne': [('araber', True)],
          'arade': [('arade', False)],
          'araden': [('arade', False)],
          'aradens': [('arade', False)],
          'arader': [('arade', False)],
          'araderne': [('arade', False)],
          'aradernes': [('arade', False)],
          'araders': [('arade', False)],
          'arades': [('arade', False)],
          'aradiser': [('aradis', False)],
          'aradiserne': [('aradis', False)],
          'aradisernes': [('aradis', False)],
          'aradisers': [('aradis', False)],
          'arads': [('arad', False)],
          'arager': [('arage', False)],
          'aragerne': [('arage', False)],
          'aragernes': [('arage', False)],
          'aragers': [('arage', False)],
          'arakkens': [('arak', False)],
          'arakker': [('arak', False)],
          'arakkerne': [('arak', False)],
          'arakkernes': [('arak', False)],
          'arakkers': [('arak', False)],
          'arakter': [('arakter', False)],
          'arakters': [('arakter', False)],
          'aralierne': [('aralie', True)],
          'araliers': [('aralie', True)],
          'aramenter': [('aramenter', False)],
          'aramenterne': [('aramenter', False)],
          'aramenters': [('aramenter', False)],
          'arander': [('arand', False)],
          'aranen': [('aran', False)],
          'araner': [('aran', False)],
          'araners': [('aran', False)],
          'arans': [('aran', False)],
          'arantis': [('aranti', False)],
          'araten': [('arat', False)],
          'aratens': [('arat', False)],
          'arater': [('arat', False)],
          'araterne': [('arat', False)],
          'araternes': [('arat', False)],
          'araters': [('arat', False)],
          'aravanen': [('aravan', False)],
          'aravanens': [('aravan', False)],
          'aravaner': [('aravan', False)],
          'aravanerne': [('aravane', False)],
          'aravanernes': [('aravan', False)],
          'aravaners': [('aravan', False)],
          'arbarierne': [('arbari', False)],
          'arbariernes': [('arbari', False)],
          'arbariets': [('arbari', False)],
          'arbejder': [('arbejder', True), ('arbejde', True)],
          'arbejderne': [('arbejder', True), ('arbejde', True)],
          'arbejdernes': [('arbejder', True), ('arbejde', True)],
          'arbejders': [('arbejde', True), ('arbejder', True)],
          'arben': [('arbe', False)],
          'arboret': [('arboret', True)],
          'arborets': [('arboret', True)],
          'arbrødrene': [('arbror', False)],
          'arcellen': [('arcel', False)],
          'arcellers': [('arcel', False)],
          'archen': [('arch', False)],
          'archens': [('arch', False)],
          'archernes': [('archer', False)],
          'arde': [('arde', False)],
          'arden': [('ard', True)],
          'ardens': [('ard', True)],
          'arder': [('ard', False)],
          'arderne': [('ard', True)],
          'ardernes': [('ard', True)],
          'arders': [('ard', True)],
          'ardes': [('arde', False)],
          'ardinen': [('ardine', False)],
          'ardinens': [('ardine', False)],
          'ardiner': [('ardine', False)],
          'ardinerne': [('ardin', False)],
          'ardinernes': [('ardine', False)],
          'ardiners': [('ardin', False)],
          'ardinet': [('ardine', False)],
          'ardinets': [('ardine', False)],
          'ardiniere': [('ardinier', False)],
          'ardinieren': [('ardinier', False)],
          'ardinierens': [('ardinier', False)],
          'ardinieres': [('ardinier', False)],
          'arelser': [('arelse', False)],
          'arelserne': [('arelse', False)],
          'arelsernes': [('arelse', False)],
          'aremmer': [('arem', False)],
          'aremmerne': [('arem', False)],
          'aremmernes': [('arem', False)],
          'aremmers': [('arem', False)],
          'aren': [('ar', False)],
          'arene': [('ar', False)],
          'arenes': [('ar', False)],
          'arengs': [('arengs', False)],
          'arens': [('ar', False)],
          'arenten': [('arent', False)],
          'arentens': [('arent', False)],
          'arenter': [('arent', False)],
          'arenterne': [('arente', False)],
          'arenternes': [('arente', False)],
          'arenters': [('arent', False)],
          'arentes': [('arentes', False)],
          'arer': [('ar', False)],
          'arernes': [('ar', False)],
          'arers': [('are', False)],
          'ares': [('are', False)],
          'aresers': [('arese', False)],
          'aret': [('ar', False)],
          'areterne': [('aret', False)],
          'areternes': [('aret', False)],
          'arets': [('ar', False)],
          'aretter': [('aret', False)],
          'arge': [('arge', False)],
          'argen': [('argen', False)],
          'argens': [('argen', False)],
          'arger': [('arge', False)],
          'argerne': [('arg', False)],
          'argernes': [('arge', False)],
          'argers': [('arge', False)],
          'arges': [('arges', False)],
          'arginers': [('argin', False)],
          'arhandlernes': [('arhandler', False)],
          'arhedens': [('arhed', False)],
          'arianer': [('arianer', False)],
          'arianers': [('arianer', False)],
          'arians': [('arians', False)],
          'arias': [('aria', False)],
          'ariaternes': [('ariat', False)],
          'arider': [('arid', False)],
          'ariderne': [('arid', False)],
          'aridernes': [('arid', False)],
          'ariders': [('arid', False)],
          'arids': [('arid', False)],
          'arien': [('arie', False)],
          'ariens': [('arie', True)],
          'arier': [('arier', True), ('arie', True)],
          'arierne': [('arier', True), ('arie', True)],
          'ariernes': [('arier', True), ('arie', True)],
          'ariers': [('arier', True), ('arie', True)],
          'aries': [('arie', True)],
          'ariet': [('arie', False)],
          'ariets': [('arie', False)],
          'arilds': [('arilds', True)],
          'arinden': [('arinde', False)],
          'arindens': [('arinde', False)],
          'arinen': [('arin', False)],
          'arinens': [('arin', False)],
          'ariner': [('arine', False)],
          'arinerne': [('arin', False)],
          'arinernes': [('arin', False)],
          'ariners': [('arine', False)],
          'arinet': [('arin', False)],
          'arinets': [('arin', False)],
          'aringer': [('aring', False)],
          'aringerne': [('aring', False)],
          'aringernes': [('aring', False)],
          'aringers': [('aring', False)],
          'arins': [('arin', False)],
          'ario': [('ario', False)],
          'arioer': [('ario', False)],
          'arioerne': [('ario', False)],
          'arioernes': [('ario', False)],
          'arioers': [('ario', False)],
          'arionet': [('arionet', False)],
          'arionets': [('arionet', False)],
          'arios': [('ario', False)],
          'aris': [('aris', False)],
          'ariser': [('ariser', False)],
          'arisernes': [('ariser', False)],
          'arisers': [('ariser', False)],
          'arissers': [('aris', False)],
          'arister': [('arist', False)],
          'aristerne': [('arist', False)],
          'aristernes': [('arist', False)],
          'aristers': [('arist', False)],
          'aritten': [('arit', False)],
          'arittens': [('arit', False)],
          'aritter': [('arit', False)],
          'aritterne': [('arit', False)],
          'aritternes': [('arit', False)],
          'aritters': [('arit', False)],
          'arium': [('arium', False)],
          'ariums': [('arium', False)],
          'arken': [('ark', True)],
          'arkens': [('ark', False)],
          'arker': [('ark', True)],
          'arkerne': [('ark', True)],
          'arkernes': [('ark', True)],
          'arkers': [('ark', False)],
          'arket': [('ark', True)],
          'arkets': [('ark', True)],
          'arkis': [('arki', False)],
          'arkurser': [('arkurs', False)],
          'arkurserne': [('arkurs', False)],
          'arkursers': [('arkurs', False)],
          'arlerne': [('arl', False)],
          'arlernes': [('arl', False)],
          'arlers': [('arl', False)],
          'arme': [('arm', True)],
          'armen': [('arm', True)],
          'armens': [('arm', True)],
          'armer': [('arm', False)],
          'armerne': [('armer', False)],
          'armernes': [('armer', False)],
          'armers': [('armer', False)],
          'armes': [('arm', True)],
          'arnas': [('arnas', False)],
          'arne': [('arne', True)],
          'arnebillet': [('ørnebillet', False)],
          'arnebillets': [('ørnebillet', False)],
          'arnebilletten': [('ørnebillet', False)],
          'arnebillettens': [('ørnebillet', False)],
          'arnebilletter': [('ørnebillet', False)],
          'arnebilletterne': [('ørnebillet', False)],
          'arnebilletternes': [('ørnebillet', False)],
          'arnebilletters': [('ørnebillet', False)],
          'arnecykel': [('ørnecykel', False)],
          'arnecykels': [('ørnecykel', False)],
          'arnecyklen': [('ørnecykel', False)],
          'arnecyklens': [('ørnecykel', False)],
          'arnecykler': [('ørnecykel', False)],
          'arnecyklerne': [('ørnecykel', False)],
          'arnecyklernes': [('ørnecykel', False)],
          'arnecyklers': [('ørnecykel', False)],
          'arnen': [('arne', True)],
          'arnens': [('arne', True)],
          'arner': [('arne', True)],
          'arnerne': [('arne', True)],
          'arnernes': [('arne', True)],
          'arners': [('arne', True)],
          'arnes': [('arne', True)],
          'arneseng': [('ørneseng', False)],
          'arnesenge': [('ørneseng', False)],
          'arnesengen': [('ørneseng', False)],
          'arnesengene': [('ørneseng', False)],
          'arnesengenes': [('ørneseng', False)],
          'arnesengens': [('ørneseng', False)],
          'arnesenges': [('ørneseng', False)],
          'arnesengs': [('ørneseng', False)],
          'arnesoldat': [('ørnesoldat', False)],
          'arnesoldaten': [('ørnesoldat', False)],
          'arnesoldatens': [('ørnesoldat', False)],
          'arnesoldater': [('ørnesoldat', False)],
          'arnesoldaterne': [('ørnesoldat', False)],
          'arnesoldaternes': [('ørnesoldat', False)],
          'arnesoldaters': [('ørnesoldat', False)],
          'arnesoldats': [('ørnesoldat', False)],
          'arnestol': [('ørnestol', False)],
          'arnestole': [('ørnestol', False)],
          'arnestolen': [('ørnestol', False)],
          'arnestolene': [('ørnestol', False)],
          'arnestolenes': [('ørnestol', False)],
          'arnestolens': [('ørnestol', False)],
          'arnestoles': [('ørnestol', False)],
          'arnestols': [('ørnestol', False)],
          'arnesæde': [('ørnesæde', False)],
          'arnesæder': [('ørnesæde', False)],
          'arnesæderne': [('ørnesæde', False)],
          'arnesædernes': [('ørnesæde', False)],
          'arnesæders': [('ørnesæde', False)],
          'arnesædes': [('ørnesæde', False)],
          'arnesædet': [('ørnesæde', False)],
          'arnesædets': [('ørnesæde', False)],
          'arnier': [('arni', False)],
          'arnis': [('arni', False)],
          'arok': [('arok', False)],
          'arokken': [('arok', False)],
          'arokkens': [('arok', False)],
          'arokker': [('arok', False)],
          'arokkerne': [('arok', False)],
          'arokkernes': [('arok', False)],
          'arokkers': [('arok', False)],
          'aroks': [('arok', False)],
          'aroler': [('arole', False)],
          'arolerne': [('arole', False)],
          'arolernes': [('arole', False)],
          'aronen': [('aron', False)],
          'aronens': [('aron', False)],
          'aroner': [('aron', False)],
          'aronerne': [('aron', False)],
          'aronernes': [('aron', False)],
          'aroners': [('aron', False)],
          'arossen': [('arosse', False)],
          'arossens': [('arosse', False)],
          'arosser': [('arosse', False)],
          'arosserne': [('arosse', False)],
          'arotten': [('arot', False)],
          'arottens': [('arot', False)],
          'arotter': [('arotte', False)],
          'arotterne': [('arot', False)],
          'arotternes': [('arotte', False)],
          'arotters': [('arot', False)],
          'arpe': [('arpe', False)],
          'arpen': [('arp', True)],
          'arpens': [('arp', True)],
          'arper': [('arpe', False)],
          'arperne': [('arpe', False)],
          'arpernes': [('arp', False)],
          'arpers': [('arp', False)],
          'arpes': [('arp', False)],
          'arre': [('arre', False)],
          'arrens': [('arre', False)],
          'arrer': [('arre', False)],
          'arrerne': [('arre', False)],
          'arret': [('ar', False)],
          'arrets': [('ar', False)],
          'arrieren': [('arrier', False)],
          'arrierens': [('arrier', False)],
          'arrotten': [('arrotte', False)],
          'arrotterne': [('arrotte', False)],
          'arruller': [('arruller', False)],
          'ars': [('ar', False)],
          "ars'": [('ar', False)],
          'arsen': [('arsen', True)],
          'arsene': [('ar', False)],
          'arsenes': [('ar', False)],
          'arsens': [('arsen', True)],
          'arser': [('arser', False)],
          'arserne': [('arser', False)],
          'arsernes': [('arser', False)],
          'arsers': [('arser', False)],
          'arses': [('arsis', True)],
          'arsis': [('arsis', True)],
          'arsken': [('arsk', False)],
          'arskifte': [('arskift', False)],
          'artager': [('artager', False)],
          'artagerne': [('artager', False)],
          'artagernes': [('artager', False)],
          'artagers': [('artager', False)],
          'artaler': [('artal', False)],
          'artalers': [('artal', False)],
          'arte': [('arte', False)],
          'arteller': [('artel', False)],
          'artellers': [('artel', False)],
          'arten': [('art', True)],
          'artens': [('art', True)],
          'arter': [('art', True)],
          'arterne': [('art', True)],
          'arternes': [('art', False)],
          'arters': [('art', True)],
          'artes': [('arte', False)],
          'artet': [('artet', False)],
          'artets': [('artet', False)],
          'artien': [('arti', False)],
          'artiens': [('arti', False)],
          'artier': [('arti', False)],
          'artierne': [('arti', False)],
          'artiernes': [('arti', False)],
          'artiers': [('arti', False)],
          'arties': [('arty', False)],
          'artiet': [('arti', False)],
          'artiets': [('arti', False)],
          'artisanen': [('artisan', False)],
          'artisanens': [('artisan', False)],
          'artisaner': [('artisan', False)],
          'artisanerne': [('artisan', False)],
          'artisanernes': [('artisan', False)],
          'artlerne': [('artel', False)],
          'artlernes': [('artel', False)],
          'artlers': [('artel', False)],
          'artonen': [('artone', False)],
          'artonens': [('artone', False)],
          'artoner': [('arton', False)],
          'artonerne': [('arton', False)],
          'artonernes': [('artone', False)],
          'artoners': [('arton', False)],
          'arts': [('art', True)],
          "arts'": [('arts', False)],
          'artænder': [('artænder', False)],
          'artændernes': [('artænder', False)],
          'aruller': [('arulle', False)],
          'arullers': [('arulle', False)],
          'arus': [('arus', False)],
          'arussen': [('arusse', False)],
          'arussens': [('arusse', False)],
          'arusser': [('arusse', False)],
          'arusserne': [('arusse', False)],
          'arussernes': [('arus', False)],
          'arussers': [('arus', False)],
          'arutter': [('arut', False)],
          'arve': [('arve', False)],
          'arveje': [('arvej', False)],
          'arvejene': [('arvej', False)],
          'arvejenes': [('arvej', False)],
          'arvelader': [('arvelader', True)],
          'arveladerne': [('arvelader', True)],
          'arveladernes': [('arvelader', True)],
          'arveladers': [('arvelader', True)],
          'arven': [('arv', True), ('arve', True)],
          'arvens': [('arv', True), ('arve', True)],
          'arver': [('arve', False)],
          'arverne': [('arve', False)],
          'arvernes': [('arve', False)],
          'arvers': [('arve', False)],
          'arves': [('arve', False)],
          'arykkens': [('aryk', False)],
          'arykker': [('aryk', False)],
          'arykkerne': [('aryk', False)],
          'arykkernes': [('aryk', False)],
          'arykkers': [('aryk', False)],
          'arylen': [('aryl', False)],
          'arylens': [('aryl', False)],
          'aryler': [('aryl', False)],
          'arylerne': [('aryl', False)],
          'arylernes': [('aryl', False)],
          'arylers': [('aryl', False)],
          'aræer': [('aræer', False)],
          'aræerne': [('aræer', False)],
          'aræernes': [('aræer', False)],
          'aræers': [('aræer', False)],
          'as': [('as', False)],
          "as'": [('as', False)],
          'asaks': [('asak', False)],
          'asalternes': [('asalt', False)],
          'asalters': [('asalt', False)],
          'asaners': [('asan', False)],
          'asans': [('asan', False)],
          'aschen': [('asch', False)],
          'aschens': [('asch', False)],
          'aseliner': [('aseline', False)],
          'aselinernes': [('aseline', False)],
          'asen': [('asen', True), ('as', True)],
          'asene': [('as', False)],
          'asenen': [('asen', False)],
          'asenens': [('asen', False)],
          'asener': [('asen', True)],
          'asenerne': [('asen', True)],
          'asenernes': [('asen', True)],
          'aseners': [('asen', True)],
          'asenes': [('as', False)],
          'asens': [('asen', True), ('as', True)],
          'aser': [('as', False)],
          'asere': [('aser', False)],
          'aseren': [('aser', False)],
          'aserens': [('aser', False)],
          'aseres': [('aser', False)],
          'aserne': [('as', True)],
          'asernes': [('as', False)],
          'asers': [('as', False)],
          'aset': [('as', False)],
          'asets': [('as', False)],
          'asiater': [('asiater', True), ('asiat', True)],
          'asiaterne': [('asiater', True), ('asiat', True)],
          'asiaternes': [('asiat', True), ('asiater', True)],
          'asiaters': [('asiater', True), ('asiat', True)],
          'asiden': [('asid', False)],
          'asidens': [('asid', False)],
          'asider': [('asid', False)],
          'asiderne': [('asid', False)],
          'asidernes': [('asid', False)],
          'asiders': [('asid', False)],
          'asien': [('asie', True)],
          'asiens': [('asie', True)],
          'asier': [('asie', True)],
          'asierne': [('asie', True)],
          'asiernes': [('asie', False)],
          'asiers': [('asie', True)],
          'asiet': [('asiet', True)],
          'asiets': [('asiet', True)],
          'asinen': [('asin', False)],
          'asinens': [('asin', False)],
          'asinernes': [('asin', False)],
          'asingers': [('asing', False)],
          'asis': [('asis', False)],
          'asitter': [('asit', False)],
          'asitterne': [('asit', False)],
          'aske': [('ask', True), ('aske', True)],
          'asken': [('ask', True), ('aske', True)],
          'askene': [('ask', False)],
          'askens': [('aske', True), ('ask', True)],
          'asker': [('aske', False)],
          'askeris': [('askeri', False)],
          'askerne': [('aske', False)],
          'askernes': [('aske', True)],
          'askers': [('aske', False)],
          'askes': [('ask', True), ('aske', True)],
          'asket': [('asket', True)],
          'asketer': [('asket', True)],
          'asketers': [('asket', True)],
          'askets': [('asket', True)],
          'asketten': [('asket', False)],
          'askettens': [('asket', False)],
          'asketterne': [('asket', False)],
          'asketternes': [('asket', False)],
          'asketters': [('asket', False)],
          'askos': [('asko', False)],
          'askotten': [('askot', False)],
          'askottens': [('askot', False)],
          'askotter': [('askot', False)],
          'askotterne': [('askot', False)],
          'askotternes': [('askot', False)],
          'askotters': [('askot', False)],
          'askys': [('askys', False)],
          'aslags': [('aslag', False)],
          'aslangen': [('aslange', False)],
          'aslangens': [('aslange', False)],
          'aslen': [('assel', False)],
          'aslens': [('aslen', False)],
          'asler': [('assel', False)],
          'aslerne': [('asler', False)],
          'aslernes': [('asler', False)],
          'aslers': [('assel', False)],
          'asmer': [('asme', False)],
          'asmerne': [('asme', False)],
          'asmernes': [('asme', False)],
          'asnerne': [('asen', False)],
          'asollens': [('asol', False)],
          'aspe': [('asp', False)],
          'aspekter': [('aspekt', True)],
          'aspekters': [('aspekt', True)],
          'aspen': [('asp', True)],
          'aspens': [('asp', True)],
          'asper': [('aspe', False)],
          'asperne': [('aspe', False)],
          'aspernes': [('aspe', False)],
          'aspers': [('aspe', False)],
          'aspes': [('asp', True)],
          'assagen': [('assage', False)],
          'assagers': [('assage', False)],
          'assen': [('asse', False)],
          'assene': [('as', False)],
          'assenes': [('as', False)],
          'assens': [('asse', False)],
          'asser': [('as', True)],
          'asserne': [('as', True)],
          'assernes': [('as', False)],
          'assers': [('as', False)],
          'asset': [('as', False)],
          'assets': [('as', False)],
          'assetten': [('asset', False)],
          'assettens': [('asset', False)],
          'assetter': [('assette', False)],
          'assetterne': [('asset', False)],
          'assetternes': [('asset', False)],
          'assetters': [('asset', False)],
          'assiner': [('assin', False)],
          'assinerne': [('assin', False)],
          'assiners': [('assin', False)],
          'assioner': [('assion', False)],
          'assionerne': [('assion', False)],
          'assionernes': [('assion', False)],
          'assioners': [('assion', False)],
          'assyrerne': [('assyrer', True)],
          'astanker': [('astanker', False)],
          'astankernes': [('astanker', False)],
          'astankers': [('astanker', False)],
          'aste': [('aste', False)],
          'astemmer': [('astemme', False)],
          'astemmerne': [('astemme', False)],
          'astemmernes': [('astemme', False)],
          'astemmers': [('astemme', False)],
          'asten': [('aste', False)],
          'astene': [('ast', False)],
          'astenes': [('ast', False)],
          'aster': [('aster', False)],
          'asterier': [('asteri', False)],
          'asterierne': [('asteri', False)],
          'asteriernes': [('asteri', False)],
          'asteriers': [('asteri', False)],
          'asteriet': [('asteri', False)],
          'asteriets': [('asteri', False)],
          'asterne': [('aste', False)],
          'asternes': [('aster', False)],
          'asteroider': [('asteroide', True)],
          'asteroiderne': [('asteroide', True)],
          'asteroidernes': [('asteroide', True)],
          'asteroiders': [('asteroide', True)],
          'asters': [('asters', True)],
          "asters'": [('asters', False)],
          'astes': [('aste', False)],
          'asthandlerne': [('asthandel', False)],
          'asthandlernes': [('asthandel', False)],
          'asti': [('asti', False)],
          'astiet': [('asti', False)],
          'astiets': [('asti', False)],
          'astikas': [('astika', False)],
          'astikken': [('astik', False)],
          'astikker': [('astik', False)],
          'astikkerne': [('astik', False)],
          'astikkernes': [('astik', False)],
          'astikkers': [('astik', False)],
          'astiks': [('astiks', False)],
          'astiller': [('astil', False)],
          'astillerne': [('astil', False)],
          'astillernes': [('astil', False)],
          'astillers': [('astil', False)],
          'astis': [('asti', False)],
          'astningers': [('astning', False)],
          'astole': [('astole', False)],
          'astolen': [('astole', False)],
          'astolens': [('astole', False)],
          'astoles': [('astole', False)],
          'astraten': [('astrat', False)],
          'astratens': [('astrat', False)],
          'astrater': [('astrat', False)],
          'astraterne': [('astrat', False)],
          'astraternes': [('astrat', False)],
          'astraters': [('astrat', False)],
          'astre': [('aster', False)],
          'astykkers': [('astykke', False)],
          'astænder': [('astænder', False)],
          'astænderne': [('astænder', False)],
          'astændernes': [('astænder', False)],
          'astænders': [('astænder', False)],
          'asuren': [('asur', False)],
          'asurens': [('asur', False)],
          'asurer': [('asur', False)],
          'asurerne': [('asur', False)],
          'asurernes': [('asur', False)],
          'asurers': [('asur', False)],
          'asus': [('asus', False)],
          'asværker': [('asværk', False)],
          'asværkerne': [('asværk', False)],
          'asværkernes': [('asværk', False)],
          'asværkers': [('asværk', False)],
          'ata': [('at', False)],
          'ataene': [('atum', False)],
          'ataenes': [('ata', False)],
          'ataks': [('atak', False)],
          'ataksen': [('atakse', False)],
          'ataksens': [('atakse', False)],
          'atalen': [('atal', False)],
          'atalens': [('atal', False)],
          'ataler': [('atal', False)],
          'atalerne': [('atal', False)],
          'atalernes': [('atal', False)],
          'atalers': [('atal', False)],
          'atan': [('atan', False)],
          'atanen': [('atan', False)],
          'ataner': [('atan', False)],
          'ataners': [('atan', False)],
          'atanet': [('atan', False)],
          'atanets': [('atan', False)],
          'atans': [('atan', False)],
          'atarer': [('atar', False)],
          'atarerne': [('atarer', False)],
          'atarernes': [('atar', False)],
          'atarers': [('atarer', False)],
          'atarierne': [('atarium', False)],
          'atariernes': [('atarium', False)],
          'atariers': [('atarium', False)],
          'atarium': [('atarium', False)],
          'atariums': [('atarium', False)],
          'atas': [('ata', False)],
          'ataten': [('atat', False)],
          'atatens': [('atat', False)],
          'atater': [('atat', False)],
          'ataterne': [('atat', False)],
          'ataternes': [('atat', False)],
          'ataters': [('atat', False)],
          'atats': [('atat', False)],
          'atches': [('atch', False)],
          'ategen': [('ateg', False)],
          'ategens': [('ateg', False)],
          'ateger': [('ateg', False)],
          'ategerne': [('ateg', False)],
          'ategernes': [('ateg', False)],
          'ateker': [('atek', False)],
          'atekerne': [('atek', False)],
          'atekernes': [('atek', False)],
          'atekers': [('atek', False)],
          'ateket': [('atek', False)],
          'atekets': [('atek', False)],
          'atelen': [('atel', False)],
          'atelens': [('atel', False)],
          'atelisternes': [('atelist', False)],
          'atelisters': [('atelist', False)],
          'atellen': [('atelle', False)],
          'atellens': [('atel', False)],
          'atellerne': [('atel', False)],
          'atellernes': [('atel', False)],
          'aten': [('at', False)],
          'atene': [('ate', False)],
          'atenes': [('ate', False)],
          'atens': [('at', False)],
          'atenter': [('atent', False)],
          'ater': [('at', False)],
          'ateret': [('ater', False)],
          'aterets': [('ater', False)],
          'aterien': [('aterie', False)],
          'ateriens': [('aterie', False)],
          'aterier': [('aterie', False)],
          'aterierne': [('aterie', False)],
          'ateriernes': [('aterie', False)],
          'ateriers': [('aterie', False)],
          'aterne': [('at', False)],
          'aters': [('at', False)],
          'ates': [('ates', False)],
          "ates'": [('ates', False)],
          'ateser': [('atese', False)],
          'atesernes': [('atese', False)],
          'atesers': [('atese', False)],
          'atet': [('at', False)],
          'atets': [('at', False)],
          'ather': [('ather', False)],
          'atherne': [('ather', False)],
          'athernes': [('ather', False)],
          'athers': [('ather', False)],
          'atialer': [('atiale', False)],
          'atialerne': [('atiale', False)],
          'atialernes': [('atiale', False)],
          'atialers': [('atiale', False)],
          'atialet': [('atiale', False)],
          'atialets': [('atiale', False)],
          'atiden': [('atide', False)],
          'atidens': [('atide', False)],
          'atider': [('atide', False)],
          'atiderne': [('atide', False)],
          'atidernes': [('atide', False)],
          'atiders': [('atid', False)],
          'atids': [('atid', False)],
          'atien': [('atie', False)],
          'atiens': [('atie', False)],
          'aties': [('atie', False)],
          'atiet': [('atie', False)],
          'atiets': [('atie', False)],
          'atikkens': [('atik', False)],
          'atikker': [('atik', False)],
          'atikkernes': [('atik', False)],
          'atikkers': [('atik', False)],
          'atiks': [('atik', False)],
          'atinen': [('atin', False)],
          'atinens': [('atin', False)],
          'atiner': [('atiner', False)],
          'atinerne': [('atine', False)],
          'atinernes': [('atiner', False)],
          'atiners': [('atin', False)],
          'atinet': [('atin', False)],
          'atinets': [('atin', False)],
          'ationaler': [('ationale', False)],
          'ationalerne': [('ationale', False)],
          'ationalernes': [('ationale', False)],
          'ationalers': [('ationale', False)],
          'ationalet': [('ationale', False)],
          'ationalets': [('ationale', False)],
          'atis': [('atis', False)],
          'atisen': [('atis', False)],
          'atisens': [('atis', False)],
          'atits': [('atit', False)],
          'atium': [('atium', False)],
          'atiums': [('atium', False)],
          'ativer': [('ativ', False)],
          'ativernes': [('ativ', False)],
          'atlens': [('atel', False)],
          'atler': [('atel', False)],
          'atlets': [('atlet', False)],
          'atningen': [('atning', False)],
          'atninger': [('atning', False)],
          'atningerne': [('atning', False)],
          'atningernes': [('atning', False)],
          'atoer': [('ato', False)],
          'atoerne': [('ato', False)],
          'atoernes': [('ato', False)],
          'atoers': [('ato', False)],
          'atoler': [('atoler', False)],
          'atolerne': [('atoler', False)],
          'atollens': [('atol', True)],
          'atollerne': [('atol', True)],
          'atollernes': [('atol', False)],
          'atomer': [('atom', False)],
          'atomers': [('atom', True)],
          'atonen': [('aton', False)],
          'atonens': [('aton', False)],
          'atoner': [('aton', False)],
          'atonerne': [('aton', False)],
          'atonernes': [('aton', False)],
          'atoners': [('aton', False)],
          'atonet': [('aton', False)],
          'atonets': [('aton', False)],
          'atops': [('atops', False)],
          'atorierne': [('atorie', False)],
          'atoriers': [('atorie', False)],
          'atoriet': [('atorie', False)],
          'atoriets': [('atorie', False)],
          'atos': [('atos', False)],
          "atos'": [('atos', False)],
          'atossen': [('atos', False)],
          'atossens': [('atos', False)],
          'atrene': [('ater', False)],
          'atrenes': [('ater', False)],
          'atrers': [('atrer', False)],
          'atres': [('ater', False)],
          'atret': [('atret', False)],
          'atrets': [('atret', False)],
          'atrice': [('atice', False)],
          'atricen': [('atrice', False)],
          'atricens': [('atrice', False)],
          'atricerne': [('atrice', False)],
          'atricernes': [('atrice', False)],
          'atricers': [('atrice', False)],
          'atrier': [('atrium', True)],
          'atrierne': [('atrium', True)],
          'atriernes': [('atrium', True)],
          'atriers': [('atrium', True)],
          'atriner': [('atrin', False)],
          'atriners': [('atrin', False)],
          'atringens': [('atring', False)],
          'atroden': [('atrod', False)],
          'atrodens': [('atrod', False)],
          'atrods': [('atrod', False)],
          'atronen': [('atrone', False)],
          'atronens': [('atrone', False)],
          'atroner': [('atron', False)],
          'atronerne': [('atrone', False)],
          'atronernes': [('atrone', False)],
          'atroners': [('atrone', False)],
          'atros': [('atros', False)],
          'atrossen': [('atros', False)],
          'atrossens': [('atros', False)],
          'atrosser': [('atros', False)],
          'atrosserne': [('atros', False)],
          'atrossernes': [('atros', False)],
          'atrossers': [('atros', False)],
          'atrum': [('atrum', False)],
          'atrums': [('atrum', False)],
          'atrusser': [('atrusse', False)],
          'atrusserne': [('atrusse', False)],
          'atrussernes': [('atrusse', False)],
          'atrussers': [('atrusse', False)],
          'ats': [('at', False)],
          "ats'": [('at', False)],
          'atsider': [('atside', False)],
          'atsiderne': [('atside', False)],
          'atsidernes': [('atside', False)],
          'atsiders': [('atside', False)],
          'atstifterne': [('atstifter', False)],
          'atstifternes': [('atstifter', False)],
          'atstifters': [('atstifter', False)],
          'atte': [('atte', False)],
          'attelys': [('attely', False)],
          'atten': [('atte', False)],
          'attens': [('atte', False)],
          'atter': [('at', False)],
          'atteret': [('atteret', False)],
          'atterets': [('atteret', False)],
          'atterne': [('at', False)],
          'atternes': [('atter', False)],
          'atters': [('atter', False)],
          'attes': [('atte', False)],
          'attetiden': [('attetid', False)],
          'atts': [('atts', False)],
          "atts'": [('atts', False)],
          'atuens': [('atue', False)],
          'atuer': [('atue', False)],
          'atuerne': [('atue', False)],
          'atuernes': [('atue', False)],
          'atuers': [('atuer', False)],
          'ature': [('ature', False)],
          'aturen': [('atur', False)],
          'aturene': [('ature', False)],
          'aturenes': [('ature', False)],
          'aturens': [('atur', False)],
          'aturer': [('atur', False)],
          'aturerne': [('atur', False)],
          'aturernes': [('atur', False)],
          'aturers': [('atur', False)],
          'atures': [('ature', False)],
          'aturet': [('atur', False)],
          'atus': [('atus', False)],
          'atyrens': [('atyr', False)],
          'atyrer': [('atyr', False)],
          'atyrerne': [('atyr', False)],
          'atyrernes': [('atyr', False)],
          'atyrers': [('atyr', False)],
          'atører': [('atør', False)],
          'aucer': [('auce', False)],
          'aucerne': [('auce', False)],
          'aucernes': [('auce', False)],
          'aucers': [('auce', False)],
          'aude': [('aude', False)],
          'auden': [('aude', False)],
          'audens': [('aude', False)],
          'auderne': [('aude', False)],
          'auders': [('aude', False)],
          'audes': [('aude', False)],
          'audiens': [('audiens', True)],
          'audier': [('audier', False)],
          'audierne': [('audier', False)],
          'audiernes': [('audier', False)],
          'audiers': [('audier', False)],
          'auen': [('au', False)],
          'auens': [('au', False)],
          'auer': [('au', False)],
          'auerne': [('au', False)],
          'auernes': [('auer', False)],
          'auers': [('au', False)],
          'auet': [('au', False)],
          'auets': [('au', False)],
          'auge': [('auge', False)],
          'aula': [('aula', True)],
          'aulas': [('aula', True)],
          'aulets': [('aulet', False)],
          'auletten': [('aulet', False)],
          'aulten': [('ault', False)],
          'aultens': [('ault', False)],
          'aumet': [('aume', False)],
          'aunerne': [('aun', False)],
          'auners': [('aun', False)],
          'auns': [('aun', False)],
          'aurer': [('aurer', False)],
          'aurerne': [('aurer', False)],
          'aurernes': [('aurer', False)],
          'aurers': [('aurer', False)],
          'aurs': [('aur', False)],
          'auruers': [('auruer', False)],
          'aus': [('au', False)],
          'ause': [('ause', False)],
          'ausen': [('ause', False)],
          'ausens': [('ause', False)],
          'auser': [('ause', False)],
          'auserne': [('ause', False)],
          'ausernes': [('ause', False)],
          'ausers': [('ause', False)],
          'auses': [('ause', False)],
          'ausser': [('ausse', False)],
          'aussernes': [('ausse', False)],
          'aussers': [('ausse', False)],
          'austen': [('aust', False)],
          'austens': [('aust', False)],
          'auster': [('aust', False)],
          'austerne': [('aust', False)],
          'austernes': [('aust', False)],
          'austers': [('aust', False)],
          'auter': [('aut', False)],
          'auterne': [('auterne', False)],
          'autoklaven': [('autoklave', True), ('autoklav', True)],
          'autoklavens': [('autoklav', True), ('autoklave', True)],
          'autoklaver': [('autoklave', True), ('autoklav', True)],
          'autoklaverne': [('autoklave', True), ('autoklav', True)],
          'autoklavernes': [('autoklave', True), ('autoklav', True)],
          'autoklavers': [('autoklav', True), ('autoklave', True)],
          'avader': [('avade', False)],
          'avaderne': [('avade', False)],
          'avadernes': [('avade', False)],
          'avaders': [('avade', False)],
          'avager': [('avage', False)],
          'avagerne': [('avage', False)],
          'avagernes': [('avage', False)],
          'avagers': [('avage', False)],
          'avajer': [('avaj', False)],
          'avajerne': [('avaj', False)],
          'avajernes': [('avaj', False)],
          'avajers': [('avaj', False)],
          'avalers': [('avaler', False)],
          'avanders': [('avand', False)],
          'avaner': [('avaner', False)],
          'avanker': [('avank', False)],
          'avannen': [('avanne', False)],
          'avanner': [('avanne', False)],
          'avanners': [('avanne', False)],
          'avans': [('avan', False)],
          'avarers': [('avare', False)],
          'avarier': [('avari', False)],
          'avarierne': [('avari', False)],
          'avariers': [('avari', False)],
          'avariet': [('avari', False)],
          'avariets': [('avari', False)],
          'avaten': [('avat', False)],
          'avatens': [('avat', False)],
          'avater': [('avat', False)],
          'ave': [('ave', True)],
          'avejen': [('avej', False)],
          'avejens': [('avej', False)],
          'aveksler': [('aveksel', False)],
          'avekslerne': [('aveksel', False)],
          'avekslernes': [('aveksel', False)],
          'avekslers': [('aveksel', False)],
          'aveler': [('avel', False)],
          'avelers': [('avel', False)],
          'avellens': [('avel', False)],
          'aveller': [('avel', False)],
          'avellerne': [('avel', False)],
          'avellernes': [('avel', False)],
          'aven': [('av', False)],
          'avende': [('avende', False)],
          'avender': [('avende', False)],
          'avenderne': [('avende', False)],
          'avendernes': [('avende', False)],
          'avenders': [('avende', False)],
          'avendes': [('avende', False)],
          'avene': [('ave', True)],
          'avenes': [('ave', True)],
          'avens': [('av', False)],
          'avenuen': [('avenue', True)],
          'avenuens': [('avenue', True)],
          'avenuer': [('avenue', True)],
          'avenuerne': [('avenue', True)],
          'avenuernes': [('avenue', True)],
          'avenuers': [('avenue', True)],
          'aver': [('aver', False)],
          'averens': [('aver', False)],
          'averer': [('aver', False)],
          'avererne': [('aver', False)],
          'averernes': [('aver', False)],
          'averers': [('aver', False)],
          'averet': [('aver', False)],
          'averets': [('aver', False)],
          'averne': [('aver', False)],
          'avernes': [('aver', False)],
          'avers': [('avers', True)],
          'averstemmer': [('averstemmer', False)],
          'averstemmerne': [('averstemmer', False)],
          'averstemmernes': [('averstemmer', False)],
          'averstemmers': [('averstemmer', False)],
          'averter': [('avert', False)],
          'averternes': [('avert', False)],
          'aves': [('ave', True)],
          'avets': [('av', False)],
          'avetter': [('avet', False)],
          'avetterne': [('avet', False)],
          'avetters': [('avet', False)],
          'avgassernes': [('avgasse', False)],
          'avianerne': [('avian', False)],
          'avianernes': [('avian', False)],
          'aviden': [('avid', False)],
          'avidens': [('avid', False)],
          'avider': [('avid', False)],
          'aviderne': [('avid', False)],
          'avidernes': [('avid', False)],
          'aviders': [('avid', False)],
          'avinde': [('avinde', False)],
          'avinden': [('avinde', False)],
          'avindens': [('avinde', False)],
          'avinder': [('avinde', False)],
          'avinderne': [('avinde', False)],
          'avindernes': [('avinde', False)],
          'avinders': [('avinde', False)],
          'avindes': [('avinde', False)],
          'avine': [('avine', False)],
          'avinen': [('avine', False)],
          'avinens': [('avine', False)],
          'aviner': [('avine', False)],
          'avinerne': [('avine', False)],
          'aviners': [('avine', False)],
          'avines': [('avine', False)],
          'avis': [('avis', False)],
          'avisen': [('avis', False)],
          'avisens': [('avis', False)],
          'aviser': [('avis', False)],
          'aviserne': [('avis', False)],
          'avisernes': [('avis', False)],
          'avisers': [('avis', False)],
          'avits': [('avit', False)],
          'avle': [('avle', False)],
          'avlen': [('avl', True)],
          'avlene': [('avel', False)],
          'avlenes': [('avel', False)],
          'avlens': [('avl', True)],
          'avler': [('avler', False)],
          'avlerne': [('avler', False)],
          'avlernes': [('avler', False)],
          'avlers': [('avler', True)],
          'avles': [('avle', False)],
          'avne': [('avne', True)],
          'avnen': [('avne', True)],
          'avnens': [('avne', True)],
          'avner': [('avne', True)],
          'avnerne': [('avne', True)],
          'avnernes': [('avne', True)],
          'avners': [('avne', True)],
          'avnes': [('avne', True)],
          'avre': [('avre', False)],
          'avren': [('avr', False)],
          'avrens': [('avr', False)],
          'avres': [('avr', False)],
          'avs': [('av', False)],
          'avsens': [('avs', False)],
          'avsers': [('avs', False)],
          'avsten': [('avsten', False)],
          'avstens': [('avsten', False)],
          'avvandet': [('avvand', False)],
          'avvandets': [('avvand', False)],
          'aværet': [('avær', False)],
          'aværets': [('avær', False)],
          'aværs': [('avær', False)],
          'awer': [('aw', False)],
          'awerne': [('aw', False)],
          'awernes': [('aw', False)],
          'awers': [('aw', False)],
          'awier': [('awier', False)],
          'awierne': [('awier', False)],
          'awiernes': [('awier', False)],
          'awlerne': [('awler', False)],
          'awlernes': [('awler', False)],
          'axer': [('ax', False)],
          'axerne': [('ax', False)],
          'axernes': [('ax', False)],
          'axers': [('ax', False)],
          'ayen': [('ay', False)],
          'ayens': [('ay', False)],
          'ayer': [('ay', False)],
          'ayere': [('ayer', False)],
          'ayeren': [('ayer', False)],
          'ayerens': [('ayer', False)],
          'ayeres': [('ayer', False)],
          'ayerne': [('ay', False)],
          'ayernes': [('ay', False)],
          'ayers': [('ay', False)],
          'ayrer': [('ayrer', False)],
          'ayrers': [('ayrer', False)],
          'ays': [('ay', False)],
          "ays'": [('ay', False)],
          'azen': [('aze', False)],
          'azens': [('aze', False)],
          'azer': [('aze', False)],
          'azerne': [('azer', False)],
          'azernes': [('azer', False)],
          'azers': [('aze', False)],
          'azi': [('azi', False)],
          'azinen': [('azin', False)],
          'azinens': [('azin', False)],
          'azis': [('azi', False)],
          'azzi': [('azzo', False)],
          'azzis': [('azzo', False)],
          "b'erne": [('b', False)],
          'ba': [('ba', False)],
          'babbens': [('bab', False)],
          'babber': [('bab', False)],
          'babbernes': [('bab', False)],
          'babbers': [('bab', False)],
          'babs': [('bab', False)],
          'babys': [('baby', True)],
          'backerne': [('back', True)],
          'backers': [('back', False)],
          'backet': [('back', False)],
          'backets': [('back', False)],
          'backs': [('back', False)],
          "backs'": [('back', False)],
          'backsene': [('back', False)],
          'backsenes': [('back', False)],
          'bacter': [('bacter', False)],
          'bader': [('bader', False)],
          'baderne': [('bader', False)],
          'badernes': [('bader', False)],
          'baders': [('bader', False)],
          'badier': [('badier', False)],
          'badiers': [('badier', False)],
          'baen': [('ba', False)],
          'baens': [('ba', False)],
          'baer': [('ba', False)],
          'baerne': [('ba', False)],
          'baernes': [('ba', False)],
          'baers': [('ba', False)],
          'bagens': [('bag', False)],
          'bagerne': [('bager', True)],
          'bagernes': [('bager', True)],
          'baggen': [('bag', False)],
          'baggens': [('bag', False)],
          'baggerne': [('bagge', False)],
          'baggernes': [('bagge', False)],
          'baggers': [('bagge', False)],
          'baisser': [('baisse', True)],
          'baisserne': [('baisse', True)],
          'baissernes': [('baisse', False)],
          'baissers': [('baisse', False)],
          'bajer': [('bajer', False)],
          'bajerne': [('bajer', True)],
          'bajernes': [('bajer', False)],
          'bajers': [('bajer', True)],
          'bajs': [('bajs', False)],
          'bakken': [('bak', True), ('bakke', True)],
          'bakkens': [('bak', True), ('bakke', True)],
          'bakker': [('bakke', False)],
          'bakkerne': [('bakke', True)],
          'bakkernes': [('bakke', False)],
          'bakkers': [('bakke', False)],
          'baks': [('bak', False)],
          'bakshandlerne': [('bakshandler', False)],
          'bakshandlernes': [('bakshandler', False)],
          'bakter': [('bakter', False)],
          'bakters': [('bakter', False)],
          'balas': [('bala', False)],
          'balder': [('balde', False)],
          'balderne': [('balde', False)],
          'baldernes': [('balde', False)],
          'balders': [('balde', False)],
          'balen': [('bale', False)],
          'balens': [('bale', False)],
          'baler': [('bale', False)],
          'balerne': [('bale', False)],
          'balernes': [('bale', False)],
          'balers': [('bale', False)],
          'bales': [('bale', False)],
          'balkoner': [('balkon', True)],
          'balkoners': [('balkon', True)],
          'ballen': [('bal', True), ('balle', True)],
          'ballens': [('bal', True), ('balle', True)],
          'ballepresser': [('ballepresser', True), ('ballepresse', True)],
          'ballepresserne': [('ballepresser', True), ('ballepresse', True)],
          'ballepressernes': [('ballepresse', True), ('ballepresser', True)],
          'ballepressers': [('ballepresser', True), ('ballepresse', True)],
          'baller': [('balle', True), ('bal', True)],
          'ballerne': [('bal', True), ('balle', True)],
          'ballernes': [('bal', True), ('balle', True)],
          'ballers': [('balle', True), ('bal', True)],
          'ballet': [('ballet', True), ('bal', True)],
          'ballets': [('ballet', True), ('bal', True)],
          'baloer': [('balo', False)],
          'baloerne': [('balo', False)],
          'baloernes': [('balo', False)],
          'baloers': [('balo', False)],
          'balter': [('balter', True)],
          'balterne': [('balter', True)],
          'balternes': [('balter', True)],
          'balters': [('balter', True)],
          'bana': [('bana', False)],
          'bancen': [('banc', False)],
          'bancens': [('banc', False)],
          'bancer': [('banc', False)],
          'bancerne': [('banc', False)],
          'bancernes': [('banc', False)],
          'bancers': [('banc', False)],
          'bandagens': [('bandage', False)],
          'banden': [('bande', True)],
          'bandens': [('bande', True)],
          'bander': [('bande', False)],
          'banderne': [('bande', False)],
          'bandernes': [('bande', False)],
          'banders': [('bande', True)],
          'bandet': [('band', False)],
          'bandets': [('band', False)],
          'bane': [('bane', False)],
          'banen': [('bane', False)],
          'banens': [('bane', False)],
          'baner': [('bane', False)],
          'banerne': [('bane', False)],
          'banernes': [('bane', False)],
          'baners': [('bane', False)],
          'banes': [('bane', False)],
          'banke': [('banke', True)],
          'banken': [('banke', True), ('bank', True)],
          'bankens': [('bank', True), ('banke', True)],
          'banker': [('bank', True), ('banke', True)],
          'bankerne': [('banke', True), ('bank', True)],
          'bankernes': [('banke', True), ('bank', True)],
          'bankers': [('banke', True), ('bank', True)],
          'bankes': [('banke', True)],
          'banket': [('banket', True), ('bank', True)],
          'bankets': [('banket', True), ('bank', True)],
          'banks': [('bank', False)],
          'bannerne': [('banner', True)],
          'bannernes': [('banner', True)],
          'banners': [('banner', True)],
          'banten': [('bant', False)],
          'bantens': [('bant', False)],
          'banterne': [('bant', False)],
          'banternes': [('bant', False)],
          'banters': [('bant', False)],
          'bants': [('bant', False)],
          'bantus': [('bantu', True)],
          'barber': [('barbe', True), ('barber', True)],
          'barberne': [('barbe', True)],
          'barbernes': [('barbe', True)],
          'barbers': [('barbe', True), ('barber', True)],
          'barden': [('barde', True)],
          'bardens': [('barde', True)],
          'barder': [('barde', True)],
          'barderne': [('barde', True)],
          'bardernes': [('barde', True)],
          'barders': [('barde', True)],
          'bardinerne': [('bardine', False)],
          'bardiners': [('bardine', False)],
          'barerne': [('bar', False)],
          'barers': [('bar', False)],
          'baret': [('baret', True)],
          'barets': [('baret', False)],
          'barier': [('barium', False)],
          'bariers': [('barium', False)],
          'bariet': [('barium', False)],
          'baris': [('bari', False)],
          'barker': [('bark', True)],
          'barme': [('barm', True)],
          'barmens': [('barm', True)],
          'barren': [('barre', False)],
          'barrernes': [('barre', True)],
          'barrers': [('barre', True)],
          'barres': [('barre', True)],
          'barrieren': [('barriere', True)],
          'barrierens': [('barriere', False)],
          'bars': [('bars', True), ('bar', True)],
          "bars'": [('bars', True)],
          'barsen': [('bars', True)],
          'barsens': [('bars', True)],
          'barser': [('bars', True)],
          'barserne': [('bars', True)],
          'barsernes': [('bars', True)],
          'barsers': [('bars', True)],
          'barten': [('bart', False)],
          'barterne': [('bart', False)],
          'bas': [('bas', True)],
          'base': [('base', True)],
          'basen': [('base', True), ('basis', True)],
          'basens': [('basis', True), ('base', True)],
          'baser': [('basis', True), ('base', True)],
          'baserne': [('base', True), ('basis', True)],
          'basernes': [('base', True), ('basis', True)],
          'basers': [('base', True), ('basis', True)],
          'bases': [('base', False)],
          'basken': [('bask', False)],
          'baskens': [('bask', False)],
          'basker': [('basker', True)],
          'baskerne': [('basker', True)],
          'baskernes': [('basker', True)],
          'baskers': [('basker', True)],
          'basket': [('basket', True), ('bask', True)],
          'baskets': [('bask', True), ('basket', True)],
          'bassen': [('basse', True), ('bas', True)],
          'bassens': [('basse', True), ('bas', True)],
          'basser': [('bas', True), ('basse', True)],
          'basserne': [('bas', True), ('basse', True)],
          'bassernes': [('bas', True), ('basse', True)],
          'bassers': [('bas', True), ('basse', True)],
          'basset': [('basset', True)],
          'bassets': [('basset', True)],
          'bassetter': [('basset', True)],
          'basten': [('bast', False)],
          'bastens': [('bast', True)],
          'baternes': [('bat', False)],
          'batier': [('batier', False)],
          'batierne': [('batier', False)],
          'batiernes': [('batier', False)],
          'batiers': [('batier', False)],
          'batten': [('bat', False)],
          'battens': [('bat', False)],
          'batternes': [('bat', False)],
          'batters': [('bat', False)],
          'bavne': [('bavn', True)],
          'bavnen': [('bavn', True)],
          'bavnens': [('bavn', True)],
          'bavner': [('bavn', True)],
          'bavnerne': [('bavn', True)],
          'bavnernes': [('bavn', True)],
          'bavners': [('bavn', True)],
          'bavnes': [('bavn', True)],
          'bbanken': [('bbank', False)],
          'bbankens': [('bbank', False)],
          'bbanker': [('bbank', False)],
          'bbankerne': [('bbank', False)],
          'bbankernes': [('bbank', False)],
          'bbankers': [('bbank', False)],
          'bbeden': [('bbed', False)],
          'bbedens': [('bbed', False)],
          'bbeder': [('bbed', False)],
          'bbederne': [('bbed', False)],
          'bbedernes': [('bbed', False)],
          'bbeders': [('bbed', False)],
          'bben': [('bbe', False)],
          'bbens': [('b', False)],
          'bberas': [('bberas', False)],
          'bberet': [('bber', False)],
          'bberets': [('bber', False)],
          'bberiers': [('bberi', False)],
          'bberne': [('bbe', False)],
          'bbet': [('b', False)],
          'bbets': [('b', False)],
          'bbiner': [('bbiner', False)],
          'bbinernes': [('bbiner', False)],
          'bbinger': [('bbing', False)],
          'bbingers': [('bbing', False)],
          'bble': [('bble', False)],
          'bbles': [('bble', False)],
          'bboners': [('bbon', False)],
          'bcyklen': [('bcykel', False)],
          'bcyklens': [('bcykel', False)],
          'bcykler': [('bcykel', False)],
          'bcyklerne': [('bcykel', False)],
          'bcyklernes': [('bcykel', False)],
          'bcyklers': [('bcykel', False)],
          'bdas': [('bda', False)],
          'bder': [('bde', False)],
          'bderne': [('bde', False)],
          'bdernes': [('bde', False)],
          'bdes': [('bde', False)],
          'be': [('be', False)],
          'bearbejdernes': [('bearbejder', False)],
          'bearbejders': [('bearbejder', False)],
          'bearen': [('bear', False)],
          'bearens': [('bear', False)],
          'bebens': [('beben', False)],
          'beboer': [('beboer', True)],
          'beboerne': [('beboer', True)],
          'beboernes': [('beboer', True)],
          'beboers': [('beboer', True)],
          'becker': [('becker', False)],
          'beckernes': [('becker', False)],
          'becuen': [('becue', False)],
          'bedagens': [('bedag', False)],
          'bede': [('bed', True), ('bede', True)],
          'beden': [('bede', False)],
          'bedens': [('bede', True)],
          'beder': [('bede', False)],
          'bederne': [('bede', False)],
          'bedernes': [('bede', False)],
          'beders': [('bede', False)],
          'bedes': [('bed', True), ('bede', True)],
          'bedet': [('bed', True)],
          'bedets': [('bed', True)],
          'bedier': [('bedi', False)],
          'bedierne': [('bedi', False)],
          'bediernes': [('bedi', False)],
          'bediers': [('bedi', False)],
          'bediet': [('bedi', False)],
          'bediets': [('bedi', False)],
          'bedis': [('bedi', False)],
          'bedsteforældre': [('bedsteforældre', True), ('bedsteforælder', True)],
          'bedsteforældres': [('bedsteforælder', True), ('bedsteforældre', True)],
          'bedømmer': [('bedømmer', True)],
          'bedømmerne': [('bedømmer', True)],
          'been': [('be', False)],
          'beens': [('be', False)],
          'beer': [('be', False)],
          'beerne': [('be', False)],
          'beernes': [('be', False)],
          'beers': [('be', False)],
          'behandlerne': [('behandler', True)],
          'behandlernes': [('behandler', True)],
          'beis': [('bei', False)],
          'bejerne': [('bejer', False)],
          'bejler': [('bejler', False)],
          'bejlers': [('bejler', True)],
          'bejs': [('bejs', False)],
          'bejsen': [('bejs', False)],
          'bejsens': [('bejs', False)],
          'bejser': [('bejs', False)],
          'bejserne': [('bejs', False)],
          'bejsernes': [('bejs', False)],
          'bejsers': [('bejs', False)],
          'bekender': [('bekender', True)],
          'bekenders': [('bekender', True)],
          'beker': [('beker', False)],
          'bekerne': [('beker', False)],
          'bekernes': [('beker', False)],
          'bekers': [('beker', False)],
          'bekrans': [('bekran', False)],
          'beladernes': [('belader', False)],
          'beladers': [('belader', False)],
          'beler': [('beler', False)],
          'belerne': [('bel', False)],
          'belers': [('beler', False)],
          'belets': [('bel', False)],
          'belier': [('belie', False)],
          'belierne': [('belie', False)],
          'beliers': [('belie', False)],
          'beliner': [('belin', False)],
          'belinernes': [('belin', False)],
          'beliners': [('belin', False)],
          'belle': [('belle', False)],
          'bellen': [('bel', False)],
          'bellens': [('belle', False)],
          'beller': [('bel', False)],
          'bellerne': [('belle', False)],
          'bellernes': [('belle', False)],
          'bellers': [('bel', False)],
          'belles': [('belle', False)],
          'bellis': [('bellis', True)],
          'belsers': [('belse', False)],
          'bemanden': [('bemand', False)],
          'bemandens': [('bemand', False)],
          'bemærker': [('bemærke', False)],
          'ben': [('ben', True)],
          'benden': [('bend', False)],
          'bendens': [('bend', False)],
          'bender': [('bend', False)],
          'benderne': [('bende', False)],
          'bendernes': [('bend', False)],
          'benders': [('bend', False)],
          'bene': [('', False)],
          'benen': [('ben', False)],
          'benens': [('ben', False)],
          'benerne': [('ben', False)],
          'benernes': [('ben', False)],
          'benes': [('', False)],
          'benet': [('ben', True)],
          'benets': [('ben', True)],
          'bens': [('ben', False)],
          'benten': [('bent', False)],
          'bentens': [('bent', False)],
          'benter': [('bent', False)],
          'benterne': [('bent', False)],
          'benternes': [('bent', False)],
          'benters': [('bent', False)],
          'beposen': [('bepose', False)],
          'beposens': [('bepose', False)],
          'beposer': [('bepose', False)],
          'beposerne': [('bepose', False)],
          'beposernes': [('bepose', False)],
          'bera': [('bera', False)],
          'beraene': [('bera', False)],
          'beraenes': [('bera', False)],
          'beraks': [('berak', False)],
          'beras': [('bera', False)],
          'bereder': [('bereder', False)],
          'berederne': [('bereder', False)],
          'bereders': [('bereder', False)],
          'berenser': [('berenser', False)],
          'berenserne': [('berenser', False)],
          'berer': [('berer', False)],
          'bererne': [('berer', False)],
          'berernes': [('berer', False)],
          'berers': [('berer', False)],
          'beret': [('beret', True)],
          'berets': [('beret', False)],
          'beretten': [('beret', True)],
          'berettens': [('beret', False)],
          'beretter': [('beretter', True), ('beret', True)],
          'beretterne': [('beret', True), ('beretter', True)],
          'beretternes': [('beretter', True), ('beret', True)],
          'beretters': [('beret', True), ('beretter', True)],
          'bergamotten': [('bergamotte', True), ('bergamot', True)],
          'bergamottens': [('bergamotte', True), ('bergamot', True)],
          'bergamotter': [('bergamot', True), ('bergamotte', True)],
          'bergamotterne': [('bergamot', True), ('bergamotte', True)],
          'bergamotternes': [('bergamotte', True), ('bergamot', True)],
          'bergamotters': [('bergamotte', True), ('bergamot', True)],
          'bergenser': [('bergenser', True)],
          'bergensernes': [('bergenser', True)],
          'berger': [('berg', False)],
          'bergerne': [('berger', False)],
          'bergernes': [('berg', False)],
          'bergers': [('berg', False)],
          'berggylten': [('berggylt', True), ('berggylte', True)],
          'berggyltens': [('berggylt', True), ('berggylte', True)],
          'berggylter': [('berggylt', True), ('berggylte', True)],
          'berggylterne': [('berggylt', True), ('berggylte', True)],
          'berggylternes': [('berggylt', True), ('berggylte', True)],
          'berggylters': [('berggylt', True), ('berggylte', True)],
          'berianerne': [('berianer', False)],
          'berianernes': [('berianer', False)],
          'berien': [('beri', False)],
          'beriens': [('beri', False)],
          'berier': [('beri', False)],
          'berierne': [('beri', False)],
          'beriernes': [('beri', False)],
          'beriet': [('beri', False)],
          'beriets': [('beri', False)],
          'beris': [('beri', False)],
          'beroen': [('bero', False)],
          'beroens': [('bero', False)],
          'beros': [('bero', False)],
          'berpen': [('berpen', False)],
          'berpens': [('berpen', False)],
          'bers': [('be', False)],
          'bersten': [('bersten', False)],
          'berstens': [('berst', False)],
          'berten': [('bert', False)],
          'bertens': [('bert', False)],
          'berter': [('bert', False)],
          'berterne': [('bert', False)],
          'berters': [('bert', False)],
          'bertet': [('bertet', False)],
          'berts': [('bert', False)],
          'berusser': [('berus', False)],
          'berussernes': [('berus', False)],
          'bes': [('be', False)],
          "bes'": [('be', False)],
          'beskeder': [('besked', False)],
          'beskederne': [('besked', False)],
          'beskedernes': [('besked', False)],
          'beskeders': [('besked', False)],
          'besken': [('besk', False)],
          'besker': [('besk', False)],
          'beskerne': [('besk', False)],
          'beskers': [('besk', False)],
          'beskytter': [('beskytter', False)],
          'beskytterne': [('beskytter', False)],
          'beskøjter': [('beskøjt', True)],
          'beskøjterne': [('beskøjt', True)],
          'beskøjternes': [('beskøjt', True)],
          'bessiner': [('bessiner', False)],
          'bessinerne': [('bessiner', False)],
          'bessiners': [('bessiner', False)],
          'besten': [('best', False)],
          'bestene': [('besten', False)],
          'bestens': [('besten', False)],
          'bestierne': [('bestie', True)],
          'bestiers': [('bestie', True)],
          'bestiet': [('bestie', True)],
          'bestiets': [('bestie', True)],
          'bestiger': [('bestiger', False)],
          'bestyrer': [('bestyrer', False)],
          'bestyrerne': [('bestyrer', False)],
          'bestyrernes': [('bestyrer', False)],
          'bet': [('bet', True)],
          'betalerne': [('betaler', True)],
          'betalernes': [('betaler', True)],
          'betaner': [('betaner', False)],
          'betaners': [('betaner', False)],
          'beter': [('bet', False)],
          'beters': [('bet', False)],
          'betiden': [('betid', False)],
          'betler': [('betler', True), ('betel', True)],
          'betlerne': [('betel', True), ('betler', True)],
          'betlernes': [('betel', True), ('betler', True)],
          'betlers': [('betel', True), ('betler', True)],
          'bets': [('bet', False)],
          'betøjet': [('betøjet', False)],
          'bevisernes': [('bevis', False)],
          'bevisers': [('bevis', False)],
          'beværternes': [('beværter', True)],
          'beøjne': [('beøje', False)],
          'beøjnene': [('beøje', False)],
          'beøjnenes': [('beøje', False)],
          'beøjnes': [('beøje', False)],
          'bh': [('bh', False)],
          "bh'ernes": [('bh', True)],
          "bh'ers": [('bh', False)],
          'bhals': [('bhals', False)],
          'bhaver': [('bhaver', False)],
          'bhaverne': [('bhaver', False)],
          'bhavernes': [('bhaver', False)],
          'bhavers': [('bhaver', False)],
          'bhus': [('bhus', False)],
          'bi': [('bi', False)],
          'bialer': [('bial', False)],
          'bialerne': [('bial', False)],
          'bialernes': [('bial', False)],
          'bialers': [('bial', False)],
          'bialet': [('bial', False)],
          'bialets': [('bial', False)],
          'bianerne': [('bianer', False)],
          'bianernes': [('bianer', False)],
          'bias': [('bias', True)],
          'bidden': [('bid', False)],
          'biddens': [('bid', False)],
          'bidder': [('bid', False)],
          'bidderne': [('bid', True)],
          'biddernes': [('bid', False)],
          'bidders': [('bid', True)],
          'bidens': [('bid', False)],
          'bider': [('bider', False)],
          'biderne': [('bider', False)],
          'bidernes': [('bider', False)],
          'biders': [('bider', False)],
          'bidet': [('bidet', True)],
          'bidets': [('bidet', True)],
          'bien': [('bi', False)],
          'biene': [('bi', False)],
          'bienes': [('bi', False)],
          'biens': [('bi', False)],
          'bier': [('bi', False)],
          'biere': [('bier', False)],
          'bieren': [('bier', False)],
          'bierens': [('bier', False)],
          'bieres': [('bier', False)],
          'bierne': [('bi', False)],
          'biernes': [('bi', False)],
          'biers': [('bi', False)],
          'bies': [('bies', False)],
          "bies'": [('bies', False)],
          'biet': [('bi', False)],
          'biets': [('bi', True)],
          'bigten': [('bigt', False)],
          'bigtens': [('bigt', False)],
          'biken': [('bike', False)],
          'bikens': [('bike', False)],
          'bikke': [('bik', False)],
          'bikken': [('bik', False)],
          'bikkerne': [('bik', False)],
          'bikkes': [('bik', False)],
          'biks': [('biks', True)],
          "biks'": [('biks', True)],
          'bikse': [('biks', True)],
          'biksen': [('biks', True)],
          'biksens': [('biks', True)],
          'bikserne': [('biks', True)],
          'biksernes': [('biks', True)],
          'biksers': [('biks', True)],
          'bikses': [('biks', True)],
          'bile': [('bile', False)],
          'bilen': [('bil', True)],
          'bilens': [('bil', True)],
          'biler': [('bil', False)],
          'bilerne': [('bil', True)],
          'bilernes': [('bil', True)],
          'bilers': [('bil', True)],
          'biles': [('bile', False)],
          'bilets': [('bil', False)],
          'bilierne': [('bil', False)],
          'biliernes': [('bil', False)],
          'bilisten': [('bilist', False)],
          'bilistens': [('bilist', False)],
          'bilister': [('bilist', False)],
          'bilisterne': [('bilist', False)],
          'bilken': [('bilken', False)],
          'bilkens': [('bilken', False)],
          'billens': [('bille', False)],
          'biller': [('bille', False)],
          'billerne': [('bille', False)],
          'billernes': [('bille', False)],
          'billers': [('bille', False)],
          'billet': [('billet', False)],
          'billets': [('billet', False)],
          'billetten': [('billet', False)],
          'billetter': [('billet', False)],
          'billetterne': [('billet', False)],
          'billetternes': [('billet', False)],
          'bilæer': [('bilæum', False)],
          'bilæerne': [('bilæum', False)],
          'bilæernes': [('bilæum', False)],
          'bindet': [('bind', False)],
          'bindets': [('bind', False)],
          'bine': [('bine', False)],
          'binen': [('bine', False)],
          'binens': [('bine', False)],
          'binerne': [('biner', False)],
          'binernes': [('bine', False)],
          'biners': [('biner', False)],
          'bines': [('bine', False)],
          'binet': [('binet', False)],
          'binets': [('binet', False)],
          'binetten': [('binet', False)],
          'binettens': [('binet', False)],
          'binetter': [('binet', False)],
          'binetterne': [('binet', False)],
          'binetternes': [('binet', False)],
          'binetters': [('binet', False)],
          'bingen': [('bing', False)],
          'bingens': [('bing', False)],
          'bingenser': [('bingenser', False)],
          'bingensernes': [('bingenser', False)],
          'binger': [('binger', False)],
          'bingerne': [('bing', False)],
          'bingernes': [('bing', False)],
          'bingers': [('binger', False)],
          'bings': [('bing', False)],
          'binierne': [('binie', False)],
          'biniernes': [('binie', False)],
          'biniers': [('binie', False)],
          'biplanet': [('biplanet', True), ('biplan', True)],
          'biplanets': [('biplan', True), ('biplanet', True)],
          'bipper': [('bipper', True)],
          'bipperne': [('bipper', True)],
          'birke': [('birk', True)],
          'birken': [('birk', True)],
          'birker': [('birk', True)],
          'birkerne': [('birk', True)],
          'birkernes': [('birk', True)],
          'birkers': [('birk', True)],
          'birkes': [('birkes', True), ('birk', True)],
          'birket': [('birk', True)],
          'birkets': [('birk', True)],
          'bis': [('bi', True)],
          'bise': [('bise', True)],
          'bisen': [('bise', True)],
          'bisens': [('bise', True)],
          'biser': [('bise', True)],
          'biserne': [('bise', True)],
          'bisernes': [('bise', True)],
          'bisers': [('bise', True)],
          'bises': [('bise', True)],
          'bisken': [('bisken', False)],
          'biskens': [('bisken', False)],
          'bismen': [('bisme', False)],
          'bismens': [('bisme', False)],
          'bismer': [('bismer', True)],
          'bismerne': [('bismer', True)],
          'bismernes': [('bismer', True)],
          'bismers': [('bismer', True)],
          'bisolens': [('bisol', True)],
          'bissen': [('bisse', True)],
          'bissens': [('bisse', True)],
          'bisser': [('bisse', True), ('bisser', True)],
          'bisserne': [('bisser', True), ('bisse', True)],
          'bissernes': [('bisse', True), ('bisser', True)],
          'bissers': [('bisse', True), ('bisser', True)],
          'bisten': [('bist', False)],
          'bistens': [('bist', False)],
          'bister': [('bist', False)],
          'bisterne': [('bist', False)],
          'bisternes': [('bist', False)],
          'bisters': [('bist', False)],
          'bits': [('bit', True)],
          "bits'": [('bit', True)],
          'bitsen': [('bits', False)],
          'bitsens': [('bits', False)],
          'bitser': [('bits', False)],
          'bitserne': [('bits', False)],
          'bitsernes': [('bits', False)],
          'bitsers': [('bits', False)],
          'bitten': [('bit', False)],
          'bittens': [('bit', False)],
          'bitter': [('bitter', True)],
          'bitterne': [('bitter', True)],
          'bitternes': [('bitter', True)],
          'bitters': [('bitter', True)],
          'bivalens': [('bivalens', False)],
          'blade': [('blad', False)],
          'bladen': [('blad', False)],
          'bladens': [('blad', False)],
          'blades': [('blad', False)],
          'blads': [('blad', False)],
          'blaffer': [('blaffer', True)],
          'blafferne': [('blaffer', True)],
          'blaffernes': [('blaffer', True)],
          'blaffers': [('blaffer', True)],
          'blanderne': [('blander', False)],
          'blandernes': [('blander', False)],
          'blanders': [('blander', True)],
          'blanter': [('blant', False)],
          'blanterne': [('blant', False)],
          'blanternes': [('blant', False)],
          'blanters': [('blant', False)],
          'blas': [('bla', False)],
          'blasen': [('blase', True)],
          'blasens': [('blase', True)],
          'blaser': [('blase', True)],
          'blaserne': [('blase', True)],
          'blasernes': [('blase', True)],
          'blasers': [('blase', True)],
          'blaster': [('blaster', False)],
          'blasterne': [('blaster', False)],
          'blasternes': [('blaster', False)],
          'blasters': [('blaster', False)],
          'blatens': [('blat', False)],
          'blats': [('blat', False)],
          'ble': [('ble', True)],
          'blen': [('bel', False)],
          'blene': [('bel', False)],
          'blenes': [('bel', False)],
          'blere': [('bler', False)],
          'bleren': [('bler', False)],
          'blerens': [('bler', False)],
          'bleres': [('bler', False)],
          'blerne': [('bel', False)],
          'blernes': [('bel', False)],
          'blers': [('bel', False)],
          'bles': [('ble', True)],
          'blet': [('ble', False)],
          'bletonen': [('bleton', False)],
          'bletonens': [('bleton', False)],
          'bletoner': [('bleton', False)],
          'bletonerne': [('bleton', False)],
          'bletonernes': [('bleton', False)],
          'bletoners': [('bleton', False)],
          'blets': [('ble', False)],
          'bletten': [('blet', False)],
          'blettens': [('blet', False)],
          'bletter': [('blet', False)],
          'bletterne': [('blet', False)],
          'bletternes': [('blet', False)],
          'bletters': [('blet', False)],
          'blidens': [('blide', True)],
          'blider': [('blide', True)],
          'bliderne': [('blide', True)],
          'blidernes': [('blide', True)],
          'bliders': [('blide', True)],
          'blikanerne': [('blikaner', False)],
          'blikanernes': [('blikaner', False)],
          'blikker': [('blik', False)],
          'blikkernes': [('blik', False)],
          'blikkers': [('blik', False)],
          'blinde': [('blinde', True)],
          'blingers': [('bling', False)],
          'blinien': [('blini', True)],
          'blinkens': [('blink', True)],
          'blis': [('blis', False)],
          'blisen': [('blis', False)],
          'blisens': [('blis', False)],
          'bliser': [('blis', False)],
          'bliserne': [('blis', False)],
          'blisernes': [('blis', False)],
          'blisers': [('blis', False)],
          'blisten': [('blist', True)],
          'blistens': [('blist', True)],
          'blister': [('blist', True)],
          'blisterne': [('blist', True)],
          'blisternes': [('blist', True)],
          'blisters': [('blist', True)],
          'blods': [('blod', False)],
          'blogger': [('blogger', True)],
          'bloggerne': [('blogger', True)],
          'bloggernes': [('blogger', True)],
          'bloggers': [('blogger', True)],
          'blokkens': [('blok', True)],
          'blokker': [('blokker', False)],
          'blokkerne': [('blokker', False)],
          'blokkernes': [('blokker', False)],
          'blokkers': [('blokker', False)],
          'bloks': [('blok', False)],
          'blomme': [('blomme', False)],
          'blommen': [('blomme', False)],
          'blommens': [('blomme', False)],
          'blommer': [('blomme', False)],
          'blommerne': [('blomme', False)],
          'blommernes': [('blomme', False)],
          'blommers': [('blomme', True)],
          'blommes': [('blomme', False)],
          'blomsterhandler': [('blomsterhandel', True), ('blomsterhandler', True)],
          'blomsterhandlerne': [('blomsterhandel', True), ('blomsterhandler', True)],
          'blomsterhandlernes': [('blomsterhandler', True), ('blomsterhandel', True)],
          'blomsterhandlers': [('blomsterhandel', True), ('blomsterhandler', True)],
          'blotter': [('blotter', True)],
          'blotterne': [('blotter', True)],
          'blotternes': [('blotter', True)],
          'blotters': [('blotter', True)],
          'bluen': [('blu', False)],
          'bluens': [('blu', False)],
          'blues': [('blues', True)],
          'bluffer': [('bluffer', True)],
          'blufferne': [('bluffer', True)],
          'bluffernes': [('bluffer', True)],
          'bluffers': [('bluffer', True)],
          'blus': [('blu', True), ('blus', True)],
          'blusen': [('bluse', False)],
          'blusens': [('bluse', False)],
          'blys': [('bly', True)],
          'blås': [('blå', True)],
          'blænden': [('blænde', False)],
          'blændens': [('blænde', False)],
          'blænder': [('blænde', True)],
          'blændere': [('blænde', False)],
          'blænderen': [('blænde', False)],
          'blænderens': [('blænde', True)],
          'blænderes': [('blænde', False)],
          'blænderne': [('blænde', False)],
          'blændernes': [('blænde', False)],
          'blænders': [('blænde', True)],
          'blærer': [('blære', False)],
          'blærerne': [('blære', False)],
          'blærernes': [('blære', False)],
          'blærers': [('blære', False)],
          'blæser': [('blæser', False)],
          'blæserne': [('blæser', False)],
          'blæsernes': [('blæser', True)],
          'bløden': [('bløde', True)],
          'blødens': [('bløde', True)],
          'bløder': [('bløder', True), ('bløde', True)],
          'bløderne': [('bløder', True), ('bløde', True)],
          'blødernes': [('bløde', True), ('bløder', True)],
          'bløders': [('bløder', True), ('bløde', True)],
          'bmarker': [('bmark', False)],
          'bmarkerne': [('bmark', False)],
          'bmarkernes': [('bmark', False)],
          'bmarkers': [('bmark', False)],
          'bmaster': [('bmaster', False)],
          'bmasterne': [('bmaster', False)],
          'bmasternes': [('bmaster', False)],
          'bmasters': [('bmaster', False)],
          'bmænd': [('bmand', False)],
          'bmændene': [('bmand', False)],
          'bmændenes': [('bmand', False)],
          'bmænds': [('bmand', False)],
          'bmøller': [('bmølle', False)],
          'bmøllerne': [('bmølle', False)],
          'bmøllernes': [('bmølle', False)],
          'bmøllers': [('bmølle', False)],
          'bnene': [('ben', False)],
          'bnet': [('ben', False)],
          'bnets': [('ben', False)],
          'bningers': [('bning', False)],
          'bo': [('bo', False)],
          'bobinernes': [('bobine', True)],
          'bobinet': [('bobinet', True)],
          'bobinets': [('bobinet', True)],
          'boblens': [('boble', False)],
          'bobler': [('boble', True)],
          'bobs': [('bob', True)],
          'boden': [('bod', False)],
          'bodens': [('bod', False)],
          'boder': [('bod', True)],
          'boderne': [('bod', True)],
          'bodernes': [('bod', False)],
          'boders': [('bod', False)],
          'boen': [('bo', False)],
          'boens': [('bo', False)],
          'boer': [('boer', True), ('bo', True)],
          'boerne': [('boer', True), ('bo', True)],
          'boernes': [('boer', True), ('bo', True)],
          'boers': [('boer', True), ('bo', True)],
          'boet': [('bo', False)],
          'boets': [('bo', False)],
          'bogen': [('bog', True)],
          'boghandler': [('boghandel', True), ('boghandler', True)],
          'boghandlerne': [('boghandler', True), ('boghandel', True)],
          'boghandlernes': [('boghandler', True), ('boghandel', True)],
          'boghandlers': [('boghandler', True), ('boghandel', True)],
          'bogiens': [('bogie', True)],
          'bohaver': [('bohave', True)],
          'bohaverne': [('bohave', True)],
          'bohavernes': [('bohave', True)],
          'bohavers': [('bohave', True)],
          'bojanernes': [('bojan', True)],
          'boks': [('boks', False)],
          "boks'": [('boks', False)],
          'bokse': [('boks', False)],
          'boksen': [('boks', False)],
          'boksens': [('boks', True)],
          'bokser': [('bokser', True)],
          'bokserne': [('bokser', True)],
          'boksernes': [('bokser', True)],
          'boksers': [('bokser', True)],
          'bokses': [('boks', False)],
          'bolader': [('bolader', False)],
          'boladernes': [('bolader', False)],
          'boladers': [('bolader', False)],
          'bolde': [('bold', False)],
          'bolden': [('bold', False)],
          'boldene': [('bold', False)],
          'boldenes': [('bold', False)],
          'boldens': [('bold', False)],
          'boldes': [('bold', False)],
          'bole': [('bole', False)],
          'boler': [('bol', False)],
          'bolerne': [('bol', False)],
          'boles': [('bole', False)],
          'bolet': [('bolet', False)],
          'bolets': [('bolet', False)],
          'bollens': [('bolle', False)],
          'bollerne': [('bolle', False)],
          'bollernes': [('bolle', False)],
          'bollers': [('bolle', False)],
          'bolte': [('bolt', False)],
          'bolten': [('bolt', False)],
          'boltens': [('bolt', False)],
          'boltes': [('bolt', False)],
          'bomber': [('bomber', True), ('bombe', True)],
          'bomberne': [('bomber', True), ('bombe', True)],
          'bombernes': [('bomber', True), ('bombe', True)],
          'bombers': [('bombe', True), ('bomber', True)],
          'bomme': [('bom', False)],
          'bommen': [('bom', True)],
          'bommens': [('bom', False)],
          'bommes': [('bom', False)],
          'bonaternes': [('bonat', False)],
          'bonden': [('bonde', True)],
          'bondens': [('bonde', True)],
          'bonder': [('bond', False)],
          'bonderne': [('bond', False)],
          'bondernes': [('bond', False)],
          'bonders': [('bond', False)],
          'bonds': [('bond', False)],
          'bonen': [('bon', True)],
          'bonens': [('bon', True)],
          'boner': [('bon', True)],
          'bonerne': [('bon', True)],
          'bonernes': [('bon', True)],
          'boners': [('bon', True)],
          'bonnet': [('bon', False)],
          'bonnets': [('bon', False)],
          'boppen': [('bop', False)],
          'boppens': [('bop', False)],
          'bopper': [('bopper', False)],
          'boppernes': [('bopper', False)],
          'boppers': [('bopper', False)],
          'borde': [('bord', False)],
          'bordes': [('bord', False)],
          'borer': [('borer', False)],
          'borerne': [('borer', False)],
          'borernes': [('borer', False)],
          'borers': [('borer', False)],
          'boret': [('bor', True)],
          'borets': [('bor', True)],
          'borgen': [('borgen', True), ('borg', True)],
          'borgens': [('borgen', True), ('borg', True)],
          'borger': [('borger', True)],
          'borgerne': [('borger', True)],
          'borgernes': [('borger', True)],
          'borgers': [('borger', True)],
          'borges': [('borg', False)],
          'borren': [('borre', False)],
          'borten': [('bort', False)],
          'bortens': [('bort', True)],
          'borter': [('bort', False)],
          'borterne': [('bort', True)],
          'borters': [('bort', False)],
          'borts': [('bort', True)],
          'bos': [('bo', False)],
          "bos'": [('bo', False)],
          'bosen': [('bose', False)],
          'bosens': [('bose', False)],
          'boser': [('bose', False)],
          'boserne': [('bose', False)],
          'bosernes': [('bose', False)],
          'bosers': [('bose', False)],
          'bossen': [('boss', False)],
          'bosser': [('boss', True)],
          'bosserne': [('boss', False)],
          'bossernes': [('boss', True)],
          'bossers': [('boss', True)],
          'botten': [('bot', False)],
          'bottens': [('bot', False)],
          'botter': [('bot', False)],
          'botterne': [('bot', False)],
          'botternes': [('bot', False)],
          'botters': [('bot', False)],
          'bours': [('bours', False)],
          'bowler': [('bowler', True), ('bowle', True)],
          'bowlerne': [('bowle', True), ('bowler', True)],
          'bowlernes': [('bowle', True), ('bowler', True)],
          'bowlers': [('bowler', True), ('bowle', True)],
          'boxer': [('boxer', True)],
          'boxerne': [('boxer', True)],
          'boxernes': [('boxer', True)],
          'boxers': [('boxer', True)],
          'boyens': [('boy', False)],
          'boykotter': [('boykot', True), ('boykotter', True)],
          'boykotterne': [('boykotter', True), ('boykot', True)],
          'boykotternes': [('boykotter', True), ('boykot', True)],
          'boykotters': [('boykot', True), ('boykotter', True)],
          'braden': [('brad', False)],
          'bradens': [('brad', False)],
          'braderne': [('brad', False)],
          'braders': [('brad', False)],
          'brakkens': [('brak', True)],
          'branchen': [('branche', False)],
          'branchens': [('branche', True)],
          'brancher': [('branche', True)],
          'brancherne': [('branche', True)],
          'branchernes': [('branche', True)],
          'branchers': [('branche', True)],
          'branderne': [('brander', True)],
          'brandernes': [('brander', True)],
          'branders': [('brander', True)],
          'branen': [('bran', False)],
          'braner': [('bran', False)],
          'braners': [('bran', False)],
          'bras': [('bras', True)],
          'brasen': [('bras', True), ('brasen', True)],
          'brasens': [('brasen', True), ('bras', True)],
          'braser': [('bras', True)],
          'braserne': [('bras', True)],
          'brasernes': [('bras', True)],
          'brasers': [('bras', True)],
          'bre': [('ber', False)],
          'bredden': [('bredde', True), ('bred', True)],
          'breddens': [('bredde', True), ('bred', True)],
          'bredder': [('bredde', True), ('bred', True)],
          'bredderne': [('bredde', True), ('bred', True)],
          'breddernes': [('bredde', True), ('bred', True)],
          'bredders': [('bredde', True), ('bred', True)],
          'breden': [('bred', False)],
          'bredens': [('bred', False)],
          'breder': [('breder', False)],
          'brederne': [('breder', False)],
          'bredernes': [('breder', False)],
          'breders': [('breder', False)],
          'breds': [('bred', False)],
          'bregnen': [('bregne', False)],
          'bregnens': [('bregne', False)],
          'bregner': [('bregne', True)],
          'bregnernes': [('bregne', True)],
          'bremser': [('bremse', False)],
          'bremserne': [('bremse', False)],
          'bremsernes': [('bremse', False)],
          'bremsers': [('bremse', True)],
          'bren': [('bre', False)],
          'brens': [('bre', False)],
          'brer': [('brer', False)],
          'brerne': [('brer', False)],
          'brernes': [('brer', False)],
          'bres': [('bre', False)],
          'bretten': [('brette', False)],
          'brettens': [('brette', False)],
          'bretter': [('brette', False)],
          'bretterne': [('brette', False)],
          'bretternes': [('brette', False)],
          'bretters': [('brette', False)],
          'breve': [('brev', False)],
          'breves': [('brev', False)],
          'brianders': [('briand', False)],
          'brianerne': [('brian', False)],
          'brianernes': [('brian', False)],
          'bricen': [('bric', False)],
          'bricens': [('bric', False)],
          'briden': [('brid', False)],
          'bridens': [('brid', False)],
          'brider': [('brid', False)],
          'briderne': [('brid', False)],
          'bridernes': [('brid', False)],
          'briders': [('brid', False)],
          'brids': [('brid', False)],
          'brien': [('brie', True)],
          'briens': [('brie', True)],
          'brier': [('brie', True)],
          'brierne': [('brie', True)],
          'briernes': [('brie', True)],
          'briers': [('brie', True)],
          'bries': [('brie', True)],
          'brigader': [('brigade', True), ('brigader', True)],
          'brigaders': [('brigader', True), ('brigade', True)],
          'brigger': [('brig', True)],
          'briggerne': [('brig', True)],
          'briggernes': [('brig', True)],
          'briggers': [('brig', True)],
          'brikkens': [('brik', False)],
          'brikker': [('brik', False)],
          'brikkernes': [('brik', False)],
          'brikkers': [('brik', False)],
          'briks': [('briks', True), ('brik', True)],
          'brille': [('briller', False)],
          'brillen': [('briller', False)],
          'brillens': [('briller', False)],
          'briller': [('briller', False)],
          'brillerne': [('briller', False)],
          'brillernes': [('briller', False)],
          'brillers': [('briller', False)],
          'brilles': [('briller', False)],
          'bringe': [('bringe', True)],
          'bringen': [('bringe', True)],
          'bringens': [('bringe', True)],
          'bringer': [('bringe', True)],
          'bringerne': [('bringe', True)],
          'bringernes': [('bringe', True)],
          'bringers': [('bringe', True)],
          'bringes': [('bringe', True)],
          'brinten': [('brint', True)],
          'brintens': [('brint', True)],
          'brinter': [('brinte', False)],
          'brinterne': [('brinte', False)],
          'brinternes': [('brinte', False)],
          'brinters': [('brinte', False)],
          'briolet': [('briolet', False)],
          'briolets': [('briolet', False)],
          'bris': [('bris', False)],
          'brisen': [('brise', True)],
          'brisens': [('brise', True)],
          'briserne': [('brise', False)],
          'brisers': [('brise', True)],
          'brissers': [('bris', False)],
          'brister': [('brist', False)],
          'bristerne': [('brist', False)],
          'bristernes': [('brist', False)],
          'bristers': [('brist', False)],
          'briten': [('brite', True)],
          'britens': [('brite', True)],
          'briter': [('brite', True)],
          'briterne': [('brite', True)],
          'briternes': [('brite', True)],
          'briters': [('brite', True)],
          'brium': [('brium', False)],
          'briums': [('brium', False)],
          'brodde': [('brodde', True), ('brod', True)],
          'brodden': [('brodde', True), ('brod', True)],
          'broddens': [('brodde', True), ('brod', True)],
          'broddes': [('brodde', True), ('brod', True)],
          'broder': [('bror', True)],
          'broderen': [('bror', True)],
          'broderens': [('bror', True)],
          'broders': [('bror', True)],
          'brods': [('brod', False)],
          'broen': [('bro', False)],
          'broens': [('bro', False)],
          'broer': [('bro', True)],
          'broerne': [('bro', False)],
          'broernes': [('bro', False)],
          'broers': [('bro', True)],
          'brokke': [('brok', True), ('brokke', True)],
          'brokken': [('brok', True), ('brokke', True)],
          'brokkens': [('brokke', True), ('brok', True)],
          'brokker': [('brokke', True)],
          'brokkerne': [('brokke', True)],
          'brokkernes': [('brokke', True)],
          'brokkers': [('brokke', True)],
          'brokkes': [('brokke', True), ('brok', True)],
          'bromer': [('brom', False)],
          'bromerne': [('brom', False)],
          'bromernes': [('brom', False)],
          'bromers': [('brom', False)],
          'bros': [('bro', False)],
          'brosten': [('brosten', False)],
          'brostens': [('brosten', True)],
          'brude': [('brud', False)],
          'bruden': [('brud', False)],
          'brudens': [('brud', False)],
          'brudes': [('brud', True)],
          'bruds': [('brud', False)],
          'brugen': [('brug', False)],
          'bruger': [('bruger', False)],
          'brugs': [('brugs', True), ('brug', True)],
          'brummen': [('brummen', True)],
          'brummer': [('brummer', True)],
          'brummernes': [('brummer', True)],
          'brummers': [('brummer', True)],
          'brummet': [('brum', True)],
          'bruner': [('bruner', False)],
          'brunerne': [('bruner', False)],
          'brunernes': [('bruner', False)],
          'bruners': [('bruner', False)],
          'brunsten': [('brunst', True), ('brunsten', True)],
          'brunstens': [('brunst', True), ('brunsten', True)],
          'brus': [('brus', True)],
          'bruser': [('bruser', True)],
          'bruserne': [('bruser', True)],
          'brusernes': [('bruser', False)],
          'brusers': [('bruser', False)],
          'brydernes': [('bryder', False)],
          'bryders': [('bryder', False)],
          'brygge': [('brygge', True)],
          'bryggen': [('brygge', True)],
          'bryggens': [('brygge', True)],
          'brygger': [('brygge', True), ('brygger', True)],
          'bryggerne': [('brygge', True), ('brygger', True)],
          'bryggernes': [('brygge', True), ('brygger', True)],
          'bryggers': [('brygge', True), ('brygger', True), ('bryggers', True)],
          'brygges': [('brygge', True)],
          'bryns': [('bryn', False)],
          'bryster': [('bryst', True)],
          'brysterne': [('bryst', False)],
          'brysternes': [('bryst', False)],
          'brysters': [('bryst', True)],
          'brædder': [('bræt', False)],
          'brædderne': [('bræt', False)],
          'bræddernes': [('bræt', False)],
          'brædders': [('bræt', False)],
          'bræer': [('bræ', True)],
          'bræerne': [('bræ', True)],
          'bræernes': [('bræ', True)],
          'bræers': [('bræ', True)],
          'brækken': [('bræk', False)],
          'brækkens': [('bræk', False)],
          'brækker': [('brækker', False)],
          'brækkerne': [('brækker', False)],
          'brækkernes': [('brækker', False)],
          'brækkers': [('brækker', False)],
          'bræmmer': [('bræmme', True)],
          'bræmmerne': [('bræmme', True)],
          'brænders': [('brænder', False)],
          'bræs': [('bræ', True)],
          'brætterne': [('bræt', False)],
          'brøden': [('brøde', True)],
          'brødens': [('brøde', True)],
          'brødre': [('bror', False)],
          'brødrene': [('bror', False)],
          'brødrenes': [('bror', False)],
          'brødres': [('bror', False)],
          'brøken': [('brøk', True)],
          'brøkens': [('brøk', True)],
          'bs': [('bs', False)],
          "bs'": [('bs', False)],
          'bsaks': [('bsak', False)],
          'bsammen': [('bsammen', False)],
          'bsammens': [('bsammen', False)],
          'bsen': [('bs', False)],
          'bsene': [('bs', False)],
          'bsenes': [('bs', False)],
          'bsens': [('bs', False)],
          'bservanten': [('bservant', False)],
          'bservantens': [('bservant', False)],
          'bservanter': [('bservant', False)],
          'bservanterne': [('bservant', False)],
          'bservanternes': [('bservant', False)],
          'bservanters': [('bservant', False)],
          'bset': [('bs', False)],
          'bsets': [('bs', False)],
          'bshandlerne': [('bshandler', False)],
          'bshandlernes': [('bshandler', False)],
          'bshoppen': [('bshop', False)],
          'bsidier': [('bsidier', False)],
          'bsinter': [('bsint', False)],
          'bsinters': [('bsint', False)],
          'bsistens': [('bsistens', False)],
          'bskallen': [('bskal', False)],
          'bskallens': [('bskal', False)],
          'bskaller': [('bskal', False)],
          'bskallerne': [('bskal', False)],
          'bskallernes': [('bskal', False)],
          'bskallers': [('bskal', False)],
          'bskifte': [('bskifte', False)],
          'bskifter': [('bskifte', False)],
          'bskifterne': [('bskifte', False)],
          'bskifternes': [('bskifte', False)],
          'bskifters': [('bskifte', False)],
          'bskiftes': [('bskifte', False)],
          'bskiftet': [('bskifte', False)],
          'bskiftets': [('bskifte', False)],
          'bskisten': [('bskiste', False)],
          'bskister': [('bskiste', False)],
          'bskisters': [('bskiste', False)],
          'bskovs': [('bskovs', False)],
          'bskurve': [('bskurv', False)],
          'bskytter': [('bskytte', False)],
          'bskytterne': [('bskytte', False)],
          'bskytternes': [('bskytte', False)],
          'bsmediciner': [('bsmedicin', False)],
          'bsmedicinerne': [('bsmedicin', False)],
          'bsmedicinernes': [('bsmedicin', False)],
          'bsmediciners': [('bsmedicin', False)],
          'bspillets': [('bsspil', False)],
          'bsrederne': [('bsreder', False)],
          'bsreders': [('bsreder', False)],
          'bssagens': [('bssag', False)],
          'bssager': [('bssag', False)],
          'bssagerne': [('bssag', False)],
          'bssagernes': [('bssag', False)],
          'bstads': [('bstad', False)],
          'bstans': [('bstans', False)],
          'bstansen': [('bstans', False)],
          'bstansens': [('bstans', False)],
          'bstanser': [('bstans', False)],
          'bstanserne': [('bstans', False)],
          'bstansernes': [('bstans', False)],
          'bstansers': [('bstans', False)],
          'bstiger': [('bstige', False)],
          'bstrater': [('bstrat', False)],
          'bstraterne': [('bstrat', False)],
          'bstraternes': [('bstrat', False)],
          'bstraters': [('bstrat', False)],
          'bsvarer': [('bsvare', False)],
          'bsvarerne': [('bsvare', False)],
          'bsvarernes': [('bsvare', False)],
          'bsvarers': [('bsvare', False)],
          'bsøer': [('bso', False)],
          'bsøerne': [('bso', False)],
          'bsøernes': [('bso', False)],
          'bsøers': [('bso', False)],
          'btangen': [('btang', False)],
          'btangens': [('btang', False)],
          'btroper': [('btroper', False)],
          'btroperne': [('btroper', False)],
          'btropernes': [('btroper', False)],
          'btropers': [('btroper', False)],
          'btudse': [('btudse', False)],
          'btudsens': [('btudse', False)],
          'btudser': [('btudse', False)],
          'btudsers': [('btudse', False)],
          'btængernes': [('btang', False)],
          'btængers': [('btang', False)],
          'buder': [('buder', False)],
          'buderne': [('buder', False)],
          'budernes': [('buder', False)],
          'buders': [('buder', False)],
          'buds': [('bud', True)],
          'budsen': [('buds', False)],
          'budsens': [('buds', False)],
          'budser': [('buds', False)],
          'budserne': [('buds', False)],
          'budsernes': [('buds', False)],
          'budsers': [('buds', False)],
          'buen': [('bue', True)],
          'buens': [('bue', True)],
          'buer': [('bue', True)],
          'buerne': [('bue', True)],
          'buernes': [('bue', True)],
          'buers': [('bue', True)],
          'buet': [('bu', False)],
          'buets': [('bu', False)],
          'buffer': [('buffer', True)],
          'bufferne': [('buffer', True)],
          'buffernes': [('buffer', True)],
          'buffers': [('buffer', True)],
          'buffets': [('buffet', True)],
          'buge': [('bug', False)],
          'bugen': [('bug', False)],
          'bugens': [('bug', False)],
          'buges': [('bug', False)],
          'buggen': [('bug', True)],
          'buggens': [('bug', False)],
          'bugter': [('bugt', True)],
          'bugterne': [('bugt', True)],
          'bugternes': [('bugt', True)],
          'bukke': [('buk', False)],
          'bukken': [('buk', False)],
          'bukkes': [('buk', True)],
          'buks': [('buk', True), ('buks', True)],
          'bukser': [('buks', True), ('bukser', True)],
          'bukserne': [('buks', True), ('bukser', True)],
          'buksernes': [('buks', True), ('bukser', True)],
          'buksers': [('buks', True), ('bukser', True)],
          'bula': [('bula', False)],
          'bulas': [('bula', False)],
          'bule': [('bule', False)],
          'bulen': [('bule', True)],
          'bulens': [('bule', False)],
          'bulers': [('bule', False)],
          'bules': [('bule', False)],
          'bulkernes': [('bulk', True)],
          'bulle': [('bul', True), ('bulle', True)],
          'bullen': [('bul', True), ('bulle', True)],
          'bullens': [('bul', True), ('bulle', True)],
          'buller': [('bul', True), ('bulle', True)],
          'bullerne': [('bul', True), ('bulle', True)],
          'bullernes': [('bulle', True), ('bul', True)],
          'bullers': [('bul', True), ('bulle', True)],
          'bulles': [('bul', True), ('bulle', True)],
          'bullet': [('bullet', True)],
          'bullets': [('bullet', True)],
          'bum': [('bum', False)],
          'buminer': [('bumin', False)],
          'buminerne': [('bumin', False)],
          'buminernes': [('bumin', False)],
          'buminers': [('bumin', False)],
          'bummernes': [('bum', False)],
          'bummers': [('bum', False)],
          'bums': [('bums', True)],
          'bumsen': [('bums', True)],
          'bumsens': [('bums', True)],
          'bumser': [('bums', True)],
          'bumserne': [('bums', True)],
          'bumsernes': [('bums', True)],
          'bumsers': [('bums', True)],
          'bunde': [('bund', False)],
          'bunden': [('bund', False)],
          'bundens': [('bund', False)],
          'bundes': [('bund', False)],
          'bunkens': [('bunke', True)],
          'bunker': [('bunker', True), ('bunke', True)],
          'bunkerne': [('bunker', True), ('bunke', True)],
          'bunkernes': [('bunker', True), ('bunke', True)],
          'bunkers': [('bunkers', True), ('bunker', True), ('bunke', True)],
          "bunkers'": [('bunker', True), ('bunkers', True)],
          'buns': [('bun', False)],
          'buret': [('bur', True)],
          'burets': [('bur', True)],
          'buretten': [('burette', True)],
          'burettens': [('burette', True)],
          'buretter': [('burette', True)],
          'buretterne': [('burette', True)],
          'buretternes': [('burette', True)],
          'buretters': [('burette', True)],
          'burgerne': [('burger', True)],
          'burs': [('bur', False)],
          "burs'": [('burs', False)],
          'bursen': [('burs', False)],
          'bursens': [('burs', False)],
          'burser': [('burs', False)],
          'burserne': [('burs', False)],
          'bursernes': [('burs', False)],
          'bursers': [('burs', False)],
          'bus': [('bus', True)],
          'busher': [('bush', True)],
          'busherne': [('bush', True)],
          'bushernes': [('bush', True)],
          'bushers': [('bush', True)],
          'buske': [('busk', False)],
          'busken': [('busk', False)],
          'busket': [('busket', True)],
          'buskets': [('busket', True)],
          'bussen': [('bus', False)],
          'bussens': [('bus', False)],
          'busser': [('bus', False)],
          'busserne': [('bus', False)],
          'busten': [('buste', True)],
          'buster': [('buste', True)],
          'busterne': [('buste', True)],
          'busternes': [('buste', True)],
          'busters': [('buste', True)],
          'butanerne': [('butan', True)],
          'butanernes': [('butan', True)],
          'buter': [('but', False)],
          'butten': [('but', False)],
          'buttens': [('but', False)],
          'butter': [('butter', False)],
          'butterne': [('but', False)],
          'butternes': [('but', False)],
          'butters': [('but', False)],
          'bybo': [('byboer', True)],
          'byboen': [('byboer', True)],
          'byboens': [('byboer', True)],
          'byboer': [('byboer', True)],
          'byboerne': [('byboer', True)],
          'byboernes': [('byboer', True)],
          'byboers': [('byboer', True)],
          'bybos': [('byboer', True)],
          'byder': [('byder', False)],
          'byen': [('by', False)],
          'byens': [('by', False)],
          'byer': [('by', False)],
          'byere': [('byer', False)],
          'byeren': [('byer', False)],
          'byerens': [('byer', False)],
          'byeres': [('byer', False)],
          'byerne': [('by', False)],
          'byernes': [('by', False)],
          'byers': [('by', False)],
          'bygen': [('byge', False)],
          'byger': [('byge', False)],
          'byggearbejder': [('byggearbejder', True), ('byggearbejde', True)],
          'byggearbejderne': [('byggearbejder', True), ('byggearbejde', True)],
          'byggearbejdernes': [('byggearbejde', True), ('byggearbejder', True)],
          'byggearbejders': [('byggearbejde', True), ('byggearbejder', True)],
          'byggen': [('byg', False)],
          'byggens': [('byg', False)],
          'bygger': [('bygger', False)],
          'byggerne': [('bygger', False)],
          'byggernes': [('bygger', False)],
          'bykernes': [('bykerne', True)],
          'bylden': [('byld', False)],
          'byldens': [('byld', False)],
          'bylder': [('byld', False)],
          'bylders': [('byld', False)],
          'byler': [('byler', False)],
          'bylerne': [('byler', False)],
          'bylernes': [('byler', False)],
          'bylers': [('byler', False)],
          'byllens': [('bylle', False)],
          'byllerne': [('bylle', False)],
          'byllernes': [('bylle', False)],
          'bylten': [('bylt', True)],
          'byltens': [('bylt', True)],
          'bylter': [('bylt', True)],
          'bylterne': [('bylt', True)],
          'bylternes': [('bylt', True)],
          'bylters': [('bylt', True)],
          'byrden': [('byrde', True), ('byrd', True)],
          'byrdens': [('byrd', True), ('byrde', True)],
          'byrder': [('byrde', True)],
          'byrderne': [('byrde', True)],
          'byrdernes': [('byrde', True)],
          'byrders': [('byrde', True)],
          'byrerne': [('byr', False)],
          'byrernes': [('byr', False)],
          'byret': [('byret', True)],
          'byrets': [('byret', True)],
          'bys': [('by', False)],
          'byssen': [('bys', False)],
          'byssens': [('bys', False)],
          'bysser': [('bys', False)],
          'bysserne': [('bys', False)],
          'bysten': [('byste', True)],
          'byster': [('byste', True)],
          'bysterne': [('byste', True)],
          'bysters': [('byste', True)],
          'byterne': [('byter', False)],
          'bytter': [('bytter', False)],
          'bytterne': [('bytter', False)],
          'bytternes': [('bytter', True)],
          'bytters': [('bytter', True)],
          "bz'er": [("bz'er", True)],
          "bz'erne": [("bz'er", True)],
          "bz'ernes": [("bz'er", True)],
          "bz'ers": [("bz'er", True)],
          'båltaler': [('båltale', True)],
          'båltalerne': [('båltale', True)],
          'båltalernes': [('båltale', True)],
          'båltalers': [('båltale', True)],
          'bånden': [('bånd', False)],
          'båndens': [('bånd', False)],
          'bårers': [('båre', True)],
          'bås': [('bås', True)],
          'bæer': [('bæ', True)],
          'bæerne': [('bæ', False)],
          'bæernes': [('bæ', False)],
          'bæers': [('bæ', True)],
          'bæet': [('bæ', True)],
          'bæets': [('bæ', True)],
          'bægerne': [('bæger', False)],
          'bægernes': [('bæger', False)],
          'bægers': [('bæger', False)],
          'bække': [('bæk', True)],
          'bækken': [('bæk', True), ('bækken', True)],
          'bækkens': [('bæk', True), ('bækken', True)],
          'bækker': [('bækker', False)],
          'bækkernes': [('bækker', False)],
          'bækkers': [('bækker', False)],
          'bækkes': [('bæk', True)],
          'bælter': [('bælt', True), ('bælte', True)],
          'bælterne': [('bælt', True), ('bælte', True)],
          'bælternes': [('bælt', True), ('bælte', True)],
          'bælters': [('bælt', True), ('bælte', True)],
          'bæltet': [('bælt', True), ('bælte', True)],
          'bæltets': [('bælt', True), ('bælte', True)],
          'bænke': [('bænk', False)],
          'bænken': [('bænk', False)],
          'bænkes': [('bænk', False)],
          'bærden': [('bærde', False)],
          'bærdens': [('bærde', False)],
          'bærder': [('bærde', False)],
          'bærdernes': [('bærde', False)],
          'bærer': [('bærer', False)],
          'bærerne': [('bærer', False)],
          'bærernes': [('bærer', False)],
          'bærers': [('bærer', False)],
          'bærrens': [('bær', False)],
          'bæs': [('bæ', True)],
          'bæster': [('bæst', True)],
          'bæsterne': [('bæst', True)],
          'bæsternes': [('bæst', True)],
          'bæsters': [('bæst', True)],
          'bæstet': [('bæst', True)],
          'bæstets': [('bæst', True)],
          'bæven': [('bæven', True)],
          'bævens': [('bæven', True)],
          'bøden': [('bøde', False)],
          'bødens': [('bøde', False)],
          'bøder': [('bøde', True)],
          'bøderne': [('bøde', True)],
          'bødernes': [('bøde', True)],
          'bøders': [('bøde', True)],
          'bøger': [('bog', False)],
          'bøje': [('bøje', False)],
          'bøjen': [('bøje', True)],
          'bøjens': [('bøje', False)],
          'bøjernes': [('bøje', False)],
          'bøjers': [('bøje', True)],
          'bøjes': [('bøje', False)],
          'bøjlerne': [('bøjle', False)],
          'bøjlernes': [('bøjle', False)],
          'bølgerne': [('bølge', False)],
          'bølgernes': [('bølge', False)],
          'bølgers': [('bølge', False)],
          'bøllen': [('bølle', True)],
          'bøllens': [('bølle', False)],
          'bøller': [('bølle', False)],
          'bøllerne': [('bølle', True)],
          'bøllernes': [('bølle', False)],
          'bøllers': [('bølle', True)],
          'bønders': [('bonde', False)],
          'bønnen': [('bønne', True), ('bøn', True)],
          'bønnens': [('bønne', True), ('bøn', True)],
          'bønner': [('bønne', True), ('bøn', True)],
          'bønnerne': [('bønne', True), ('bøn', True)],
          'bønnernes': [('bøn', True), ('bønne', True)],
          'bønners': [('bønne', True), ('bøn', True)],
          'børe': [('bør', True)],
          'børen': [('bør', True)],
          'børene': [('bør', True)],
          'børenes': [('bør', True)],
          'børens': [('bør', False)],
          'børes': [('bør', True)],
          'børn': [('barn', True)],
          'børnene': [('barn', False)],
          'børnenes': [('barn', False)],
          'børns': [('barn', False)],
          'børs': [('børs', True), ('bør', True)],
          'børstens': [('børste', False)],
          'bøvlet': [('bøvl', True)],
          'bøvlets': [('bøvl', True)],
          'bøvs': [('bøvs', True)],
          "c'erne": [('c', False)],
          'c.': [('c.', False)],
          'ca': [('ca', False)],
          'cade': [('cade', False)],
          'caden': [('cade', False)],
          'cadens': [('cade', False)],
          'caderne': [('cade', False)],
          'caders': [('cade', False)],
          'cades': [('cade', False)],
          'cados': [('cado', False)],
          'caen': [('ca', False)],
          'caens': [('ca', False)],
          'caer': [('ca', False)],
          'caerne': [('ca', False)],
          'caernes': [('ca', False)],
          'caers': [('ca', False)],
          'caken': [('cake', False)],
          'cakene': [('cake', False)],
          'cakenes': [('cake', False)],
          'cakens': [('cake', False)],
          'cakes': [('cake', False)],
          "cakes'": [('cake', False)],
          'calen': [('cal', False)],
          'calens': [('cal', False)],
          'caler': [('caler', False)],
          'calerne': [('caler', False)],
          'calernes': [('caler', False)],
          'calers': [('caler', False)],
          'callet': [('call', False)],
          'callets': [('call', False)],
          'campen': [('camp', True)],
          'campens': [('camp', True)],
          'camper': [('camper', False)],
          'campere': [('camper', False)],
          'camperes': [('camper', False)],
          'camperne': [('camper', False)],
          'cancer': [('cancer', True)],
          'cancerne': [('cancer', True)],
          'cancernes': [('cancer', True)],
          'cancers': [('cancer', True)],
          'canen': [('can', False)],
          'canens': [('can', False)],
          'caner': [('caner', False)],
          'canerne': [('caner', False)],
          'canernes': [('caner', False)],
          'caners': [('caner', False)],
          'cannerne': [('canner', False)],
          'cannernes': [('canner', False)],
          'canners': [('canner', False)],
          'caper': [('cape', True)],
          'caperne': [('cape', True)],
          'capper': [('capper', False)],
          'capperne': [('capper', False)],
          'cappernes': [('capper', False)],
          'cappers': [('capper', False)],
          'caravanerne': [('caravan', True)],
          'caries': [('caries', True)],
          'cas': [('ca', False)],
          "cas'": [('ca', False)],
          'case': [('case', True)],
          'casen': [('case', True)],
          'casene': [('case', True)],
          'casenes': [('case', True)],
          'casens': [('case', True)],
          'cases': [('case', True)],
          'casestudies': [('casestudie', True), ('casestudy', True)],
          'casten': [('cast', False)],
          'castens': [('cast', False)],
          'casterne': [('caster', True)],
          'casters': [('caster', True)],
          'cata': [('cata', False)],
          'catos': [('cato', False)],
          'ccenter': [('ccent', False)],
          'ccenters': [('ccent', False)],
          'ccepter': [('ccept', False)],
          'cces': [('cces', False)],
          "cces'": [('cces', False)],
          'cciner': [('ccine', False)],
          'ccinerne': [('ccine', False)],
          'ccinernes': [('ccine', False)],
          'cciners': [('ccine', False)],
          'cd': [('cd', True)],
          "cd'er": [('cd', True)],
          "cd'ers": [('cd', True)],
          'ce': [('ce', False)],
          'ceaner': [('cean', False)],
          'ceaners': [('cean', False)],
          'ceans': [('cean', False)],
          'ceboer': [('cebo', False)],
          'ceboerne': [('cebo', False)],
          'ceboers': [('cebo', False)],
          'cedens': [('cedens', False)],
          'ceder': [('ceder', True)],
          'ceders': [('ceder', True)],
          'cekunsterne': [('cekunst', False)],
          'cekunsters': [('cekunst', False)],
          'cekurser': [('cekursus', False)],
          'cekurserne': [('cekursus', False)],
          'cekursernes': [('cekursus', False)],
          'celier': [('celium', False)],
          'celierne': [('celium', False)],
          'celiernes': [('celium', False)],
          'celiet': [('celium', False)],
          'celiets': [('celium', False)],
          'celisternes': [('celiste', False)],
          'celisters': [('celiste', False)],
          'celle': [('celle', False)],
          'cellen': [('celle', True)],
          'cellens': [('celle', False)],
          'celler': [('celle', True)],
          'cellerne': [('celle', False)],
          'cellernes': [('celle', False)],
          'cellers': [('celle', True)],
          'celles': [('celle', False)],
          'cen': [('ce', False)],
          'cendens': [('cendens', False)],
          'cene': [('cene', False)],
          'cenen': [('cene', False)],
          'cenens': [('cene', False)],
          'cener': [('cene', False)],
          'cenerne': [('cene', False)],
          'cenernes': [('cene', False)],
          'ceners': [('cene', False)],
          'cenes': [('cene', False)],
          'cenier': [('cenium', False)],
          'cenierne': [('cenium', False)],
          'ceniernes': [('cenium', False)],
          'ceniers': [('cenium', False)],
          'cens': [('ce', False)],
          "cens'": [('cens', False)],
          'censen': [('cens', False)],
          'censens': [('cens', False)],
          'censer': [('cens', False)],
          'censernes': [('cens', False)],
          'censers': [('cens', False)],
          'centen': [('cent', False)],
          'centens': [('cent', False)],
          'center': [('center', True)],
          'centerne': [('cent', False)],
          'centernes': [('cent', False)],
          'centers': [('center', True)],
          'centre': [('centrum', True), ('center', True)],
          'centrene': [('centrum', True), ('center', True)],
          'centrenes': [('centrum', True), ('center', True)],
          'centres': [('centrum', True), ('center', True)],
          'centret': [('centrum', True), ('center', True)],
          'centrets': [('centrum', True), ('center', True)],
          'centrum': [('centrum', True)],
          'centrummer': [('centrum', True)],
          'centrummerne': [('centrum', True)],
          'centrummernes': [('centrum', True)],
          'centrummers': [('centrum', True)],
          'centrummet': [('centrum', True)],
          'centrummets': [('centrum', True)],
          'centrums': [('centrum', True)],
          'ceps': [('ceps', False)],
          "ceps'": [('ceps', False)],
          'cepter': [('cepter', False)],
          'cepters': [('cept', False)],
          'ceptets': [('cept', False)],
          'cer': [('ce', False)],
          'cerne': [('ce', False)],
          'cernen': [('cern', False)],
          'cernens': [('cern', False)],
          'cerner': [('cern', False)],
          'cernerne': [('cerne', False)],
          'cernernes': [('cern', False)],
          'cerners': [('cerne', False)],
          'cernes': [('ce', False)],
          'ceroen': [('cero', False)],
          'ceroens': [('cero', False)],
          'ceroner': [('cerone', False)],
          'ceronerne': [('cerone', False)],
          'ceronernes': [('cerone', False)],
          'ceroners': [('cerone', False)],
          'ceros': [('cero', False)],
          'cers': [('ce', False)],
          'certen': [('cert', False)],
          'certens': [('cert', False)],
          'certer': [('cert', False)],
          'certerne': [('cert', False)],
          'certers': [('cert', False)],
          'certs': [('cert', False)],
          'ces': [('ces', True)],
          "ces'": [('ces', True)],
          'ceser': [('ces', False)],
          'ceserne': [('ces', False)],
          'cesernes': [('ces', False)],
          'cesers': [('ces', False)],
          'cessen': [('ces', False)],
          'cessens': [('ces', False)],
          'cesser': [('ces', False)],
          'cesserne': [('ces', False)],
          'cessernes': [('ces', False)],
          'cessers': [('ces', False)],
          'cesten': [('cest', False)],
          'cestens': [('cest', False)],
          'cet': [('ce', False)],
          'cetonen': [('cetone', False)],
          'cetonens': [('cetone', False)],
          'cetoner': [('cetone', False)],
          'cetonerne': [('cetone', False)],
          'cetonernes': [('cetone', False)],
          'cetoners': [('cetone', False)],
          'cets': [('cet', False)],
          'cetten': [('cet', False)],
          'cettens': [('cet', False)],
          'cetter': [('cet', False)],
          'cetterne': [('cet', False)],
          'cetternes': [('cet', False)],
          'cetters': [('cet', False)],
          'cettet': [('cet', False)],
          'cettets': [('cet', False)],
          'ceværter': [('cevært', False)],
          'ceværterne': [('cevært', False)],
          'ceværters': [('cevært', False)],
          'cfaren': [('cfar', False)],
          'cfarens': [('cfar', False)],
          'cfars': [('cfar', False)],
          'cfædre': [('cfar', False)],
          'cfædrenes': [('cfar', False)],
          'ch': [('ch', False)],
          'chas': [('cha', False)],
          'cheller': [('cheller', False)],
          'chellerne': [('cheller', False)],
          'chellernes': [('cheller', False)],
          'chellers': [('cheller', False)],
          'chen': [('ch', False)],
          'chens': [('ch', False)],
          'cher': [('ch', False)],
          'cherne': [('ch', False)],
          'chernes': [('che', False)],
          'chers': [('ch', False)],
          'chet': [('ch', False)],
          'chets': [('ch', False)],
          'chikaner': [('chikane', True)],
          'chips': [('chip', True), ('chips', True)],
          "chips'": [('chip', True), ('chips', True)],
          'chipsene': [('chips', True), ('chip', True)],
          'chipsenes': [('chip', True), ('chips', True)],
          'chis': [('chi', True)],
          'chisen': [('chis', False)],
          'chisens': [('chis', False)],
          'chonen': [('chon', False)],
          'chonens': [('chon', False)],
          'choner': [('chon', False)],
          'chonerne': [('chon', False)],
          'chonernes': [('chon', False)],
          'choners': [('chon', False)],
          'chopper': [('chopper', True)],
          'chopperne': [('chopper', True)],
          'choppernes': [('chopper', True)],
          'choppers': [('chopper', True)],
          'chter': [('cht', False)],
          'chternes': [('cht', False)],
          'chters': [('cht', False)],
          'chører': [('chør', False)],
          'chørerne': [('chør', False)],
          'chørernes': [('chør', False)],
          'chørers': [('chør', False)],
          'ci': [('ci', False)],
          'cialer': [('cial', False)],
          'cialerne': [('cial', False)],
          'cialernes': [('cial', False)],
          'cialers': [('cial', False)],
          'cianerne': [('cianer', False)],
          'cianernes': [('cianer', False)],
          'ciater': [('ciat', False)],
          'ciaterne': [('ciat', False)],
          'ciaters': [('ciat', False)],
          'cidens': [('cidens', False)],
          'cider': [('cider', True)],
          'ciderne': [('cider', True)],
          'cidernes': [('cider', True)],
          'ciders': [('cider', False)],
          'cienser': [('cienser', False)],
          'ciensernes': [('cienser', False)],
          'ciensers': [('cienser', False)],
          'cier': [('cier', False)],
          'ciere': [('cier', False)],
          'cieren': [('cier', False)],
          'cierens': [('cier', False)],
          'cierer': [('cier', False)],
          'ciererne': [('cier', False)],
          'cierernes': [('cier', False)],
          'cierers': [('cier', False)],
          'cieres': [('cier', False)],
          'cierne': [('cie', False)],
          'ciernes': [('cie', False)],
          'ciers': [('cier', False)],
          "cies'": [('cies', False)],
          'ciklen': [('cikel', False)],
          'ciklerne': [('cikel', False)],
          'ciklernes': [('cikel', False)],
          'ciklers': [('cikel', False)],
          'ciler': [('cil', False)],
          'cilets': [('cil', False)],
          'ciliernes': [('cilium', False)],
          'ciliets': [('cilium', False)],
          'cillen': [('cil', False)],
          'cillens': [('cille', False)],
          'ciller': [('cil', False)],
          'cillerne': [('cil', False)],
          'cillernes': [('cille', False)],
          'cillers': [('cille', False)],
          'cimers': [('cim', False)],
          'cinders': [('cinders', True)],
          'cine': [('cine', False)],
          'cinen': [('cine', False)],
          'cinens': [('cine', False)],
          'cinerne': [('ciner', False)],
          'cinernes': [('ciner', False)],
          'cines': [('cine', False)],
          'cingen': [('cing', False)],
          'cingens': [('cing', False)],
          'cinger': [('cing', False)],
          'cingerne': [('cing', False)],
          'cingernes': [('cing', False)],
          'cings': [('cing', False)],
          'cinten': [('cint', False)],
          'cintens': [('cint', False)],
          'cinter': [('cint', False)],
          'cinterne': [('cint', False)],
          'cinternes': [('cint', False)],
          'cinters': [('cint', False)],
          'cipier': [('cipium', False)],
          'cipiernes': [('cipium', False)],
          'cipper': [('cip', False)],
          'cipperne': [('cip', False)],
          'cippernes': [('cip', False)],
          'cippers': [('cip', False)],
          'cis': [('cis', True)],
          'cisers': [('cis', False)],
          'cismen': [('cisme', False)],
          'cismens': [('cisme', False)],
          'cismers': [('cisme', False)],
          'cissen': [('cis', False)],
          'cissens': [('cis', False)],
          'cisser': [('cis', False)],
          'cisserne': [('cis', True)],
          'cissernes': [('cis', True)],
          'cissers': [('cis', True)],
          'cisten': [('cist', False)],
          'cistens': [('cist', False)],
          'cister': [('cist', False)],
          'cisterne': [('cisterne', True)],
          'cisternes': [('cisterne', True)],
          'cisters': [('cist', False)],
          'citerne': [('citer', True)],
          'citrater': [('citrat', True)],
          'citraterne': [('citrat', True)],
          'citraternes': [('citrat', True)],
          'citraters': [('citrat', True)],
          'citre': [('citer', True)],
          'citrinen': [('citrin', True)],
          'citrinens': [('citrin', True)],
          'citrinerne': [('citrin', True)],
          'citrinernes': [('citrin', True)],
          'cits': [('cits', False)],
          "cits'": [('cits', False)],
          'citsen': [('cits', False)],
          'citsens': [('cits', False)],
          'citser': [('cits', False)],
          'citserne': [('cits', False)],
          'citsernes': [('cits', False)],
          'citsers': [('cits', False)],
          'citten': [('cit', False)],
          'citternes': [('cit', False)],
          'citters': [('cit', False)],
          'ck': [('ck', False)],
          'cken': [('ck', False)],
          'ckene': [('ck', False)],
          'ckenes': [('ck', False)],
          'ckens': [('ck', False)],
          'cker': [('cker', False)],
          'ckere': [('cker', False)],
          'ckeren': [('cker', False)],
          'ckerens': [('cker', False)],
          'ckeres': [('cker', False)],
          'cklingen': [('ckling', False)],
          'cklingens': [('ckling', False)],
          'cklinger': [('ckling', False)],
          'cklingerne': [('ckling', False)],
          'cklingernes': [('ckling', False)],
          'cklingers': [('ckling', False)],
          'cks': [('ck', False)],
          "cks'": [('ck', False)],
          'cksene': [('ck', False)],
          'cksenes': [('ck', False)],
          'clats': [('clat', False)],
          'clauder': [('claude', False)],
          'clauderne': [('claude', False)],
          'claudernes': [('claude', False)],
          'clauders': [('claude', False)],
          'cm': [('centimeter', True)],
          'cm.': [('centimeter', True)],
          'cman': [('cman', False)],
          'cmen': [('cman', False)],
          'cmens': [('cman', False)],
          'coater': [('coat', False)],
          'coaterne': [('coat', False)],
          'coaters': [('coat', False)],
          'coen': [('co', False)],
          'coens': [('co', False)],
          'coer': [('co', False)],
          'coerne': [('co', False)],
          'coernes': [('co', False)],
          'coers': [('co', False)],
          'coli': [('coli', False)],
          'colien': [('coli', False)],
          'colienes': [('coli', False)],
          'coliens': [('coli', False)],
          'colinen': [('coline', False)],
          'colinens': [('coline', False)],
          'colinerne': [('coline', False)],
          'colinernes': [('coline', False)],
          'coliners': [('coline', False)],
          'colis': [('coli', False)],
          'colleger': [('college', True)],
          'collegerne': [('college', True)],
          'collegers': [('college', True)],
          'collier': [('collie', True), ('collier', True)],
          'colliers': [('collie', True), ('collier', True)],
          'colos': [('colo', False)],
          'commen': [('com', False)],
          'commens': [('com', False)],
          'controllernes': [('controller', True)],
          'core': [('core', False)],
          'coren': [('core', False)],
          'corens': [('core', False)],
          'corsagerne': [('corsage', True)],
          'corsagernes': [('corsage', True)],
          'corten': [('cort', False)],
          'cortens': [('cort', False)],
          'corts': [('cort', False)],
          'cos': [('co', False)],
          "cos'": [('co', False)],
          'coten': [('cote', False)],
          'cotens': [('cote', False)],
          'coter': [('cote', False)],
          'coterne': [('cote', False)],
          'coternes': [('cote', False)],
          'coters': [('cote', False)],
          'cotes': [('cote', False)],
          'coulis': [('coulis', True)],
          'cous': [('cous', False)],
          'cover': [('cover', True)],
          'coverne': [('cover', False)],
          'cposers': [('cpose', False)],
          'creen': [('creen', False)],
          'creens': [('creen', False)],
          'cremens': [('creme', False)],
          'cricket': [('cricket', True)],
          'crickets': [('cricket', True)],
          'crosset': [('cross', False)],
          'crossets': [('cross', False)],
          'croupier': [('croupier', True)],
          'cs': [('c', False)],
          "cs'": [('c', False)],
          'ct.': [('rocent', False)],
          'ct.-gebyret': [('rocent-gebyr', False)],
          'ct.s': [('rocent', False)],
          'cterne': [('ct', False)],
          'cternes': [('ct', False)],
          'ctet': [('ct', False)],
          'ctets': [('ct', False)],
          'ctoris': [('ctoris', False)],
          'cudas': [('cuda', False)],
          'culier': [('culier', False)],
          'culler': [('culler', False)],
          'cullerne': [('culler', False)],
          'cullernes': [('culler', False)],
          'cullers': [('culler', False)],
          'culotten': [('culotte', True)],
          'culottens': [('culotte', True)],
          'culotter': [('culotte', True)],
          'culotterne': [('culotte', True)],
          'culotternes': [('culotte', True)],
          'culotters': [('culotte', True)],
          'cum': [('cum', False)],
          'cums': [('cum', False)],
          'cuppen': [('cup', True)],
          'cuppens': [('cup', True)],
          'cupperne': [('cup', True)],
          'cuppers': [('cup', True)],
          'cure': [('cure', False)],
          'curen': [('cure', False)],
          'curens': [('cure', False)],
          'curer': [('cure', False)],
          'curerne': [('cure', False)],
          'curernes': [('cure', False)],
          'curers': [('cure', False)],
          'cures': [('cure', False)],
          'curs': [('cur', False)],
          'cussen': [('cus', False)],
          'cussens': [('cus', False)],
          'cusser': [('cus', False)],
          'cusserne': [('cus', False)],
          'cutten': [('cut', False)],
          'cuttens': [('cut', False)],
          'cutter': [('cutter', True)],
          'cutternes': [('cutter', True)],
          'cutters': [('cutter', True)],
          'cyklen': [('cyklus', True), ('cykel', True)],
          'cyklens': [('cyklus', True), ('cykel', True)],
          'cykler': [('cykel', True), ('cyklus', True)],
          'cyklerne': [('cyklus', True), ('cykel', True)],
          'cyklernes': [('cyklus', True), ('cykel', True)],
          'cyklers': [('cyklus', True), ('cykel', True)],
          'cyklister': [('cyklist', True)],
          'cyklisternes': [('cyklist', False)],
          'cyklisters': [('cyklist', True)],
          'cysten': [('cyste', True)],
          'cyster': [('cyste', True)],
          'cysterne': [('cyste', True)],
          'cysters': [('cyste', True)],
          'cytten': [('cyt', False)],
          'cyttens': [('cyt', False)],
          'cytternes': [('cyt', False)],
          'cytters': [('cyt', False)],
          'cøren': [('cør', False)],
          'cørens': [('cør', False)],
          'cører': [('cør', False)],
          'cørerne': [('cør', False)],
          'cørernes': [('cør', False)],
          'cørers': [('cør', False)],
          'd': [('d', True)],
          "d'er": [('d', True)],
          "d'erne": [('d', False)],
          "d'ernes": [('d', True)],
          "d'ers": [('d', True)],
          'd-': [('dregning', False)],
          'd.': [('d.', False)],
          'da': [('da', False)],
          'dader': [('dader', False)],
          'daderne': [('dader', False)],
          'dadernes': [('dader', False)],
          'daders': [('dader', False)],
          'dadlen': [('dadel', True), ('daddel', True)],
          'dadlens': [('daddel', True), ('dadel', True)],
          'dadler': [('daddel', True)],
          'dadlers': [('daddel', True)],
          'daen': [('da', False)],
          'daene': [('da', False)],
          'daenes': [('da', False)],
          'daens': [('da', False)],
          'daer': [('da', False)],
          'daerne': [('da', False)],
          'daernes': [('da', False)],
          'daers': [('da', False)],
          'daftalens': [('daftale', False)],
          'dagbøder': [('dagbod', True), ('dagbøde', True)],
          'dagbøderne': [('dagbod', True), ('dagbøde', True)],
          'dagbødernes': [('dagbod', True), ('dagbøde', True)],
          'dagbøders': [('dagbod', True), ('dagbøde', True)],
          'dage': [('dag', True)],
          'dagen': [('dag', True)],
          'dagene': [('dag', True)],
          'dagenes': [('dag', True)],
          'dagens': [('dag', False)],
          'dager': [('dage', False)],
          'dagerne': [('dager', False)],
          'dagernes': [('dager', False)],
          'dagers': [('dager', False)],
          'dages': [('dag', True)],
          'dagisters': [('dagist', False)],
          'daglejer': [('daglejer', True), ('dagleje', True)],
          'daglejerne': [('dagleje', True), ('daglejer', True)],
          'daglejernes': [('daglejer', True), ('dagleje', True)],
          'daglejers': [('dagleje', True), ('daglejer', True)],
          'dagplejer': [('dagplejer', True), ('dagpleje', True)],
          'dagplejerne': [('dagpleje', True), ('dagplejer', True)],
          'dagplejernes': [('dagplejer', True), ('dagpleje', True)],
          'dagplejers': [('dagplejer', True), ('dagpleje', True)],
          'dagter': [('dagt', False)],
          'dagterne': [('dagt', False)],
          'dagternes': [('dagt', False)],
          "daks'": [('daks', False)],
          'daksen': [('daks', False)],
          'daksens': [('daks', False)],
          'dakter': [('dakt', False)],
          'dalders': [('dalder', False)],
          'dale': [('dal', False)],
          'dalen': [('dal', False)],
          'dalene': [('dal', True)],
          'dalenes': [('dal', False)],
          'dalens': [('dal', False)],
          'daler': [('daler', True)],
          'dalerne': [('daler', False)],
          'dalernes': [('daler', True)],
          'dalers': [('daler', True)],
          'dales': [('dal', True)],
          'daller': [('daller', False)],
          'damen': [('dame', False)],
          'damenter': [('dament', False)],
          'damenterne': [('dament', False)],
          'damentet': [('dament', False)],
          'damentets': [('dament', False)],
          'damer': [('dame', False)],
          'damerne': [('dame', False)],
          'damernes': [('dame', True)],
          'damme': [('dam', False)],
          'dammen': [('dam', False)],
          'dammens': [('dam', True)],
          'dammer': [('dam', True)],
          'dammerne': [('dam', True)],
          'dammernes': [('dam', True)],
          'dammers': [('dam', True)],
          'dammes': [('dam', False)],
          'dampe': [('damp', True)],
          'dampen': [('damp', True)],
          'dampens': [('damp', False)],
          'damper': [('damper', False)],
          'dampere': [('damper', False)],
          'damperes': [('damper', False)],
          'damperne': [('damper', False)],
          'dampes': [('damp', True)],
          'dana': [('dana', False)],
          'dancer': [('dancer', False)],
          'dancerne': [('dancer', False)],
          'dancernes': [('dancer', False)],
          'dancers': [('dancer', False)],
          'danden': [('dand', False)],
          'danen': [('dan', False)],
          'danens': [('dan', False)],
          'daner': [('daner', True)],
          'danerne': [('daner', False)],
          'danernes': [('daner', False)],
          'daners': [('daner', False)],
          'dannerne': [('danner', False)],
          'dannernes': [('danner', False)],
          'danners': [('danner', False)],
          'dans': [('dans', False)],
          "dans'": [('dans', False)],
          'danse': [('dans', True)],
          'dansen': [('dans', False)],
          'dansenes': [('dans', False)],
          'dansens': [('dans', False)],
          'danser': [('danser', True)],
          'danserne': [('danser', False)],
          'dansernes': [('danser', True)],
          'dansers': [('danser', True)],
          'danses': [('dans', False)],
          'danten': [('dant', False)],
          'dantens': [('dant', False)],
          'danterne': [('dant', False)],
          'danternes': [('dant', False)],
          'danters': [('dant', False)],
          'dants': [('dant', False)],
          'darbejder': [('darbejder', False)],
          'darbejderne': [('darbejder', False)],
          'darbejdernes': [('darbejde', False)],
          'darbejders': [('darbejde', False)],
          'darden': [('dard', False)],
          'darderne': [('dard', False)],
          'dardernes': [('dard', False)],
          'darerne': [('dar', False)],
          'darers': [('dar', False)],
          'darier': [('darium', False)],
          'darierne': [('darium', False)],
          'dariernes': [('darium', False)],
          'dariers': [('darium', False)],
          'dariet': [('darium', False)],
          'dariets': [('darium', False)],
          'dariner': [('darin', False)],
          'dariners': [('darin', False)],
          'darmens': [('darm', False)],
          'darmerne': [('darm', False)],
          'darmernes': [('darm', False)],
          'darmers': [('darm', False)],
          'darten': [('dart', False)],
          'darter': [('dart', False)],
          'darterne': [('dart', False)],
          'darts': [('dart', False)],
          'darven': [('darve', False)],
          'darvens': [('darve', False)],
          'das': [('das', True)],
          "das'": [('das', True)],
          'dasen': [('das', False)],
          'dasens': [('das', False)],
          'dasker': [('dasker', False)],
          'daskerne': [('dasker', False)],
          'daskernes': [('dasker', False)],
          'daskers': [('dasker', False)],
          'dasket': [('dask', True)],
          'daskets': [('dask', True)],
          'dassen': [('das', False)],
          'dassens': [('das', False)],
          'dasserne': [('das', False)],
          'data': [('data', False)],
          'dataene': [('data', False)],
          'datanet': [('datanet', True)],
          'datanets': [('datanet', True)],
          'datarerne': [('datar', False)],
          'datarers': [('datar', False)],
          'daten': [('date', True)],
          'datens': [('date', True)],
          'daternes': [('dat', False)],
          'dates': [('date', True)],
          "dates'": [('date', True)],
          'datiden': [('datid', True)],
          'datidens': [('datid', True)],
          'datider': [('datid', False)],
          'datiderne': [('datid', False)],
          'datidernes': [('datid', False)],
          'datos': [('dato', False)],
          "dats'": [('dats', False)],
          'datter': [('datter', False)],
          'dauer': [('dauer', False)],
          'dauerne': [('dauer', False)],
          'dauers': [('dauer', False)],
          'davers': [('daver', False)],
          'davlen': [('davl', False)],
          'davlens': [('davl', False)],
          'davren': [('davre', True)],
          'davrens': [('davre', True)],
          'davres': [('davre', True)],
          'dbaggen': [('dbagge', False)],
          'dbaggens': [('dbagge', False)],
          'dbakken': [('dbakke', False)],
          'dbakkens': [('dbakke', False)],
          'dbakkerne': [('dbakke', False)],
          'dballen': [('dballe', False)],
          'dballens': [('dballe', False)],
          'dballer': [('dballe', False)],
          'dballerne': [('dballe', False)],
          'dballernes': [('dballe', False)],
          'dballers': [('dballe', False)],
          'dbanken': [('dbank', False)],
          'dbankens': [('dbank', False)],
          'dbanker': [('dbank', False)],
          'dbankerne': [('dbank', False)],
          'dbankernes': [('dbank', False)],
          'dbankers': [('dbank', False)],
          'dbassen': [('dbasse', False)],
          'dbassens': [('dbasse', False)],
          'dbasser': [('dbasse', False)],
          'dbasserne': [('dbasse', False)],
          'dbassernes': [('dbasse', False)],
          'dbassers': [('dbasse', False)],
          'dbede': [('dbede', False)],
          'dbedes': [('dbede', False)],
          'dben': [('dben', False)],
          'dbenets': [('dben', False)],
          'dbidders': [('dbid', False)],
          'dbilens': [('dbil', False)],
          'dbilerne': [('dbil', False)],
          'dbilernes': [('dbil', False)],
          'dbilers': [('dbil', False)],
          'dblus': [('dblus', False)],
          'dbo': [('dboer', False)],
          'dboen': [('dboer', False)],
          'dboens': [('dboer', False)],
          'dboer': [('dboer', False)],
          'dboerne': [('dboer', False)],
          'dboernes': [('dboer', False)],
          'dboers': [('dbo', False)],
          'dbogen': [('dbog', False)],
          'dbomber': [('dbombe', False)],
          'dbomberne': [('dbombe', False)],
          'dbombernes': [('dbombe', False)],
          'dbombers': [('dbombe', False)],
          'dboret': [('dbor', False)],
          'dborets': [('dbor', False)],
          'dbos': [('dboer', False)],
          'dbredden': [('dbred', False)],
          'dbreddens': [('dbred', False)],
          'dbredder': [('dbred', False)],
          'dbredderne': [('dbred', False)],
          'dbreddernes': [('dbred', False)],
          'dbredders': [('dbred', False)],
          'dbringer': [('dbringer', False)],
          'dbringerne': [('dbringer', False)],
          'dbringernes': [('dbringer', False)],
          'dbringers': [('dbringer', False)],
          'dbroder': [('dbroder', False)],
          'dbroderen': [('dbror', False)],
          'dbroderens': [('dbroder', False)],
          'dbroders': [('dbroder', False)],
          'dbrugs': [('dbrug', False)],
          'dbrødre': [('dbroder', False)],
          'dbrødrene': [('dbroder', False)],
          'dbrødrenes': [('dbroder', False)],
          'dbrødres': [('dbroder', False)],
          'dbuen': [('dbue', False)],
          'dbuer': [('dbue', False)],
          'dbuers': [('dbue', False)],
          'dbukser': [('dbukser', False)],
          'dbukserne': [('dbukser', False)],
          'dbuksernes': [('dbukser', False)],
          'dbuksers': [('dbukser', False)],
          'dbulle': [('dbulle', False)],
          'dbullen': [('dbulle', False)],
          'dbullens': [('dbulle', False)],
          'dbuller': [('dbulle', False)],
          'dbullerne': [('dbulle', False)],
          'dbullernes': [('dbulle', False)],
          'dbullers': [('dbulle', False)],
          'dbulles': [('dbulle', False)],
          'dburet': [('dbur', False)],
          'dburets': [('dbur', False)],
          'dbyer': [('dbyer', False)],
          'dbyerne': [('dbyer', False)],
          'dbyernes': [('dbyer', False)],
          'dbyers': [('dbyer', False)],
          'dbælter': [('dbælte', False)],
          'dbælterne': [('dbælte', False)],
          'dbælternes': [('dbælte', False)],
          'dbælters': [('dbælte', False)],
          'dbæltet': [('dbælte', False)],
          'dbæltets': [('dbælte', False)],
          'dbønnen': [('dbøn', False)],
          'dbønnens': [('dbøn', False)],
          'dbønner': [('dbøn', False)],
          'dbønnerne': [('dbøn', False)],
          'dbønnernes': [('dbøn', False)],
          'dbønners': [('dbøn', False)],
          'dbørs': [('dbør', False)],
          'dcellen': [('dcelle', False)],
          'dcellers': [('dcelle', False)],
          'dcyklen': [('dcykel', False)],
          'dcyklens': [('dcykel', False)],
          'dcykler': [('dcykel', False)],
          'dcyklerne': [('dcykel', False)],
          'dcyklernes': [('dcykel', False)],
          'dcyklers': [('dcykel', False)],
          'ddage': [('ddag', False)],
          'ddagen': [('ddag', False)],
          'ddagene': [('ddag', False)],
          'ddagenes': [('ddag', False)],
          'ddages': [('ddag', False)],
          'ddarer': [('ddar', False)],
          'ddarernes': [('ddar', False)],
          'ddele': [('ddele', False)],
          'ddelene': [('ddel', False)],
          'ddelenes': [('ddele', False)],
          'ddelerne': [('ddeler', False)],
          'ddeles': [('ddele', False)],
          'dden': [('d', False)],
          'ddender': [('ddend', False)],
          'ddenderne': [('ddend', False)],
          'ddendernes': [('ddend', False)],
          'ddenders': [('ddend', False)],
          'ddens': [('d', False)],
          'dder': [('d', False)],
          'ddere': [('dder', False)],
          'dderen': [('dder', False)],
          'dderens': [('dder', False)],
          'dderes': [('dder', False)],
          'dderet': [('dder', False)],
          'dderets': [('dder', False)],
          'dderne': [('d', False)],
          'ddernes': [('d', False)],
          'dderok': [('dderokke', False)],
          'dderokke': [('dderokke', False)],
          'dderokken': [('dderokke', False)],
          'dderokkens': [('dderokke', False)],
          'dderokkes': [('dderokke', False)],
          'dderoks': [('dderokke', False)],
          'dders': [('dder', False)],
          'ddet': [('d', False)],
          'ddhas': [('ddha', False)],
          'ddien': [('ddie', False)],
          'ddiens': [('ddie', False)],
          'ddier': [('ddie', False)],
          'ddierne': [('ddie', False)],
          'ddiernes': [('ddie', False)],
          'ddiers': [('ddie', False)],
          'ddomme': [('ddom', False)],
          'ddrager': [('ddrager', False)],
          'ddragerne': [('ddrager', False)],
          'ddragernes': [('ddrager', False)],
          'ddragers': [('ddrager', False)],
          'ddrenges': [('ddreng', False)],
          'ddriver': [('ddriver', False)],
          'ddriverne': [('ddriver', False)],
          'ddrivernes': [('ddriver', False)],
          'ddrivers': [('ddriver', False)],
          'ddråbers': [('ddråbe', False)],
          'ddækker': [('ddække', False)],
          'ddækket': [('ddæk', False)],
          'ddækkets': [('ddæk', False)],
          'de': [('de', False)],
          'dealer': [('dealer', True)],
          'dealerne': [('dealer', True)],
          'dealernes': [('dealer', True)],
          'dealers': [('dealer', True)],
          'dearbejder': [('dearbejde', False)],
          'dearbejderne': [('dearbejde', False)],
          'deballerne': [('deballe', False)],
          'deballernes': [('deballe', False)],
          'debens': [('deben', False)],
          'debet': [('debet', True)],
          'debets': [('debet', True)],
          'debroderen': [('debroder', False)],
          'debroderens': [('debror', False)],
          'debroerne': [('debro', False)],
          'debroernes': [('debro', False)],
          'debrødre': [('debror', False)],
          'debrødrene': [('debror', False)],
          'debrødrenes': [('debror', False)],
          'debrødres': [('debror', False)],
          'debønnen': [('debøn', False)],
          'debønnens': [('debøn', False)],
          'debønner': [('debøn', False)],
          'debønnerne': [('debøn', False)],
          'debønnernes': [('debøn', False)],
          'debønners': [('debøn', False)],
          'dedagens': [('dedag', False)],
          'dedans': [('dedans', False)],
          'deen': [('de', False)],
          'deer': [('de', False)],
          'defaderen': [('defar', False)],
          'defaderens': [('defar', False)],
          'defaren': [('defar', False)],
          'deforældre': [('deforældre', False)],
          'defædrene': [('defar', False)],
          'defædres': [('defar', False)],
          'degas': [('dega', False)],
          'degaver': [('degave', False)],
          'degaverne': [('degave', False)],
          'degavernes': [('degave', False)],
          'degavers': [('degave', False)],
          'degne': [('degn', False)],
          'degnen': [('degn', True)],
          'degnens': [('degn', False)],
          'degrene': [('degren', False)],
          'degrenes': [('degren', False)],
          'degrøden': [('degrød', False)],
          'degrødens': [('degrød', False)],
          'dehals': [('dehals', False)],
          'dehandler': [('dehandel', False)],
          'dehandlerne': [('dehandler', False)],
          'dehandlernes': [('dehandler', False)],
          'dehandlers': [('dehandel', False)],
          'dehave': [('dehav', False)],
          'deje': [('dej', True)],
          'dejenes': [('dej', True)],
          'dejerne': [('dejer', False)],
          'dejes': [('dej', True)],
          'dejet': [('deje', False)],
          'dejets': [('deje', False)],
          'dejnen': [('dejn', False)],
          'dejnens': [('dejn', False)],
          'dejner': [('dejn', False)],
          'dejnerne': [('dejn', False)],
          'dejnernes': [('dejn', False)],
          'dejners': [('dejn', False)],
          'dekartofler': [('dekartofler', False)],
          'dekartoflerne': [('dekartofler', False)],
          'dekartoflernes': [('dekartofler', False)],
          'dekartoflers': [('dekartofler', False)],
          'dekerne': [('dekerne', False)],
          'dekernes': [('dekerne', False)],
          'deklæderne': [('deklæde', False)],
          'dekoder': [('dekoder', True)],
          'dekoderne': [('dekoder', True)],
          'dekodernes': [('dekoder', True)],
          'dekoders': [('dekoder', True)],
          'dekrans': [('dekran', False)],
          'deks': [('deks', False)],
          'dekserne': [('deks', False)],
          'deksernes': [('deks', False)],
          'deksers': [('deks', False)],
          'dekunster': [('dekunster', False)],
          'dekunsternes': [('dekunster', False)],
          'dekurs': [('dekur', False)],
          'delagen': [('delagen', False)],
          'delaks': [('delaks', False)],
          'dele': [('del', True)],
          'delene': [('del', True)],
          'delenes': [('del', True)],
          'deler': [('deler', False)],
          'delernes': [('deler', False)],
          'delers': [('deler', False)],
          'deles': [('del', True)],
          'delfarter': [('delfarter', False)],
          'delfarterne': [('delfarter', False)],
          'delfarters': [('delfarter', False)],
          'delinen': [('deline', False)],
          'delinens': [('deline', False)],
          'delinerne': [('deline', False)],
          'deliners': [('deline', False)],
          'delisten': [('delist', False)],
          'delistens': [('delist', False)],
          'delisternes': [('deliste', False)],
          'delisters': [('deliste', False)],
          'delle': [('delle', False)],
          'dellen': [('delle', True)],
          'dellens': [('delle', True)],
          'deller': [('delle', True)],
          'dellerne': [('delle', False)],
          'dellernes': [('delle', False)],
          'dellers': [('delle', True)],
          'delles': [('delle', False)],
          'dellevetiden': [('dellevetid', False)],
          'delsers': [('delse', False)],
          'delukker': [('delukke', False)],
          'delukkernes': [('delukke', False)],
          'delærer': [('delære', False)],
          'delærers': [('delære', False)],
          'deløber': [('deløber', False)],
          'deløbernes': [('deløber', False)],
          'demagerne': [('demager', False)],
          'demagernes': [('demager', False)],
          'demagers': [('demager', False)],
          'demanden': [('demand', False)],
          'demandens': [('demand', False)],
          'demarchens': [('demarche', True)],
          'demarcherne': [('demarche', True)],
          'demarchers': [('demarche', True)],
          'demaster': [('demast', False)],
          'demasters': [('demast', False)],
          'demens': [('demens', True)],
          'demmen': [('dem', False)],
          'demmens': [('dem', False)],
          'demmer': [('dem', False)],
          'demmerne': [('dem', False)],
          'demmernes': [('dem', False)],
          'demmers': [('dem', False)],
          'demoder': [('demor', False)],
          'demoderne': [('demor', False)],
          'demodernes': [('demor', False)],
          'demoders': [('demode', False)],
          'demodet': [('demode', False)],
          'demodets': [('demode', False)],
          'demærker': [('demærke', False)],
          'den': [('de', False)],
          'denden': [('dend', False)],
          'dendens': [('dend', False)],
          'dender': [('dende', False)],
          'denderne': [('dende', False)],
          'dendernes': [('dende', False)],
          'denders': [('dende', False)],
          'dene': [('', False)],
          'denen': [('den', False)],
          'denens': [('den', False)],
          'dener': [('den', False)],
          'denerne': [('den', False)],
          'denernes': [('den', False)],
          'deners': [('den', False)],
          'denes': [('', False)],
          'denet': [('denet', False)],
          'denets': [('denet', False)],
          'denge': [('deng', False)],
          'dengenes': [('deng', False)],
          'denges': [('deng', False)],
          'dengs': [('deng', False)],
          'dengsen': [('dengse', True)],
          'dengsens': [('dengse', True)],
          'denier': [('denier', True)],
          'denierne': [('denia', False)],
          'deniernes': [('denia', False)],
          'deniers': [('denier', True)],
          'dennes': [('dennes', True)],
          'dens': [('de', False)],
          "dens'": [('dens', False)],
          'densen': [('dens', False)],
          'densens': [('dens', False)],
          'denser': [('dens', False)],
          'denserne': [('denser', False)],
          'densernes': [('dens', False)],
          'densers': [('dens', False)],
          'dentalen': [('dental', False)],
          'dentalens': [('dental', True)],
          'dentaler': [('dental', True)],
          'dentalerne': [('dental', False)],
          'dentalernes': [('dental', False)],
          'dentalers': [('dental', True)],
          'denten': [('dente', True)],
          'dentens': [('dente', True)],
          'denter': [('dente', True)],
          'denterne': [('dente', True)],
          'denternes': [('dente', True)],
          'denters': [('dente', True)],
          'dentet': [('dent', False)],
          'dentets': [('dent', False)],
          'dentinen': [('dentin', True)],
          'dentinens': [('dentin', True)],
          'deoner': [('deon', False)],
          'deonerne': [('deon', False)],
          'deonernes': [('deon', False)],
          'deoners': [('deon', False)],
          'deplage': [('deplage', False)],
          'deposen': [('depose', False)],
          'deposens': [('depose', False)],
          'deposer': [('depose', False)],
          'deposerne': [('depose', False)],
          'deposernes': [('depose', False)],
          'depottens': [('depotte', False)],
          'depotter': [('depotte', False)],
          'depotterne': [('depotte', False)],
          'dera': [('dera', False)],
          'deras': [('dera', False)],
          'derasters': [('derast', False)],
          'derbassens': [('derbasse', False)],
          'derbasser': [('derbasse', False)],
          'derbasserne': [('derbasse', False)],
          'deret': [('deret', False)],
          'derets': [('deret', False)],
          'deretten': [('deret', False)],
          'derettens': [('deret', False)],
          'deretterne': [('deret', False)],
          'deretternes': [('deret', False)],
          'deretters': [('deret', False)],
          'derhandler': [('derhandler', False)],
          'derhandlerne': [('derhandler', False)],
          'derhandlernes': [('derhandel', False)],
          'derhandlers': [('derhandler', False)],
          'derier': [('deri', False)],
          'derierne': [('deri', False)],
          'deriernes': [('deri', False)],
          'deriers': [('deri', False)],
          'deriet': [('deri', False)],
          'deriets': [('deri', False)],
          'deris': [('deri', False)],
          'derlagen': [('derlagen', False)],
          'derlagens': [('derlagen', False)],
          'derminers': [('dermine', False)],
          'dermænd': [('dermand', False)],
          'dermændene': [('dermand', False)],
          'dermændenes': [('dermand', False)],
          'dermænds': [('dermand', False)],
          'derok': [('derok', False)],
          'derokke': [('derok', False)],
          'derokken': [('derok', False)],
          'derokkens': [('derok', False)],
          'derokkes': [('derok', False)],
          'deroks': [('derok', False)],
          'derolen': [('derole', False)],
          'derolens': [('derole', False)],
          'derreden': [('derred', False)],
          'derredens': [('derred', False)],
          'derredes': [('derred', False)],
          'derret': [('derret', False)],
          'ders': [('de', False)],
          "ders'": [('ders', False)],
          'derserne': [('ders', False)],
          'dersernes': [('ders', False)],
          'dersken': [('derske', False)],
          'dersker': [('derske', False)],
          'derskerne': [('derske', False)],
          'derskers': [('derske', False)],
          'derstemmer': [('derstemme', False)],
          'derstemmerne': [('derstemme', False)],
          'derstemmernes': [('derstemme', False)],
          'derstemmers': [('derstemme', False)],
          'dersten': [('dersten', False)],
          'derten': [('dert', False)],
          'dertens': [('dert', False)],
          'derter': [('dert', False)],
          'derterne': [('dert', False)],
          'derters': [('dert', False)],
          'derts': [('dert', False)],
          'derusserne': [('derusser', False)],
          'derussers': [('derusser', False)],
          'des': [('des', True)],
          "des'": [('des', True)],
          'desager': [('desag', False)],
          'desagerne': [('desag', False)],
          'dese': [('dese', False)],
          'desen': [('dese', False)],
          'desens': [('dese', False)],
          'deser': [('des', False)],
          'deserne': [('des', False)],
          'desernes': [('des', False)],
          'desers': [('des', False)],
          'deses': [('dese', False)],
          'desidens': [('deside', False)],
          'deskaber': [('deskaber', False)],
          'deskaberne': [('deskaber', False)],
          'deskabernes': [('deskaber', False)],
          'deskabers': [('deskaber', False)],
          'deske': [('desk', False)],
          'desken': [('desk', False)],
          'deskenes': [('desk', False)],
          'deskes': [('desk', False)],
          'deskifte': [('deskifte', False)],
          'deskifter': [('deskifte', False)],
          'deskifterne': [('deskifte', False)],
          'deskifternes': [('deskifte', False)],
          'deskiftes': [('deskifte', False)],
          'deskiftet': [('deskifte', False)],
          'deskiftets': [('deskifte', False)],
          'desmerter': [('desmerte', False)],
          'desmerternes': [('desmerte', False)],
          'desmerters': [('desmerte', False)],
          'desparker': [('desparker', False)],
          'desparkerne': [('desparker', False)],
          'desparkernes': [('desparker', False)],
          'despiller': [('despiller', False)],
          'despillerne': [('despiller', False)],
          'despillernes': [('despiller', False)],
          'despillers': [('despiller', False)],
          'dessens': [('desse', False)],
          'desser': [('des', True)],
          'desserne': [('des', True)],
          'dessernes': [('des', True)],
          'dessers': [('des', True)],
          'dessinernes': [('dessin', True)],
          'destalen': [('destal', False)],
          'destene': [('desten', False)],
          'destens': [('desten', False)],
          'dester': [('dest', False)],
          'desterne': [('dest', False)],
          'desternes': [('dest', False)],
          'desters': [('dest', False)],
          'destier': [('desti', False)],
          'destiernes': [('desti', False)],
          'destigerne': [('destige', False)],
          'destigernes': [('destige', False)],
          'destigers': [('destige', False)],
          'destøvlers': [('destøvle', False)],
          'det': [('de', False)],
          'detage': [('detag', False)],
          'detages': [('detag', False)],
          'detailhandler': [('detailhandel', True), ('detailhandler', True)],
          'detailhandlerne': [('detailhandel', True), ('detailhandler', True)],
          'detailhandlernes': [('detailhandler', True), ('detailhandel', True)],
          'detailhandlers': [('detailhandel', True), ('detailhandler', True)],
          'deter': [('det', False)],
          'deters': [('det', False)],
          'detiden': [('detid', False)],
          'dets': [('', False)],
          'detten': [('det', False)],
          'dettens': [('det', False)],
          'detter': [('det', False)],
          'detterne': [('det', False)],
          'detternes': [('det', False)],
          'detters': [('det', False)],
          'detæer': [('detå', False)],
          'detæerne': [('detå', False)],
          'detæernes': [('detå', False)],
          'detæers': [('detå', False)],
          'devinden': [('devind', False)],
          'devindens': [('devind', False)],
          'devindes': [('devind', False)],
          'deviser': [('devise', False)],
          'deviserne': [('devise', True)],
          'dfanger': [('dfanger', False)],
          'dfangerne': [('dfanger', False)],
          'dfangernes': [('dfanger', False)],
          'dfangers': [('dfanger', False)],
          'dfaren': [('dfar', False)],
          'dfarens': [('dfar', False)],
          'dfars': [('dfar', False)],
          'dfe': [('dfe', False)],
          'dfes': [('dfe', False)],
          'dfladen': [('dflade', False)],
          'dfladens': [('dflade', False)],
          'dflisen': [('dflise', False)],
          'dflisens': [('dflise', False)],
          'dfliser': [('dflise', False)],
          'dfliserne': [('dflise', False)],
          'dflisernes': [('dflise', False)],
          'dflisers': [('dflise', False)],
          'dflomme': [('dflom', False)],
          'dflommen': [('dflom', False)],
          'dflommens': [('dflom', False)],
          'dflommes': [('dflom', False)],
          'dflugter': [('dflugt', False)],
          'dflugterne': [('dflugt', False)],
          'dflugternes': [('dflugt', False)],
          'dflugters': [('dflugt', False)],
          'dformer': [('dform', False)],
          'dformerne': [('dform', False)],
          'dformernes': [('dform', False)],
          'dformers': [('dform', False)],
          'dforældre': [('dforælder', False)],
          'dfruers': [('dfrue', False)],
          'dfædre': [('dfar', False)],
          'dfædrenes': [('dfar', False)],
          'dfærden': [('dfærd', False)],
          'dfærdens': [('dfærd', False)],
          'dfæster': [('dfæste', False)],
          'dfæsterne': [('dfæste', False)],
          'dfæsternes': [('dfæste', False)],
          'dfæsters': [('dfæste', False)],
          'dførerne': [('dfører', False)],
          'dgader': [('dgade', False)],
          'dgas': [('dgas', False)],
          "dgas'": [('dgas', False)],
          'dgen': [('dge', False)],
          'dgene': [('dge', False)],
          'dgenes': [('dge', False)],
          'dgens': [('dge', False)],
          'dges': [('dge', False)],
          "dges'": [('dge', False)],
          'dget': [('dget', False)],
          'dgets': [('dget', False)],
          'dgetter': [('dget', False)],
          'dgifte': [('dgifte', False)],
          'dgiftes': [('dgifte', False)],
          'dgrøden': [('dgrød', False)],
          'dgrødens': [('dgrød', False)],
          'dgyder': [('dgyde', False)],
          'dgyderne': [('dgyde', False)],
          'dgydernes': [('dgyder', False)],
          'dgyders': [('dgyder', False)],
          'dgænger': [('dgænger', False)],
          'dgængerne': [('dgænger', False)],
          'dgængernes': [('dgænger', False)],
          'dgængers': [('dgænger', False)],
          'dgørerne': [('dgører', False)],
          'dhakker': [('dhakker', False)],
          'dhakkerne': [('dhakker', False)],
          'dhakkernes': [('dhakker', False)],
          'dhakkers': [('dhakker', False)],
          'dhaler': [('dhaler', False)],
          'dhalerne': [('dhaler', False)],
          'dhalernes': [('dhaler', False)],
          'dhalers': [('dhaler', False)],
          'dhals': [('dhals', False)],
          'dhandler': [('dhandel', False)],
          'dhandlerne': [('dhandler', False)],
          'dhandlernes': [('dhandel', False)],
          'dhandlers': [('dhandel', False)],
          'dhas': [('dhas', False)],
          "dhas'": [('dhas', False)],
          'dhase': [('dhas', False)],
          'dhasen': [('dhas', False)],
          'dhasens': [('dhas', False)],
          'dhases': [('dhas', False)],
          'dhave': [('dhave', False)],
          'dhaves': [('dhav', False)],
          'dheden': [('dhed', False)],
          'dhedens': [('dhed', False)],
          'dheder': [('dhed', False)],
          'dhederne': [('dhed', False)],
          'dhedernes': [('dhed', False)],
          'dheders': [('dhed', False)],
          'dholterne': [('dholt', False)],
          'dholters': [('dholt', False)],
          'dhopper': [('dhopper', False)],
          'dhopperne': [('dhopper', False)],
          'dhoppernes': [('dhopper', False)],
          'dhoppers': [('dhopper', False)],
          'dhuen': [('dhue', False)],
          'dhuens': [('dhu', False)],
          'dhunternes': [('dhunter', False)],
          'dhus': [('dhus', False)],
          'dhvilerne': [('dhviler', False)],
          'dhvilernes': [('dhviler', False)],
          'dhvilers': [('dhviler', False)],
          'dhytten': [('dhytte', False)],
          'dhyttens': [('dhytte', False)],
          'dhærens': [('dhærens', False)],
          'dhøjder': [('dhøjde', False)],
          'dhøjderne': [('dhøjde', False)],
          'dhøjdernes': [('dhøjde', False)],
          'dhøjders': [('dhøjde', False)],
          'di': [('di', False)],
          'dia': [('die', False)],
          'dianer': [('dian', False)],
          'dianerne': [('dianer', False)],
          'dianernes': [('dianer', False)],
          'dianers': [('dian', False)],
          'dians': [('dian', False)],
          'dias': [('dias', True)],
          'diater': [('diat', False)],
          'diaterne': [('diat', False)],
          'diaternes': [('diater', False)],
          'diaters': [('diat', False)],
          'dices': [('deks', False)],
          "dices'": [('deks', False)],
          'dicierne': [('dicie', False)],
          'diciernes': [('dicie', False)],
          'dicium': [('dicie', False)],
          'diciums': [('dicie', False)],
          'dien': [('di', False)],
          'diene': [('dus', False)],
          'dienes': [('dus', False)],
          'diens': [('di', False)],
          'dienserne': [('diens', False)],
          'diere': [('dier', False)],
          'dieren': [('dier', False)],
          'dierens': [('dier', False)],
          'dieres': [('dier', False)],
          'dierne': [('di', False)],
          'diers': [('di', False)],
          'dies': [('die', True)],
          "dies'": [('die', False)],
          'differens': [('differens', False)],
          'dige': [('dige', True)],
          'diger': [('dige', True)],
          'diges': [('dige', True)],
          'diget': [('dige', True)],
          'digets': [('dige', True)],
          'diglen': [('digel', True)],
          'diglens': [('digel', False)],
          'digler': [('digel', True)],
          'diglerne': [('digel', True)],
          'diglernes': [('digel', False)],
          'diglers': [('digel', False)],
          'digte': [('digt', True)],
          'digters': [('digter', True)],
          'digtes': [('digt', False)],
          'digtet': [('digt', True)],
          'digtets': [('digt', False)],
          'dika': [('dikum', False)],
          'dikaene': [('dikum', False)],
          'dikaenes': [('dikum', False)],
          'dikas': [('dikum', False)],
          'diken': [('dike', False)],
          'dikens': [('dike', False)],
          'diker': [('dike', False)],
          'dikerne': [('dike', False)],
          'dikernes': [('dike', False)],
          'dikers': [('dike', False)],
          'dikken': [('dik', False)],
          'dikkerne': [('dik', False)],
          'diklen': [('dikel', False)],
          'diklerne': [('dikel', False)],
          'diklernes': [('dikel', False)],
          'diklers': [('dikel', False)],
          'diks': [('dik', True)],
          "diks'": [('diks', False)],
          'diksen': [('diks', False)],
          'diksens': [('diks', False)],
          'dikserne': [('diks', False)],
          'diksernes': [('diks', False)],
          'diksers': [('diks', False)],
          'dikter': [('dikt', False)],
          'dikterne': [('dikt', False)],
          'dikternes': [('dikt', False)],
          'dikters': [('dikt', False)],
          'dikum': [('dikum', False)],
          'dikums': [('dikum', False)],
          'dildens': [('dild', True)],
          'dillens': [('dille', False)],
          'diller': [('dille', False)],
          'dillerne': [('dille', False)],
          'dillernes': [('dille', False)],
          'dillers': [('dille', False)],
          'dimenterne': [('diment', False)],
          'dimentet': [('diment', False)],
          'dimentets': [('diment', False)],
          'dims': [('dims', True)],
          'dinalens': [('dinal', False)],
          'dinder': [('dinde', False)],
          'dinderne': [('dinde', False)],
          'dindernes': [('dinde', False)],
          'dinders': [('dinde', False)],
          'dine': [('dine', False)],
          'dinen': [('dine', False)],
          'dinens': [('dine', False)],
          'diner': [('diner', True)],
          'dinerne': [('din', False)],
          'dinernes': [('dine', False)],
          'diners': [('diner', True)],
          'dines': [('dine', False)],
          'dinge': [('ding', False)],
          'dingen': [('ding', False)],
          'dingens': [('ding', False)],
          'dingenser': [('dingenser', False)],
          'dingensernes': [('dingenser', False)],
          'dinger': [('ding', False)],
          'dingerne': [('ding', False)],
          'dingernes': [('ding', False)],
          'dinges': [('ding', False)],
          'dings': [('ding', False)],
          'dinier': [('dinier', False)],
          'diniernes': [('dinier', False)],
          'diniers': [('dinier', False)],
          'dionerne': [('dion', False)],
          'dionernes': [('dion', False)],
          'dioners': [('dion', False)],
          'dionet': [('dion', False)],
          'dionets': [('dion', False)],
          'dions': [('dion', False)],
          'dippen': [('dip', True)],
          'dippens': [('dip', True)],
          'direr': [('direr', False)],
          'dirernes': [('direr', False)],
          'dirers': [('direr', False)],
          'dirke': [('dirk', True)],
          'dirken': [('dirk', True)],
          'dirkes': [('dirk', True)],
          'dis': [('dis', True)],
          'dise': [('dise', False)],
          'disen': [('dis', True)],
          'disens': [('dis', True)],
          'diser': [('dise', False)],
          'diserne': [('dise', False)],
          'disernes': [('dise', False)],
          'disers': [('diser', False)],
          'dises': [('dise', False)],
          'diset': [('dise', False)],
          'disets': [('dise', False)],
          'diske': [('disk', False)],
          'disken': [('disk', False)],
          'diskos': [('diskos', True), ('disko', True)],
          'diskrimination': [('aldersdiskrimination', True), ('diskrimination', True)],
          'diskriminationen': [('aldersdiskrimination', True), ('diskrimination', True)],
          'diskriminationens': [('aldersdiskrimination', True), ('diskrimination', True)],
          'diskriminations': [('aldersdiskrimination', True), ('diskrimination', True)],
          'dismen': [('disme', False)],
          'dismens': [('disme', False)],
          'dissen': [('dis', False)],
          'dissens': [('dissens', True)],
          'disser': [('dis', False)],
          'disserne': [('dis', False)],
          'dissernes': [('dis', False)],
          'dissers': [('dis', True)],
          'disten': [('dist', False)],
          'distens': [('dist', False)],
          'dister': [('dist', False)],
          'disterne': [('dist', False)],
          'disternes': [('dist', False)],
          'disters': [('dist', False)],
          'distikaene': [('distikon', True)],
          'distikaenes': [('distikon', True)],
          'distikon': [('distikon', True)],
          'distikons': [('distikon', True)],
          'ditorier': [('ditori', False)],
          'ditorierne': [('ditori', False)],
          'ditoriernes': [('ditori', False)],
          'ditoriers': [('ditori', False)],
          'ditoriet': [('ditori', False)],
          'ditoriets': [('ditori', False)],
          'ditoris': [('ditori', False)],
          'ditten': [('ditten', True)],
          'dittens': [('dit', False)],
          'ditternes': [('dit', False)],
          'ditters': [('dit', False)],
          'ditørerne': [('ditør', False)],
          'ditørernes': [('ditør', False)],
          'ditørers': [('ditør', False)],
          'dium': [('die', False)],
          'diums': [('die', False)],
          'diver': [('diver', False)],
          'diverne': [('div', False)],
          'divernes': [('diver', False)],
          'divers': [('div', False)],
          'dividenden': [('dividend', True), ('dividende', True)],
          'dividendens': [('dividend', True), ('dividende', True)],
          'dividender': [('dividende', True), ('dividend', True)],
          'dividenderne': [('dividende', True), ('dividend', True)],
          'dividendernes': [('dividende', True), ('dividend', True)],
          'dividenders': [('dividende', True), ('dividend', True)],
          'diæter': [('diæt', True), ('diæter', True)],
          'diæterne': [('diæt', True), ('diæter', True)],
          'diæternes': [('diæter', True), ('diæt', True)],
          'diæters': [('diæter', True), ('diæt', True)],
          'djakken': [('djakke', False)],
          'djanernes': [('djaner', False)],
          'djens': [('dje', False)],
          'djer': [('dje', False)],
          'djorden': [('djord', False)],
          'djordens': [('djord', False)],
          'dka': [('dka', False)],
          'dkagen': [('dkage', False)],
          'dkagens': [('dkage', False)],
          'dkandernes': [('dkande', False)],
          'dkanoner': [('dkanon', False)],
          'dkanoners': [('dkanon', False)],
          'dkapers': [('dkaper', False)],
          'dkartofler': [('dkartoffel', False)],
          'dkartoflerne': [('dkartoffel', False)],
          'dkartoflernes': [('dkartoffel', False)],
          'dkas': [('dka', False)],
          'dkaster': [('dkaster', False)],
          'dkasterne': [('dkaster', False)],
          'dkasternes': [('dkaster', False)],
          'dkasters': [('dkaster', False)],
          'dker': [('dker', False)],
          'dkere': [('dker', False)],
          'dkeren': [('dker', False)],
          'dkerens': [('dker', False)],
          'dkeres': [('dker', False)],
          'dkerne': [('dker', False)],
          'dkernes': [('dker', False)],
          'dkers': [('dker', False)],
          'dkiks': [('dkik', False)],
          'dklips': [('dklip', False)],
          'dklæder': [('dklæde', False)],
          'dklæderne': [('dklæde', False)],
          'dklædernes': [('dklæde', False)],
          'dklæders': [('dklæde', False)],
          'dkontroller': [('dkontrol', False)],
          'dkontrollerne': [('dkontrol', False)],
          'dkontrollernes': [('dkontrol', False)],
          'dkontrollers': [('dkontrol', False)],
          'dkopper': [('dkopper', False)],
          'dkopperne': [('dkopper', False)],
          'dkoppernes': [('dkop', False)],
          'dkoppers': [('dkopper', False)],
          'dkornet': [('dkorn', False)],
          'dkornets': [('dkorn', False)],
          'dkreds': [('dkreds', False)],
          'dkrigernes': [('dkriger', False)],
          'dkunsternes': [('dkunst', False)],
          'dkuren': [('dkur', False)],
          'dkures': [('dkur', False)],
          'dkurs': [('dkurs', False)],
          'dkurve': [('dkurv', False)],
          'dkurven': [('dkurv', False)],
          'dkurvens': [('dkurv', False)],
          'dkurves': [('dkurv', False)],
          'dkvarter': [('dkvarter', False)],
          'dkvarters': [('dkvarter', False)],
          'dkæmper': [('dkæmper', False)],
          'dkæmperne': [('dkæmper', False)],
          'dkæmpernes': [('dkæmper', False)],
          'dkæmpers': [('dkæmper', False)],
          'dkøbet': [('dkøb', False)],
          'dkøer': [('dkø', False)],
          'dkøerne': [('dkø', False)],
          'dkøernes': [('dkø', False)],
          'dkøers': [('dkø', False)],
          'dl': [('deciliter', True)],
          'dlader': [('dlader', False)],
          'dladerne': [('dlader', False)],
          'dladernes': [('dlader', False)],
          'dladers': [('dlader', False)],
          'dlaks': [('dlaks', False)],
          'dlanger': [('dlanger', False)],
          'dlangerne': [('dlanger', False)],
          'dlangernes': [('dlanger', False)],
          'dlangers': [('dlanger', False)],
          'dlapper': [('dlap', False)],
          'dlappernes': [('dlap', False)],
          'dlaps': [('dlap', False)],
          'dle': [('ddel', False)],
          'dleder': [('dleder', False)],
          'dledernes': [('dleder', False)],
          'dlejer': [('dlejer', False)],
          'dlejerne': [('dleje', False)],
          'dlejernes': [('dleje', False)],
          'dlejers': [('dleje', False)],
          'dlemmerne': [('dlem', False)],
          'dlemmers': [('dlem', False)],
          'dlen': [('del', False)],
          'dlens': [('ddel', False)],
          'dler': [('dler', False)],
          'dlere': [('dler', False)],
          'dleren': [('dler', False)],
          'dlerens': [('dler', False)],
          'dleres': [('dler', False)],
          'dlers': [('dler', False)],
          'dles': [('ddel', False)],
          'dlet': [('ddel', False)],
          'dlets': [('ddel', False)],
          'dleven': [('dleven', False)],
          'dlevens': [('dleven', False)],
          'dlighters': [('dlighter', False)],
          'dlinene': [('dline', False)],
          'dlinenes': [('dline', False)],
          'dliner': [('dline', False)],
          'dlinerne': [('dline', False)],
          'dlinernes': [('dline', False)],
          'dliners': [('dline', False)],
          'dlingers': [('dling', False)],
          'dlinien': [('dlinie', False)],
          'dlisten': [('dliste', False)],
          'dlistens': [('dliste', False)],
          'dlister': [('dliste', False)],
          'dlisterne': [('dliste', False)],
          'dlocks': [('dlocks', False)],
          'dlodden': [('dlod', False)],
          'dloddens': [('dlod', False)],
          'dlodder': [('dlod', False)],
          'dlodderne': [('dlod', False)],
          'dloddernes': [('dlod', False)],
          'dlodders': [('dlod', False)],
          'dlods': [('dlod', False)],
          'dlove': [('dlov', False)],
          'dlus': [('dlus', False)],
          'dlusen': [('dlus', False)],
          'dlyde': [('dlyd', False)],
          'dlyden': [('dlyd', False)],
          'dlydens': [('dlyd', False)],
          'dlydes': [('dlyd', False)],
          'dlys': [('dlys', False)],
          'dlægernes': [('dlæge', False)],
          'dlænder': [('dlænder', False)],
          'dlænderne': [('dlænder', False)],
          'dlændernes': [('dlænder', False)],
          'dlænders': [('dlænder', False)],
          'dlærer': [('dlærer', False)],
          'dlærerne': [('dlære', False)],
          'dlærernes': [('dlære', False)],
          'dlærers': [('dlærer', False)],
          'dløberne': [('dløber', False)],
          'dløbers': [('dløber', False)],
          'dløs': [('dløs', False)],
          'dløsen': [('dløs', False)],
          'dløsens': [('dløs', False)],
          'dløser': [('dløser', False)],
          'dløserne': [('dløser', False)],
          'dløsers': [('dløser', False)],
          'dm.': [('dm.', False)],
          'dmadders': [('dmad', False)],
          'dmaden': [('dmad', False)],
          'dmadens': [('dmad', False)],
          'dmads': [('dmad', False)],
          'dmager': [('dmager', False)],
          'dmagerne': [('dmager', False)],
          'dmagernes': [('dmager', False)],
          'dmagers': [('dmager', False)],
          'dmappen': [('dmap', False)],
          'dmappens': [('dmap', False)],
          'dmarchen': [('dmarch', False)],
          'dmarchens': [('dmarch', False)],
          'dmarcherne': [('dmarch', False)],
          'dmarker': [('dmarker', False)],
          'dmarkerne': [('dmarker', False)],
          'dmarkernes': [('dmark', False)],
          'dmarkers': [('dmark', False)],
          'dmassens': [('dmasse', False)],
          'dmasserne': [('dmasse', False)],
          'dmen': [('dme', False)],
          'dmens': [('dme', False)],
          'dmeter': [('dmeter', False)],
          'dmeters': [('dmeter', False)],
          'dmilen': [('dmile', False)],
          'dmilens': [('dmile', False)],
          'dminers': [('dmine', False)],
          'dmosen': [('dmose', False)],
          'dmosens': [('dmose', False)],
          'dmælken': [('dmælk', False)],
          'dmælkens': [('dmælk', False)],
          'dmænd': [('dmand', False)],
          'dmændene': [('dmand', False)],
          'dmændenes': [('dmand', False)],
          'dmærkerne': [('dmærke', False)],
          'dmærkernes': [('dmærke', False)],
          'dmærkers': [('dmærke', False)],
          'dmøller': [('dmølle', False)],
          'dmøllerne': [('dmølle', False)],
          'dmøllernes': [('dmølle', False)],
          'dmøllers': [('dmølle', False)],
          'dnapper': [('dnapper', False)],
          'dnappers': [('dnapper', False)],
          'dnerne': [('dne', False)],
          'dnernes': [('dner', False)],
          'dnets': [('dnet', False)],
          'dningers': [('dning', False)],
          'dnis': [('dnis', False)],
          "dnis'": [('dnis', False)],
          'dnisser': [('dnis', False)],
          'dnisserne': [('dnis', False)],
          'dnissernes': [('dnis', False)],
          'dnissers': [('dnis', False)],
          'dnoten': [('dnote', False)],
          'dnotens': [('dnote', False)],
          'dnoter': [('dnote', False)],
          'dnoterne': [('dnote', False)],
          'dnoternes': [('dnote', False)],
          'dnoters': [('dnote', False)],
          'do': [('do', False)],
          'doblens': [('doble', False)],
          'dobler': [('doble', False)],
          'dobroer': [('dobro', False)],
          'dobroerne': [('dobro', False)],
          'dobroernes': [('dobro', False)],
          'docenter': [('docent', True)],
          'dodder': [('dodder', True)],
          'dodders': [('dodder', True)],
          'doen': [('do', False)],
          'doens': [('do', False)],
          'doer': [('do', False)],
          'doerne': [('do', False)],
          'doernes': [('do', False)],
          'doers': [('do', False)],
          'doet': [('do', False)],
          'doets': [('do', True)],
          'dofret': [('doffer', False)],
          'dofrets': [('doffer', False)],
          'doge': [('doge', True)],
          'dogen': [('doge', True)],
          'dogens': [('doge', True)],
          'doger': [('doge', True)],
          'dogerne': [('doge', True)],
          'dogernes': [('doge', True)],
          'dogers': [('doge', True)],
          'doges': [('doge', True)],
          'doggen': [('dog', False)],
          'doggens': [('dog', False)],
          'dogger': [('dog', False)],
          'doggerne': [('dog', False)],
          'doggernes': [('dog', False)],
          'doirer': [('doir', False)],
          'doirernes': [('doir', False)],
          'doiret': [('doir', False)],
          'doirets': [('doir', False)],
          'dokken': [('dok', False)],
          'dokker': [('dok', False)],
          'dokkerne': [('dok', True)],
          'dokkernes': [('dok', True)],
          'dokkers': [('dok', False)],
          'doks': [('dok', True)],
          "doks'": [('doks', False)],
          'dokser': [('doks', False)],
          'dokserne': [('doks', False)],
          'doksernes': [('doks', False)],
          'doksers': [('doks', False)],
          'dokus': [('doku', False)],
          'doler': [('dol', False)],
          'dolerne': [('dol', False)],
          'doliner': [('dolin', False)],
          'dolkens': [('dolk', False)],
          'dolmerne': [('dolme', True)],
          'domaner': [('doman', False)],
          'domanerne': [('doman', False)],
          'domanernes': [('doman', False)],
          'domaners': [('doman', False)],
          'domen': [('dom', True)],
          'domens': [('dom', True)],
          'domhus': [('domhus', True)],
          'domme': [('domme', True), ('dom', True)],
          'dommen': [('dom', False)],
          'dommens': [('dom', False)],
          'dommer': [('dommer', False)],
          'dommerne': [('dommer', False)],
          'dommernes': [('dommer', False)],
          'dommes': [('dom', False)],
          'donen': [('done', True)],
          'donens': [('done', True)],
          'doner': [('done', True)],
          'donerne': [('done', True)],
          'donernes': [('done', True)],
          'doners': [('done', True)],
          'donier': [('donier', False)],
          'donierne': [('donier', False)],
          'doniernes': [('donier', False)],
          'doniers': [('donier', False)],
          'donissens': [('donis', False)],
          'donisser': [('donis', False)],
          'donisserne': [('donis', False)],
          'donissernes': [('donis', False)],
          'donissers': [('donis', False)],
          'donner': [('donner', False)],
          'donnerne': [('donner', False)],
          'donnernes': [('donner', False)],
          'donners': [('donner', False)],
          'donten': [('dont', True)],
          'dontens': [('dont', True)],
          'donterne': [('dont', False)],
          'donternes': [('dont', False)],
          'donters': [('dont', False)],
          'dopen': [('dope', True)],
          'doraner': [('doraner', False)],
          'doraners': [('doraner', False)],
          'dore': [('dore', False)],
          'dorer': [('dorer', True)],
          'dorerne': [('dorer', True)],
          'dorernes': [('dorer', True)],
          'dorers': [('dorer', True)],
          'dorgen': [('dorg', True)],
          'dorges': [('dorg', True)],
          'dorianerne': [('dorianer', False)],
          'dorianernes': [('dorianer', False)],
          'dorne': [('dorn', True)],
          'dornen': [('dorn', True)],
          'dornens': [('dorn', True)],
          'dornes': [('dorn', True)],
          'dorter': [('dorte', False)],
          'dorternes': [('dorte', False)],
          'dorters': [('dorte', False)],
          'dos': [('do', False)],
          "dos'": [('do', False)],
          'dosen': [('dosis', True)],
          'dosens': [('dosis', False)],
          'doser': [('dosis', True)],
          'doserne': [('dosis', True)],
          'dosernes': [('dosis', False)],
          'dosers': [('dosis', True)],
          'dosmer': [('dosmer', True)],
          'dosmernes': [('dosmer', True)],
          'dostens': [('dost', False)],
          'doten': [('dote', False)],
          'dotens': [('dote', False)],
          'doter': [('dote', False)],
          'doterne': [('dote', False)],
          'doternes': [('dote', False)],
          'doters': [('dote', False)],
          'dotes': [('dote', False)],
          'doucher': [('douche', True)],
          'doucherne': [('douche', True)],
          'douchers': [('douche', True)],
          'dourer': [('dour', False)],
          'dourers': [('dour', False)],
          'douter': [('doute', False)],
          'dover': [('dover', False)],
          'doverne': [('dover', False)],
          'doyen': [('doyen', True)],
          'dpakker': [('dpakker', False)],
          'dpakkerne': [('dpakke', False)],
          'dpakkernes': [('dpakker', False)],
          'dpakkers': [('dpakker', False)],
          'dpanter': [('dpant', False)],
          'dpanterne': [('dpant', False)],
          'dpanternes': [('dpant', False)],
          'dpanters': [('dpant', False)],
          'dpassager': [('dpassager', False)],
          'dpassagers': [('dpassager', False)],
          'dpiber': [('dpibe', False)],
          'dpiberne': [('dpibe', False)],
          'dpibernes': [('dpibe', False)],
          'dpibers': [('dpibe', False)],
          'dpigernes': [('dpige', False)],
          'dpigers': [('dpige', False)],
          'dpinernes': [('dpine', False)],
          'dpiners': [('dpine', False)],
          'dplanet': [('dplan', False)],
          'dplanets': [('dplan', False)],
          'dplanter': [('dplante', False)],
          'dplanterne': [('dplante', False)],
          'dplanternes': [('dplante', False)],
          'dplanters': [('dplante', False)],
          'dplejer': [('dplejer', False)],
          'dplejerne': [('dplejer', False)],
          'dplejernes': [('dplejer', False)],
          'dplejers': [('dplejer', False)],
          'dpolen': [('dpol', False)],
          'dpolers': [('dpol', False)],
          'dposter': [('dpost', False)],
          'dposterne': [('dpost', False)],
          'dposternes': [('dpost', False)],
          'dposters': [('dpost', False)],
          'dpotten': [('dpotte', False)],
          'dpottens': [('dpotte', False)],
          'dpotter': [('dpotte', False)],
          'dpotterne': [('dpotte', False)],
          'dpotternes': [('dpotte', False)],
          'dpotters': [('dpotte', False)],
          'dpressens': [('dpresse', False)],
          'dprisen': [('dpris', False)],
          'dprisens': [('dpris', False)],
          'dpriser': [('dpris', False)],
          'dpriserne': [('dpris', False)],
          'dprisernes': [('dpris', False)],
          'dprisers': [('dpris', False)],
          'dprocenter': [('dprocent', False)],
          'dprocenters': [('dprocent', False)],
          'dpumpen': [('dpumpe', False)],
          'dpumpens': [('dpumpe', False)],
          'dr.': [('doktor', True)],
          'dracer': [('drace', False)],
          'dracerne': [('drace', False)],
          'dracernes': [('drace', False)],
          'dracers': [('drace', False)],
          'drager': [('drage', True), ('drager', True)],
          'dragerne': [('drage', True), ('drager', True)],
          'dragernes': [('drage', True), ('drager', True)],
          'dragers': [('drage', True), ('drager', True)],
          'dragters': [('dragt', False)],
          'dralen': [('dral', False)],
          'draler': [('dral', False)],
          'dralerne': [('dral', False)],
          'dralernes': [('dral', False)],
          'dralers': [('dral', False)],
          'dramme': [('dram', True)],
          'drammen': [('dram', True)],
          'drammens': [('dram', True)],
          'drammer': [('dram', True)],
          'drammerne': [('dram', True)],
          'drammernes': [('dram', True)],
          'drammers': [('dram', True)],
          'drammes': [('dram', True)],
          'dranke': [('dranke', False)],
          'dranken': [('dranke', False)],
          'dranker': [('dranker', True)],
          'drankerne': [('dranker', True)],
          'drankernes': [('dranker', True)],
          'drankers': [('dranker', False)],
          'dras': [('dras', False)],
          'drasser': [('dras', False)],
          'drassernes': [('dras', False)],
          'drassers': [('dras', False)],
          'drater': [('drat', False)],
          'draterne': [('drat', False)],
          'draternes': [('drat', False)],
          'draters': [('drat', False)],
          'dre': [('der', False)],
          'drede': [('dred', False)],
          'dreder': [('dred', False)],
          'drederne': [('dred', False)],
          'dredernes': [('dred', False)],
          'dreders': [('dred', False)],
          'dredes': [('drede', False)],
          'dreds': [('dred', False)],
          'drehals': [('drehal', False)],
          'drejer': [('drejer', True)],
          'drejerne': [('drejer', True)],
          'drejernes': [('drejer', False)],
          'drejers': [('drejer', False)],
          'drejet': [('drej', True)],
          'drejets': [('drej', True)],
          'drejler': [('drejl', True)],
          'drejlers': [('drejl', True)],
          'drejser': [('drejse', False)],
          'drelser': [('drelse', False)],
          'drelserne': [('drelse', False)],
          'drelsernes': [('drelse', False)],
          'drelærerne': [('drelære', False)],
          'drelærernes': [('drelære', False)],
          'dren': [('dre', False)],
          'drendens': [('drende', False)],
          'drenge': [('dreng', True)],
          'drengene': [('dreng', True)],
          'drengenes': [('dreng', True)],
          'drenges': [('dreng', True)],
          'drens': [('dren', False)],
          'drer': [('drer', False)],
          'drerne': [('drer', False)],
          'drernes': [('drer', False)],
          'drers': [('dre', False)],
          'dres': [('dre', False)],
          'dressen': [('dresse', False)],
          'dresser': [('dresse', False)],
          'dresserne': [('dresse', False)],
          'dressernes': [('dresse', False)],
          'dressers': [('dresse', False)],
          'drestens': [('drest', False)],
          'dret': [('der', False)],
          'drets': [('dre', False)],
          'dretter': [('dret', False)],
          'drianerne': [('drian', False)],
          'drianernes': [('drian', False)],
          'drider': [('drid', False)],
          'driderne': [('drid', False)],
          'dridernes': [('drid', False)],
          'driders': [('drid', False)],
          'drids': [('drid', False)],
          'drier': [('drie', False)],
          'drierne': [('drie', False)],
          'driernes': [('drie', False)],
          'driers': [('drie', False)],
          'dries': [('drie', False)],
          'driggerne': [('drigger', False)],
          'driggernes': [('drigger', False)],
          'driglens': [('drigel', False)],
          'driglerne': [('drigel', False)],
          'drikke': [('drikke', True), ('drik', True)],
          'drikkens': [('drik', False)],
          'drikker': [('drik', False)],
          'drikkerne': [('drikker', False)],
          'drikkernes': [('drik', False)],
          'drikkers': [('drikker', False)],
          'driks': [('drik', True)],
          'drikse': [('drikse', False)],
          'driksen': [('drikse', False)],
          'driksens': [('drikse', False)],
          'drikses': [('drikse', False)],
          'drille': [('dril', True)],
          'drillen': [('dril', True)],
          'drillene': [('dril', True)],
          'drillenes': [('dril', True)],
          'drillens': [('dril', True)],
          'driller': [('drille', False)],
          'drillerne': [('drille', False)],
          'drillernes': [('drille', False)],
          'drillers': [('dril', False)],
          'drilles': [('dril', True)],
          'driner': [('driner', False)],
          'driners': [('driner', False)],
          'dringer': [('dring', False)],
          'dringerne': [('dring', False)],
          'dringernes': [('dring', False)],
          'dringers': [('dring', False)],
          'dris': [('dris', False)],
          'drisen': [('dris', False)],
          'drister': [('drister', False)],
          'dristerne': [('drister', False)],
          'dritten': [('drit', False)],
          'drittens': [('drit', False)],
          'dritter': [('drit', False)],
          'dritterne': [('drit', False)],
          'dritternes': [('drit', False)],
          'dritters': [('drit', False)],
          'drivene': [('drive', True)],
          'drivenes': [('drive', True)],
          'driver': [('drive', True), ('driver', True)],
          'driverne': [('drive', True), ('driver', True)],
          'drivernes': [('drive', True), ('driver', True)],
          'drivers': [('drive', True), ('driver', True)],
          'drivis': [('drivis', True)],
          'drockerens': [('drocker', False)],
          'drockerne': [('drocker', False)],
          'droden': [('drod', False)],
          'drodens': [('drod', False)],
          'drods': [('drod', False)],
          'droen': [('dro', False)],
          'droens': [('dro', False)],
          'drogen': [('droge', True)],
          'drogens': [('droge', True)],
          'droider': [('droide', False)],
          'droiderne': [('droide', False)],
          'droidernes': [('droide', False)],
          'droiders': [('droide', False)],
          'droller': [('drolle', False)],
          'drollerne': [('drolle', False)],
          'drollers': [('drolle', False)],
          'dromer': [('drom', False)],
          'dromerne': [('drom', False)],
          'dromernes': [('drom', False)],
          'dromers': [('drom', False)],
          'dronen': [('drone', True)],
          'dronens': [('drone', True)],
          'droner': [('drone', True)],
          'dronerne': [('drone', True)],
          'dronernes': [('drone', True)],
          'droners': [('drone', True)],
          'dronten': [('dronte', True)],
          'drontens': [('dronte', True)],
          'dronterne': [('dronte', True)],
          'dronternes': [('dronte', True)],
          'dronters': [('dronte', True)],
          'dropperne': [('dropper', False)],
          'droppers': [('dropper', False)],
          'drops': [('drops', True), ('drop', True)],
          "drops'": [('drop', True), ('drops', True)],
          'dros': [('dro', False)],
          'droscher': [('drosche', True)],
          'droschernes': [('drosche', True)],
          'droschers': [('drosche', True)],
          'drosen': [('drose', False)],
          'drosens': [('drose', False)],
          'drotten': [('drot', True)],
          'drottens': [('drot', True)],
          'drotter': [('drot', True)],
          'drotterne': [('drot', True)],
          'drotternes': [('drot', True)],
          'drotters': [('drot', True)],
          'drover': [('drover', False)],
          'droverne': [('drover', False)],
          'drovernes': [('drover', False)],
          'drovers': [('drover', False)],
          'druder': [('drude', True)],
          'druderne': [('drude', True)],
          'drudernes': [('drude', True)],
          'druders': [('drude', True)],
          'druen': [('drue', True)],
          'druens': [('drue', False)],
          'druer': [('drue', False)],
          'druerne': [('drue', True)],
          'druernes': [('drue', False)],
          'druers': [('drue', False)],
          "drugs'": [('drug', True)],
          'druks': [('druk', True)],
          'drullers': [('drulle', False)],
          'drummer': [('drum', False)],
          'drummerne': [('drum', False)],
          'drummet': [('drum', False)],
          'drummets': [('drum', False)],
          'druplerne': [('drupel', False)],
          'druplers': [('drupel', False)],
          'drus': [('drus', False)],
          'drusen': [('drus', False)],
          'drusens': [('drus', False)],
          'druser': [('druser', True)],
          'druserne': [('druser', True)],
          'drusernes': [('druser', True)],
          'drusers': [('druser', True)],
          'drykkerne': [('drykker', False)],
          'drykkernes': [('drykker', False)],
          'drys': [('drys', True)],
          'dråber': [('dråbe', False)],
          'dråberne': [('dråbe', False)],
          'dråbernes': [('dråbe', False)],
          'dråbers': [('dråbe', True)],
          'dræs': [('dræ', True)],
          'drætter': [('drætter', False)],
          'drætterne': [('dræt', False)],
          'drætternes': [('drætter', False)],
          'drætters': [('drætter', False)],
          'drøret': [('drør', False)],
          'drørets': [('drør', False)],
          'drøverne': [('drøver', False)],
          'drøvernes': [('drøver', False)],
          'drøvers': [('drøver', False)],
          'ds': [('ds', False)],
          "ds'": [('ds', False)],
          'dsagen': [('dsag', False)],
          'dsagers': [('dsag', False)],
          'dsalvers': [('dsalve', False)],
          'dsammen': [('dsammen', False)],
          'dsammens': [('dsammen', False)],
          'dsanden': [('dsande', False)],
          'dsandens': [('dsande', False)],
          'dsander': [('dsande', False)],
          'dsanders': [('dsande', False)],
          'dsandet': [('dsande', False)],
          'dsandets': [('dsande', False)],
          'dsanger': [('dsanger', False)],
          'dsarbejder': [('dsarbejde', False)],
          'dsarbejderne': [('dsarbejde', False)],
          'dsarbejdernes': [('dsarbejde', False)],
          'dsarbejders': [('dsarbejder', False)],
          'dsbo': [('dsbo', False)],
          'dsboer': [('dsbo', False)],
          'dsboerne': [('dsbo', False)],
          'dsbomber': [('dsbombe', False)],
          'dsbomberne': [('dsbombe', False)],
          'dsbos': [('dsbo', False)],
          'dsbroderen': [('dsbroder', False)],
          'dse': [('ds', False)],
          'dsejer': [('dsejer', False)],
          'dsejerne': [('dsejer', False)],
          'dsejernes': [('dsejer', False)],
          'dsejers': [('dsejer', False)],
          'dselen': [('dsel', False)],
          'dselens': [('dsel', False)],
          'dselet': [('dsel', False)],
          'dsen': [('ds', False)],
          'dsene': [('ds', False)],
          'dsenes': [('ds', False)],
          'dsens': [('ds', False)],
          'dser': [('ds', False)],
          'dsere': [('dser', False)],
          'dseren': [('dser', False)],
          'dserens': [('dser', False)],
          'dseres': [('dser', False)],
          'dserier': [('dseri', False)],
          'dserierne': [('dseri', False)],
          'dseriernes': [('dseri', False)],
          'dseriers': [('dseri', False)],
          'dserne': [('ds', False)],
          'dsernes': [('ds', False)],
          'dsers': [('ds', False)],
          'dses': [('ds', False)],
          'dset': [('ds', False)],
          'dsets': [('ds', False)],
          'dsfornemmelser': [('dsfornemmelse', False)],
          'dsfornemmelsers': [('dsfornemmelse', False)],
          'dsfædre': [('dsfader', False)],
          'dsfædrenes': [('dsfader', False)],
          'dshandler': [('dshandel', False)],
          'dshandlers': [('dshandel', False)],
          'dsigten': [('dsigt', False)],
          'dsigtens': [('dsigt', False)],
          'dsigter': [('dsigt', False)],
          'dsigterne': [('dsigt', False)],
          'dsigternes': [('dsigt', False)],
          'dsigters': [('dsigt', False)],
          'dsingers': [('dsing', False)],
          'dsis': [('dsis', False)],
          'dskaber': [('dskab', False)],
          'dskaberne': [('dskab', False)],
          'dskabernes': [('dskab', False)],
          'dskabers': [('dskab', False)],
          'dskallen': [('dskalle', False)],
          'dskallens': [('dskal', False)],
          'dskaller': [('dskalle', False)],
          'dskallerne': [('dskal', False)],
          'dskallernes': [('dskalle', False)],
          'dskallers': [('dskalle', False)],
          'dske': [('dske', False)],
          'dskeder': [('dskede', False)],
          'dskeders': [('dskede', False)],
          'dsken': [('dske', False)],
          'dsker': [('dske', False)],
          'dskerne': [('dske', False)],
          'dskers': [('dske', False)],
          'dskes': [('dske', False)],
          'dskifte': [('dskifte', False)],
          'dskifter': [('dskifte', False)],
          'dskifterne': [('dskifter', False)],
          'dskifternes': [('dskifter', False)],
          'dskifters': [('dskifter', False)],
          'dskiftes': [('dskifte', False)],
          'dskiftet': [('dskifte', False)],
          'dskiftets': [('dskifte', False)],
          'dskreds': [('dskred', False)],
          'dskræfternes': [('dskræfter', False)],
          'dskvaler': [('dskval', False)],
          'dskvalerne': [('dskval', False)],
          'dskvalernes': [('dskval', False)],
          'dskærve': [('dskærv', False)],
          'dskærven': [('dskærv', False)],
          'dskærvens': [('dskærv', False)],
          'dskærves': [('dskærv', False)],
          'dslags': [('dslag', False)],
          'dslangen': [('dslange', False)],
          'dslangens': [('dslange', False)],
          'dslens': [('dsel', False)],
          'dsler': [('dsel', False)],
          'dslinger': [('dsling', False)],
          'dslingerne': [('dsling', False)],
          'dslingernes': [('dsling', False)],
          'dslingers': [('dsling', False)],
          'dslips': [('dslip', False)],
          'dslommer': [('dslomme', False)],
          'dslommernes': [('dslomme', False)],
          'dslommers': [('dslomme', False)],
          'dslærer': [('dslære', False)],
          'dsnet': [('dsnet', False)],
          'dsnets': [('dsnet', False)],
          'dsoffer': [('dsoffer', False)],
          'dsoffers': [('dsoffer', False)],
          'dsorden': [('dsorden', False)],
          'dsordens': [('dsorden', False)],
          'dspids': [('dspids', False)],
          'dspidser': [('dspids', False)],
          'dspidsernes': [('dspids', False)],
          'dspild': [('dspild', False)],
          'dspildets': [('dspild', False)],
          'dsporerne': [('dspore', False)],
          'dsporernes': [('dspore', False)],
          'dspørger': [('dspørge', False)],
          'dspørgerne': [('dspørge', False)],
          'dspørgernes': [('dspørge', False)],
          'dspørgers': [('dspørge', False)],
          'dsretterne': [('dsret', False)],
          'dsretternes': [('dsret', False)],
          'dsretters': [('dsret', False)],
          'dsselen': [('dssele', False)],
          'dsselens': [('dssele', False)],
          'dsskifternes': [('dsskifte', False)],
          'dsskiftes': [('dsskifte', False)],
          'dsskiftet': [('dsskifte', False)],
          'dsskiftets': [('dsskift', False)],
          'dstads': [('dstad', False)],
          'dstager': [('dstager', False)],
          'dstagerne': [('dstager', False)],
          'dstagernes': [('dstager', False)],
          'dstagers': [('dstager', False)],
          'dstages': [('dstage', False)],
          'dstammen': [('dstamme', False)],
          'dstammens': [('dstamme', False)],
          'dstammer': [('dstamme', False)],
          'dstammerne': [('dstamme', False)],
          'dstammernes': [('dstamme', False)],
          'dstammers': [('dstamme', False)],
          'dstarter': [('dstart', False)],
          'dstarterne': [('dstart', False)],
          'dstarternes': [('dstart', False)],
          'dstarters': [('dstart', False)],
          'dste': [('dste', False)],
          'dsteltene': [('dstelt', False)],
          'dsteltenes': [('dstelt', False)],
          'dsten': [('dsten', False)],
          'dstens': [('dsten', False)],
          'dster': [('dster', False)],
          'dsterne': [('dster', False)],
          'dsternes': [('dster', False)],
          'dsters': [('dster', False)],
          'dstes': [('dste', False)],
          'dstifter': [('dstifter', False)],
          'dstifterne': [('dstifter', False)],
          'dstifternes': [('dstifter', False)],
          'dstifters': [('dstifter', False)],
          'dstikken': [('dstik', False)],
          'dstikkens': [('dstikke', False)],
          'dstikker': [('dstik', False)],
          'dstikkere': [('dstik', False)],
          'dstikkeren': [('dstik', False)],
          'dstikkerens': [('dstik', False)],
          'dstikkeres': [('dstik', False)],
          'dstikkerne': [('dstik', False)],
          'dstikkernes': [('dstikke', False)],
          'dstikkers': [('dstik', False)],
          'dstrømperne': [('dstrømpe', False)],
          'dstykkernes': [('dstykke', False)],
          'dstykkers': [('dstykke', False)],
          'dstyrer': [('dstyrer', False)],
          'dstyrerne': [('dstyrer', False)],
          'dstyrernes': [('dstyrer', False)],
          'dstyrers': [('dstyrer', False)],
          'dstyret': [('dstyr', False)],
          'dstyrets': [('dstyr', False)],
          'dstænger': [('dstang', False)],
          'dstængerne': [('dstang', False)],
          'dstængernes': [('dstang', False)],
          'dstængers': [('dstang', False)],
          'dstøvler': [('dstøvle', False)],
          'dstøvlerne': [('dstøvle', False)],
          'dstøvlernes': [('dstøvle', False)],
          'dsuger': [('dsuge', False)],
          'dsugerne': [('dsuge', False)],
          'dsugernes': [('dsuge', False)],
          'dsugers': [('dsuge', False)],
          'dsværker': [('dsværk', False)],
          'dsværkerne': [('dsværk', False)],
          'dsværkernes': [('dsværk', False)],
          'dsværkers': [('dsværk', False)],
          'dsæder': [('dsæde', False)],
          'dsæderne': [('dsæde', False)],
          'dsædernes': [('dsæde', False)],
          'dsæders': [('dsæde', False)],
          'dsætter': [('dsætter', False)],
          'dsætternes': [('dsætter', False)],
          'dsøer': [('dsø', False)],
          'dsøren': [('dsøre', False)],
          'dsørens': [('dsøre', False)],
          'dsørerne': [('dsøre', False)],
          'dsørers': [('dsøre', False)],
          'dtabenes': [('dtab', False)],
          'dtage': [('dtag', False)],
          'dtagen': [('dtagen', False)],
          'dtagere': [('dtager', False)],
          'dtageren': [('dtager', False)],
          'dtagerens': [('dtager', False)],
          'dtageres': [('dtager', False)],
          'dtages': [('dtag', False)],
          'dtaler': [('dtale', False)],
          'dtalerne': [('dtale', False)],
          'dtalernes': [('dtale', False)],
          'dtalers': [('dtale', False)],
          'dtanden': [('dtand', False)],
          'dtandens': [('dtand', False)],
          'dtangen': [('dtange', False)],
          'dtangens': [('dtange', False)],
          'dtanten': [('dtante', False)],
          'dtanter': [('dtante', False)],
          'dtanters': [('dtante', False)],
          'dte': [('dt', False)],
          'dteater': [('dteater', False)],
          'dtekster': [('dtekst', False)],
          'dteksterne': [('dtekst', False)],
          'dteksternes': [('dtekst', False)],
          'dteksters': [('dtekst', False)],
          'dten': [('dt', False)],
          'dtene': [('dt', False)],
          'dtenes': [('dt', False)],
          'dtens': [('dt', False)],
          'dter': [('dt', False)],
          'dterne': [('dt', False)],
          'dternes': [('dt', False)],
          'dters': [('dt', False)],
          'dtes': [('dt', False)],
          'dtet': [('dt', False)],
          'dtets': [('dt', False)],
          'dtidernes': [('dtid', False)],
          'dtids': [('dtid', False)],
          'dtimer': [('dtimer', False)],
          'dtimerne': [('dtimer', False)],
          'dtimernes': [('dtimer', False)],
          'dtimers': [('dtime', False)],
          'dtips': [('dtip', False)],
          'dtmads': [('dtmads', False)],
          'dtningen': [('dtning', False)],
          'dtninger': [('dtning', False)],
          'dtningerne': [('dtning', False)],
          'dtningernes': [('dtning', False)],
          'dtoner': [('dtone', False)],
          'dtonerne': [('dtone', False)],
          'dtonernes': [('dtone', False)],
          'dtoners': [('dtone', False)],
          'dtopper': [('dtop', False)],
          'dtoppernes': [('dtop', False)],
          'dtoppers': [('dtop', False)],
          'dtops': [('dtop', False)],
          "dtops'": [('dtop', False)],
          'dtrappernes': [('dtrappe', False)],
          'dtresser': [('dtresse', False)],
          'dtresserne': [('dtresse', False)],
          'dtressernes': [('dtresse', False)],
          'dtressers': [('dtresse', False)],
          'dtribunen': [('dtribune', False)],
          'dtropper': [('dtrop', False)],
          'dtropperne': [('dtrop', False)],
          'dtroppernes': [('dtrop', False)],
          'dtroppers': [('dtrop', False)],
          'dtræder': [('dtræder', False)],
          'dtræderne': [('dtræder', False)],
          'dtrædernes': [('dtræder', False)],
          'dts': [('dt', False)],
          'dtsider': [('dtside', False)],
          'dtsiderne': [('dtside', False)],
          'dtsidernes': [('dtside', False)],
          'dtsiders': [('dtside', False)],
          'dttiden': [('dttid', False)],
          'dtudens': [('dtud', False)],
          'dtudes': [('dtud', False)],
          'dtuds': [('dtud', False)],
          'dtudsen': [('dtudse', False)],
          'dtudsens': [('dtudse', False)],
          'dtudser': [('dtudse', False)],
          'dtudsers': [('dtudse', False)],
          'dtungens': [('dtunge', False)],
          'dtunger': [('dtunge', False)],
          'dtungerne': [('dtunge', False)],
          'dtungernes': [('dtunge', False)],
          'dture': [('dtur', False)],
          'dturen': [('dtur', False)],
          'dturene': [('dtur', False)],
          'dturens': [('dtur', False)],
          'dtures': [('dtur', False)],
          'dtusinder': [('dtusinder', False)],
          'dtusinders': [('dtusinder', False)],
          'dtypens': [('dtype', False)],
          'dtypernes': [('dtype', False)],
          'dtypers': [('dtype', False)],
          'dtænder': [('dtand', False)],
          'dtænderne': [('dtand', False)],
          'dtændernes': [('dtand', False)],
          'dtænders': [('dtand', False)],
          'dtængernes': [('dtang', False)],
          'dtængers': [('dtang', False)],
          'dtøjers': [('dtøj', False)],
          'dtøjet': [('dtøj', False)],
          'dubberne': [('dubber', True)],
          'dubbernes': [('dubber', True)],
          'dubbers': [('dubber', True)],
          'duen': [('due', True)],
          'duens': [('due', True)],
          'duer': [('due', True)],
          'duerne': [('due', True)],
          'duernes': [('due', True)],
          'duers': [('due', True)],
          'duet': [('duet', True)],
          'duets': [('duet', True)],
          'duetter': [('duet', True)],
          'duge': [('dug', True)],
          'dugen': [('dug', False)],
          'dugens': [('dug', False)],
          'duges': [('dug', False)],
          'duggen': [('dug', False)],
          'duggens': [('dug', False)],
          'dugter': [('dugt', True)],
          'dugterne': [('dugt', True)],
          'dugternes': [('dugt', True)],
          'dukken': [('dukke', True)],
          'dukkens': [('dukke', True)],
          'dukker': [('dukke', False)],
          'dukkerne': [('dukke', False)],
          'dukkernes': [('dukke', False)],
          'dukkers': [('dukke', False)],
          'duks': [('duks', True)],
          'dulens': [('dul', False)],
          'duler': [('dul', False)],
          'dulerne': [('dul', False)],
          'dulernes': [('dul', False)],
          'dulet': [('dul', False)],
          'duljen': [('duljen', False)],
          'dullens': [('dulle', True)],
          'dullerne': [('dulle', False)],
          'dullernes': [('dulle', True)],
          'dum': [('dum', False)],
          'dummernes': [('dum', False)],
          'dummers': [('dum', False)],
          'dumper': [('dumper', True)],
          'dumperne': [('dumper', True)],
          'dumpernes': [('dumper', True)],
          'dumpers': [('dumper', True)],
          'dums': [('dum', False)],
          'dunderne': [('dunder', False)],
          'dunders': [('dunder', True)],
          'dunerne': [('dun', False)],
          'duners': [('dun', False)],
          'dunke': [('dunk', False)],
          'dunken': [('dunk', True)],
          'dunkes': [('dunk', False)],
          'duns': [('dun', False)],
          'duppen': [('dup', True)],
          'duppens': [('dup', True)],
          'dupper': [('dup', True)],
          'dupperne': [('dup', True)],
          'duppernes': [('dup', True)],
          'duppers': [('dup', True)],
          'dure': [('dure', False)],
          'duren': [('dure', False)],
          'durens': [('dure', False)],
          'durer': [('dure', False)],
          'durerne': [('dure', False)],
          'durernes': [('dure', False)],
          'durers': [('dure', False)],
          'dures': [('dure', False)],
          'duret': [('dur', False)],
          'durets': [('dur', False)],
          'durs': [('dur', False)],
          'durter': [('durt', False)],
          'dus': [('dus', True)],
          'dusen': [('dusen', False)],
          'duser': [('dus', False)],
          'dusernes': [('dus', False)],
          'dusers': [('dus', False)],
          'duske': [('dusk', True)],
          'dusken': [('dusk', True)],
          'dussen': [('dus', False)],
          'dussens': [('dus', False)],
          'dutten': [('dut', True)],
          'duttens': [('dut', False)],
          'dutterne': [('dut', False)],
          'dutternes': [('dut', True)],
          'dutters': [('dut', False)],
          'dvalen': [('dvale', True)],
          'dvalens': [('dvale', True)],
          'dvande': [('dvande', False)],
          'dvandes': [('dvande', False)],
          'dvandet': [('dvande', False)],
          'dvandets': [('dvande', False)],
          'dvanen': [('dvane', False)],
          'dvanens': [('dvane', False)],
          'dvaner': [('dvane', False)],
          'dvanerne': [('dvane', False)],
          'dvanernes': [('dvane', False)],
          'dvaners': [('dvane', False)],
          'dveje': [('dvej', False)],
          'dvejens': [('dvej', False)],
          'dvejes': [('dvej', False)],
          'dver': [('dver', False)],
          'dverens': [('dver', False)],
          'dvers': [('dver', False)],
          'dvesten': [('dvest', False)],
          'dvestens': [('dvest', False)],
          'dvidder': [('dvidde', False)],
          'dvider': [('dvider', False)],
          'dvidernes': [('dvider', False)],
          'dvikler': [('dvikler', False)],
          'dviklerne': [('dvikler', False)],
          'dviklernes': [('dvikler', False)],
          'dviklers': [('dvikler', False)],
          'dvinde': [('dvind', False)],
          'dvinden': [('dvind', False)],
          'dvindens': [('dvind', False)],
          'dvindes': [('dvind', False)],
          'dvine': [('dvin', False)],
          'dvinen': [('dvin', False)],
          'dvinens': [('dvin', False)],
          'dvines': [('dvin', False)],
          'dvins': [('dvin', False)],
          'dvinter': [('dvinter', False)],
          'dvis': [('dvis', False)],
          'dvisen': [('dvis', False)],
          'dvisens': [('dvis', False)],
          'dviser': [('dvis', False)],
          'dviserne': [('dvis', False)],
          'dvisernes': [('dvise', False)],
          'dvisers': [('dvise', False)],
          'dvolde': [('dvolde', False)],
          'dvoldene': [('dvolde', False)],
          'dvoldenes': [('dvolde', False)],
          'dvoldes': [('dvolde', False)],
          'dvortes': [('dvorte', False)],
          'dværge': [('dværg', True)],
          'dværgen': [('dværg', True)],
          'dværgens': [('dværg', True)],
          'dværges': [('dværg', True)],
          'dyder': [('dyd', False)],
          'dyderne': [('dyd', False)],
          'dydernes': [('dyd', False)],
          'dyders': [('dyd', False)],
          'dyen': [('dy', False)],
          'dyens': [('dy', False)],
          'dyer': [('dy', False)],
          'dyerne': [('dy', False)],
          'dyernes': [('dy', False)],
          'dyers': [('dy', False)],
          'dykker': [('dykker', False)],
          'dykkerne': [('dykker', True)],
          'dykkers': [('dykker', True)],
          'dyllen': [('dyl', False)],
          'dyller': [('dyl', False)],
          'dyllers': [('dyl', False)],
          'dymen': [('dyman', False)],
          'dynen': [('dyne', False)],
          'dynens': [('dyne', False)],
          'dyner': [('dyne', True)],
          'dynernes': [('dyne', False)],
          'dyngernes': [('dynge', True)],
          'dyngers': [('dynge', True)],
          'dyrehandler': [('dyrehandel', True), ('dyrehandler', True)],
          'dyrehandlerne': [('dyrehandler', True), ('dyrehandel', True)],
          'dyrehandlernes': [('dyrehandler', True), ('dyrehandel', True)],
          'dyrehandlers': [('dyrehandel', True), ('dyrehandler', True)],
          'dyrker': [('dyrker', True)],
          'dyrkerne': [('dyrker', True)],
          'dyrkers': [('dyrker', False)],
          'dys': [('dy', False)],
          'dysen': [('dyse', True)],
          'dysens': [('dyse', True)],
          'dyser': [('dyse', True)],
          'dyserne': [('dyse', True)],
          'dysernes': [('dyse', True)],
          'dysser': [('dysse', False)],
          'dyssernes': [('dysse', True)],
          'dyssers': [('dysse', True)],
          'dysten': [('dyst', True)],
          'dystens': [('dyst', True)],
          'dyster': [('dyst', True)],
          'dysterne': [('dyst', True)],
          'dysternes': [('dyst', True)],
          'dysters': [('dyst', True)],
          'dytten': [('dyt', False)],
          'dyttens': [('dyt', False)],
          'dytternes': [('dyt', False)],
          'dytters': [('dyt', False)],
          'dyttet': [('dyt', True)],
          'dyttets': [('dyt', True)],
          'dåben': [('dåb', False)],
          'dåbens': [('dåb', False)],
          'dåernes': [('då', True)],
          'dåers': [('då', True)],
          'dånden': [('dånd', False)],
          'dåndens': [('dånd', False)],
          'dåre': [('dåre', False)],
          'dårens': [('dåre', False)],
          'dårerne': [('dåre', False)],
          'dårernes': [('dåre', False)],
          'dårers': [('dåre', False)],
          'dås': [('då', True)],
          'dåse': [('dåse', False)],
          'dåsen': [('dåse', False)],
          'dåsens': [('dåse', False)],
          'dåser': [('dåse', False)],
          'dåserne': [('dåse', False)],
          'dåsernes': [('dåse', False)],
          'dåses': [('dåse', False)],
          'dæder': [('dæder', False)],
          'dæer': [('dæ', False)],
          'dæerne': [('dæ', False)],
          'dæernes': [('dæ', False)],
          'dæers': [('dæ', False)],
          'dægge': [('dægge', False)],
          'dæggen': [('dægge', False)],
          'dæggens': [('dægge', False)],
          'dæggerne': [('dægge', False)],
          'dæggernes': [('dægge', False)],
          'dæggers': [('dægge', False)],
          'dægges': [('dægge', False)],
          'dækken': [('dækken', False)],
          'dækkens': [('dækken', True)],
          'dækker': [('dække', True)],
          'dækkerne': [('dække', True)],
          'dækkernes': [('dække', False)],
          'dækkers': [('dække', True)],
          'dækket': [('dække', True), ('dæk', True)],
          'dækkets': [('dæk', True), ('dække', True)],
          'dælen': [('dælen', True)],
          'dælens': [('dælen', True)],
          'dæmperne': [('dæmper', False)],
          'dænders': [('dand', False)],
          'dæren': [('dær', False)],
          'dærens': [('dær', False)],
          'dærers': [('dær', False)],
          'dærver': [('dærver', False)],
          'dærverne': [('dærver', False)],
          'dæs': [('dæ', False)],
          'dæsen': [('dæse', False)],
          'dæsens': [('dæse', False)],
          'dæser': [('dæse', False)],
          'dæserne': [('dæse', False)],
          'dæsernes': [('dæse', False)],
          'dæses': [('dæse', False)],
          'dæsken': [('dæsk', False)],
          'dæskens': [('dæsk', False)],
          'dæsker': [('dæsk', False)],
          'dæskerne': [('dæsk', False)],
          'dæskernes': [('dæsk', False)],
          'dæskers': [('dæsk', False)],
          'dæter': [('dæt', False)],
          'dæterne': [('dæt', False)],
          'dæternes': [('dæt', False)],
          'dæters': [('dæt', False)],
          'døber': [('døber', True)],
          'døbernes': [('døber', True)],
          'døje': [('døje', False)],
          'døjen': [('døje', False)],
          'døjens': [('døje', False)],
          'døjers': [('døje', False)],
          'døjes': [('døje', True)],
          'døjet': [('døje', False)],
          'døllen': [('døl', False)],
          'døller': [('døl', False)],
          'døllers': [('døl', False)],
          'dømmernes': [('dømme', False)],
          'dømmers': [('dømme', False)],
          'dømmet': [('dømme', False)],
          'dømmets': [('dømme', False)],
          'døre': [('dør', True)],
          'døren': [('dør', False)],
          'dørene': [('dør', False)],
          'dørenes': [('dør', False)],
          'dørens': [('dør', False)],
          'dørerne': [('dør', False)],
          'dørernes': [('dør', False)],
          'døres': [('dør', False)],
          'dørgen': [('dørg', True)],
          'dørgens': [('dørg', True)],
          'dørke': [('dørk', True)],
          'dørken': [('dørk', True)],
          'dørkens': [('dørk', True)],
          'dørkes': [('dørk', True)],
          'døs': [('døs', True)],
          'døsen': [('døs', True)],
          'døsens': [('døs', True)],
          'døsten': [('døst', False)],
          'døstens': [('døst', False)],
          'e': [('e', True)],
          "e'erne": [('e', False)],
          'e-': [('evarer', False)],
          'ea': [('ea', False)],
          'eabe': [('eabe', False)],
          'eaben': [('eabe', False)],
          'eabens': [('eabe', False)],
          'eaberne': [('eabe', False)],
          'eabernes': [('eabe', False)],
          'eabers': [('eabe', False)],
          'eabes': [('eabe', False)],
          'eade': [('eade', False)],
          'eaden': [('eade', False)],
          'eadens': [('eade', False)],
          'eader': [('eader', False)],
          'eaderne': [('eade', False)],
          'eadernes': [('eader', False)],
          'eaders': [('eade', False)],
          'eades': [('eade', False)],
          'eaen': [('ea', False)],
          'eaens': [('ea', False)],
          'eaer': [('ea', False)],
          'eaerne': [('ea', False)],
          'eaernes': [('ea', False)],
          'eaers': [('ea', False)],
          'eaftalens': [('eaftale', False)],
          'eaftens': [('eaften', False)],
          'eagenser': [('eagens', False)],
          'eaglens': [('eagle', True)],
          'eagler': [('eagle', True)],
          'eaglerne': [('eagle', True)],
          'eakers': [('eakers', False)],
          'eaket': [('eak', False)],
          'eakets': [('eak', False)],
          'eaks': [('eak', False)],
          "eaks'": [('eaks', False)],
          'eaksen': [('eaks', False)],
          'eaksens': [('eaks', False)],
          'ealen': [('eal', False)],
          'ealene': [('eal', False)],
          'ealenes': [('eal', False)],
          'ealens': [('eal', False)],
          'ealer': [('ealer', False)],
          'ealerne': [('ealer', False)],
          'ealernes': [('ealer', False)],
          'ealers': [('ealer', False)],
          'ealias': [('ealia', False)],
          'ealiernes': [('ealier', False)],
          'ealogens': [('ealog', False)],
          'eamen': [('eam', False)],
          'eamene': [('eam', False)],
          'eamens': [('eam', False)],
          'eamenter': [('eament', False)],
          'eamenterne': [('eament', False)],
          'eamentet': [('eament', False)],
          'eamentets': [('eament', False)],
          'eamer': [('eamer', False)],
          'eamerne': [('eamer', False)],
          'eamernes': [('eamer', False)],
          'eamers': [('eamer', False)],
          'eamets': [('eam', False)],
          'eanden': [('eand', False)],
          'eander': [('eander', False)],
          'eaner': [('eaner', False)],
          'eanerne': [('ean', False)],
          'eanernes': [('ean', False)],
          'eaners': [('eaner', False)],
          'eanierne': [('eanier', False)],
          'eaniers': [('eanier', False)],
          'eans': [('eans', False)],
          "eans'": [('eans', False)],
          'eansenes': [('eans', False)],
          'eanten': [('eant', False)],
          'eantens': [('eant', False)],
          'eanterne': [('eant', False)],
          'eanternes': [('eant', False)],
          'eanters': [('eant', False)],
          'eants': [('eant', False)],
          'earbejder': [('earbejder', False)],
          'earbejderne': [('earbejder', False)],
          'earbejdernes': [('earbejde', False)],
          'earbejders': [('earbejde', False)],
          'earcher': [('earcher', False)],
          'earcherne': [('earcher', False)],
          'earchers': [('earcher', False)],
          'earen': [('eare', False)],
          'earens': [('eare', False)],
          'earer': [('eare', False)],
          'earerne': [('eare', False)],
          'earernes': [('eare', False)],
          'earkets': [('eark', False)],
          'earme': [('earm', False)],
          'earten': [('eart', False)],
          'earter': [('eart', False)],
          'earterne': [('eart', False)],
          'earts': [('eart', False)],
          'earven': [('earv', False)],
          'earvens': [('earv', False)],
          'eas': [('ea', False)],
          'ease': [('ease', False)],
          'easen': [('ease', False)],
          'easene': [('ease', False)],
          'easenes': [('ease', False)],
          'easens': [('ease', False)],
          'eases': [('ease', False)],
          'easke': [('easke', False)],
          'easken': [('eask', False)],
          'easkens': [('easke', False)],
          'easkes': [('eask', False)],
          'easpes': [('easp', False)],
          'easten': [('east', False)],
          'eastens': [('east', False)],
          'easter': [('east', False)],
          'easterne': [('east', False)],
          'easternes': [('east', False)],
          'easters': [('east', False)],
          'eatene': [('eat', False)],
          'eatenes': [('eat', False)],
          'eater': [('eater', False)],
          'eaterne': [('eater', False)],
          'eaternes': [('eat', False)],
          'eaters': [('eater', False)],
          'eatret': [('eater', False)],
          'eatrets': [('eater', False)],
          'eaturen': [('eature', False)],
          'eaturens': [('eature', False)],
          'eauernes': [('eau', False)],
          'eavlen': [('eavl', False)],
          'eavlens': [('eavl', False)],
          'ebakken': [('ebakke', False)],
          'ebakkens': [('ebakke', False)],
          'ebakker': [('ebak', False)],
          'ebakkerne': [('ebakke', False)],
          'ebakkernes': [('ebak', False)],
          'ebakkers': [('ebak', False)],
          'eballen': [('eballe', False)],
          'eballens': [('eballe', False)],
          'eballer': [('eballe', False)],
          'eballerne': [('ebal', False)],
          'eballernes': [('ebal', False)],
          'eballers': [('eballe', False)],
          'eballet': [('ebal', False)],
          'eballets': [('ebal', False)],
          'ebanke': [('ebanke', False)],
          'ebanken': [('ebanken', False)],
          'ebankens': [('ebanken', False)],
          'ebanker': [('ebanke', False)],
          'ebankerne': [('ebanker', False)],
          'ebankernes': [('ebanker', False)],
          'ebankers': [('ebanke', False)],
          'ebankes': [('ebanke', False)],
          'ebarden': [('ebard', False)],
          'ebardens': [('ebard', False)],
          'ebarder': [('ebard', False)],
          'ebarderne': [('ebard', False)],
          'ebardernes': [('ebard', False)],
          'ebarders': [('ebard', False)],
          'ebars': [('ebar', False)],
          'ebassen': [('ebasse', False)],
          'ebassens': [('ebasse', False)],
          'ebasser': [('ebasse', False)],
          'ebasserne': [('ebasse', False)],
          'ebassernes': [('ebasse', False)],
          'ebassers': [('ebasse', False)],
          'ebbe': [('ebbe', True)],
          'ebben': [('ebbe', True)],
          'ebbens': [('ebbe', True)],
          'ebbes': [('ebbe', True)],
          'ebe': [('eb', False)],
          'ebede': [('ebed', False)],
          'ebedes': [('ebed', False)],
          'ebellens': [('ebel', False)],
          'ebellerne': [('ebel', False)],
          'ebellernes': [('ebel', False)],
          'eben': [('eben', False)],
          'ebene': [('eb', False)],
          'ebener': [('eben', False)],
          'ebeners': [('eben', False)],
          'ebenes': [('eb', False)],
          'ebenet': [('eben', False)],
          'ebenets': [('eben', False)],
          'eber': [('eb', False)],
          'eberet': [('eber', False)],
          'eberets': [('eber', False)],
          'eberne': [('eber', False)],
          'ebernes': [('eb', False)],
          'ebers': [('eber', False)],
          'ebes': [('eb', False)],
          'ebet': [('eb', False)],
          'ebets': [('eb', False)],
          'ebiks': [('ebik', False)],
          'ebilen': [('ebil', False)],
          'ebilens': [('ebil', False)],
          'ebilerne': [('ebil', False)],
          'ebilernes': [('ebil', False)],
          'ebilers': [('ebil', False)],
          'ebirkes': [('ebirkes', False)],
          'ebis': [('ebis', False)],
          'ebisser': [('ebis', False)],
          'ebisserne': [('ebis', False)],
          'ebissernes': [('ebis', False)],
          'ebissers': [('ebis', False)],
          'eblens': [('ebel', False)],
          'ebler': [('ebel', False)],
          'eblus': [('eblus', False)],
          'eblænder': [('eblænder', False)],
          'eblændere': [('eblænder', False)],
          'eblænderen': [('eblænder', False)],
          'eblænderens': [('eblænder', False)],
          'eblænderes': [('eblænder', False)],
          'eblænderne': [('eblænder', False)],
          'eblændernes': [('eblænder', False)],
          'eblænders': [('eblænder', False)],
          'eboernes': [('ebo', False)],
          'ebogen': [('ebog', False)],
          'ebomber': [('ebombe', False)],
          'ebomberne': [('ebombe', False)],
          'ebombernes': [('ebombe', False)],
          'ebombers': [('ebombe', False)],
          'ebonden': [('ebonde', False)],
          'ebondens': [('ebonde', False)],
          'eboret': [('ebor', False)],
          'eborets': [('ebor', False)],
          'eborgen': [('eborg', False)],
          'eborgens': [('eborg', False)],
          'eborger': [('eborger', False)],
          'eborgernes': [('eborger', False)],
          'ebras': [('ebra', False)],
          'ebres': [('eber', False)],
          'ebriks': [('ebrik', False)],
          'ebringer': [('ebringer', False)],
          'ebringerne': [('ebringer', False)],
          'ebringernes': [('ebringer', False)],
          'ebringers': [('ebringer', False)],
          'ebrodde': [('ebrod', False)],
          'ebrodden': [('ebrod', False)],
          'ebroddens': [('ebrod', False)],
          'ebroddes': [('ebrod', False)],
          'ebroder': [('ebroder', False)],
          'ebroderen': [('ebror', False)],
          'ebroderens': [('ebroder', False)],
          'ebroders': [('ebroder', False)],
          'ebroer': [('ebro', False)],
          'ebroerne': [('ebroer', False)],
          'ebroernes': [('ebroer', False)],
          'ebroers': [('ebro', False)],
          'ebrugs': [('ebrug', False)],
          'ebryggen': [('ebryg', False)],
          'ebryggens': [('ebryg', False)],
          'ebræer': [('ebræer', False)],
          'ebræerne': [('ebræer', False)],
          'ebræernes': [('ebræer', False)],
          'ebræers': [('ebræer', False)],
          'ebrøden': [('ebrød', False)],
          'ebrødens': [('ebrød', False)],
          'ebrødre': [('ebroder', False)],
          'ebrødrene': [('ebroder', False)],
          'ebrødrenes': [('ebroder', False)],
          'ebrødres': [('ebroder', False)],
          'ebs': [('eb', False)],
          'ebuen': [('ebu', False)],
          'ebuens': [('ebu', False)],
          'ebuer': [('ebu', False)],
          'ebuerne': [('ebu', False)],
          'ebuernes': [('ebu', False)],
          'ebuers': [('ebu', False)],
          'ebuks': [('ebuk', False)],
          'ebukser': [('ebukser', False)],
          'ebukserne': [('ebukser', False)],
          'ebuksernes': [('ebukser', False)],
          'ebuksers': [('ebukser', False)],
          'ebulle': [('ebulle', False)],
          'ebullen': [('ebulle', False)],
          'ebullens': [('ebulle', False)],
          'ebuller': [('ebulle', False)],
          'ebullerne': [('ebulle', False)],
          'ebullernes': [('ebulle', False)],
          'ebullers': [('ebulle', False)],
          'ebulles': [('ebulle', False)],
          'eburet': [('ebur', False)],
          'eburets': [('ebur', False)],
          'ebus': [('ebu', False)],
          'ebybo': [('ebybo', False)],
          'ebyboen': [('ebybo', False)],
          'ebyboens': [('ebybo', False)],
          'ebyboer': [('ebybo', False)],
          'ebyboerne': [('ebybo', False)],
          'ebyboernes': [('ebybo', False)],
          'ebyboers': [('ebybo', False)],
          'ebybos': [('ebybo', False)],
          'ebyrden': [('ebyrd', False)],
          'ebyrdens': [('ebyrd', False)],
          'ebyret': [('ebyr', False)],
          'ebyrets': [('ebyr', False)],
          'ebækken': [('ebækken', False)],
          'ebækkens': [('ebækken', False)],
          'ebælter': [('ebælte', False)],
          'ebælterne': [('ebælte', False)],
          'ebælternes': [('ebælte', False)],
          'ebælters': [('ebælte', False)],
          'ebæltet': [('ebælte', False)],
          'ebæltets': [('ebælte', False)],
          'ebøderne': [('ebøde', False)],
          'ebøders': [('ebøde', False)],
          'ebøllen': [('ebølle', False)],
          'ebønnen': [('ebønne', False)],
          'ebønnens': [('ebønne', False)],
          'ebønner': [('ebønne', False)],
          'ebønnerne': [('ebønne', False)],
          'ebønnernes': [('ebønne', False)],
          'ebønners': [('ebønne', False)],
          'ebørn': [('ebarn', False)],
          'ebørs': [('ebør', False)],
          'ecellen': [('ecelle', False)],
          'eceller': [('ecelle', False)],
          'ecellers': [('ecelle', False)],
          'ecen': [('ec', False)],
          'ecens': [('ec', False)],
          'ecenter': [('ecenter', False)],
          'ecenters': [('ecenter', False)],
          'ecentre': [('ecenter', False)],
          'ecentrene': [('ecenter', False)],
          'ecentrenes': [('ecenter', False)],
          'ecentres': [('ecenter', False)],
          'ecentret': [('ecenter', False)],
          'ecentrets': [('ecenter', False)],
          'ecepter': [('ecept', False)],
          'ecer': [('ec', False)],
          'ecerne': [('ec', False)],
          'ecernes': [('ec', False)],
          'ecers': [('ec', False)],
          'eces': [('eces', False)],
          "eces'": [('eces', False)],
          'ecets': [('ece', False)],
          'eche': [('eche', False)],
          'echen': [('eche', False)],
          'echens': [('eche', False)],
          'echer': [('eche', False)],
          'echerne': [('eche', False)],
          'echers': [('eche', False)],
          'eches': [('eche', False)],
          'ecialer': [('eciale', False)],
          'ecialerne': [('eciale', False)],
          'ecialernes': [('eciale', False)],
          'ecialers': [('eciale', False)],
          'ecien': [('ecie', False)],
          'eciens': [('ecie', False)],
          'ecier': [('ecie', False)],
          'eciers': [('ecie', False)],
          'ecker': [('eck', False)],
          'eckerne': [('ecker', False)],
          'eckernes': [('eck', False)],
          'eckers': [('ecker', False)],
          'ecuen': [('ecu', True)],
          'ecyklen': [('ecykel', False)],
          'ecyklens': [('ecykel', False)],
          'ecykler': [('ecykel', False)],
          'ecyklerne': [('ecykel', False)],
          'ecyklernes': [('ecykel', False)],
          'ecyklers': [('ecykel', False)],
          'ed': [('ed', False)],
          'ed.': [('edaktør', False)],
          'edage': [('edag', False)],
          'edagen': [('edag', False)],
          'edagene': [('edag', False)],
          'edagenes': [('edag', False)],
          'edagens': [('edagen', False)],
          'edages': [('edag', False)],
          'edaler': [('edal', False)],
          'edalerne': [('edal', False)],
          'edalernes': [('edal', False)],
          'edalers': [('edal', False)],
          'edales': [('edal', False)],
          'edaner': [('edan', False)],
          'edanerne': [('edan', False)],
          'edanernes': [('edan', False)],
          'edaners': [('edan', False)],
          'edans': [('edan', False)],
          'edanser': [('edanser', False)],
          'edanserne': [('edans', False)],
          'edansernes': [('edanser', False)],
          'edansers': [('edanser', False)],
          'edanter': [('edant', False)],
          'edarbejdernes': [('edarbejder', False)],
          'edarbejders': [('edarbejder', False)],
          'edarer': [('edar', False)],
          'edarerne': [('edarer', False)],
          'edarernes': [('edar', False)],
          'edarers': [('edarer', False)],
          'edas': [('edas', False)],
          "edas'": [('edas', False)],
          'edbo': [('edbo', False)],
          'edboen': [('edbo', False)],
          'edboens': [('edbo', False)],
          'edboer': [('edbo', False)],
          'edboerne': [('edbo', False)],
          'edboernes': [('edbo', False)],
          'edbos': [('edbo', False)],
          'edbroderens': [('edbror', False)],
          'edbrødre': [('edbror', False)],
          'edbrødrene': [('edbror', False)],
          'edbrødrenes': [('edbror', False)],
          'edbrødres': [('edbror', False)],
          'edde': [('edde', False)],
          'edden': [('edde', False)],
          'eddens': [('edde', False)],
          'edder': [('edder', True)],
          'edders': [('edder', True)],
          'eddes': [('edde', False)],
          'ede': [('et', False)],
          'ededage': [('ededag', False)],
          'ededagene': [('ededag', False)],
          'ededagenes': [('ededag', False)],
          'ededages': [('ededag', False)],
          'edeje': [('edej', False)],
          'edejes': [('edej', False)],
          'edele': [('edel', False)],
          'edelene': [('edel', False)],
          'edelenes': [('edel', False)],
          'edelerne': [('edeler', False)],
          'edeles': [('edel', False)],
          'edellen': [('edel', False)],
          'edellens': [('edel', False)],
          'edeller': [('edel', False)],
          'edellerne': [('edel', False)],
          'edellernes': [('edel', False)],
          'edellers': [('edel', False)],
          'eden': [('eden', True), ('ed', True)],
          'edene': [('ed', False)],
          'edenes': [('ed', False)],
          'edens': [('eden', True), ('ed', True)],
          'edenserne': [('edens', False)],
          'eder': [('ed', False)],
          'edere': [('eder', False)],
          'ederen': [('eder', False)],
          'ederens': [('eder', False)],
          'ederes': [('eder', False)],
          'ederet': [('eder', False)],
          'ederets': [('eder', False)],
          'ederne': [('ed', False)],
          'edernes': [('ed', False)],
          'eders': [('ed', False)],
          'edet': [('ed', False)],
          'edets': [('ed', False)],
          'edianerne': [('edian', False)],
          'edianernes': [('edian', False)],
          'edias': [('edie', False)],
          'edien': [('edie', False)],
          'ediens': [('edie', False)],
          'edier': [('edie', False)],
          'edierne': [('edie', False)],
          'ediernes': [('edie', False)],
          'ediers': [('edie', False)],
          'edies': [('edie', False)],
          'ediet': [('edie', False)],
          'ediets': [('edie', False)],
          'edinen': [('edin', False)],
          'edinens': [('edin', False)],
          'ediner': [('edin', False)],
          'edinernes': [('edin', False)],
          'ediners': [('edin', False)],
          'edis': [('edis', False)],
          'edisen': [('edise', False)],
          'edisens': [('edise', False)],
          'edisers': [('edise', False)],
          'ediskrimination': [('ediskrimination', False)],
          'ediskriminationen': [('ediskrimination', False)],
          'ediskriminationens': [('ediskrimination', False)],
          'ediskriminations': [('ediskrimination', False)],
          'edissen': [('edisse', False)],
          'edissens': [('edisse', False)],
          'edisser': [('edisse', False)],
          'edisserne': [('edisse', False)],
          'edissernes': [('edisse', False)],
          'edissers': [('edisse', False)],
          'edister': [('edister', False)],
          'edisters': [('edister', False)],
          'editten': [('edit', False)],
          'ediverne': [('ediver', False)],
          'edivers': [('ediver', False)],
          'edlen': [('eddel', False)],
          'edlens': [('edel', False)],
          'edler': [('edel', False)],
          'edlerne': [('eddel', False)],
          'edlernes': [('eddel', False)],
          'edlers': [('edel', False)],
          'edmarkernes': [('edmarker', False)],
          'edmarkers': [('edmarker', False)],
          'edoks': [('edok', False)],
          'edomme': [('edom', False)],
          'edonen': [('edon', False)],
          'edonens': [('edon', False)],
          'edoner': [('edon', False)],
          'edonerne': [('edon', False)],
          'edonernes': [('edon', False)],
          'edoners': [('edon', False)],
          'edoren': [('edor', False)],
          'edorens': [('edor', False)],
          'edorer': [('edore', False)],
          'edorerne': [('edore', False)],
          'edorernes': [('edore', False)],
          'edorers': [('edore', False)],
          'edos': [('edos', False)],
          "edos'": [('edos', False)],
          'edosen': [('edos', False)],
          'edosens': [('edos', False)],
          'edoser': [('edos', False)],
          'edoserne': [('edos', False)],
          'edosernes': [('edos', False)],
          'edosers': [('edos', False)],
          'edrager': [('edrager', False)],
          'edragerne': [('edrager', False)],
          'edragernes': [('edrager', False)],
          'edragers': [('edrager', False)],
          'edrene': [('eder', False)],
          'edrenes': [('eder', False)],
          'edrenge': [('edreng', False)],
          'edrengenes': [('edreng', False)],
          'edrenges': [('edreng', False)],
          'edres': [('eder', False)],
          'edret': [('edret', False)],
          'edrets': [('eder', False)],
          'edrikke': [('edrik', False)],
          'edrikker': [('edrikker', False)],
          'edrikkernes': [('edrikker', False)],
          'edriver': [('edrive', False)],
          'edriverne': [('edrive', False)],
          'edrivernes': [('edrive', False)],
          'edrivers': [('edrive', False)],
          'edråber': [('edråber', False)],
          'edråberne': [('edråber', False)],
          'edråbernes': [('edråber', False)],
          'edråbers': [('edråber', False)],
          'edrætter': [('edræt', False)],
          'edrætternes': [('edræt', False)],
          'edrætters': [('edræt', False)],
          'eds': [('ed', False)],
          'edsager': [('edsag', False)],
          'edsagerne': [('edsag', False)],
          'edsagernes': [('edsag', False)],
          'edsagers': [('edsager', False)],
          'edsdage': [('edsdag', False)],
          'edsdagene': [('edsdag', False)],
          'edsdagenes': [('edsdag', False)],
          'edsdages': [('edsdag', False)],
          'edser': [('edser', False)],
          'edserne': [('edser', False)],
          'edsernes': [('edser', False)],
          'edsers': [('edser', False)],
          'edskallen': [('edskal', False)],
          'edskaller': [('edskal', False)],
          'edskallernes': [('edskal', False)],
          'edskallers': [('edskal', False)],
          'edskifterne': [('edskifte', False)],
          'edskifternes': [('edskifte', False)],
          'edskifters': [('edskifte', False)],
          'edsskiftets': [('edsskifte', False)],
          'eduens': [('edue', False)],
          'edukkens': [('edukke', False)],
          'edumper': [('edumpe', False)],
          'edumperne': [('edumpe', False)],
          'edumpernes': [('edumpe', False)],
          'edumpers': [('edumpe', False)],
          'edværker': [('edværk', False)],
          'edværkerne': [('edværk', False)],
          'edværkernes': [('edværk', False)],
          'edværkers': [('edværk', False)],
          'edækker': [('edækker', False)],
          'edækkerne': [('edækker', False)],
          'edækkernes': [('edækker', False)],
          'edækkers': [('edækker', False)],
          'edækket': [('edæk', False)],
          'edækkets': [('edæk', False)],
          'edømmer': [('edømme', False)],
          'edømmerne': [('edømme', False)],
          'edømmernes': [('edømmer', False)],
          'edømmers': [('edømmer', False)],
          'edører': [('edør', False)],
          'edørers': [('edør', False)],
          'ee': [('ee', False)],
          'eecen': [('eece', False)],
          'eecens': [('eece', False)],
          'eeces': [('eece', False)],
          'eeden': [('eed', False)],
          'eedens': [('eed', False)],
          'eeder': [('eeder', False)],
          'eederne': [('eeder', False)],
          'eedernes': [('eeder', False)],
          'eeders': [('eeder', False)],
          'eege': [('eeg', False)],
          'eegen': [('eeg', False)],
          'eegens': [('eeg', False)],
          'eeges': [('eeg', False)],
          'eeje': [('eeje', False)],
          'eejes': [('eeje', False)],
          'eekenderne': [('eekend', False)],
          'eekendernes': [('eekend', False)],
          'eelerne': [('eel', False)],
          'eeleverne': [('eelev', False)],
          'eelevernes': [('eelev', False)],
          'eelsers': [('eelse', False)],
          'een': [('een', False)],
          'eenagerne': [('eenager', False)],
          'eenagernes': [('eenager', False)],
          'eenagers': [('eenager', False)],
          'eenderne': [('eende', False)],
          'eendernes': [('eende', False)],
          'eenders': [('eende', False)],
          'eene': [('e', False)],
          'eenen': [('een', False)],
          'eenens': [('een', False)],
          'eenes': [('e', False)],
          'eens': [('een', False)],
          'eepen': [('eep', False)],
          'eepens': [('eep', False)],
          'eeper': [('eep', False)],
          'eeperne': [('eep', False)],
          'eepernes': [('eeper', False)],
          'eepers': [('eeper', False)],
          'eer': [('eer', False)],
          'eerene': [('eer', False)],
          'eerenes': [('eer', False)],
          'eers': [('eer', False)],
          'ees': [('ee', False)],
          "ees'": [('ee', False)],
          'eesser': [('ees', False)],
          'eesserne': [('ees', False)],
          'eessernes': [('ees', False)],
          'eessers': [('ees', False)],
          'eet': [('eum', False)],
          'eetage': [('eetage', False)],
          'eets': [('eum', False)],
          'eevners': [('eevne', False)],
          'ef': [('ef', False)],
          'efader': [('efader', False)],
          'efaderen': [('efader', False)],
          'efaderens': [('efader', False)],
          'efaders': [('efader', False)],
          'efangen': [('efange', False)],
          'efanger': [('efanger', False)],
          'efangerne': [('efanger', False)],
          'efangernes': [('efanger', False)],
          'efangers': [('efanger', False)],
          'efarens': [('efar', False)],
          'efarer': [('efare', False)],
          'efarerne': [('efarer', False)],
          'efarernes': [('efarer', False)],
          'efarers': [('efare', False)],
          'efars': [('efar', False)],
          'efarternes': [('efart', False)],
          'efase': [('efase', False)],
          'efasen': [('efase', False)],
          'efasens': [('efase', False)],
          'efaser': [('efase', False)],
          'efaserne': [('efase', False)],
          'efasernes': [('efase', False)],
          'efasers': [('efase', False)],
          'efases': [('efase', False)],
          'efejernes': [('efejer', False)],
          'efejers': [('efejer', False)],
          'efen': [('ef', False)],
          'efene': [('ef', False)],
          'efenes': [('ef', False)],
          'efens': [('ef', False)],
          'efer': [('ef', False)],
          'eferien': [('eferie', False)],
          'eferiens': [('eferie', False)],
          'eferier': [('eferie', False)],
          'eferierne': [('eferie', False)],
          'eferiers': [('eferie', False)],
          'eferne': [('ef', False)],
          'efernes': [('ef', False)],
          'efers': [('ef', False)],
          'efferne': [('ef', False)],
          'effets': [('ef', False)],
          'efg': [('de_erhvervsfaglige_grunduddannelser', True)],
          'eficers': [('efice', False)],
          'efilets': [('efilet', False)],
          'efilter': [('efilt', False)],
          'efilters': [('efilt', False)],
          'efinger': [('efing', False)],
          'efingers': [('efing', False)],
          'efladen': [('eflade', False)],
          'efladens': [('eflade', False)],
          'eflipper': [('eflip', False)],
          'eflipperne': [('eflip', False)],
          'eflippernes': [('eflip', False)],
          'eflippers': [('eflip', False)],
          'eflisen': [('eflise', False)],
          'eflisens': [('eflise', False)],
          'efliser': [('eflise', False)],
          'efliserne': [('eflise', False)],
          'eflisernes': [('eflise', False)],
          'eflisers': [('eflise', False)],
          'efloks': [('eflok', False)],
          'eflugter': [('eflugt', False)],
          'eflugterne': [('eflugt', False)],
          'eflugternes': [('eflugt', False)],
          'eflugters': [('eflugt', False)],
          'eflys': [('efly', False)],
          'eflægen': [('eflæge', False)],
          'eflægens': [('eflæge', False)],
          'efløjten': [('efløjte', False)],
          'efolder': [('efold', False)],
          'efolderne': [('efold', False)],
          'efoldernes': [('efold', False)],
          'efolders': [('efold', False)],
          'efonds': [('efond', False)],
          'efons': [('efon', False)],
          'eformer': [('eform', False)],
          'eformerne': [('eform', False)],
          'eformernes': [('eform', False)],
          'eformers': [('eform', False)],
          'efornemmelser': [('efornemmelse', False)],
          'efornemmelsernes': [('efornemmelse', False)],
          'eforternes': [('efort', False)],
          'eforældrene': [('eforældre', False)],
          'eforældrenes': [('eforældre', False)],
          'eforældres': [('eforældre', False)],
          'efragter': [('efragter', False)],
          'efragterne': [('efragter', False)],
          'efragternes': [('efragter', False)],
          'efragters': [('efragter', False)],
          'efrister': [('efrist', False)],
          'efristerne': [('efrist', False)],
          'efristernes': [('efrist', False)],
          'efristers': [('efrist', False)],
          'efruers': [('efrue', False)],
          'efylden': [('efylde', False)],
          'efyldens': [('efylde', False)],
          'efædre': [('efar', False)],
          'efædrene': [('efader', False)],
          'efædrenes': [('efar', False)],
          'efædres': [('efader', False)],
          'efærden': [('efærd', False)],
          'efærdens': [('efærd', False)],
          'efæren': [('efær', False)],
          'efærens': [('efær', False)],
          'efødder': [('efod', False)],
          'efølger': [('efølge', False)],
          'efølgerne': [('efølge', False)],
          'efølgernes': [('efølge', False)],
          'efølgers': [('efølge', False)],
          'eførerne': [('efører', False)],
          'eg': [('eg', False)],
          'egader': [('egade', False)],
          'egale': [('egale', False)],
          'egalet': [('egal', False)],
          'egalets': [('egal', False)],
          'eganer': [('eganer', False)],
          'eganerne': [('eganer', False)],
          'eganernes': [('eganer', False)],
          'eganers': [('eganer', False)],
          'egarder': [('egarde', False)],
          'egarderne': [('egarde', False)],
          'egardernes': [('egarde', False)],
          'egarders': [('egarde', False)],
          'egarer': [('egar', False)],
          'egarernes': [('egar', False)],
          'egas': [('egas', False)],
          "egas'": [('egas', False)],
          'egasen': [('egasus', False)],
          'egasens': [('egasus', False)],
          'egassernes': [('egas', False)],
          'egassers': [('egas', False)],
          'egaten': [('egat', False)],
          'egatens': [('egat', False)],
          'ege': [('ege', True), ('eg', True)],
          'egels': [('egel', False)],
          'egen': [('ege', True), ('eg', True)],
          'egene': [('eg', False)],
          'egenes': [('eg', False)],
          'egens': [('ege', True), ('eg', True)],
          'egenser': [('egenser', False)],
          'egensernes': [('egenser', False)],
          'eger': [('ege', True), ('eger', True)],
          'egere': [('eger', False)],
          'egeredes': [('egeret', False)],
          'egeren': [('eger', False)],
          'egerens': [('eger', True)],
          'egeres': [('eger', False)],
          'egerne': [('eger', True), ('ege', True)],
          'egernes': [('ege', True), ('eger', True)],
          'egers': [('ege', True), ('eger', True)],
          'eges': [('ege', True), ('eg', True)],
          'eget': [('eg', False)],
          'egets': [('eg', False)],
          'egheden': [('eghede', False)],
          'egien': [('egi', False)],
          'egiens': [('egi', False)],
          'egiets': [('egie', False)],
          'egis': [('egi', False)],
          'egisters': [('egister', False)],
          'eglans': [('eglans', False)],
          'egle': [('egle', False)],
          'eglen': [('egel', False)],
          'eglens': [('egl', False)],
          'egler': [('egel', False)],
          'eglerne': [('egel', False)],
          'eglernes': [('egle', False)],
          'eglers': [('egle', False)],
          'egles': [('egle', False)],
          'eglet': [('egl', False)],
          'egne': [('egn', True)],
          'egnen': [('egn', True)],
          'egnens': [('egn', True)],
          'egnerne': [('egner', False)],
          'egners': [('egner', False)],
          'egnes': [('egn', True)],
          'egnet': [('egnum', False)],
          'egnets': [('egnum', False)],
          'egnummers': [('egnum', False)],
          'egonien': [('egonie', False)],
          'egoniens': [('egonie', False)],
          'egrams': [('egram', False)],
          'egrene': [('eger', False)],
          'egrenes': [('eger', False)],
          'egres': [('eger', False)],
          'egrever': [('egreve', False)],
          'egreverne': [('egreve', False)],
          'egrevernes': [('egreve', False)],
          'egrevers': [('egrever', False)],
          'egridernes': [('egrid', False)],
          'egrillen': [('egrill', False)],
          'egrillens': [('egrill', False)],
          'egriller': [('egrill', False)],
          'egrillerne': [('egrill', False)],
          'egrillernes': [('egrill', False)],
          'egrillers': [('egrill', False)],
          'egros': [('egro', False)],
          'egrus': [('egrus', False)],
          'egrøden': [('egrøde', False)],
          'egrødens': [('egrøde', False)],
          'egs': [('eg', False)],
          'egænger': [('egænger', False)],
          'egængerne': [('egænger', False)],
          'egængernes': [('egænger', False)],
          'egængers': [('egænger', False)],
          'egæren': [('egære', False)],
          'egærens': [('egære', False)],
          'egørerne': [('egører', False)],
          'eh': [('eh', False)],
          'ehakker': [('ehakker', False)],
          'ehakkerne': [('ehakker', False)],
          'ehakkernes': [('ehakker', False)],
          'ehakkers': [('ehakker', False)],
          'ehalerne': [('ehale', False)],
          'ehallen': [('ehal', False)],
          'ehallens': [('ehal', False)],
          'ehaller': [('ehal', False)],
          'ehallerne': [('ehal', False)],
          'ehallernes': [('ehal', False)],
          'ehallers': [('ehal', False)],
          'ehals': [('ehal', False)],
          'ehams': [('ehams', False)],
          'ehandler': [('ehandler', False)],
          'ehandlerne': [('ehandel', False)],
          'ehandlernes': [('ehandel', False)],
          'ehandlers': [('ehandler', False)],
          'eharerne': [('ehare', False)],
          'ehave': [('ehave', False)],
          'ehaver': [('ehaver', False)],
          'ehaverne': [('ehaver', False)],
          'ehavernes': [('ehaver', False)],
          'ehavers': [('ehaver', False)],
          'ehaves': [('ehav', False)],
          'ehavets': [('ehav', False)],
          'eheden': [('ehed', False)],
          'ehedens': [('ehed', False)],
          'eheder': [('ehed', False)],
          'ehederne': [('ehed', False)],
          'ehedernes': [('ehed', False)],
          'eheders': [('ehed', False)],
          'ehen': [('eh', False)],
          'ehens': [('eh', False)],
          'eher': [('eh', False)],
          'eherne': [('eh', False)],
          'ehernes': [('eh', False)],
          'ehers': [('eh', False)],
          'ehinde': [('ehinde', False)],
          'ehinden': [('ehinde', False)],
          'ehindens': [('ehinde', False)],
          'ehinder': [('ehinde', False)],
          'ehinderne': [('ehinde', False)],
          'ehindernes': [('ehinde', False)],
          'ehinders': [('ehinde', False)],
          'ehindes': [('ehinde', False)],
          'ehuen': [('ehue', False)],
          'ehuens': [('ehue', False)],
          'ehus': [('ehus', False)],
          'ehvide': [('ehvide', False)],
          'ehvides': [('ehvide', False)],
          'ehvirvler': [('ehvirvel', False)],
          'ehvirvlerne': [('ehvirvel', False)],
          'ehvirvlernes': [('ehvirvel', False)],
          'ehvirvlers': [('ehvirvel', False)],
          'ehylden': [('ehyld', False)],
          'ehyldens': [('ehyld', False)],
          'ehøjder': [('ehøjde', False)],
          'ehøjderne': [('ehøjde', False)],
          'ehøjdernes': [('ehøjde', False)],
          'ehøjders': [('ehøjde', False)],
          'ei': [('ei', False)],
          'eide': [('eide', False)],
          'eiden': [('eid', True)],
          'eidens': [('eid', True)],
          'eider': [('eide', False)],
          'eiderne': [('eide', False)],
          'eidernes': [('eide', False)],
          'eiders': [('eide', False)],
          'eides': [('eide', False)],
          'eiene': [('eu', False)],
          'eienes': [('eu', False)],
          'eier': [('eier', False)],
          'eiere': [('eier', False)],
          'eieren': [('eier', False)],
          'eierens': [('eier', False)],
          'eieres': [('eier', False)],
          'eiers': [('eier', False)],
          'eiken': [('eik', False)],
          'eiker': [('eik', False)],
          'eikerne': [('eik', False)],
          'eikernes': [('eik', False)],
          'eikers': [('eik', False)],
          'eild': [('eild', False)],
          'eildens': [('eild', False)],
          'eilds': [('eild', False)],
          'eilerne': [('eiler', False)],
          'eilernes': [('eiler', False)],
          'eilers': [('eiler', False)],
          'eillens': [('eille', False)],
          'eiller': [('eille', False)],
          'eillerne': [('eille', False)],
          'eillernes': [('eille', False)],
          'eillers': [('eille', False)],
          'eilten': [('eilte', False)],
          'eiltens': [('eilte', False)],
          'einder': [('einde', False)],
          'einderne': [('einde', False)],
          'eindernes': [('einde', False)],
          'einders': [('einde', False)],
          'eingen': [('eing', False)],
          'eingens': [('eing', False)],
          'eings': [('eing', False)],
          'einten': [('eint', False)],
          'eintens': [('eint', False)],
          'eira': [('eira', False)],
          'eiras': [('eira', False)],
          'eis': [('eis', True)],
          'eismen': [('eisme', False)],
          'eismens': [('eisme', False)],
          'eissen': [('eiss', False)],
          'eissene': [('eiss', False)],
          'eissenes': [('eiss', False)],
          'eissens': [('eiss', False)],
          'eisser': [('eis', True)],
          'eisserne': [('eis', True)],
          'eissernes': [('eis', True)],
          'eissers': [('eis', True)],
          'eisten': [('eist', False)],
          'eistens': [('eist', False)],
          'eister': [('eist', False)],
          'eisterne': [('eist', False)],
          'eisternes': [('eist', False)],
          'eisters': [('eist', False)],
          'eiver': [('eiver', False)],
          'eivernes': [('eiver', False)],
          'eizer': [('eizer', False)],
          'eizers': [('eizer', False)],
          'ejakken': [('ejakke', False)],
          'ejavs': [('ejav', False)],
          'ejden': [('ejde', False)],
          'ejdens': [('ejde', False)],
          'ejder': [('ejder', False)],
          'ejderne': [('ejder', False)],
          'ejdernes': [('ejder', False)],
          'ejders': [('ejde', False)],
          'eje': [('eje', True)],
          'ejen': [('ej', False)],
          'ejene': [('ej', False)],
          'ejens': [('ej', False)],
          'ejer': [('ejer', True)],
          'ejerne': [('ejer', True)],
          'ejernes': [('ejer', True)],
          'ejers': [('ejer', False)],
          'ejes': [('eje', True)],
          'ejet': [('ej', False)],
          'ejets': [('ej', False)],
          'ejfen': [('ejf', False)],
          'ejfens': [('ejf', False)],
          'ejfer': [('ejf', False)],
          'ejle': [('ejle', False)],
          'ejlen': [('ejle', False)],
          'ejlens': [('ejle', False)],
          'ejler': [('ejle', False)],
          'ejlerne': [('ejler', False)],
          'ejlernes': [('ejler', False)],
          'ejles': [('ejle', False)],
          'ejne': [('ejne', False)],
          'ejnen': [('ejne', False)],
          'ejnens': [('ejne', False)],
          'ejner': [('ejne', False)],
          'ejnerne': [('ejne', False)],
          'ejnernes': [('ejne', False)],
          'ejners': [('ejne', False)],
          'ejnes': [('ejne', False)],
          'ejorden': [('ejord', False)],
          'ejordens': [('ejord', False)],
          'ejre': [('ejre', False)],
          'ejren': [('ejre', False)],
          'ejrens': [('ejre', False)],
          'ejrer': [('ejre', False)],
          'ejrerne': [('ejre', False)],
          'ejrernes': [('ejre', False)],
          'ejrers': [('ejrer', False)],
          'ejres': [('ejre', False)],
          'ejs': [('ej', False)],
          'ejse': [('ejse', False)],
          'ejsen': [('ejse', False)],
          'ejsens': [('ejse', False)],
          'ejserne': [('ejse', False)],
          'ejsernes': [('ejse', False)],
          'ejsers': [('ejser', False)],
          'ejses': [('ejse', False)],
          'ejuicer': [('ejuice', False)],
          'ejuicerne': [('ejuice', False)],
          'ejuicernes': [('ejuice', False)],
          'ejuicers': [('ejuice', False)],
          'ek': [('ekund', False)],
          'ek.': [('ekund', False)],
          'ekagen': [('ekage', False)],
          'ekagens': [('ekage', False)],
          'ekalken': [('ekalk', False)],
          'ekalkens': [('ekalk', False)],
          'ekanden': [('ekande', False)],
          'ekandernes': [('ekande', False)],
          'ekanen': [('ekan', False)],
          'ekanens': [('ekan', False)],
          'ekaner': [('ekan', False)],
          'ekanerne': [('ekan', False)],
          'ekanernes': [('ekan', False)],
          'ekaners': [('ekan', False)],
          'ekanoner': [('ekanon', False)],
          'ekanoners': [('ekanon', False)],
          'ekans': [('ekan', False)],
          'ekarambolen': [('ekarambole', False)],
          'ekarambolens': [('ekarambole', False)],
          'ekaren': [('ekar', False)],
          'ekarens': [('ekar', False)],
          'ekarer': [('ekar', False)],
          'ekarernes': [('ekar', False)],
          'ekartofler': [('ekartoffel', False)],
          'ekartoflerne': [('ekartoffel', False)],
          'ekartoflernes': [('ekartoffel', False)],
          'ekartoflers': [('ekartoffel', False)],
          'ekaster': [('ekaster', False)],
          'ekasterne': [('ekaster', False)],
          'ekasternes': [('ekaster', False)],
          'ekasters': [('ekaster', False)],
          'eken': [('ek', False)],
          'ekender': [('ekend', False)],
          'ekenderne': [('ekender', False)],
          'ekendernes': [('ekender', False)],
          'ekenders': [('ekend', False)],
          'ekens': [('ek', False)],
          'eker': [('ek', False)],
          'ekere': [('eker', False)],
          'ekeren': [('eker', False)],
          'ekerens': [('eker', False)],
          'ekeres': [('eker', False)],
          'ekerne': [('ek', False)],
          'ekernes': [('ek', False)],
          'ekers': [('ek', False)],
          'ekiks': [('ekiks', False)],
          'ekilder': [('ekilde', False)],
          'ekilderne': [('ekilde', False)],
          'ekildernes': [('ekilde', False)],
          'ekilders': [('ekilde', False)],
          'ekilers': [('ekile', False)],
          'ekillingernes': [('ekilling', False)],
          'ekinen': [('ekin', False)],
          'ekinens': [('ekin', False)],
          'ekiner': [('ekin', False)],
          'ekinernes': [('ekin', False)],
          'ekismen': [('ekismus', False)],
          'ekismens': [('ekismus', False)],
          'ekisten': [('ekiste', False)],
          'ekistens': [('ekiste', False)],
          'ekisterne': [('ekiste', False)],
          'ekisternes': [('ekiste', False)],
          'ekke': [('ekke', False)],
          'ekken': [('ekke', False)],
          'ekker': [('ek', False)],
          'ekkere': [('ekke', False)],
          'ekkeren': [('ekke', False)],
          'ekkerens': [('ekke', False)],
          'ekkeres': [('ekke', False)],
          'ekkerne': [('ekke', False)],
          'ekkernes': [('ek', False)],
          'ekkers': [('ek', False)],
          'ekkes': [('ekke', False)],
          'ekket': [('ek', False)],
          'ekkets': [('ek', False)],
          'eklager': [('eklage', False)],
          'eklagerne': [('eklage', False)],
          'eklagernes': [('eklage', False)],
          'eklagers': [('eklage', False)],
          'eklapper': [('eklap', False)],
          'eklapperne': [('eklap', False)],
          'eklappernes': [('eklap', False)],
          'eklappers': [('eklap', False)],
          'eklaps': [('eklap', False)],
          'eklatters': [('eklat', False)],
          'ekler': [('ekel', False)],
          'eklipper': [('eklipper', False)],
          'eklipperne': [('eklipper', False)],
          'eklippernes': [('eklipper', False)],
          'eklippers': [('eklipper', False)],
          'eklips': [('eklip', False)],
          'eklipsen': [('eklipse', True)],
          'eklipsens': [('eklipse', True)],
          'eklister': [('ekliste', False)],
          'eklisternes': [('ekliste', False)],
          'eklisters': [('ekliste', False)],
          'eklokker': [('eklokke', False)],
          'eklokkerne': [('eklokke', False)],
          'eklokkernes': [('eklokke', False)],
          'eklokkers': [('eklokke', False)],
          'eklæder': [('eklæde', False)],
          'eklæderne': [('eklæder', False)],
          'eklædernes': [('eklæde', False)],
          'eklæders': [('eklæde', False)],
          'ekniks': [('eknik', False)],
          'ekogger': [('ekogger', False)],
          'ekoggerne': [('ekogger', False)],
          'ekoggernes': [('ekogger', False)],
          'ekoggers': [('ekogger', False)],
          'ekoller': [('ekolle', False)],
          'ekollers': [('ekolle', False)],
          'ekonger': [('ekonger', False)],
          'ekongers': [('ekonger', False)],
          'ekontroller': [('ekontrol', False)],
          'ekontrollerne': [('ekontrol', False)],
          'ekontrollernes': [('ekontrol', False)],
          'ekontrollers': [('ekontrol', False)],
          'ekopper': [('ekop', False)],
          'ekopperne': [('ekop', False)],
          'ekoppernes': [('ekop', False)],
          'ekoppers': [('ekop', False)],
          'ekorden': [('ekord', False)],
          'ekordens': [('ekord', False)],
          'ekorder': [('ekord', False)],
          'ekorderne': [('ekord', False)],
          'ekordernes': [('ekord', False)],
          'ekorders': [('ekord', False)],
          'ekornet': [('ekorn', False)],
          'ekornets': [('ekorn', False)],
          'ekors': [('ekor', False)],
          'ekorset': [('ekors', False)],
          'ekorsets': [('ekors', False)],
          'ekorter': [('ekort', False)],
          'ekorterne': [('ekort', False)],
          'ekorternes': [('ekort', False)],
          'ekoster': [('ekoster', False)],
          'ekostningers': [('ekostning', False)],
          'ekrans': [('ekrans', False)],
          'ekraterne': [('ekrater', False)],
          'ekreds': [('ekreds', False)],
          'ekret': [('ekret', False)],
          'ekreter': [('ekret', False)],
          'ekreterne': [('ekret', False)],
          'ekreternes': [('ekret', False)],
          'ekreters': [('ekret', False)],
          'ekrige': [('ekrige', False)],
          'ekrigen': [('ekrige', False)],
          'ekrigens': [('ekrige', False)],
          'ekriger': [('ekrige', False)],
          'ekrigerne': [('ekrige', False)],
          'ekrigernes': [('ekrige', False)],
          'ekrigers': [('ekrige', False)],
          'ekriges': [('ekrige', False)],
          'ekronen': [('ekrone', False)],
          'ekroner': [('ekrone', False)],
          'ekronerne': [('ekrone', False)],
          'ekronernes': [('ekrone', False)],
          'ekrutten': [('ekrut', False)],
          'ekræfternes': [('ekraft', False)],
          'ekræs': [('ekræ', False)],
          'eks': [('eks', True)],
          'ekser': [('eks', False)],
          'ekserne': [('eks', True)],
          'eksernes': [('eks', True)],
          'eksers': [('eks', True)],
          'eksis': [('eksi', False)],
          'eksten': [('ekst', False)],
          'ekstens': [('ekst', False)],
          'ekster': [('ekst', False)],
          'eksterne': [('ekst', False)],
          'eksternes': [('ekst', False)],
          'eksters': [('ekst', False)],
          'ekstiden': [('ekstid', False)],
          'ekturen': [('ekture', False)],
          'ekturens': [('ekture', False)],
          'ektures': [('ekture', False)],
          'ekunden': [('ekund', False)],
          'ekundens': [('ekund', False)],
          'ekunder': [('ekund', False)],
          'ekunderne': [('ekund', False)],
          'ekundernes': [('ekund', False)],
          'ekunders': [('ekund', False)],
          'ekunster': [('ekunst', False)],
          'ekunsterne': [('ekunster', False)],
          'ekunsternes': [('ekunst', False)],
          'ekunsters': [('ekunster', False)],
          'ekuren': [('ekur', False)],
          'ekurens': [('ekur', False)],
          'ekures': [('ekur', False)],
          'ekurs': [('ekurs', False)],
          'ekurser': [('ekurs', False)],
          'ekurserne': [('ekurs', False)],
          'ekursernes': [('ekurs', False)],
          'ekursers': [('ekursus', False)],
          'ekvalers': [('ekval', False)],
          'ekvarter': [('ekvarter', False)],
          'ekvarters': [('ekvarter', False)],
          'ekyler': [('ekyl', False)],
          'ekylerne': [('ekyl', False)],
          'ekylernes': [('ekyl', False)],
          'ekylers': [('ekyl', False)],
          'ekøbet': [('ekøb', False)],
          'ekød': [('ekød', False)],
          'ekøds': [('ekød', False)],
          'ekøer': [('eko', False)],
          'ekøerne': [('eko', False)],
          'ekøernes': [('eko', False)],
          'ekøers': [('eko', False)],
          'ekørerne': [('ekører', False)],
          'el': [('el', False)],
          'elader': [('elader', False)],
          'eladerne': [('elader', False)],
          'eladernes': [('elade', False)],
          'eladers': [('elade', False)],
          'elads': [('elad', False)],
          'elagen': [('elage', False)],
          'elagens': [('elagen', False)],
          'elager': [('elage', False)],
          'elagerne': [('elag', False)],
          'elagernes': [('elage', False)],
          'elagers': [('elage', False)],
          'elags': [('elag', False)],
          'elaisen': [('elaise', False)],
          'elaisens': [('elaise', False)],
          'elaks': [('elak', False)],
          'elaner': [('elaner', False)],
          'elanerne': [('elaner', False)],
          'elanernes': [('elaner', False)],
          'elans': [('elan', True)],
          'elappernes': [('elap', False)],
          'elaps': [('elap', False)],
          'elarbejder': [('elarbejde', False)],
          'elarbejderne': [('elarbejde', False)],
          'elarbejdernes': [('elarbejde', False)],
          'elarbejders': [('elarbejde', False)],
          'elarer': [('elar', False)],
          'elarernes': [('elar', False)],
          'elars': [('elar', False)],
          'elas': [('ela', False)],
          'elassen': [('elasse', False)],
          'elassens': [('elasse', False)],
          'elaster': [('elaster', False)],
          'elasterne': [('elaster', False)],
          'elasternes': [('elaster', False)],
          'elasters': [('elaster', False)],
          'elatiner': [('elatine', False)],
          'elatinerne': [('elatine', False)],
          'elatinernes': [('elatine', False)],
          'elatiners': [('elatine', False)],
          'elats': [('elat', False)],
          'elatter': [('elatter', False)],
          'elatters': [('elatter', False)],
          'elavet': [('elav', False)],
          'elavets': [('elav', False)],
          'elbaner': [('elbane', False)],
          'elbanerne': [('elbane', False)],
          'elbanernes': [('elbane', False)],
          'elbaners': [('elbane', False)],
          'elben': [('elben', False)],
          'elbens': [('elben', False)],
          'elbo': [('elbo', False)],
          'elboen': [('elbo', True)],
          'elboens': [('elbo', False)],
          'elboer': [('elbo', False)],
          'elboerne': [('elbo', False)],
          'elbos': [('elbo', False)],
          'eldene': [('eld', False)],
          'elder': [('elder', False)],
          'elderne': [('elder', False)],
          'eldernes': [('elder', False)],
          'ele': [('el', False)],
          'eleaser': [('elease', False)],
          'eleaserne': [('elease', False)],
          'eleasernes': [('elease', False)],
          'eleasers': [('elease', False)],
          'eleder': [('eleder', False)],
          'eledernes': [('eleder', False)],
          'elege': [('eleg', False)],
          'eleges': [('eleg', False)],
          'elejer': [('eleje', False)],
          'elejerne': [('eleje', False)],
          'elejernes': [('eleje', False)],
          'elejers': [('eleje', False)],
          'elen': [('el', False)],
          'elene': [('el', False)],
          'elenes': [('el', False)],
          'elenet': [('elen', False)],
          'elenets': [('elen', False)],
          'elens': [('el', False)],
          'eler': [('el', False)],
          'elere': [('eler', False)],
          'eleren': [('eler', False)],
          'elerens': [('eler', False)],
          'elerer': [('eler', False)],
          'elererne': [('eler', False)],
          'elerernes': [('eler', False)],
          'elerers': [('eler', False)],
          'eleres': [('eler', False)],
          'eleret': [('eler', False)],
          'elerets': [('eler', False)],
          'elerne': [('ele', False)],
          'elernes': [('el', False)],
          'elers': [('el', False)],
          'eles': [('el', False)],
          'elestens': [('eleste', False)],
          'elet': [('el', False)],
          'eletten': [('elet', False)],
          'elettens': [('elet', False)],
          'eletter': [('elet', False)],
          'eletterne': [('elet', False)],
          'eletternes': [('elet', False)],
          'eletters': [('elet', False)],
          'eleven': [('elev', False)],
          'elevens': [('elev', False)],
          'elever': [('elev', False)],
          'eleverne': [('elev', True)],
          'elevernes': [('elev', True)],
          'elevers': [('elev', False)],
          'elfarter': [('elfart', False)],
          'elfarterne': [('elfart', False)],
          'elfarternes': [('elfarter', False)],
          'elfarters': [('elfart', False)],
          'elfer': [('elf', False)],
          'elferne': [('elf', False)],
          'elfernes': [('elf', False)],
          'elfilters': [('elfilter', False)],
          'elflugter': [('elflugter', False)],
          'elflugterne': [('elflugt', False)],
          'elflugternes': [('elflugter', False)],
          'elflugters': [('elflugter', False)],
          'elgen': [('elg', True)],
          'elgens': [('elg', True)],
          'elhandlernes': [('elhandler', False)],
          'elhedens': [('elhed', False)],
          'elias': [('elia', False)],
          'elien': [('elie', False)],
          'eliens': [('elie', False)],
          'elier': [('elier', False)],
          'elierne': [('eli', False)],
          'eliernes': [('elie', False)],
          'eliers': [('elium', False)],
          'elies': [('elie', False)],
          'eliet': [('elie', False)],
          'eliets': [('elie', False)],
          'elikaner': [('elikan', False)],
          'elikaners': [('elikan', False)],
          'elikker': [('elik', False)],
          'elikkernes': [('elik', False)],
          'elikkers': [('elik', False)],
          'elil': [('elil', False)],
          'elils': [('elil', False)],
          'elime': [('elim', False)],
          'elimen': [('elim', False)],
          'elimene': [('elim', False)],
          'elimenes': [('elim', False)],
          'elimens': [('elim', False)],
          'elimes': [('elim', False)],
          'elimmer': [('elim', False)],
          'elinen': [('elin', False)],
          'elinene': [('eline', False)],
          'elinenes': [('eline', False)],
          'elinens': [('elin', False)],
          'eliner': [('eline', False)],
          'elinerne': [('elin', False)],
          'elinernes': [('eline', False)],
          'eliners': [('eliner', False)],
          'elinet': [('elin', False)],
          'elinets': [('elin', False)],
          'elingers': [('eling', False)],
          'elinien': [('elinie', False)],
          'eliren': [('elire', False)],
          'elirens': [('elire', False)],
          'elis': [('elis', False)],
          'elisen': [('elis', False)],
          'elisens': [('elis', False)],
          'eliskens': [('elisk', False)],
          'elisker': [('elisk', False)],
          'eliskerne': [('elisk', False)],
          'eliskernes': [('elisk', False)],
          'eliskers': [('elisk', False)],
          'elismen': [('elisme', False)],
          'elisser': [('elisse', False)],
          'elisserne': [('elisse', False)],
          'elissernes': [('elisse', False)],
          'elissers': [('elisse', False)],
          'elisten': [('eliste', False)],
          'elistens': [('eliste', False)],
          'elister': [('eliste', False)],
          'elisterne': [('eliste', False)],
          'elisternes': [('elist', False)],
          'elisters': [('elist', False)],
          'eliter': [('elite', False)],
          'eliterne': [('elite', False)],
          'eliternes': [('elite', True)],
          'eliters': [('elite', True)],
          'elits': [('elit', False)],
          'elitter': [('elit', False)],
          'elium': [('elium', False)],
          'eliums': [('elium', False)],
          'elkurs': [('elkur', False)],
          'elkurve': [('elkurv', False)],
          'elkurvens': [('elkurv', False)],
          'elle': [('el', True)],
          'ellen': [('el', True)],
          'ellene': [('el', False)],
          'ellenes': [('el', False)],
          'ellens': [('el', False)],
          'eller': [('elle', False)],
          'ellerne': [('el', False)],
          'ellernes': [('el', False)],
          'ellers': [('elle', False)],
          'elles': [('el', True)],
          'ellet': [('el', False)],
          'ellets': [('el', False)],
          'elletten': [('ellette', False)],
          'elletter': [('ellette', False)],
          'elletterne': [('ellette', False)],
          'elletternes': [('ellette', False)],
          'ellevetiden': [('ellevetiden', True)],
          'ellier': [('elli', False)],
          'elliernes': [('elli', False)],
          'elliers': [('elli', False)],
          'ellis': [('elli', False)],
          'ellisten': [('ellist', False)],
          'ellistens': [('ellist', False)],
          'ellisterne': [('ellist', False)],
          'ellos': [('ello', False)],
          'elminens': [('elmine', False)],
          'elodder': [('elod', False)],
          'elodderne': [('elod', False)],
          'eloddernes': [('elod', False)],
          'elodders': [('elod', False)],
          'elods': [('elod', False)],
          'eloer': [('elo', False)],
          'elokker': [('elokker', False)],
          'elokkerne': [('elokker', False)],
          'elokkernes': [('elokker', False)],
          'elokkers': [('elokker', False)],
          'eloksen': [('elokse', False)],
          'eloksens': [('elokse', False)],
          'elomme': [('elomme', False)],
          'elommen': [('elomme', False)],
          'elommens': [('elomme', False)],
          'elommer': [('elomme', False)],
          'elommerne': [('elomme', False)],
          'elommernes': [('elomme', False)],
          'elommers': [('elomme', False)],
          'elommes': [('elomme', False)],
          'elongen': [('elong', False)],
          'elongens': [('elong', False)],
          'elonger': [('elong', False)],
          'elongerne': [('elong', False)],
          'elongernes': [('elong', False)],
          'elongers': [('elong', False)],
          'eloper': [('eloper', False)],
          'eloperne': [('eloper', False)],
          'elopernes': [('eloper', False)],
          'eloren': [('elor', False)],
          'elorens': [('elor', False)],
          'elorer': [('elor', False)],
          'elorerne': [('elor', False)],
          'elorernes': [('elor', False)],
          'elos': [('elo', False)],
          'elotten': [('elot', False)],
          'elottens': [('elot', False)],
          'elotter': [('elot', False)],
          'elotterne': [('elot', False)],
          'elotternes': [('elot', False)],
          'elotters': [('elot', False)],
          'elove': [('elov', False)],
          'els': [('el', False)],
          "els'": [('el', False)],
          'else': [('else', False)],
          'elsen': [('else', False)],
          'elsens': [('else', False)],
          'elser': [('else', False)],
          'elserne': [('else', False)],
          'elsernes': [('else', False)],
          'elses': [('else', False)],
          'elstyrets': [('elstyr', False)],
          'elten': [('elten', False)],
          'eltene': [('elt', False)],
          'eltens': [('elten', False)],
          'elter': [('elter', False)],
          'elterne': [('elter', False)],
          'elternes': [('elter', False)],
          'elters': [('elt', False)],
          'elukker': [('elukker', False)],
          'elukkerne': [('elukke', False)],
          'elukkernes': [('elukker', False)],
          'elukkers': [('elukke', False)],
          'elunerne': [('elune', False)],
          'eluners': [('elune', False)],
          'elure': [('elure', False)],
          'eluren': [('elure', False)],
          'elurens': [('elure', False)],
          'elurer': [('elure', False)],
          'elurerne': [('elure', False)],
          'elurernes': [('elure', False)],
          'elurers': [('elure', False)],
          'elures': [('elur', False)],
          'elus': [('elus', False)],
          'elvers': [('elver', True)],
          'elvinden': [('elvind', False)],
          'elvindens': [('elvind', False)],
          'elvindes': [('elvind', False)],
          'elyde': [('elyd', False)],
          'elyden': [('elyd', False)],
          'elydens': [('elyd', False)],
          'elydes': [('elyd', False)],
          'elys': [('elys', False)],
          'elysen': [('elys', False)],
          'elysens': [('elys', False)],
          'elytter': [('elyt', False)],
          'elytterne': [('elyt', False)],
          'elytternes': [('elyt', False)],
          'elytters': [('elyt', False)],
          'elås': [('elås', False)],
          'elæber': [('elæbe', False)],
          'elæbernes': [('elæbe', False)],
          'elæder': [('elæder', False)],
          'elæer': [('elæ', False)],
          'elæerne': [('elæ', False)],
          'elæernes': [('elæ', False)],
          'elæers': [('elæ', False)],
          'elægens': [('elæge', False)],
          'elægerne': [('elæge', False)],
          'elægernes': [('elæge', False)],
          'elægers': [('elæge', False)],
          'elænder': [('eland', False)],
          'elænderne': [('eland', False)],
          'elændernes': [('eland', False)],
          'elænders': [('eland', False)],
          'elæner': [('elæn', False)],
          'elænerne': [('elæn', False)],
          'elænernes': [('elæn', False)],
          'elærer': [('elærer', False)],
          'elærerne': [('elære', False)],
          'elærernes': [('elære', False)],
          'elærers': [('elærer', False)],
          'elærke': [('elærke', False)],
          'elærken': [('elærke', False)],
          'elærkens': [('elærke', False)],
          'elærkes': [('elærke', False)],
          'elæs': [('elæ', False)],
          'elæsernes': [('elæser', False)],
          'eløben': [('eløbe', False)],
          'eløbens': [('eløbe', False)],
          'eløberne': [('eløber', False)],
          'eløbers': [('eløber', False)],
          'eløfter': [('eløfter', False)],
          'eløfterne': [('eløfter', False)],
          'eløfternes': [('eløfter', False)],
          'eløfters': [('eløfter', False)],
          'eløret': [('eløre', False)],
          'eløs': [('eløs', False)],
          'eløsen': [('eløs', False)],
          'eløsens': [('eløs', False)],
          'eløven': [('eløv', False)],
          'eløvens': [('eløv', False)],
          'em': [('em', False)],
          'emadders': [('emad', False)],
          'emaden': [('emad', False)],
          'emads': [('emad', False)],
          'emagens': [('emage', False)],
          'emager': [('emager', False)],
          'emakker': [('emak', False)],
          'emakkerne': [('emak', False)],
          'emakkernes': [('emak', False)],
          'emakkers': [('emak', False)],
          'emaler': [('emal', False)],
          'emalerne': [('emal', False)],
          'emalernes': [('emal', False)],
          'emalers': [('emal', False)],
          'eman': [('eman', False)],
          'emander': [('emande', False)],
          'emanderne': [('emande', False)],
          'emandernes': [('emande', False)],
          'emanders': [('emande', False)],
          'emanens': [('emanens', False)],
          'emaner': [('emaner', False)],
          'emanerne': [('emaner', False)],
          'emanernes': [('emaner', False)],
          'emaners': [('emaner', False)],
          'emanner': [('emanner', False)],
          'emans': [('eman', False)],
          'emarchen': [('emarche', False)],
          'emarchens': [('emarch', False)],
          'emarcher': [('emarche', False)],
          'emarcherne': [('emarch', False)],
          'emarchernes': [('emarche', False)],
          'emarchers': [('emarch', False)],
          'emarker': [('emark', False)],
          'emarkerne': [('emark', False)],
          'emarkernes': [('emark', False)],
          'emarkers': [('emark', False)],
          'emas': [('ema', False)],
          'emasken': [('emaske', False)],
          'emaskens': [('emaske', False)],
          'emasker': [('emaske', False)],
          'emaskers': [('emaske', False)],
          'emassens': [('emasse', False)],
          'emasser': [('emasse', False)],
          'emasserne': [('emasse', False)],
          'emaster': [('emaster', False)],
          'emasterne': [('emast', False)],
          'emasternes': [('emast', False)],
          'emasters': [('emaster', False)],
          'ematis': [('ematis', False)],
          'ember': [('ember', False)],
          'embler': [('emble', False)],
          'emblerne': [('emble', False)],
          'emblers': [('emble', False)],
          'emblet': [('emble', False)],
          'emblets': [('emble', False)],
          'emediciner': [('emedicin', False)],
          'emedicinerne': [('emedicin', False)],
          'emedicinernes': [('emedicin', False)],
          'emediciners': [('emedicin', False)],
          'emejer': [('emeje', False)],
          'emejerne': [('emeje', False)],
          'emejernes': [('emeje', False)],
          'emejers': [('emeje', False)],
          'emejsen': [('emejse', False)],
          'emejsens': [('emejse', False)],
          'emejser': [('emejse', False)],
          'emejserne': [('emejse', False)],
          'emejsernes': [('emejse', False)],
          'emejsers': [('emejse', False)],
          'emelet': [('emel', False)],
          'emen': [('em', False)],
          'emens': [('eme', False)],
          'ementen': [('ement', False)],
          'ementens': [('ement', False)],
          'ementer': [('ement', False)],
          'ementerne': [('ement', False)],
          'ementernes': [('ement', False)],
          'ementers': [('ement', False)],
          'emer': [('em', False)],
          'emerne': [('em', False)],
          'emernes': [('em', False)],
          'emers': [('em', False)],
          'emesis': [('emesis', False)],
          'emet': [('em', False)],
          'emeter': [('emeter', False)],
          'emeters': [('emeter', False)],
          'emetre': [('emeter', False)],
          'emetrene': [('emeter', False)],
          'emetrenes': [('emeter', False)],
          'emetres': [('emeter', False)],
          'emetret': [('emeter', False)],
          'emetrets': [('emeter', False)],
          'emets': [('em', False)],
          'emidler': [('emiddel', False)],
          'emidlerne': [('emiddel', False)],
          'emidlernes': [('emiddel', False)],
          'emidlers': [('emiddel', False)],
          'emiere': [('emiere', False)],
          'emieren': [('emiere', False)],
          'emierens': [('emiere', False)],
          'emierer': [('emiere', False)],
          'emiererne': [('emiere', False)],
          'emierernes': [('emiere', False)],
          'emierers': [('emiere', False)],
          'emieres': [('emiere', False)],
          'emiet': [('emi', False)],
          'emiks': [('emik', False)],
          'eminaret': [('eminar', False)],
          'eminarets': [('eminar', False)],
          'eminder': [('eminder', False)],
          'eminderne': [('eminder', False)],
          'emindernes': [('eminder', False)],
          'eminders': [('eminder', False)],
          'eminister': [('eminist', False)],
          'eministers': [('eminister', False)],
          'emis': [('emi', False)],
          'emisers': [('emise', False)],
          'emissen': [('emisse', False)],
          'emissens': [('emisse', False)],
          'emisser': [('emisse', False)],
          'emisserne': [('emisse', False)],
          'emissernes': [('emisse', False)],
          'emissers': [('emisse', False)],
          'emissioner': [('emission', True)],
          'emissionerne': [('emission', False)],
          'emitten': [('emit', False)],
          'emittens': [('emit', False)],
          'emitter': [('emit', False)],
          'emitterne': [('emit', False)],
          'emitternes': [('emit', False)],
          'emitters': [('emit', False)],
          'emlejer': [('emlejer', False)],
          'emlejerne': [('emlejer', False)],
          'emlejernes': [('emleje', False)],
          'emlejers': [('emlejer', False)],
          'emler': [('emmel', False)],
          'emme': [('emme', False)],
          'emmebogen': [('emmebogen', False)],
          'emmelsers': [('emmelse', False)],
          'emmen': [('em', True)],
          'emmens': [('em', True)],
          'emmer': [('emmer', True)],
          'emmeret': [('emmeret', False)],
          'emmerets': [('emmeret', False)],
          'emmerne': [('emmer', True)],
          'emmernes': [('emmer', False)],
          'emmers': [('emmer', True)],
          'emmes': [('emme', False)],
          'emmet': [('em', False)],
          'emmets': [('em', False)],
          'emner': [('emne', False)],
          'emnernes': [('emne', True)],
          'emoden': [('emod', False)],
          'emodens': [('emod', False)],
          'emoderne': [('emode', False)],
          'emodernes': [('emode', False)],
          'emoders': [('emor', False)],
          'emodet': [('emod', False)],
          'emodets': [('emod', False)],
          'emonierne': [('emoni', False)],
          'emoniernes': [('emoni', False)],
          'emoniers': [('emoni', False)],
          'emoralen': [('emoral', False)],
          'emoralens': [('emoral', False)],
          'emos': [('emo', False)],
          'emosen': [('emose', False)],
          'emosens': [('emose', False)],
          'emoster': [('emost', False)],
          'emosters': [('emost', False)],
          'empe': [('empe', False)],
          'empen': [('empe', False)],
          'empens': [('empe', False)],
          'emper': [('empe', False)],
          'emperne': [('empe', False)],
          'empes': [('empe', False)],
          'emplerne': [('empel', False)],
          'emplernes': [('empel', False)],
          'emplers': [('empel', False)],
          'ems': [('em', False)],
          "ems'": [('em', False)],
          'emse': [('emse', False)],
          'emsen': [('emse', False)],
          'emsene': [('em', False)],
          'emsenes': [('em', False)],
          'emsens': [('emse', False)],
          'emser': [('emse', False)],
          'emserne': [('emse', False)],
          'emsernes': [('emse', False)],
          'emsers': [('emse', False)],
          'emses': [('emse', False)],
          'emskaberne': [('emskab', False)],
          'emskabernes': [('emskab', False)],
          'emskifterne': [('emskifte', False)],
          'emskifternes': [('emskifte', False)],
          'emtiden': [('emtid', False)],
          'emunde': [('emunde', False)],
          'emunke': [('emunke', False)],
          'emunken': [('emunke', False)],
          'emunkens': [('emunke', False)],
          'emunkes': [('emunke', False)],
          'emurer': [('emur', False)],
          'emurerne': [('emur', False)],
          'emurernes': [('emur', False)],
          'emurers': [('emur', False)],
          'emus': [('emu', True)],
          'emusen': [('emus', False)],
          'emusens': [('emus', False)],
          'emyren': [('emyre', False)],
          'emyrens': [('emyre', False)],
          'emyrer': [('emyre', False)],
          'emyrerne': [('emyre', False)],
          'emyrernes': [('emyre', False)],
          'emyrers': [('emyre', False)],
          'emælken': [('emælk', False)],
          'emælkens': [('emælk', False)],
          'emænd': [('emand', False)],
          'emændene': [('emand', False)],
          'emændenes': [('emand', False)],
          'emænds': [('emand', False)],
          'emærkerne': [('emærke', False)],
          'emærkernes': [('emærke', False)],
          'emærkers': [('emærke', False)],
          'emærs': [('emærs', False)],
          'emødernes': [('emøde', False)],
          'emøller': [('emølle', False)],
          'emøllerne': [('emølle', False)],
          'emøllernes': [('emølle', False)],
          'emøllers': [('emølle', False)],
          'emørens': [('emøre', False)],
          'emørernes': [('emøre', False)],
          'emøret': [('emøre', False)],
          'en': [('', False)],
          'enader': [('enade', False)],
          'enager': [('enager', False)],
          'enagerne': [('enage', False)],
          'enagernes': [('enage', False)],
          'enagers': [('enage', False)],
          'enakke': [('enakke', False)],
          'enakkerne': [('enakke', False)],
          'enakkernes': [('enakke', False)],
          'enakter': [('enakter', True)],
          'enakters': [('enakter', True)],
          'enalder': [('enalder', False)],
          'enalders': [('enalder', False)],
          'enaler': [('enal', False)],
          'enalerne': [('enal', False)],
          'enalernes': [('enal', False)],
          'enalers': [('enal', False)],
          'enalet': [('enal', False)],
          'enalets': [('enal', False)],
          'enaren': [('enar', False)],
          'enarens': [('enar', False)],
          'enarer': [('enar', False)],
          'enarernes': [('enar', False)],
          'enas': [('ena', False)],
          'enater': [('enat', False)],
          'enaterne': [('enat', False)],
          'enaters': [('enat', False)],
          'encen': [('ence', False)],
          'encens': [('ence', False)],
          'encer': [('ence', False)],
          'encerne': [('ence', False)],
          'encernes': [('ence', False)],
          'encers': [('ence', False)],
          'enda': [('enda', False)],
          'endagens': [('endag', False)],
          'endanten': [('endant', False)],
          'endantens': [('endant', False)],
          'endanterne': [('endant', False)],
          'endanternes': [('endant', False)],
          'endanters': [('endant', False)],
          'endas': [('enda', False)],
          'ende': [('ende', False)],
          'enden': [('ende', False)],
          'endens': [('ende', False)],
          'endenser': [('endens', False)],
          'endensernes': [('endens', False)],
          'endensers': [('endens', False)],
          'ender': [('ende', True)],
          'enderne': [('ende', True)],
          'endernes': [('ende', True)],
          'enders': [('ende', True)],
          'endes': [('ende', False)],
          'endestens': [('endesten', False)],
          'endet': [('ende', False)],
          'endets': [('ende', False)],
          'endlerne': [('endel', False)],
          'endlernes': [('endel', False)],
          'endre': [('ender', False)],
          'ene': [('ene', True)],
          'eneboer': [('eneboer', True)],
          'eneboerne': [('eneboer', True)],
          'eneboers': [('eneboer', True)],
          'enejet': [('eneje', False)],
          'enejets': [('eneje', False)],
          'enelliker': [('enellike', False)],
          'enellikerne': [('enelliker', False)],
          'enellikernes': [('enellike', False)],
          'enellikers': [('enelliker', False)],
          'enen': [('ene', True)],
          'enene': [('en', False)],
          'enenes': [('en', False)],
          'enens': [('ene', True)],
          'ener': [('ener', True), ('ene', True)],
          'enerier': [('eneri', False)],
          'enerierne': [('eneri', False)],
          'eneriernes': [('eneri', False)],
          'eneriers': [('eneri', False)],
          'enerne': [('ene', True), ('ener', True)],
          'enernes': [('ene', True), ('ener', True)],
          'eners': [('ene', True), ('ener', True)],
          'enes': [('ene', True)],
          'eneser': [('eneser', False)],
          'eneserne': [('eneser', False)],
          'enesernes': [('eneser', False)],
          'enesers': [('enese', False)],
          'enesier': [('enesi', False)],
          'enesis': [('enesis', False)],
          'enestens': [('eneste', False)],
          'enet': [('en', False)],
          'enets': [('en', False)],
          'enfølgerne': [('enfølge', False)],
          'enfølgernes': [('enfølge', False)],
          'enfølgers': [('enfølge', False)],
          'engalernes': [('engaler', False)],
          'engalers': [('engaler', False)],
          'enge': [('eng', True)],
          'engen': [('eng', True)],
          'engene': [('eng', True)],
          'engenes': [('eng', True)],
          'engens': [('eng', True)],
          'engers': [('eng', False)],
          'enges': [('eng', True)],
          'engle': [('engel', False)],
          'englen': [('engel', False)],
          'englerne': [('engel', False)],
          'englernes': [('engel', False)],
          'englers': [('engel', False)],
          'engs': [('eng', True)],
          "engs'": [('engs', False)],
          'engsen': [('engs', False)],
          'engsens': [('engs', False)],
          'eniens': [('eniens', False)],
          'enienser': [('eniens', False)],
          'enienserne': [('enienser', False)],
          'eniensernes': [('eniens', False)],
          'eniensers': [('eniens', False)],
          'enierne': [('eni', False)],
          'eniernes': [('eni', False)],
          'eniers': [('eni', False)],
          'eniet': [('enium', False)],
          'eniets': [('enium', False)],
          'eniker': [('eniker', False)],
          'enikerne': [('eniker', False)],
          'enikernes': [('eniker', False)],
          'enikers': [('eniker', False)],
          'eniner': [('eniner', False)],
          'eninerne': [('eniner', False)],
          'eniners': [('eniner', False)],
          'eningers': [('ening', False)],
          'enis': [('enis', False)],
          "enis'": [('enis', False)],
          'enissen': [('enisse', False)],
          'enissens': [('enisse', False)],
          'enisser': [('enisse', False)],
          'enisserne': [('enisse', False)],
          'enissernes': [('enisse', False)],
          'enissers': [('enisse', False)],
          'enitten': [('enit', False)],
          'enittens': [('enit', False)],
          'enitter': [('enit', False)],
          'enitterne': [('enit', False)],
          'enitternes': [('enit', False)],
          'enitters': [('enit', False)],
          'enium': [('enium', False)],
          'eniums': [('enium', False)],
          'enke': [('enke', True)],
          'enken': [('enke', True)],
          'enker': [('enke', False)],
          'enkerne': [('enke', True)],
          'enkes': [('enke', True)],
          'enkinder': [('enkind', False)],
          'enkinderne': [('enkind', False)],
          'enkindernes': [('enkind', False)],
          'enkinders': [('enkind', False)],
          'enklerne': [('enkel', False)],
          'enklernes': [('enkel', False)],
          'enklers': [('enkel', False)],
          'ennalen': [('ennale', False)],
          'ennaler': [('ennale', False)],
          'ennalerne': [('ennale', False)],
          'ennalernes': [('ennale', False)],
          'ennalers': [('ennale', False)],
          'enne': [('enne', False)],
          'ennen': [('enne', False)],
          'ennens': [('enne', False)],
          'enner': [('enne', False)],
          'ennerne': [('en', False)],
          'ennernes': [('enne', False)],
          'enners': [('enne', False)],
          'ennes': [('enne', False)],
          'ennierne': [('ennium', False)],
          'enniernes': [('ennium', False)],
          'enniers': [('ennium', False)],
          'enomer': [('enom', False)],
          'enomerne': [('enom', False)],
          'enomernes': [('enom', False)],
          'enomers': [('enom', False)],
          'enonen': [('enon', False)],
          'enonens': [('enon', False)],
          'enonet': [('enon', False)],
          'enonets': [('enon', False)],
          'enoten': [('enot', False)],
          'enotens': [('enot', False)],
          'enoter': [('enot', False)],
          'enoterne': [('enot', False)],
          'enoternes': [('enot', False)],
          'enoters': [('enot', False)],
          'enrens': [('enre', False)],
          'ens': [('', False)],
          "ens'": [('en', False)],
          'ensboernes': [('ensbo', False)],
          'ensboers': [('ensbo', False)],
          'ense': [('ense', False)],
          'ensene': [('en', False)],
          'ensenes': [('en', False)],
          'enser': [('enser', False)],
          'enserne': [('ens', False)],
          'ensernes': [('enser', False)],
          'ensers': [('enser', False)],
          'enses': [('ense', False)],
          'ensformer': [('ensform', False)],
          'ensformerne': [('ensform', False)],
          'ensformernes': [('ensform', False)],
          'ensformers': [('ensform', False)],
          'ensianer': [('ensian', True)],
          'ensianerne': [('ensian', True)],
          'ensianernes': [('ensian', True)],
          'ensianers': [('ensian', True)],
          'ensiers': [('ensie', False)],
          'ensilier': [('ensilie', False)],
          'ensilierne': [('ensilie', False)],
          'ensiliers': [('ensilie', False)],
          'ensiliet': [('ensilie', False)],
          'ensions': [('ension', False)],
          'enslerne': [('ensel', False)],
          'enslernes': [('ensel', False)],
          'enslers': [('ensel', False)],
          'enster': [('enst', False)],
          'ensterne': [('enst', False)],
          'ensternes': [('enst', False)],
          'ensters': [('enst', False)],
          'enstre': [('enstre', False)],
          'enta': [('enta', False)],
          'entanterne': [('entant', False)],
          'entanternes': [('entant', False)],
          'entanters': [('entant', False)],
          'entater': [('entat', False)],
          'entaternes': [('entat', False)],
          'ente': [('ente', False)],
          'entes': [('ente', False)],
          'entesernes': [('entes', False)],
          'entesers': [('entes', False)],
          'entesten': [('entest', False)],
          'entestens': [('entest', False)],
          'enti': [('enti', False)],
          'entier': [('enti', False)],
          'entiernes': [('enti', False)],
          'entiers': [('enti', False)],
          'entinen': [('entine', False)],
          'entinens': [('entine', False)],
          'entiner': [('entine', False)],
          'entinerne': [('entin', False)],
          'entinernes': [('entine', False)],
          'entiners': [('entin', False)],
          'entis': [('entis', False)],
          'entre': [('entre', True)],
          'entret': [('entret', False)],
          'enture': [('entur', False)],
          'entures': [('enture', False)],
          'enua': [('enua', False)],
          'enuas': [('enua', False)],
          'enuen': [('enue', False)],
          'enuens': [('enue', False)],
          'enuer': [('enue', False)],
          'enuerne': [('enue', False)],
          'enuernes': [('enue', False)],
          'enuers': [('enue', False)],
          'enuet': [('enuet', False)],
          'enuets': [('enu', False)],
          'enummers': [('enummer', False)],
          'enus': [('enus', False)],
          'enuserne': [('enuse', False)],
          'envejene': [('envej', False)],
          'envejenes': [('envej', False)],
          'envejes': [('envej', False)],
          'envinden': [('envind', False)],
          'envindens': [('envind', False)],
          'envindes': [('envind', False)],
          'enylen': [('enyl', False)],
          'enylens': [('enyl', False)],
          'enyler': [('enyl', False)],
          'enylerne': [('enyl', False)],
          'enylernes': [('enyl', False)],
          'enylers': [('enyl', False)],
          'enzen': [('enzen', False)],
          'enzens': [('enzen', False)],
          'enøren': [('enøre', True)],
          'enørens': [('enøre', True)],
          'enører': [('enøre', True)],
          'enørerne': [('enøre', True)],
          'enørernes': [('enøre', True)],
          'enørers': [('enøre', True)],
          'eoen': [('eo', False)],
          'eoens': [('eo', False)],
          'eoer': [('eo', False)],
          'eoerne': [('eo', False)],
          'eoernes': [('eo', False)],
          'eoers': [('eo', False)],
          'eofret': [('eoffer', False)],
          'eole': [('eole', False)],
          'eolen': [('eole', False)],
          'eolens': [('eole', False)],
          'eolerne': [('eol', False)],
          'eolernes': [('eole', False)],
          'eolers': [('eole', False)],
          'eoles': [('eole', False)],
          'eolet': [('eolet', False)],
          'eolets': [('eolet', False)],
          'eolierne': [('eolie', False)],
          'eoliers': [('eolie', False)],
          'eomkostninger': [('eomkostninger', False)],
          'eomkostningerne': [('eomkostninger', False)],
          'eomkostningernes': [('eomkostninger', False)],
          'eomkostningers': [('eomkostninger', False)],
          'eondernes': [('eonde', False)],
          'eordnerne': [('eorden', False)],
          'eorers': [('eor', False)],
          'eorgier': [('eorgier', False)],
          'eorgierne': [('eorgier', False)],
          'eorgiernes': [('eorgier', False)],
          'eorgiers': [('eorgier', False)],
          'eorien': [('eori', False)],
          'eoriens': [('eori', False)],
          'eorier': [('eori', False)],
          'eorierne': [('eori', False)],
          'eoriernes': [('eori', False)],
          'eoris': [('eori', False)],
          'eorlover': [('eorlov', False)],
          'eorloverne': [('eorlov', False)],
          'eos': [('eo', False)],
          'eosen': [('eose', False)],
          'eosens': [('eose', False)],
          'eoser': [('eose', False)],
          'eoserne': [('eose', False)],
          'eosernes': [('eose', False)],
          'eosers': [('eose', False)],
          'eoste': [('eost', False)],
          'eosten': [('eost', False)],
          'eostens': [('eost', False)],
          'eostes': [('eost', False)],
          'eotypens': [('eotyp', False)],
          'eotypernes': [('eotyp', False)],
          'eotypers': [('eotyp', False)],
          'eouten': [('eout', False)],
          'eoutens': [('eout', False)],
          'eouterne': [('eout', False)],
          'eouternes': [('eout', False)],
          'eouters': [('eout', False)],
          'eover': [('eover', False)],
          'eoverne': [('eover', False)],
          "ep'er": [('ep', False)],
          "ep'ernes": [('ep', False)],
          "ep'ers": [('ep', False)],
          'epagters': [('epagt', False)],
          'epakker': [('epakke', False)],
          'epakkerne': [('epakke', False)],
          'epakkernes': [('epakke', False)],
          'epakkers': [('epakke', False)],
          'epande': [('epande', False)],
          'epanden': [('epande', False)],
          'epandens': [('epande', False)],
          'epandes': [('epande', False)],
          'epanser': [('epans', False)],
          'epanserne': [('epans', False)],
          'epansernes': [('epans', False)],
          'epansers': [('epans', False)],
          'eparkers': [('epark', False)],
          'epas': [('epas', False)],
          'epasser': [('epasser', False)],
          'epasserne': [('epasser', False)],
          'epassernes': [('epasser', False)],
          'epassers': [('epasser', False)],
          'epatiens': [('epati', False)],
          'epen': [('epen', False)],
          'ependier': [('ependium', False)],
          'ependiernes': [('ependium', False)],
          'ependiers': [('ependium', False)],
          'ependiet': [('ependium', False)],
          'ependiets': [('ependium', False)],
          'epene': [('ep', False)],
          'epenes': [('ep', False)],
          'epens': [('epen', False)],
          'eper': [('eper', False)],
          'epere': [('eper', False)],
          'eperens': [('eper', False)],
          'eperes': [('eper', False)],
          'eperser': [('eperser', False)],
          'eperserne': [('eperser', False)],
          'epersernes': [('eperser', False)],
          'epersers': [('eperser', False)],
          'epes': [('epe', False)],
          'epet': [('epe', False)],
          'epeter': [('epeter', False)],
          'epeters': [('epeter', False)],
          'epets': [('epe', False)],
          'epiber': [('epibe', False)],
          'epiberne': [('epibe', False)],
          'epibernes': [('epibe', False)],
          'epibers': [('epibe', False)],
          'epien': [('epi', False)],
          'epiens': [('epi', False)],
          'epier': [('epi', False)],
          'epierne': [('epi', False)],
          'epiernes': [('epi', False)],
          'epiers': [('epi', False)],
          'epigerne': [('epige', False)],
          'epigernes': [('epige', False)],
          'epigers': [('epige', False)],
          'epiks': [('epik', True)],
          'epillen': [('epille', False)],
          'epillernes': [('epille', False)],
          'epils': [('epil', False)],
          'epinernes': [('epine', False)],
          'epiners': [('epine', False)],
          'epis': [('epi', False)],
          'epissen': [('episse', False)],
          'epissens': [('episse', False)],
          'epladerne': [('eplade', False)],
          'eplage': [('eplag', False)],
          'eplagen': [('eplage', False)],
          'eplagens': [('eplage', False)],
          'eplager': [('eplage', False)],
          'eplagerne': [('eplage', False)],
          'eplagernes': [('eplage', False)],
          'eplagers': [('eplage', False)],
          'eplages': [('eplage', False)],
          'eplanet': [('eplan', False)],
          'eplanets': [('eplan', False)],
          'eplanter': [('eplante', False)],
          'eplanterne': [('eplante', False)],
          'eplanternes': [('eplante', False)],
          'eplanters': [('eplante', False)],
          'eplejer': [('epleje', False)],
          'eplejerne': [('epleje', False)],
          'eplejernes': [('eplejer', False)],
          'eplejers': [('eplejer', False)],
          'epoet': [('epo', True)],
          'epoets': [('epo', True)],
          'epoker': [('epoke', True)],
          'epokerne': [('epoke', True)],
          'epokernes': [('epoke', True)],
          'epokers': [('epoke', True)],
          'eporter': [('eporter', False)],
          'epos': [('epo', True), ('epos', True)],
          'eposers': [('epose', False)],
          'eposter': [('epost', False)],
          'eposterne': [('epost', False)],
          'eposternes': [('epost', False)],
          'eposters': [('epost', False)],
          'epoter': [('epot', False)],
          'epoterne': [('epot', False)],
          'epoternes': [('epot', False)],
          'epoters': [('epot', False)],
          'epotten': [('epotte', False)],
          'epottens': [('epot', False)],
          'epotter': [('epot', False)],
          'epotterne': [('epot', False)],
          'epotternes': [('epotte', False)],
          'epotters': [('epotte', False)],
          'eppe': [('eppe', False)],
          'eppet': [('ep', False)],
          'eppets': [('ep', False)],
          'epressens': [('epresse', False)],
          'eprisen': [('epris', False)],
          'eprisens': [('eprise', False)],
          'epriser': [('eprise', False)],
          'epriserne': [('eprise', False)],
          'eprisernes': [('eprise', False)],
          'eprisers': [('epris', False)],
          'eprocenter': [('eprocent', False)],
          'eprocenters': [('eprocent', False)],
          'eprompter': [('eprompter', False)],
          'eprompterne': [('eprompter', False)],
          'eprompternes': [('eprompter', False)],
          'eprompters': [('eprompter', False)],
          'eps': [('ep', False)],
          "eps'": [('ep', False)],
          'epsers': [('eps', False)],
          'epsis': [('epsi', False)],
          'eptet': [('ept', False)],
          'eptets': [('eptet', False)],
          'epumpen': [('epumpe', False)],
          'epumpens': [('epumpe', False)],
          'epumper': [('epumpe', False)],
          'epumperne': [('epumpe', False)],
          'eputten': [('eput', False)],
          'eputtens': [('eput', False)],
          'eputter': [('eput', False)],
          'eputterne': [('eput', False)],
          'eputternes': [('eput', False)],
          'eputters': [('eput', False)],
          'er': [('', False)],
          'era': [('erum', False)],
          'eraben': [('erabe', False)],
          'eraber': [('erabe', False)],
          'eraberne': [('eraber', False)],
          'erabernes': [('erabe', False)],
          'erabers': [('erabe', False)],
          'eracer': [('erace', False)],
          'eracerne': [('erace', False)],
          'eracernes': [('erace', False)],
          'eracers': [('erace', False)],
          'erade': [('erade', False)],
          'eraden': [('erad', False)],
          'eradens': [('erad', False)],
          'eraderne': [('erad', False)],
          'eraders': [('erad', False)],
          'erades': [('erade', False)],
          'erads': [('erad', False)],
          'eraene': [('erum', False)],
          'eraenes': [('erum', False)],
          'erailer': [('erail', False)],
          'erakker': [('erak', False)],
          'erakkerne': [('erak', False)],
          'erakkernes': [('erak', False)],
          'erakkers': [('erak', False)],
          'eraks': [('eraks', False)],
          'eralen': [('eral', False)],
          'eraler': [('eral', False)],
          'eralerne': [('eral', False)],
          'eralernes': [('eral', False)],
          'eralers': [('eral', False)],
          'eralet': [('eral', False)],
          'eralets': [('eral', False)],
          'eralier': [('erale', False)],
          'eraliernes': [('erale', False)],
          'eraliers': [('eralier', False)],
          'erallen': [('erall', False)],
          'erallens': [('erall', False)],
          'eramenterne': [('erament', False)],
          'eramenternes': [('erament', False)],
          'eramenters': [('erament', False)],
          'eramme': [('eramme', False)],
          'erammen': [('eramme', False)],
          'erammens': [('eramme', False)],
          'erammer': [('eramme', False)],
          'erammes': [('eramme', False)],
          'erams': [('erams', False)],
          'erancen': [('erance', False)],
          'erancens': [('erance', False)],
          'eranda': [('eranda', False)],
          'erandas': [('eranda', False)],
          'eranen': [('eran', False)],
          'eraner': [('eran', False)],
          'eranerne': [('eraner', False)],
          'eranernes': [('eraner', False)],
          'eraners': [('eran', False)],
          'erangen': [('erang', False)],
          'erangens': [('erang', False)],
          'eranger': [('erang', False)],
          'erangerne': [('erang', False)],
          'erangernes': [('erang', False)],
          'erangers': [('erang', False)],
          'eranke': [('eranke', False)],
          'eranker': [('eranke', False)],
          'erankernes': [('eranke', False)],
          'erans': [('erans', False)],
          'erarbejder': [('erarbejde', False)],
          'erarbejderne': [('erarbejde', False)],
          'erarbejdernes': [('erarbejder', False)],
          'erarbejders': [('erarbejder', False)],
          'eras': [('eras', False)],
          'erasen': [('eras', False)],
          'erasens': [('eras', False)],
          'eraser': [('eras', False)],
          'eraserne': [('eras', False)],
          'erasernes': [('eras', False)],
          'erasers': [('eras', False)],
          'eraster': [('erast', False)],
          'erasterne': [('erast', False)],
          'erasternes': [('erast', False)],
          'erasters': [('erasters', False)],
          'erata': [('eratum', False)],
          'eraten': [('erat', False)],
          'eratens': [('erat', False)],
          'erater': [('erat', False)],
          'eraterne': [('erat', False)],
          'eraternes': [('erat', False)],
          'eraters': [('erat', False)],
          'erbanen': [('erbane', False)],
          'erbanens': [('erbane', False)],
          'erbaner': [('erbane', False)],
          'erbanerne': [('erbane', False)],
          'erbanernes': [('erbane', False)],
          'erbaners': [('erbane', False)],
          'erbarier': [('erbarium', False)],
          'erbariers': [('erbarium', False)],
          'erbariet': [('erbarium', False)],
          'erbassen': [('erbasse', False)],
          'erbassens': [('erbas', False)],
          'erbasser': [('erbas', False)],
          'erbasserne': [('erbas', False)],
          'erbassernes': [('erbasse', False)],
          'erbassers': [('erbasse', False)],
          'erber': [('erber', False)],
          'erberne': [('erber', False)],
          'erbernes': [('erber', False)],
          'erbers': [('erber', False)],
          'erbet': [('erbet', False)],
          'erbets': [('erbet', False)],
          'erbier': [('erbium', False)],
          'erbierne': [('erbium', False)],
          'erbiernes': [('erbi', False)],
          'erbiers': [('erbi', False)],
          'erbøllen': [('erbøl', False)],
          'erbørn': [('erbarn', False)],
          'erbørnene': [('erbarn', False)],
          'erbørnenes': [('erbarn', False)],
          'erbørns': [('erbarn', False)],
          'ercellens': [('ercelle', False)],
          'erceller': [('ercelle', False)],
          'ercellerne': [('ercelle', False)],
          'ercellernes': [('ercelle', False)],
          'erden': [('erden', False)],
          'erdens': [('erden', False)],
          'erder': [('erder', False)],
          'erderne': [('erder', False)],
          'erdernes': [('erder', False)],
          'erders': [('erder', False)],
          'erdner': [('erden', False)],
          'erdners': [('erden', False)],
          'ere': [('er', False)],
          'erede': [('erede', False)],
          'ereden': [('erede', False)],
          'eredens': [('erede', False)],
          'ereder': [('erede', False)],
          'erederne': [('erede', False)],
          'eredernes': [('ereder', False)],
          'ereders': [('erede', False)],
          'eregimenter': [('eregiment', False)],
          'eregimenterne': [('eregiment', False)],
          'eregimenternes': [('eregiment', False)],
          'eregimenters': [('eregiment', False)],
          'eregimentet': [('eregiment', False)],
          'eregimentets': [('eregiment', False)],
          'eregnerne': [('eregner', False)],
          'eregnernes': [('eregner', False)],
          'eregners': [('eregner', False)],
          'erejser': [('erejse', False)],
          'eren': [('er', False)],
          'erenader': [('erenade', False)],
          'erene': [('ere', False)],
          'erenes': [('ere', False)],
          'erens': [('er', False)],
          'erenser': [('erens', False)],
          'erenserne': [('erens', False)],
          'erensernes': [('erenser', False)],
          'erensers': [('erenser', False)],
          'erenten': [('erente', False)],
          'erentens': [('erente', False)],
          'erenter': [('erenter', False)],
          'erenterne': [('erente', False)],
          'erenternes': [('erente', False)],
          'erenters': [('erent', False)],
          'erentes': [('erente', False)],
          'ereolens': [('ereol', False)],
          'ereolerne': [('ereol', False)],
          'erer': [('er', False)],
          'ererne': [('er', False)],
          'erernes': [('er', False)],
          'erers': [('er', False)],
          'eres': [('er', False)],
          'eressen': [('eresse', False)],
          'eresser': [('eresse', False)],
          'eresserne': [('eresse', False)],
          'eressernes': [('eresse', False)],
          'eressers': [('eresse', False)],
          'erestens': [('erest', False)],
          'eret': [('er', False)],
          'eretager': [('eretage', False)],
          'eretagerne': [('eretage', False)],
          'eretagernes': [('eretage', False)],
          'eretagers': [('eretage', False)],
          'ereterne': [('eret', False)],
          'ereternes': [('eret', False)],
          'erets': [('er', False)],
          'eretten': [('erette', False)],
          'erettens': [('erette', False)],
          'eretter': [('eret', False)],
          'eretterne': [('erette', False)],
          'eretternes': [('erette', False)],
          'erferens': [('erfer', False)],
          'erfernes': [('erfer', False)],
          'erfers': [('erfer', False)],
          'erformer': [('erformer', False)],
          'erformerne': [('erform', False)],
          'erformernes': [('erform', False)],
          'erformers': [('erformer', False)],
          'erge': [('erge', False)],
          'ergen': [('ergen', False)],
          'ergens': [('ergens', False)],
          'ergenser': [('ergens', False)],
          'ergenserne': [('ergenser', False)],
          'ergensernes': [('ergens', False)],
          'ergensers': [('ergenser', False)],
          'erges': [('erge', False)],
          'ergier': [('ergi', False)],
          'ergierne': [('ergi', False)],
          'ergiernes': [('ergi', False)],
          'ergiers': [('ergi', False)],
          'erginen': [('ergine', False)],
          'erginens': [('ergine', False)],
          'erginer': [('ergine', False)],
          'erginerne': [('ergine', False)],
          'erginernes': [('ergine', False)],
          'erhalerne': [('erhaler', False)],
          'erhals': [('erhals', False)],
          'erhandler': [('erhandel', False)],
          'erhandlerne': [('erhandel', False)],
          'erhandlers': [('erhandel', False)],
          'erheden': [('erhede', False)],
          'erhedens': [('erhed', False)],
          'erialer': [('eriale', False)],
          'erialerne': [('eriale', False)],
          'erialernes': [('eriale', False)],
          'erialers': [('eriale', False)],
          'erianer': [('erianer', False)],
          'erianerne': [('erian', False)],
          'erianernes': [('erian', False)],
          'erianers': [('erianer', False)],
          'erias': [('eria', False)],
          'eriater': [('eriater', False)],
          'eriaterne': [('eriater', False)],
          'eriaters': [('eriater', False)],
          'eribs': [('eribs', False)],
          'erider': [('erider', False)],
          'eriderne': [('erider', False)],
          'eridernes': [('erider', False)],
          'eriders': [('erider', False)],
          'erien': [('erie', False)],
          'eriens': [('erie', False)],
          'eries': [('erie', False)],
          'eriferiens': [('eriferi', False)],
          'eriferiernes': [('eriferi', False)],
          'eriferiers': [('eriferi', False)],
          'erigerne': [('erige', False)],
          'erigernes': [('erige', False)],
          'erigers': [('erige', False)],
          'erikkens': [('erik', False)],
          'erikker': [('erik', False)],
          'erikkernes': [('erik', False)],
          'erikkers': [('erik', False)],
          'eriks': [('erik', False)],
          'erinden': [('erinde', False)],
          'erindens': [('erinde', False)],
          'erinen': [('erin', False)],
          'erinens': [('erin', False)],
          'eringer': [('ering', False)],
          'eringerne': [('ering', False)],
          'eringernes': [('ering', False)],
          'eringers': [('ering', False)],
          'erins': [('erin', False)],
          'erissers': [('eris', False)],
          'erister': [('erist', False)],
          'eristerne': [('erist', False)],
          'eristernes': [('erist', False)],
          'eristers': [('erist', False)],
          'eritis': [('eritis', False)],
          'eritten': [('erit', False)],
          'erittens': [('erit', False)],
          'eritter': [('erit', False)],
          'eritternes': [('erit', False)],
          'eritters': [('erit', False)],
          'erium': [('erium', False)],
          'eriums': [('erium', False)],
          'erkanerne': [('erkaner', False)],
          'erkaners': [('erkaner', False)],
          'erker': [('erker', False)],
          'erkerne': [('erker', False)],
          'erkernes': [('erker', False)],
          'erkisens': [('erkis', False)],
          'erkløer': [('erklo', False)],
          'erkonen': [('erkone', False)],
          'erkonens': [('erkone', False)],
          'erkoner': [('erkone', False)],
          'erkonerne': [('erkone', False)],
          'erkonernes': [('erkone', False)],
          'erkoners': [('erkone', False)],
          'erkors': [('erkors', False)],
          'erkurser': [('erkurs', False)],
          'erkurserne': [('erkurs', False)],
          'erkursernes': [('erkursus', False)],
          'erkursers': [('erkurs', False)],
          'erkører': [('erkører', False)],
          'erlagen': [('erlage', False)],
          'erlagens': [('erlage', False)],
          'erlande': [('erland', False)],
          'erlandes': [('erland', False)],
          'erle': [('erle', False)],
          'erlejer': [('erleje', False)],
          'erlejerne': [('erleje', False)],
          'erlejernes': [('erleje', False)],
          'erlejers': [('erleje', False)],
          'erlen': [('erle', False)],
          'erlens': [('erle', False)],
          'erler': [('erle', False)],
          'erles': [('erle', False)],
          'erme': [('erme', False)],
          'ermen': [('erme', False)],
          'ermens': [('erme', False)],
          'ermer': [('erm', False)],
          'ermerne': [('erme', False)],
          'ermernes': [('erme', False)],
          'ermers': [('erme', False)],
          'ermes': [('erme', False)],
          'erminen': [('ermine', False)],
          'erminens': [('ermine', False)],
          'erminer': [('ermine', False)],
          'erminerne': [('ermine', False)],
          'erminernes': [('ermine', False)],
          'erminers': [('ermin', False)],
          'erminister': [('erminister', False)],
          'erministers': [('erminist', False)],
          'erne': [('', False)],
          'ernen': [('erne', False)],
          'ernens': [('erne', False)],
          'erner': [('erne', False)],
          'ernerne': [('ern', False)],
          'ernernes': [('erne', False)],
          'ernes': [('', False)],
          'ernet': [('ernet', False)],
          'ernets': [('ernet', False)],
          'ernissen': [('ernisse', False)],
          'ernissens': [('ernis', False)],
          'ernisser': [('ernis', False)],
          'ernisserne': [('ernis', False)],
          'ernissernes': [('ernis', False)],
          'ernissers': [('ernis', False)],
          'eroden': [('erod', False)],
          'erodens': [('erod', False)],
          'erods': [('erod', False)],
          'eroer': [('ero', False)],
          'eroerne': [('ero', False)],
          'eroernes': [('ero', False)],
          'eroers': [('ero', False)],
          'erokker': [('erokke', False)],
          'erokkerne': [('erokke', False)],
          'erokkernes': [('erokke', False)],
          'erokkers': [('erokke', False)],
          'erolen': [('erol', False)],
          'erolens': [('erol', False)],
          'eroler': [('erole', False)],
          'erolerne': [('erole', False)],
          'erolernes': [('erole', False)],
          'erollen': [('erolle', False)],
          'eroller': [('erolle', False)],
          'erollerne': [('erolle', False)],
          'erollers': [('erolle', False)],
          'eroner': [('eron', False)],
          'eronerne': [('eron', False)],
          'eronernes': [('eron', False)],
          'eroners': [('eron', False)],
          'eros': [('eros', True)],
          'erosen': [('erose', False)],
          'erosens': [('erose', False)],
          'erossernes': [('eros', False)],
          'erossers': [('eros', False)],
          'erouter': [('eroute', False)],
          'erouterne': [('eroute', False)],
          'erouternes': [('eroute', False)],
          'erouters': [('eroute', False)],
          'erpas': [('erpa', False)],
          'erpasser': [('erpas', False)],
          'erpasserne': [('erpas', False)],
          'erpe': [('erpe', False)],
          'erpelse': [('erpels', False)],
          'erpelsen': [('erpels', False)],
          'erpelsens': [('erpels', False)],
          'erpelses': [('erpels', False)],
          'erpen': [('erpe', False)],
          'erpens': [('erpe', False)],
          'erpentinen': [('erpentin', False)],
          'erpentinens': [('erpentin', False)],
          'erper': [('erpe', False)],
          'erperne': [('erpe', False)],
          'erpernes': [('erper', False)],
          'erpers': [('erper', False)],
          'erpes': [('erpes', False)],
          'erre': [('erre', False)],
          'errede': [('erred', False)],
          'erreden': [('errede', False)],
          'erredens': [('errede', False)],
          'erreder': [('errede', False)],
          'errederne': [('errede', False)],
          'erredernes': [('errede', False)],
          'erreders': [('errede', False)],
          'erredes': [('errede', False)],
          'erren': [('erren', False)],
          'errene': [('erren', False)],
          'errenes': [('erren', False)],
          'errens': [('erren', False)],
          'errenter': [('errente', False)],
          'errenterne': [('errente', False)],
          'errenters': [('errente', False)],
          'errer': [('erre', False)],
          'errerne': [('erre', False)],
          'errernes': [('erre', False)],
          'errets': [('erret', False)],
          'erriere': [('errier', False)],
          'errieren': [('errier', False)],
          'errierens': [('errier', False)],
          'errieres': [('errier', False)],
          'errotten': [('errotte', False)],
          'errottens': [('errot', False)],
          'errotter': [('errot', False)],
          'errotterne': [('errotte', False)],
          'errotternes': [('errot', False)],
          'errotters': [('errot', False)],
          'errullerne': [('errulle', False)],
          'errullernes': [('errulle', False)],
          'errullers': [('errulle', False)],
          'ers': [('', False)],
          "ers'": [('er', False)],
          'ersagens': [('ersag', False)],
          'ersager': [('ersag', False)],
          'ersagerne': [('ersag', False)],
          'ersagernes': [('ersag', False)],
          'erses': [('erse', False)],
          'ersets': [('ers', False)],
          'erskens': [('erske', False)],
          'ersker': [('ersker', False)],
          'erskerne': [('ersker', False)],
          'erskernes': [('erske', False)],
          'erskers': [('ersker', False)],
          'erskifternes': [('erskifte', False)],
          'erskiftes': [('erskifte', False)],
          'erskiftet': [('erskifte', False)],
          'erskiftets': [('erskifte', False)],
          'ersten': [('erst', False)],
          'erstens': [('ersten', False)],
          'erster': [('erst', False)],
          'ersterne': [('erst', False)],
          'ersternes': [('erst', False)],
          'ersters': [('erst', False)],
          'ersætterne': [('ersætter', False)],
          'ersætters': [('ersætter', False)],
          'ertalen': [('ertale', False)],
          'ertanker': [('ertanke', False)],
          'ertankerne': [('ertanke', False)],
          'ertankernes': [('ertanke', False)],
          'ertankers': [('ertanker', False)],
          'erte': [('erte', False)],
          'erternes': [('ert', False)],
          'ertes': [('erte', False)],
          'ertet': [('erte', False)],
          'ertets': [('ertet', False)],
          'ertien': [('erti', False)],
          'ertiens': [('erti', False)],
          'ertinens': [('ertin', False)],
          'ertonen': [('ertone', False)],
          'ertonens': [('ertone', False)],
          'ertonernes': [('ertone', False)],
          'erts': [('erts', False)],
          "erts'": [('erts', False)],
          'erture': [('erture', False)],
          'erturen': [('erture', False)],
          'erturens': [('ertur', False)],
          'erturer': [('erture', False)],
          'erturerne': [('erture', False)],
          'erturernes': [('erture', False)],
          'erturers': [('erture', False)],
          'ertures': [('erture', False)],
          'ertænderne': [('ertand', False)],
          'ertænders': [('ertand', False)],
          'erubers': [('erub', False)],
          'eruder': [('erude', False)],
          'eruderne': [('erude', False)],
          'erudernes': [('erude', False)],
          'eruders': [('erude', False)],
          'erugen': [('eruge', False)],
          'erugens': [('eruge', False)],
          'erugerne': [('eruge', False)],
          'erugernes': [('eruge', False)],
          'erugers': [('eruge', False)],
          'eruller': [('erulle', False)],
          'erullers': [('erulle', False)],
          'erummer': [('erum', False)],
          'erummerne': [('erum', False)],
          'erummet': [('erum', False)],
          'erummets': [('erum', False)],
          'erunde': [('erunde', False)],
          'erunden': [('erunde', False)],
          'erundens': [('erunde', False)],
          'erunders': [('erunde', False)],
          'erundes': [('erunde', False)],
          'erundier': [('erundium', False)],
          'erundiers': [('erundium', False)],
          'erupper': [('erup', False)],
          'eruppernes': [('erup', False)],
          'erus': [('erus', False)],
          'eruse': [('eruse', False)],
          'erusen': [('erus', False)],
          'erusens': [('erus', False)],
          'eruser': [('eruser', False)],
          'eruserne': [('eruser', False)],
          'erusernes': [('eruser', False)],
          'erusers': [('eruser', False)],
          'eruses': [('erus', False)],
          'erusser': [('erusser', False)],
          'erusserne': [('erus', False)],
          'erussernes': [('erusser', False)],
          'erussers': [('erus', False)],
          'erutter': [('erut', False)],
          'ervals': [('ervals', False)],
          'ervantens': [('ervante', False)],
          'ervanter': [('ervante', False)],
          'ervarer': [('ervare', False)],
          'ervarerne': [('ervare', False)],
          'ervarernes': [('ervare', False)],
          'erve': [('erve', False)],
          'erveje': [('ervej', False)],
          'ervejene': [('ervej', False)],
          'ervejenes': [('ervej', False)],
          'erven': [('erve', False)],
          'ervens': [('erve', False)],
          'erver': [('erve', False)],
          'erverne': [('erve', False)],
          'ervernes': [('erve', False)],
          'ervers': [('erve', False)],
          'erværker': [('erværk', False)],
          'erværkerne': [('erværk', False)],
          'erværkernes': [('erværk', False)],
          'erværkers': [('erværk', False)],
          'erzoner': [('erzone', False)],
          'erzoners': [('erzone', False)],
          'eråden': [('eråd', False)],
          'erådens': [('eråd', False)],
          'eråders': [('eråd', False)],
          'erådet': [('eråd', False)],
          'erækker': [('erække', False)],
          'erænen': [('eræn', False)],
          'erænens': [('eræn', False)],
          'eræner': [('eræn', False)],
          'erænerne': [('eræn', False)],
          'erænernes': [('eræn', False)],
          'eræners': [('eræn', False)],
          'eræs': [('eræs', False)],
          'erøjer': [('erøje', False)],
          'erøllens': [('erøl', False)],
          'erøllerne': [('erøl', False)],
          'erøllernes': [('erøl', False)],
          'erønne': [('erøn', False)],
          'erønnen': [('erøn', False)],
          'erønnens': [('erøn', False)],
          'erønnes': [('erøn', False)],
          'erøret': [('erør', False)],
          'erørets': [('erør', False)],
          'erøve': [('erøv', False)],
          'erøven': [('erøv', False)],
          'erøvens': [('erøv', False)],
          'erøvernes': [('erøver', False)],
          'erøves': [('erøv', False)],
          'es': [('es', True)],
          "es'": [('es', False)],
          'esagen': [('esag', False)],
          'esager': [('esager', False)],
          'esagerne': [('esager', False)],
          'esagernes': [('esag', False)],
          'esagers': [('esag', False)],
          'esaks': [('esaks', False)],
          'esaners': [('esan', False)],
          'esanger': [('esanger', False)],
          'esangernes': [('esanger', False)],
          'esans': [('esan', False)],
          'esarbejder': [('esarbejde', False)],
          'esarbejderne': [('esarbejde', False)],
          'esarbejdernes': [('esarbejde', False)],
          'esarier': [('esario', False)],
          'esarierne': [('esario', False)],
          'esariernes': [('esario', False)],
          'esariers': [('esario', False)],
          'esbo': [('esbo', False)],
          'esboer': [('esbo', False)],
          'esboerne': [('esbo', False)],
          'esbos': [('esbo', False)],
          'escenter': [('escent', False)],
          'escenters': [('escent', False)],
          'eselen': [('esele', False)],
          'eselens': [('esele', False)],
          'esen': [('es', False)],
          'esene': [('es', False)],
          'esener': [('esen', False)],
          'eseners': [('esen', False)],
          'esenes': [('es', False)],
          'esens': [('es', False)],
          'esentens': [('esent', False)],
          'eser': [('eser', False)],
          'esere': [('eser', False)],
          'eseren': [('eser', False)],
          'eserens': [('eser', False)],
          'eseres': [('eser', False)],
          'eserne': [('eser', False)],
          'esernes': [('eser', False)],
          'eserven': [('eserve', False)],
          'eservens': [('eserve', False)],
          'eserver': [('eserve', False)],
          'eserverne': [('eserve', False)],
          'eservernes': [('eserve', False)],
          'eservers': [('eserv', False)],
          'eset': [('es', False)],
          'esets': [('es', False)],
          'esharen': [('eshare', False)],
          'esharens': [('eshare', False)],
          'esher': [('esher', False)],
          'esherne': [('esher', False)],
          'eshernes': [('esher', False)],
          'eshers': [('esher', False)],
          'esianer': [('esianer', False)],
          'esianers': [('esianer', False)],
          'esias': [('esia', False)],
          'esidens': [('esidens', False)],
          'esiderne': [('eside', False)],
          'esier': [('esi', False)],
          'esiet': [('esi', False)],
          'esignet': [('esign', False)],
          'esignets': [('esign', False)],
          'esistens': [('esistens', False)],
          'esium': [('esium', False)],
          'esiums': [('esium', False)],
          'eskaber': [('eskab', False)],
          'eskaberne': [('eskab', False)],
          'eskabernes': [('eskab', False)],
          'eskabers': [('eskab', False)],
          'eskaffer': [('eskaffe', False)],
          'eskafferne': [('eskaffe', False)],
          'eskaffernes': [('eskaffe', False)],
          'eskaffers': [('eskaffe', False)],
          'eskallen': [('eskal', False)],
          'eskallens': [('eskal', False)],
          'eskaller': [('eskal', False)],
          'eskallerne': [('eskal', False)],
          'eskallernes': [('eskal', False)],
          'eskallers': [('eskal', False)],
          'eske': [('eske', False)],
          'eskeden': [('esked', False)],
          'eskedens': [('esked', False)],
          'eskeder': [('eskede', False)],
          'eskederne': [('eskede', False)],
          'eskedernes': [('eskede', False)],
          'eskeders': [('eskede', False)],
          'esken': [('eske', False)],
          'eskene': [('esk', False)],
          'eskenes': [('eske', False)],
          'eskens': [('esk', False)],
          'esker': [('eske', False)],
          'eskerne': [('eske', False)],
          'eskernes': [('esk', False)],
          'eskers': [('eske', False)],
          'eskes': [('eske', False)],
          'esket': [('eske', False)],
          'eskets': [('eske', False)],
          'eskifte': [('eskift', False)],
          'eskifter': [('eskift', False)],
          'eskifterne': [('eskift', False)],
          'eskifternes': [('eskift', False)],
          'eskifters': [('eskifte', False)],
          'eskiftes': [('eskift', False)],
          'eskiftet': [('eskift', False)],
          'eskiftets': [('eskift', False)],
          'eskillinger': [('eskilling', False)],
          'eskillingerne': [('eskilling', False)],
          'eskner': [('esken', False)],
          'esknernes': [('esken', False)],
          'eskners': [('esken', False)],
          'eskos': [('esko', False)],
          'eskreds': [('eskred', False)],
          'eskuer': [('eskuer', False)],
          'eskuerne': [('eskuer', False)],
          'eskuernes': [('eskuer', False)],
          'eskuers': [('eskuer', False)],
          'eskulden': [('eskulde', False)],
          'eskuldens': [('eskulde', False)],
          'eskure': [('eskur', False)],
          'eskures': [('eskur', False)],
          'eskurs': [('eskur', False)],
          'eskvaler': [('eskval', False)],
          'eskvalerne': [('eskval', False)],
          'eskvalernes': [('eskval', False)],
          'eskytter': [('eskytte', False)],
          'eskytterne': [('eskytte', False)],
          'eskytternes': [('eskytter', False)],
          'eskytters': [('eskytter', False)],
          'eskød': [('eskøde', False)],
          'eskøder': [('eskøde', False)],
          'eskøderne': [('eskød', False)],
          'eskødernes': [('eskøde', False)],
          'eskøders': [('eskøde', False)],
          'eskødet': [('eskød', False)],
          'eskødets': [('eskød', False)],
          'eskøds': [('eskøde', False)],
          'eskøjten': [('eskøjt', False)],
          'eskøjtens': [('eskøjt', False)],
          'eskøjter': [('eskøjte', False)],
          'eskøjterne': [('eskøjte', False)],
          'eskøjternes': [('eskøjte', False)],
          'eskøjters': [('eskøjt', False)],
          'eslags': [('eslag', False)],
          'eslangen': [('eslange', False)],
          'eslangens': [('eslange', False)],
          'eslens': [('esel', False)],
          'eslinger': [('esling', False)],
          'eslingerne': [('esling', False)],
          'eslingernes': [('esling', False)],
          'eslingers': [('esling', False)],
          'esmakker': [('esmakker', True)],
          'esmakkerne': [('esmakker', True)],
          'esmakkernes': [('esmakker', True)],
          'esmakkers': [('esmakker', True)],
          'esmers': [('esmer', False)],
          'esmerter': [('esmerter', False)],
          'esmerterne': [('esmerte', False)],
          'esmerternes': [('esmerter', False)],
          'esmerters': [('esmerter', False)],
          'esmutter': [('esmutte', False)],
          'esmutterne': [('esmutte', False)],
          'esmutternes': [('esmutte', False)],
          'esmutters': [('esmutte', False)],
          'esmækker': [('esmækker', False)],
          'esmækkerne': [('esmækker', False)],
          'esmækkernes': [('esmækker', False)],
          'esmækkers': [('esmækker', False)],
          'esmælder': [('esmælde', False)],
          'esmælderne': [('esmælde', False)],
          'esmældernes': [('esmælde', False)],
          'esmælders': [('esmælde', False)],
          'esnaps': [('esnaps', False)],
          'esne': [('esne', False)],
          'esnes': [('esne', False)],
          'esorden': [('esorden', False)],
          'esordens': [('esorden', False)],
          'espalten': [('espalte', False)],
          'espaltens': [('espalte', False)],
          'esparker': [('espark', False)],
          'esparkerne': [('espark', False)],
          'esparkernes': [('espark', False)],
          'esparkers': [('esparker', False)],
          'espe': [('esp', True)],
          'esper': [('esper', False)],
          'esperne': [('esper', False)],
          'espernes': [('esper', False)],
          'espers': [('esper', False)],
          'espids': [('espids', False)],
          'espidser': [('espids', False)],
          'espiger': [('espige', False)],
          'espigerne': [('espige', False)],
          'espigernes': [('espige', False)],
          'espigers': [('espige', False)],
          'espild': [('espild', False)],
          'espildet': [('espild', False)],
          'espildets': [('espild', False)],
          'espiller': [('espille', False)],
          'espillerne': [('espille', False)],
          'espillernes': [('espille', False)],
          'espillers': [('espille', False)],
          'espiser': [('espiser', False)],
          'espiserne': [('espiser', False)],
          'espisernes': [('espiser', False)],
          'espisers': [('espiser', False)],
          'esporerne': [('espore', False)],
          'esporernes': [('espore', False)],
          'espænderne': [('espænde', False)],
          'espændet': [('espænde', False)],
          'espændets': [('espænde', False)],
          'essagens': [('essag', False)],
          'essager': [('essag', False)],
          'essagerne': [('essag', False)],
          'essagernes': [('essag', False)],
          'essen': [('esse', False)],
          'essene': [('essene', False)],
          'essens': [('essens', True), ('esse', True)],
          'esser': [('es', True), ('esse', True)],
          'esserne': [('es', True), ('esse', True)],
          'essernes': [('es', True), ('esse', True)],
          'essers': [('esse', True), ('es', True)],
          'esset': [('es', False)],
          'essets': [('es', False)],
          'essiner': [('essin', False)],
          'essinerne': [('essin', False)],
          'essinernes': [('essiner', False)],
          'essiners': [('essin', False)],
          'essiniernes': [('essinier', False)],
          'essiniers': [('essinier', False)],
          'essioner': [('ession', False)],
          'essionerne': [('ession', False)],
          'essionernes': [('ession', False)],
          'essioners': [('ession', False)],
          'essories': [('essories', False)],
          'estabe': [('estabe', False)],
          'estaben': [('estabe', False)],
          'estabens': [('estabe', False)],
          'estabes': [('estabe', False)],
          'establer': [('estabel', False)],
          'establerne': [('estabel', False)],
          'establernes': [('estabel', False)],
          'establers': [('estabel', False)],
          'estads': [('estads', False)],
          'estagen': [('estagen', False)],
          'estagens': [('estagen', False)],
          'estages': [('estage', False)],
          'estalen': [('estale', False)],
          'estalerne': [('estal', False)],
          'estalernes': [('estal', False)],
          'estamenterne': [('estamente', False)],
          'estamenternes': [('estamente', False)],
          'estamenters': [('estamente', False)],
          'estarter': [('estart', False)],
          'estarterne': [('estarter', False)],
          'estarternes': [('estart', False)],
          'estarters': [('estarter', False)],
          'estave': [('estav', False)],
          'estaven': [('estav', False)],
          'estavens': [('estav', False)],
          'estaver': [('estav', False)],
          'estaverne': [('estav', False)],
          'estavernes': [('estav', False)],
          'estavers': [('estav', False)],
          'estaves': [('estav', False)],
          'este': [('este', False)],
          'estemmer': [('estemme', False)],
          'estemmerne': [('estemme', False)],
          'estemmernes': [('estemme', False)],
          'estemmers': [('estemme', False)],
          'estempler': [('estempel', False)],
          'estemplerne': [('estempel', False)],
          'estemplernes': [('estempel', False)],
          'estemplers': [('estempel', False)],
          'esten': [('esten', False)],
          'estene': [('est', False)],
          'estenes': [('esten', False)],
          'esteppen': [('estep', False)],
          'esteppens': [('estep', False)],
          'estepper': [('estep', False)],
          'estepperne': [('estep', False)],
          'esteppernes': [('estep', False)],
          'esteppers': [('estep', False)],
          'ester': [('ester', True)],
          'esteret': [('esteret', False)],
          'esterets': [('esteret', False)],
          'esterier': [('esteri', False)],
          'esterierne': [('esteri', False)],
          'esteriernes': [('esteri', False)],
          'esteriers': [('esteri', False)],
          'esteriet': [('esteri', False)],
          'esteriets': [('esteri', False)],
          'esterne': [('ester', True)],
          'esternes': [('ester', True)],
          'esters': [('ester', False)],
          'estes': [('este', False)],
          'esti': [('esti', False)],
          'estiens': [('esti', False)],
          'estier': [('estie', False)],
          'estierne': [('esti', False)],
          'estiernes': [('estie', False)],
          'estiers': [('esti', False)],
          'estiet': [('esti', False)],
          'estiets': [('esti', False)],
          'estifter': [('estift', False)],
          'estifterne': [('estift', False)],
          'estifternes': [('estift', False)],
          'estifters': [('estift', False)],
          'estiger': [('estige', False)],
          'estigerne': [('estiger', False)],
          'estigernes': [('estiger', False)],
          'estigers': [('estiger', False)],
          'estikken': [('estik', False)],
          'estikker': [('estik', False)],
          'estikkerne': [('estik', False)],
          'estikkernes': [('estik', False)],
          'estikkers': [('estik', False)],
          'estilens': [('estilens', False)],
          'estis': [('esti', False)],
          'estits': [('estit', False)],
          'estler': [('estler', False)],
          'estningers': [('estning', False)],
          'estraffe': [('estraf', False)],
          'estraffene': [('estraf', False)],
          'estraffenes': [('estraf', False)],
          'estraffes': [('estraf', False)],
          'estre': [('ester', False)],
          'estringens': [('estring', False)],
          'estrømper': [('estrømper', False)],
          'estrømperne': [('estrømper', False)],
          'estrømpernes': [('estrømper', False)],
          'estrømpers': [('estrømper', False)],
          'estykkernes': [('estykke', False)],
          'estykkers': [('estykke', False)],
          'estyrer': [('estyre', False)],
          'estyrerne': [('estyre', False)],
          'estyrernes': [('estyre', False)],
          'estyrers': [('estyrer', False)],
          'estyret': [('estyre', False)],
          'estyrets': [('estyre', False)],
          'estænger': [('estang', False)],
          'estængerne': [('estang', False)],
          'estængernes': [('estang', False)],
          'estængers': [('estang', False)],
          'estævne': [('estævne', False)],
          'estævnes': [('estævne', False)],
          'estøvler': [('estøvle', False)],
          'estøvlerne': [('estøvle', False)],
          'estøvlernes': [('estøvle', False)],
          'estøvlers': [('estøvler', False)],
          'esuger': [('esuge', False)],
          'esugerne': [('esuge', False)],
          'esugernes': [('esuge', False)],
          'esugers': [('esuge', False)],
          'esummer': [('esum', False)],
          'esummerne': [('esum', False)],
          'esummernes': [('esum', False)],
          'esummers': [('esum', False)],
          'esus': [('esus', False)],
          'esynder': [('esynd', False)],
          'esynderne': [('esynd', False)],
          'esyndernes': [('esynd', False)],
          'esynders': [('esynd', False)],
          'esyren': [('esyre', False)],
          'esyrens': [('esyre', False)],
          'esyrer': [('esyre', False)],
          'esyrerne': [('esyre', False)],
          'esyrernes': [('esyre', False)],
          'esyrers': [('esyre', False)],
          'esæder': [('esæde', False)],
          'esæderne': [('esæde', False)],
          'esædernes': [('esæde', False)],
          'esæders': [('esæde', False)],
          'esætternes': [('esætter', False)],
          'esøer': [('eso', False)],
          'esøerne': [('eso', False)],
          'esøernes': [('eso', False)],
          'esøers': [('eso', False)],
          'et': [('', False)],
          'etabenes': [('etab', False)],
          'etabs': [('etab', False)],
          'etaenes': [('eta', False)],
          'etage': [('etage', True)],
          'etagens': [('etage', False)],
          'etager': [('etage', True)],
          'etagere': [('etagere', True)],
          'etageren': [('etagere', True)],
          'etagerens': [('etagere', True)],
          'etageres': [('etagere', True)],
          'etagerne': [('etage', False)],
          'etagernes': [('etage', False)],
          'etagers': [('etage', False)],
          'etages': [('etage', True)],
          'etaks': [('etak', False)],
          'etakter': [('etakter', False)],
          'etakterne': [('etakter', False)],
          'etakternes': [('etakter', False)],
          'etakters': [('etakter', False)],
          'etalens': [('etale', False)],
          'etaler': [('etaler', False)],
          'etalerne': [('etale', False)],
          'etalernes': [('etale', False)],
          'etalers': [('etaler', False)],
          'etallerne': [('etal', False)],
          'etallernes': [('etal', False)],
          'etan': [('etan', False)],
          'etanden': [('etand', False)],
          'etandens': [('etand', False)],
          'etaner': [('etan', False)],
          'etanerne': [('etaner', False)],
          'etanernes': [('etaner', False)],
          'etaners': [('etan', False)],
          'etanet': [('etan', False)],
          'etanets': [('etan', False)],
          'etangen': [('etang', False)],
          'etangens': [('etang', False)],
          'etanier': [('etanier', False)],
          'etaniernes': [('etanier', False)],
          'etanke': [('etanke', False)],
          'etanken': [('etank', False)],
          'etankens': [('etank', False)],
          'etanker': [('etanker', False)],
          'etankerne': [('etanke', False)],
          'etankernes': [('etanke', False)],
          'etankers': [('etanker', False)],
          'etankes': [('etank', False)],
          'etans': [('etan', False)],
          'etanten': [('etante', False)],
          'etanters': [('etante', False)],
          'etarer': [('etar', False)],
          'etarernes': [('etar', False)],
          'etarier': [('etarie', False)],
          'etariet': [('etarie', False)],
          'etariets': [('etarie', False)],
          'etas': [('eta', False)],
          'etaten': [('etat', True)],
          'etatens': [('etat', False)],
          'etater': [('etat', True)],
          'etaterne': [('etat', True)],
          'etaternes': [('etat', True)],
          'etaters': [('etat', True)],
          'etats': [('etat', True)],
          'etavlen': [('etavle', False)],
          'eteater': [('eteater', False)],
          'eteaters': [('eteater', False)],
          'eteker': [('etek', False)],
          'etekerne': [('etek', False)],
          'etekernes': [('etek', False)],
          'etekers': [('etek', False)],
          'eteket': [('etek', False)],
          'etekets': [('etek', False)],
          'etekster': [('etekst', False)],
          'eteksterne': [('etekst', False)],
          'eteksternes': [('etekst', False)],
          'eteksters': [('etekst', False)],
          'etelen': [('etel', False)],
          'etelens': [('etel', False)],
          'eteler': [('etel', False)],
          'etelernes': [('etel', False)],
          'etelers': [('etel', False)],
          'eteltene': [('etelt', False)],
          'eten': [('et', False)],
          'etene': [('et', False)],
          'etenes': [('et', False)],
          'etens': [('et', False)],
          'etenser': [('etenser', False)],
          'etensernes': [('etenser', False)],
          'etensers': [('etenser', False)],
          'etenten': [('etente', False)],
          'etentens': [('etente', False)],
          'etenterne': [('etente', False)],
          'etenternes': [('etente', False)],
          'etenters': [('etente', False)],
          'eterer': [('eter', False)],
          'etererne': [('eter', False)],
          'eterernes': [('eter', False)],
          'eterers': [('eter', False)],
          'eteret': [('eter', False)],
          'eterets': [('eter', False)],
          'eterier': [('eteria', False)],
          'eterierne': [('eteria', False)],
          'eteriernes': [('eteria', False)],
          'eteriers': [('eteria', False)],
          'eteriet': [('eteria', False)],
          'eteriets': [('eteria', False)],
          'eterne': [('et', False)],
          'eternes': [('et', False)],
          'eterrinen': [('eterrin', False)],
          'eterrinens': [('eterrin', False)],
          'eterriner': [('eterrin', False)],
          'eterrinerne': [('eterrin', False)],
          'eterrinernes': [('eterrin', False)],
          'eterriners': [('eterrin', False)],
          'etes': [('etes', False)],
          "etes'": [('etes', False)],
          'etesen': [('etes', False)],
          'etesens': [('etes', False)],
          'etet': [('et', False)],
          'eteten': [('etet', False)],
          'etetens': [('etet', False)],
          'eteterne': [('etet', False)],
          'eteternes': [('etet', False)],
          'etets': [('et', False)],
          'etfylden': [('etfyld', False)],
          'etfyldens': [('etfyld', False)],
          'ethandler': [('ethandel', False)],
          'ethandlers': [('ethandel', False)],
          'etichernes': [('etich', False)],
          'etider': [('etid', False)],
          'etiderne': [('etid', False)],
          'etidernes': [('etid', False)],
          'etiders': [('etid', False)],
          'etids': [('etid', False)],
          'etier': [('etier', False)],
          'etierne': [('etier', False)],
          'etiernes': [('etier', False)],
          'etiers': [('etier', False)],
          'etiger': [('etiger', False)],
          'etika': [('etikon', False)],
          'etikaene': [('etikon', False)],
          'etikaenes': [('etikon', False)],
          'etiketten': [('etikette', True), ('etiket', True)],
          'etikettens': [('etikette', True), ('etiket', True)],
          'etiketter': [('etiket', True), ('etikette', True)],
          'etiketterne': [('etikette', True), ('etiket', True)],
          'etiketternes': [('etikette', True), ('etiket', True)],
          'etiketters': [('etikette', True), ('etiket', True)],
          'etikkens': [('etik', False)],
          'etikker': [('etik', False)],
          'etikkernes': [('etik', True)],
          'etikkers': [('etik', False)],
          'etikon': [('etikon', False)],
          'etikons': [('etikon', False)],
          'etiks': [('etik', False)],
          'etimer': [('etime', False)],
          'etimerne': [('etime', False)],
          'etimernes': [('etime', False)],
          'etimers': [('etime', False)],
          'etinen': [('etin', False)],
          'etinens': [('etin', False)],
          'etiner': [('etiner', False)],
          'etinerne': [('etin', False)],
          'etinernes': [('etiner', False)],
          'etiners': [('etin', False)],
          'etinet': [('etin', False)],
          'etinets': [('etin', False)],
          'etipper': [('etip', False)],
          'etipperne': [('etip', False)],
          'etippernes': [('etip', False)],
          'etippers': [('etip', False)],
          'etips': [('etips', False)],
          "etips'": [('etips', False)],
          'etis': [('eti', False)],
          'etlens': [('etel', False)],
          'etningen': [('etning', False)],
          'etninger': [('etning', False)],
          'etningerne': [('etning', False)],
          'etningernes': [('etning', False)],
          'etoer': [('eto', False)],
          'etoerne': [('eto', False)],
          'etoernes': [('eto', False)],
          'etoers': [('eto', False)],
          'etoget': [('etog', False)],
          'etogets': [('etoget', False)],
          'etoider': [('etoide', False)],
          'etoiderne': [('etoide', False)],
          'etoidernes': [('etoide', False)],
          'etoiders': [('etoide', False)],
          'etoiletter': [('etoilet', False)],
          'etoiletterne': [('etoilet', False)],
          'etoiletternes': [('etoilet', False)],
          'etoiletters': [('etoilet', False)],
          'etoilettet': [('etoilet', False)],
          'etoilettets': [('etoilet', False)],
          'etonen': [('eton', False)],
          'etonens': [('eton', False)],
          'etoner': [('eton', False)],
          'etonerne': [('eton', False)],
          'etonernes': [('eton', False)],
          'etoners': [('eton', False)],
          'etonien': [('etonie', False)],
          'etoniens': [('etonie', False)],
          'etonnen': [('etonne', False)],
          'etonnens': [('etonne', False)],
          'etonner': [('etonne', False)],
          'etonnerne': [('etonne', False)],
          'etonnernes': [('etonne', False)],
          'etonners': [('etonne', False)],
          'etops': [('etop', False)],
          'etos': [('etos', True)],
          "etos'": [('etos', True)],
          'etransporter': [('etransport', False)],
          'etransporterne': [('etransport', False)],
          'etransporternes': [('etransport', False)],
          'etransporters': [('etransport', False)],
          'etrapper': [('etrappe', False)],
          'etrene': [('eter', False)],
          'etrenes': [('eter', False)],
          'etrer': [('etrum', False)],
          'etrerne': [('etrum', False)],
          'etrernes': [('etrum', False)],
          'etrers': [('etrum', False)],
          'etres': [('eter', False)],
          'etrier': [('etri', False)],
          'etrierne': [('etri', False)],
          'etriernes': [('etri', False)],
          'etrikken': [('etrik', False)],
          'etrikker': [('etrik', False)],
          'etrikkerne': [('etrik', False)],
          'etrikkernes': [('etrik', False)],
          'etrikkers': [('etrik', False)],
          'etriller': [('etriller', False)],
          'etrillerne': [('etriller', False)],
          'etrillernes': [('etriller', False)],
          'etrillers': [('etriller', False)],
          'etringens': [('etring', False)],
          'etropper': [('etropper', False)],
          'etroppernes': [('etropper', False)],
          'etros': [('etro', False)],
          'etrosen': [('etrose', False)],
          'etrosens': [('etrose', False)],
          'etroser': [('etrose', False)],
          'etroserne': [('etrose', False)],
          'etrosernes': [('etrose', False)],
          'etrosers': [('etrose', False)],
          'etrotters': [('etrotter', False)],
          'etrum': [('etrum', False)],
          'etrums': [('etrum', False)],
          'etræder': [('etræder', False)],
          'etræderne': [('etræder', False)],
          'etrædernes': [('etræder', False)],
          'ets': [('', False)],
          "ets'": [('et', False)],
          'etset': [('etset', False)],
          'etsets': [('etset', False)],
          'etsider': [('etside', False)],
          'etsiderne': [('etside', False)],
          'etsidernes': [('etside', False)],
          'etsiders': [('etside', False)],
          'ette': [('ette', False)],
          'etten': [('ette', False)],
          'ettens': [('ette', False)],
          'etter': [('etter', True)],
          'etterne': [('etter', True)],
          'etternes': [('etter', True)],
          'etters': [('etter', True)],
          'ettes': [('ette', False)],
          'etti': [('etti', False)],
          'ettiene': [('etti', False)],
          'ettienes': [('etti', False)],
          'ettings': [('etting', False)],
          'ettis': [('etti', False)],
          'etude': [('etude', True)],
          'etuden': [('etude', True)],
          'etudens': [('etude', True)],
          'etudes': [('etude', True)],
          'etudsen': [('etudse', False)],
          'etudsens': [('etudse', False)],
          'etuen': [('etue', False)],
          'etuens': [('etue', False)],
          'etuer': [('etue', False)],
          'etungen': [('etunge', False)],
          'etungens': [('etunge', False)],
          'etunger': [('etunge', False)],
          'etungerne': [('etunge', False)],
          'etungernes': [('etunge', False)],
          'eture': [('etur', False)],
          'eturen': [('etur', False)],
          'eturene': [('etur', False)],
          'eturenes': [('etur', False)],
          'eturens': [('etur', False)],
          'eturer': [('etur', False)],
          'eturerne': [('etur', False)],
          'eturernes': [('etur', False)],
          'eturers': [('etur', False)],
          'etures': [('etur', False)],
          'etydernes': [('etyder', False)],
          'etyders': [('etyder', False)],
          'etypens': [('etype', False)],
          'etypernes': [('etype', False)],
          'etypers': [('etype', False)],
          'etyskernes': [('etysker', False)],
          'etyve': [('etyv', False)],
          'etyves': [('etyv', False)],
          'etåren': [('etåre', False)],
          'etårens': [('etåre', False)],
          'etæer': [('etæer', False)],
          'etæerne': [('etæer', False)],
          'etæernes': [('etæer', False)],
          'etæers': [('etæer', False)],
          'etænder': [('etand', False)],
          'etænderne': [('etand', False)],
          'etændernes': [('etand', False)],
          'etænders': [('etand', False)],
          'etængernes': [('etang', False)],
          'etængers': [('etang', False)],
          'etæren': [('etær', False)],
          'etærens': [('etære', False)],
          'etærer': [('etære', False)],
          'etærerne': [('etær', False)],
          'etærernes': [('etær', False)],
          'etærers': [('etære', False)],
          'etæres': [('etære', False)],
          'etæven': [('etæve', False)],
          'etøjerne': [('etøj', False)],
          'etøjers': [('etøj', False)],
          'etøjet': [('etøj', False)],
          'etønder': [('etønde', False)],
          'etønders': [('etønde', False)],
          'euen': [('eu', False)],
          'euens': [('eu', False)],
          'euer': [('eu', False)],
          'euerne': [('eu', False)],
          'euernes': [('eu', False)],
          'euers': [('eu', False)],
          'euge': [('euge', False)],
          'eugen': [('euge', False)],
          'euges': [('euge', False)],
          'eugler': [('eugle', False)],
          'euglers': [('eugle', False)],
          'eum': [('eum', False)],
          'eummen': [('eum', False)],
          'eummens': [('eum', False)],
          'eummernes': [('eum', False)],
          'eummers': [('eum', False)],
          'eums': [('eum', False)],
          'eungers': [('eunge', False)],
          'euppen': [('eup', False)],
          'euppens': [('eup', False)],
          'eupperne': [('eup', False)],
          'euppers': [('eup', False)],
          'eure': [('eure', False)],
          'eures': [('eure', False)],
          'euret': [('eur', False)],
          'eurets': [('euret', False)],
          'euretten': [('euret', False)],
          'euretterne': [('euret', False)],
          'euretternes': [('euret', False)],
          'euretters': [('euret', False)],
          'eurs': [('eur', False)],
          'eurter': [('eurt', False)],
          'eurterne': [('eurt', False)],
          'eus': [('eu', False)],
          'euse': [('euse', False)],
          'eusen': [('euse', False)],
          'eusens': [('euse', False)],
          'euser': [('euse', False)],
          'euserne': [('euse', False)],
          'eusernes': [('euse', False)],
          'eusers': [('euse', False)],
          'euses': [('euse', False)],
          'eusserne': [('eusser', False)],
          'eussernes': [('eusser', False)],
          'eussers': [('eusser', False)],
          'euter': [('eut', False)],
          'eva': [('ev', False)],
          'evaler': [('eval', False)],
          'evalerne': [('eval', False)],
          'evalernes': [('eval', False)],
          'evalers': [('eval', False)],
          'evalet': [('eval', False)],
          'evalets': [('eval', False)],
          'evals': [('eval', False)],
          'evalse': [('evals', False)],
          'evalsen': [('evals', False)],
          'evalsens': [('evals', False)],
          'evalses': [('evals', False)],
          'evander': [('evander', False)],
          'evanderne': [('evander', False)],
          'evandernes': [('evander', False)],
          'evanders': [('evander', False)],
          'evanen': [('evane', False)],
          'evanens': [('evane', False)],
          'evaner': [('evane', False)],
          'evanerne': [('evane', False)],
          'evanernes': [('evane', False)],
          'evaners': [('evane', False)],
          'evans': [('evans', False)],
          'evarbejder': [('evarbejde', False)],
          'evarbejderne': [('evarbejde', False)],
          'evarbejders': [('evarbejde', False)],
          'evarden': [('evard', False)],
          'evardens': [('evard', False)],
          'evarder': [('evard', False)],
          'evarderne': [('evard', False)],
          'evardernes': [('evard', False)],
          'evarders': [('evard', False)],
          'evarers': [('evare', False)],
          'evas': [('ev', False)],
          'eveje': [('evej', False)],
          'evejen': [('evej', False)],
          'evejens': [('evej', False)],
          'evejes': [('evej', False)],
          'eveksler': [('eveksler', False)],
          'evekslerne': [('eveksler', False)],
          'evekslernes': [('eveksler', False)],
          'evekslers': [('eveksler', False)],
          'evenden': [('evenden', False)],
          'evendens': [('evenden', False)],
          'evenderne': [('evender', False)],
          'evendernes': [('evender', False)],
          'evenders': [('evender', False)],
          'evene': [('ev', False)],
          'evenes': [('ev', False)],
          'everens': [('ever', False)],
          'everne': [('ever', False)],
          'evernes': [('ever', False)],
          'everter': [('evert', True)],
          'everternes': [('evert', True)],
          'evesten': [('evest', False)],
          'evestens': [('evest', False)],
          'evet': [('ev', False)],
          'evets': [('ev', False)],
          'evidder': [('evidde', False)],
          'evidens': [('evidens', True)],
          'evikken': [('evikke', False)],
          'evikkens': [('evik', False)],
          'evikker': [('evikke', False)],
          'evikkerne': [('evik', False)],
          'evikkernes': [('evik', False)],
          'evikkers': [('evik', False)],
          'evillen': [('eville', False)],
          'evillerne': [('eville', False)],
          'evinde': [('evind', False)],
          'evinden': [('evinde', False)],
          'evindens': [('evinde', False)],
          'evinder': [('evinder', False)],
          'evinderne': [('evinder', False)],
          'evindernes': [('evinder', False)],
          'evinders': [('evinde', False)],
          'evindes': [('evinde', False)],
          'evinen': [('evin', False)],
          'evinens': [('evin', False)],
          'evines': [('evin', False)],
          'evingen': [('evinge', False)],
          'evinger': [('evinge', False)],
          'evingerne': [('evinge', False)],
          'evins': [('evin', False)],
          'evinsten': [('evinst', False)],
          'evinstens': [('evinst', False)],
          'evippen': [('evip', False)],
          'evippens': [('evip', False)],
          'evipper': [('evip', False)],
          'evipperne': [('evip', False)],
          'evippernes': [('evip', False)],
          'evippers': [('evip', False)],
          'evirer': [('evir', False)],
          'evirerne': [('evir', False)],
          'evirernes': [('evir', False)],
          'evirers': [('evir', False)],
          'evis': [('evis', False)],
          'eviser': [('evis', False)],
          'eviserne': [('evis', False)],
          'evisernes': [('evise', False)],
          'evisers': [('evise', False)],
          'evits': [('evit', False)],
          'evivalens': [('evival', False)],
          'evle': [('evle', False)],
          'evles': [('evle', False)],
          'evne': [('evne', False)],
          'evnen': [('evne', False)],
          'evnens': [('evne', False)],
          'evner': [('evne', False)],
          'evnerne': [('evne', False)],
          'evnernes': [('evne', False)],
          'evners': [('evne', True)],
          'evnes': [('evne', False)],
          'evoksen': [('evoks', False)],
          'evoksens': [('evoks', False)],
          'evolten': [('evolte', False)],
          'evolterne': [('evolte', False)],
          'evons': [('evon', False)],
          'evs': [('ev', False)],
          'evsens': [('evs', False)],
          'evser': [('evser', False)],
          'evserne': [('evser', False)],
          'evsernes': [('evser', False)],
          'evsers': [('evser', False)],
          'evåbner': [('evåbner', False)],
          'evåbnerne': [('evåbner', False)],
          'evåbnernes': [('evåbner', False)],
          'evåbners': [('evåbner', False)],
          'evågerne': [('evåge', False)],
          'evågers': [('evåge', False)],
          'evædernes': [('evæder', False)],
          'evæders': [('evæder', False)],
          'evælden': [('evælde', False)],
          'evældens': [('evæld', False)],
          'evældet': [('evæld', False)],
          'evældets': [('evæld', False)],
          'eværet': [('evær', False)],
          'eværets': [('evær', False)],
          'eværge': [('eværge', False)],
          'eværgen': [('eværge', False)],
          'eværs': [('evær', False)],
          'eværter': [('eværter', False)],
          'eværterne': [('eværter', False)],
          'eværternes': [('evært', False)],
          'eværters': [('eværter', False)],
          'exer': [('ex', False)],
          'exerne': [('ex', False)],
          'exernes': [('ex', False)],
          'exers': [('ex', False)],
          'eyder': [('eyder', False)],
          'eyderne': [('eyder', False)],
          'eyen': [('ey', False)],
          'eyens': [('ey', False)],
          'eyer': [('ey', False)],
          'eyerne': [('ey', False)],
          'eyernes': [('ey', False)],
          'eyers': [('ey', False)],
          'eys': [('ey', False)],
          "eys'": [('ey', False)],
          'ezen': [('ez', False)],
          'ezens': [('ez', False)],
          'ezer': [('ez', False)],
          'ezerne': [('ez', False)],
          'ezernes': [('ez', False)],
          'ezers': [('ez', False)],
          'ezet': [('ez', False)],
          'ezets': [('ez', False)],
          'ezzi': [('ezzo', False)],
          'ezzis': [('ezzo', False)],
          'eåbner': [('eåbner', False)],
          'eåbnerne': [('eåbner', False)],
          'eånden': [('eånd', False)],
          'eåndens': [('eånd', False)],
          'eånders': [('eånd', False)],
          'eåre': [('eåre', False)],
          'eårens': [('eåre', False)],
          'eårerne': [('eåre', False)],
          'eårernes': [('eåre', False)],
          'eæbler': [('eæble', False)],
          'eæden': [('eæde', False)],
          'eæder': [('eæder', False)],
          'eænders': [('eand', False)],
          'eæskernes': [('eæske', False)],
          'eøen': [('eø', False)],
          'eøens': [('eø', False)],
          'eøer': [('eø', False)],
          'eøerne': [('eø', False)],
          'eøgler': [('eøgle', False)],
          'eøglerne': [('eøgle', False)],
          'eøje': [('eøje', False)],
          'eøjen': [('eøje', False)],
          'eøjens': [('eøje', False)],
          'eøjerne': [('eøje', False)],
          'eøjernes': [('eøje', False)],
          'eøjers': [('eøje', False)],
          'eøjes': [('eøje', False)],
          'eøjet': [('eøje', False)],
          'eøjets': [('eøje', False)],
          'eøllen': [('eøl', False)],
          'eøller': [('eøl', False)],
          'eøllers': [('eøl', False)],
          'eøre': [('eøre', False)],
          'eørne': [('eørn', False)],
          'eørnene': [('eørn', False)],
          'eørnenes': [('eørn', False)],
          'eørnes': [('eørn', False)],
          'eøs': [('eø', False)],
          'f': [('f', True)],
          "f'er": [('f', True)],
          "f'erne": [('f', False)],
          "f'ernes": [('f', True)],
          "f'ers": [('f', True)],
          'fa': [('fa', False)],
          'fabets': [('fabet', False)],
          'fabler': [('fabel', True)],
          'fablerne': [('fabel', False)],
          'fablernes': [('fabel', True)],
          'fablers': [('fabel', False)],
          'facet': [('facet', True)],
          'facets': [('facet', True)],
          'fadder': [('fadder', True)],
          'fadderne': [('fadder', True)],
          'faddernes': [('fadder', True)],
          'fadders': [('fadder', True)],
          'fader': [('far', False)],
          'faderen': [('far', False)],
          'faderens': [('far', False)],
          'faders': [('far', True)],
          'faen': [('fa', False)],
          'faens': [('fa', False)],
          'faer': [('fa', False)],
          'faerne': [('fa', False)],
          'faernes': [('fa', False)],
          'faers': [('fa', False)],
          'fage': [('fage', False)],
          'fagen': [('fage', False)],
          'fagens': [('fag', False)],
          'fager': [('fag', False)],
          'fagerne': [('fag', False)],
          'fagernes': [('fag', False)],
          'fagers': [('fag', False)],
          'fages': [('fage', False)],
          'fagters': [('fagter', True)],
          'faires': [('faire', False)],
          'fakes': [('fake', True)],
          'faklens': [('fakkel', True)],
          'fakler': [('fakkel', False)],
          "faks'": [('faks', False)],
          'faksen': [('faks', False)],
          'faksens': [('faks', False)],
          'fakser': [('faks', False)],
          'fakserne': [('faks', False)],
          'faksernes': [('faks', False)],
          'faksers': [('faks', False)],
          'fakter': [('fakt', False)],
          'falke': [('falk', False)],
          'falken': [('falk', True)],
          'falkens': [('falk', False)],
          'falkers': [('falk', False)],
          'falkes': [('falk', False)],
          'fallens': [('falle', True)],
          'fallerne': [('falle', True)],
          'fallernes': [('falle', True)],
          'fallers': [('falle', True)],
          'fals': [('fals', True)],
          "fals'": [('fals', True)],
          'false': [('fals', True)],
          'falsen': [('fals', True)],
          'falsens': [('fals', True)],
          'falses': [('fals', True)],
          'faltens': [('falt', False)],
          'famier': [('fami', False)],
          'famierne': [('fami', False)],
          'famiernes': [('fami', False)],
          'famiers': [('fami', False)],
          'fanden': [('fanden', False)],
          'fandens': [('fanden', False)],
          'fane': [('fane', True)],
          'fanen': [('fane', True)],
          'fanens': [('fane', True)],
          'faner': [('fane', False)],
          'fanerne': [('fane', True)],
          'fanernes': [('fane', True)],
          'faners': [('fane', False)],
          'fanes': [('fane', True)],
          'fangen': [('fange', True)],
          'fangens': [('fange', True)],
          'fanger': [('fange', True), ('fanger', True)],
          'fangerne': [('fange', True), ('fanger', True)],
          'fangernes': [('fanger', True), ('fange', True)],
          'fangers': [('fanger', True), ('fange', True)],
          'fangster': [('fangst', False)],
          'fangsterne': [('fangst', True)],
          'fangsternes': [('fangst', False)],
          'fangsters': [('fangst', False)],
          'fansene': [('fan', True)],
          'fanten': [('fant', False)],
          'fantens': [('fant', False)],
          'fanterne': [('fant', False)],
          'fanternes': [('fant', False)],
          'fanters': [('fant', False)],
          'fants': [('fant', False)],
          'faren': [('far', True), ('fare', True)],
          'farens': [('far', True), ('fare', True)],
          'farer': [('fare', True)],
          'farerne': [('fare', False)],
          'farernes': [('fare', True)],
          'farers': [('fare', True)],
          'farien': [('fari', False)],
          'fariens': [('fari', False)],
          'farier': [('fari', False)],
          'farierne': [('fari', False)],
          'fariernes': [('fari', False)],
          'fariers': [('fari', False)],
          'faris': [('fari', False)],
          'farmens': [('farm', False)],
          'farmer': [('farmer', True)],
          'farmes': [('farm', False)],
          'fars': [('far', True), ('fars', True)],
          "fars'": [('fars', True)],
          'farsen': [('fars', False)],
          'farsens': [('fars', True)],
          'farser': [('fars', True)],
          'farserne': [('fars', False)],
          'farsernes': [('fars', True)],
          'farsers': [('fars', False)],
          'farsis': [('farsi', True)],
          'farten': [('fart', False)],
          'farter': [('fart', False)],
          'farterne': [('fart', False)],
          'farternes': [('fart', True)],
          'farters': [('fart', False)],
          'farts': [('fart', False)],
          'farvehandler': [('farvehandler', True), ('farvehandel', True)],
          'farvehandlerne': [('farvehandel', True), ('farvehandler', True)],
          'farvehandlernes': [('farvehandel', True), ('farvehandler', True)],
          'farvehandlers': [('farvehandler', True), ('farvehandel', True)],
          'farvelader': [('farvelade', True)],
          'farveladerne': [('farvelade', True)],
          'farveladernes': [('farvelade', True)],
          'farveladers': [('farvelade', True)],
          'farven': [('farve', False)],
          'farvens': [('farve', False)],
          'fas': [('fas', True), ('fa', True)],
          'fase': [('fas', True), ('fase', True)],
          'fasen': [('fas', True), ('fase', True)],
          'fasens': [('fas', True), ('fase', True)],
          'faser': [('fase', True), ('fas', True)],
          'faserne': [('fas', True), ('fase', True)],
          'fasernes': [('fas', True), ('fase', True)],
          'fasers': [('fase', True), ('fas', True)],
          'fases': [('fas', True), ('fase', True)],
          'fasien': [('fasi', False)],
          'fasiens': [('fasi', False)],
          'fasier': [('fasi', False)],
          'fasierne': [('fasi', False)],
          'fasiernes': [('fasi', False)],
          'fasiers': [('fasi', False)],
          'fasis': [('fasi', False)],
          'fastens': [('faste', True)],
          'faster': [('faste', True), ('faster', True)],
          'fasternes': [('faste', True)],
          'fasters': [('faste', True), ('faster', True)],
          'faternes': [('fat', False)],
          'fatter': [('fatter', False)],
          'fatterne': [('fatter', False)],
          'favne': [('favn', True)],
          'favnen': [('favn', True)],
          'favnens': [('favn', True)],
          'favnes': [('favn', True)],
          'fballer': [('fbal', False)],
          'fballerne': [('fbal', False)],
          'fballernes': [('fbal', False)],
          'fballers': [('fbal', False)],
          'fballet': [('fbal', False)],
          'fballets': [('fbal', False)],
          'fbuen': [('fbue', False)],
          'fbuens': [('fbue', False)],
          'fbuernes': [('fbue', False)],
          'fcellen': [('fcelle', False)],
          'fceller': [('fcelle', False)],
          'fcellers': [('fcelle', False)],
          'fder': [('fde', False)],
          'fderne': [('fde', False)],
          'fdernes': [('fde', False)],
          'fdes': [('fde', False)],
          'fe': [('fe', True)],
          'feber': [('feber', False)],
          'feen': [('fe', False)],
          'feens': [('fe', False)],
          'feer': [('fe', True)],
          'feerne': [('fe', False)],
          'feernes': [('fe', False)],
          'feers': [('fe', False)],
          'fefanger': [('fefange', False)],
          'fefangerne': [('fefange', False)],
          'fefangernes': [('fefange', False)],
          'fefangers': [('fefange', False)],
          'fege': [('fege', False)],
          'fegen': [('fege', False)],
          'fegens': [('fege', False)],
          'feges': [('fege', False)],
          'fejder': [('fejde', False)],
          'fejderne': [('fejde', False)],
          'fejdernes': [('fejde', False)],
          'fejer': [('fejer', False)],
          'fejerne': [('fejer', False)],
          'fejernes': [('fej', False)],
          'fejers': [('fej', False)],
          'fejlen': [('fejl', False)],
          'fejlens': [('fejl', False)],
          'fekter': [('fekt', False)],
          'fekterne': [('fekt', False)],
          'fekternes': [('fekt', False)],
          'fekters': [('fekt', False)],
          'fekturer': [('fektur', False)],
          'fekturerne': [('fektur', False)],
          'fekturernes': [('fektur', False)],
          'fekturers': [('fektur', False)],
          'felets': [('fel', False)],
          'felier': [('feli', False)],
          'feliernes': [('feli', False)],
          'feliers': [('feli', False)],
          'feliet': [('feli', False)],
          'feliets': [('feli', False)],
          'felsers': [('felse', False)],
          'felten': [('felt', True)],
          'feltens': [('felt', True)],
          'felter': [('felt', False)],
          'felterne': [('felt', False)],
          'felternes': [('felt', False)],
          'felure': [('felur', False)],
          'feministers': [('feminist', True)],
          'femmer': [('femmer', True)],
          'femmers': [('femmer', True)],
          'femser': [('femser', False)],
          'femserne': [('femser', False)],
          'femsernes': [('femser', False)],
          'femsers': [('femser', False)],
          'femtiden': [('femtiden', False)],
          'fender': [('fender', True)],
          'fenderne': [('fender', True)],
          'fendernes': [('fender', True)],
          'fenders': [('fender', True)],
          'fennerne': [('fenne', True)],
          'fer': [('fer', True)],
          'fere': [('fer', True)],
          'feren': [('fer', True)],
          'ferene': [('fer', True)],
          'ferenes': [('fer', True)],
          'ferens': [('fer', True)],
          'ferensernes': [('ferens', False)],
          'ferensers': [('ferens', False)],
          'ferenten': [('ferent', False)],
          'ferentens': [('ferent', False)],
          'ferenter': [('ferent', False)],
          'ferenterne': [('ferent', False)],
          'ferenternes': [('ferent', False)],
          'feres': [('fer', True)],
          'feretten': [('feret', False)],
          'ferettens': [('feret', False)],
          'ferien': [('ferie', True)],
          'feriens': [('ferie', True)],
          'ferier': [('ferie', True)],
          'ferierne': [('ferie', True)],
          'feriernes': [('ferie', False)],
          'feriers': [('ferie', True)],
          'feriet': [('feri', False)],
          'feriets': [('feri', False)],
          'feris': [('feri', False)],
          'fernissen': [('fernis', True)],
          'fers': [('fer', False)],
          'fersken': [('fersken', True)],
          'ferskens': [('fersken', True)],
          'fersker': [('ferske', False)],
          'ferskerne': [('ferske', False)],
          'ferskers': [('ferske', False)],
          'ferten': [('fert', False)],
          'fertens': [('fert', False)],
          'ferter': [('fert', False)],
          'ferterne': [('fert', False)],
          'ferters': [('fert', False)],
          'ferts': [('fert', False)],
          'fes': [('fe', True), ('fes', True)],
          'fesager': [('fesag', False)],
          'fesagerne': [('fesag', False)],
          'fesser': [('fes', True)],
          'fesserne': [('fes', True)],
          'fessernes': [('fes', True)],
          'fessers': [('fes', True)],
          'festen': [('fest', False)],
          'festens': [('fest', False)],
          'fester': [('fest', True)],
          'festerne': [('fest', False)],
          'festernes': [('fest', False)],
          'festers': [('fest', False)],
          'fet': [('fet', False)],
          'feter': [('fet', False)],
          'feters': [('fet', False)],
          'fetiden': [('fetid', False)],
          'fetier': [('feti', False)],
          'fetierne': [('feti', False)],
          'fetiernes': [('feti', False)],
          'fetiers': [('feti', False)],
          'fetten': [('fet', False)],
          'fettens': [('fet', False)],
          'fetter': [('fet', False)],
          'fetterne': [('fet', False)],
          'fetternes': [('fet', False)],
          'fetters': [('fet', False)],
          'ffagens': [('ffage', False)],
          'ffaires': [('ffaires', False)],
          'ffe': [('ffe', False)],
          'ffene': [('ff', False)],
          'ffenes': [('ff', False)],
          'ffer': [('f', False)],
          'ffere': [('ffer', False)],
          'fferes': [('ffer', False)],
          'fferet': [('ffer', False)],
          'fferets': [('ffer', False)],
          'fferne': [('ffer', False)],
          'ffernes': [('f', False)],
          'ffers': [('f', False)],
          'ffersken': [('fferske', False)],
          'fferskens': [('fferske', False)],
          'ffet': [('f', False)],
          'fficer': [('fficer', False)],
          'ffiner': [('ffin', False)],
          'ffiners': [('ffin', False)],
          'fflis': [('ffli', False)],
          'ffløse': [('ffløse', False)],
          'ffløsen': [('ffløse', False)],
          'ffløsens': [('ffløse', False)],
          'ffløser': [('ffløse', False)],
          'ffløserne': [('ffløse', False)],
          'ffløsers': [('ffløse', False)],
          'ffløses': [('ffløse', False)],
          'ffons': [('ffon', False)],
          'ffora': [('forum', False)],
          'fforaene': [('forum', False)],
          'fforaenes': [('forum', False)],
          'fforas': [('forum', False)],
          'fforummer': [('forum', False)],
          'fforummerne': [('forum', False)],
          'fforummernes': [('forum', False)],
          'fforummers': [('forum', False)],
          'fforummet': [('forum', False)],
          'fforummets': [('forum', False)],
          'fforums': [('forum', False)],
          'ffører': [('ffør', False)],
          'fførerne': [('ffør', False)],
          'fførernes': [('ffør', False)],
          'fførers': [('ffør', False)],
          "fg'er": [("fg'er", False)],
          "fg'erne": [("fg'er", False)],
          "fg'ernes": [("fg'er", False)],
          "fg'ers": [("fg'er", False)],
          'fglans': [('fglans', False)],
          'fgrøden': [('fgrøde', False)],
          'fgrødens': [('fgrøde', False)],
          'fgænger': [('fgænger', False)],
          'fgængerne': [('fgænger', False)],
          'fgængernes': [('fgænger', False)],
          'fgængers': [('fgænger', False)],
          'fhopper': [('fhopper', False)],
          'fhopperne': [('fhopper', False)],
          'fhoppernes': [('fhopper', False)],
          'fhoppers': [('fhopper', False)],
          'fi': [('fi', False)],
          'fianer': [('fian', False)],
          'fianers': [('fian', False)],
          'fians': [('fian', False)],
          'fiber': [('fiber', False)],
          'fibier': [('fibium', False)],
          'fibierne': [('fibium', False)],
          'fibiers': [('fibium', False)],
          'fibiets': [('fibium', False)],
          'ficen': [('fice', False)],
          'ficens': [('fice', False)],
          'ficer': [('fice', False)],
          'ficerne': [('fice', False)],
          'ficernes': [('fice', False)],
          'ficers': [('ficer', False)],
          'fices': [('fice', False)],
          'fichernes': [('fiche', False)],
          'ficiner': [('ficin', False)],
          'ficiners': [('ficin', False)],
          'ficitternes': [('ficit', False)],
          'ficitters': [('ficit', False)],
          'fide': [('fide', False)],
          'fiden': [('fide', False)],
          'fidens': [('fide', False)],
          'fides': [('fide', False)],
          'fidier': [('fidi', False)],
          'fidierne': [('fidi', False)],
          'fidiers': [('fidi', False)],
          'fien': [('fi', False)],
          'fiens': [('fi', False)],
          'fier': [('fi', False)],
          'fierne': [('fi', False)],
          'fiernes': [('fi', False)],
          'fiers': [('fi', False)],
          "fies'": [('fie', False)],
          'fiet': [('fi', False)],
          'fiets': [('fi', False)],
          'fif': [('fif', True)],
          'fiffet': [('fif', True)],
          'fiffets': [('fif', True)],
          'figen': [('figen', True)],
          'figens': [('figen', True)],
          'fighter': [('fight', True), ('fighter', True)],
          'fighterne': [('fighter', True), ('fight', True)],
          'fighternes': [('fight', True), ('fighter', True)],
          'fighters': [('fight', True), ('fighter', True)],
          'figner': [('figen', True)],
          'fignerne': [('figen', True)],
          'figners': [('figen', False)],
          'fikans': [('fikans', False)],
          'fikken': [('fik', False)],
          'fikkens': [('fikke', False)],
          'fikker': [('fikke', False)],
          'fikkerne': [('fik', False)],
          'fikkernes': [('fikke', False)],
          'fikkers': [('fikke', False)],
          'fiks': [('fiks', False)],
          "fiks'": [('fiks', False)],
          'fikserne': [('fiks', False)],
          'fiksernes': [('fiks', False)],
          'fiksers': [('fiks', False)],
          'fikum': [('fikum', False)],
          'fikums': [('fikum', False)],
          'filer': [('fil', False)],
          'filet': [('filet', False)],
          'filets': [('filet', True)],
          'filien': [('fili', False)],
          'filiens': [('fili', False)],
          'filippiner': [('filippiner', True), ('filippine', True)],
          'filippinerne': [('filippiner', True), ('filippine', True)],
          'filippinernes': [('filippiner', True), ('filippine', True)],
          'filippiners': [('filippine', True), ('filippiner', True)],
          'filis': [('fili', False)],
          'filister': [('filister', True)],
          'filisters': [('filister', True)],
          'fillen': [('fill', False)],
          'fillens': [('fill', False)],
          'filler': [('fill', False)],
          'fillerne': [('fill', False)],
          'fillernes': [('fill', False)],
          'fillers': [('fill', False)],
          'filten': [('filt', True)],
          'filtens': [('filt', False)],
          'filter': [('filter', True), ('filt', True)],
          'filterne': [('filt', False)],
          'filternes': [('filt', False)],
          'filters': [('filter', True), ('filt', True)],
          'filtet': [('filt', False)],
          'filtets': [('filt', False)],
          'fims': [('fims', True), ('fim', True)],
          'finalen': [('finale', True)],
          'finaler': [('finale', False)],
          'finalerne': [('finale', False)],
          'finalernes': [('finale', False)],
          'finalers': [('finale', False)],
          'finanserne': [('finanser', False)],
          'finansernes': [('finanser', False)],
          'finer': [('finer', True)],
          'finerne': [('fin', False)],
          'finers': [('finer', True)],
          'fingen': [('fing', False)],
          'fingens': [('fing', False)],
          'finger': [('finger', False)],
          'fingerne': [('fing', False)],
          'fingernes': [('fing', False)],
          'fingers': [('finger', False)],
          'fings': [('fing', False)],
          'finister': [('finist', False)],
          'finisters': [('finist', False)],
          'finkens': [('finke', False)],
          'finker': [('finker', True), ('finke', True)],
          'finkerne': [('finker', True), ('finke', True)],
          'finkernes': [('finker', True), ('finke', True)],
          'finkers': [('finker', True), ('finke', True)],
          'finter': [('finte', True)],
          'finternes': [('finte', True)],
          'fippen': [('fip', True)],
          'fippens': [('fip', True)],
          'fipper': [('fip', True)],
          'fipperne': [('fip', True)],
          'fippernes': [('fip', True)],
          'fippers': [('fip', True)],
          'firen': [('fir', False)],
          'firer': [('firer', True)],
          'firerne': [('firer', True)],
          'firernes': [('firer', True)],
          'firers': [('firer', True)],
          'fis': [('fis', True), ('fi', True)],
          'fiskehandler': [('fiskehandler', True), ('fiskehandel', True)],
          'fiskehandlerne': [('fiskehandel', True), ('fiskehandler', True)],
          'fiskehandlernes': [('fiskehandel', True), ('fiskehandler', True)],
          'fiskehandlers': [('fiskehandler', True), ('fiskehandel', True)],
          'fisken': [('fisk', False)],
          'fisker': [('fisker', False)],
          'fiskerne': [('fisker', True)],
          'fiskernes': [('fisker', False)],
          'fismen': [('fisme', False)],
          'fismens': [('fisme', False)],
          'fisser': [('fis', True), ('fisse', True)],
          'fisserne': [('fis', True), ('fisse', True)],
          'fissernes': [('fis', True), ('fisse', True)],
          'fissers': [('fis', True), ('fisse', True)],
          'fisten': [('fist', False)],
          'fistens': [('fist', False)],
          'fister': [('fist', False)],
          'fisterne': [('fist', False)],
          'fisternes': [('fist', False)],
          'fisters': [('fist', False)],
          'fiti': [('fiti', False)],
          'fitiene': [('fiti', False)],
          'fitienes': [('fiti', False)],
          'fitis': [('fiti', False)],
          'fitten': [('fit', False)],
          'fittens': [('fit', False)],
          'fitternes': [('fit', False)],
          'fitters': [('fit', False)],
          'fituren': [('fiture', False)],
          'fiturens': [('fiture', False)],
          'fiturer': [('fiture', False)],
          'fiturerne': [('fiture', False)],
          'fiturernes': [('fiture', False)],
          'fiturers': [('fiture', False)],
          'five': [('five', False)],
          'fiven': [('five', False)],
          'fivene': [('five', False)],
          'fivenes': [('five', False)],
          'fivens': [('five', False)],
          'fives': [('five', False)],
          'fixingen': [('hfixing', False)],
          'fjas': [('fjas', True)],
          'fjerners': [('fjerner', False)],
          'fjers': [('fjer', False)],
          'fjorden': [('fjord', False)],
          'fjordens': [('fjord', True)],
          'fkoder': [('fkoder', False)],
          'fkoderne': [('fkoder', False)],
          'fkodernes': [('fkoder', False)],
          'fkoders': [('fkoder', False)],
          'fkommet': [('fkom', False)],
          'fkommets': [('fkom', False)],
          'fkorter': [('fkorter', False)],
          'fkorternes': [('fkorter', False)],
          'fkorters': [('fkorter', False)],
          'fladen': [('flade', True)],
          'fladens': [('flade', True)],
          'flader': [('flade', False)],
          'fladerne': [('flade', False)],
          'fladernes': [('flade', False)],
          'fladers': [('flade', False)],
          'flagen': [('flage', False)],
          'flagens': [('flage', False)],
          'flager': [('flage', False)],
          'flagerne': [('flage', False)],
          'flagernes': [('flage', False)],
          'flagers': [('flage', False)],
          'flakken': [('flakken', False)],
          'flakkens': [('flakken', False)],
          'flaks': [('flak', True)],
          'flammens': [('flamme', False)],
          'flanen': [('flane', True)],
          'flanerne': [('flane', True)],
          'flanernes': [('flane', True)],
          'flaners': [('flane', True)],
          'flange': [('flange', False)],
          'flangen': [('flange', True)],
          'flappernes': [('flap', True)],
          'flaps': [('flap', True)],
          'flaske': [('flaske', False)],
          'flasken': [('flaske', False)],
          'flaskens': [('flaske', False)],
          'flasker': [('flaske', False)],
          'flaskerne': [('flaske', False)],
          'flaskernes': [('flaske', False)],
          'flaskers': [('flaske', False)],
          'flaskes': [('flaske', False)],
          'fleder': [('fleder', False)],
          'fledernes': [('fleder', False)],
          'flen': [('ffel', False)],
          'flens': [('ffel', False)],
          'fler': [('ffel', False)],
          'flerne': [('ffel', False)],
          'flernes': [('ffel', False)],
          'flers': [('ffel', False)],
          'flet': [('flet', False)],
          'flets': [('flet', True)],
          'fletten': [('flet', False)],
          'flettens': [('flet', False)],
          'fletter': [('flet', False)],
          'fletterne': [('flet', False)],
          'fletternes': [('flet', False)],
          'fletters': [('flet', False)],
          'fliden': [('flid', True)],
          'flids': [('flid', False)],
          'flier': [('fli', False)],
          'flierne': [('fli', False)],
          'flige': [('flig', False)],
          'fligens': [('flig', True)],
          'fliges': [('flig', False)],
          'flikker': [('flik', True)],
          'flikkerne': [('flik', True)],
          'flikkernes': [('flik', True)],
          'flikkers': [('flik', True)],
          'flimmers': [('flimmer', True)],
          'flingers': [('fling', False)],
          'flipper': [('flipper', True), ('flip', True)],
          'flipperne': [('flipper', True), ('flip', True)],
          'flippernes': [('flipper', True), ('flip', True)],
          'flippers': [('flipper', True), ('flip', True)],
          'flips': [('flip', False)],
          'fliren': [('flire', True)],
          'flirens': [('flire', True)],
          'flis': [('flis', False)],
          'flisen': [('flis', True), ('flise', True)],
          'flisens': [('flise', True), ('flis', True)],
          'fliser': [('flis', True), ('flise', True)],
          'fliserne': [('flis', True), ('flise', True)],
          'flisernes': [('flis', True), ('flise', True)],
          'flisers': [('flis', True), ('flise', True)],
          'flitters': [('flitter', True)],
          'floden': [('flod', True)],
          'flodens': [('flod', False)],
          'flods': [('flod', False)],
          'flokkens': [('flok', False)],
          'floks': [('floks', True), ('flok', True)],
          'flomme': [('flom', True), ('flomme', True)],
          'flommen': [('flomme', True), ('flom', True)],
          'flommens': [('flomme', True), ('flom', True)],
          'flommer': [('flomme', True)],
          'flommerne': [('flomme', True)],
          'flommernes': [('flomme', True)],
          'flommers': [('flomme', True)],
          'flommes': [('flomme', True), ('flom', True)],
          'flos': [('flos', True)],
          "flos'": [('flos', True)],
          'flossen': [('floss', False)],
          'flossens': [('floss', False)],
          'flosser': [('flos', True)],
          'flosserne': [('flos', True)],
          'flossernes': [('flos', True)],
          'flossers': [('flos', True)],
          'fluens': [('flue', False)],
          'fluer': [('flue', False)],
          'fluerne': [('flue', True)],
          'fluernes': [('flue', False)],
          'fluers': [('flue', False)],
          'flues': [('flue', False)],
          'flugter': [('flugt', True), ('flugter', True)],
          'flugterne': [('flugt', True), ('flugter', True)],
          'flugternes': [('flugter', True), ('flugt', True)],
          'flugters': [('flugter', True), ('flugt', True)],
          'flukker': [('flukke', False)],
          'flukkerne': [('flukke', False)],
          'flukkernes': [('flukke', False)],
          'flukkers': [('flukke', False)],
          'flus': [('flus', True)],
          'flussen': [('flus', True)],
          'flussens': [('flus', True)],
          'fluten': [('flute', True)],
          'flutens': [('flute', True)],
          'flutter': [('flutter', True)],
          'flutters': [('flutter', True)],
          'flyden': [('flyd', False)],
          'flydens': [('flyd', False)],
          'flyder': [('flyder', True)],
          'flyderne': [('flyder', True)],
          'flydernes': [('flyder', True)],
          'flyders': [('flyder', True)],
          'flyer': [('flyer', True)],
          'flyerne': [('flyer', True)],
          'flyernes': [('flyer', True)],
          'flyers': [('flyer', True)],
          'flys': [('fly', True)],
          'flytternes': [('flytter', False)],
          'flægen': [('flæg', True)],
          'flægens': [('flæg', True)],
          'flækken': [('flække', True), ('flækken', True)],
          'flækkens': [('flække', True)],
          'flækker': [('flække', True)],
          'flækkerne': [('flække', True)],
          'flækkernes': [('flække', True)],
          'flækkers': [('flække', True)],
          'flæser': [('flæse', True)],
          'flæserne': [('flæse', True)],
          'flæsernes': [('flæse', True)],
          'flæsers': [('flæse', True)],
          'fløden': [('fløde', True)],
          'flødens': [('fløde', False)],
          'fløje': [('fløj', True)],
          'fløjen': [('fløj', False)],
          'fløjens': [('fløj', True)],
          'fløjes': [('fløj', False)],
          'fløjten': [('fløjten', True), ('fløjte', True)],
          'flører': [('flør', False)],
          'flørernes': [('flør', False)],
          'fløs': [('fløs', True)],
          'fløse': [('fløs', True)],
          'fløsen': [('fløs', True)],
          'fløsens': [('fløs', True)],
          'fløser': [('fløser', False)],
          'fløserne': [('fløser', False)],
          'fløsernes': [('fløse', False)],
          'fløsers': [('fløser', False)],
          'fløses': [('fløs', True)],
          'fmarchen': [('fmarch', False)],
          'fmarchens': [('fmarch', False)],
          'fnien': [('fnie', False)],
          'fniens': [('fnie', False)],
          'fnier': [('fnie', False)],
          'fnierne': [('fnie', False)],
          'fniernes': [('fnie', False)],
          'fniers': [('fnie', False)],
          'fningers': [('fning', False)],
          'fnis': [('fnis', True)],
          "fnis'": [('fnis', True)],
          'fnium': [('fnium', False)],
          'fniums': [('fnium', False)],
          'fnuller': [('fnuller', True)],
          'fnullers': [('fnuller', True)],
          'fnys': [('fnys', True)],
          'fober': [('fob', False)],
          'fobernes': [('fob', False)],
          'fobers': [('fob', False)],
          'fobis': [('fobi', False)],
          'fobs': [('fob', False)],
          'foden': [('fod', False)],
          'fodens': [('fod', True)],
          'foder': [('foder', False)],
          'foders': [('foder', False)],
          'foen': [('fo', False)],
          'foens': [('fo', False)],
          'foer': [('fo', False)],
          'foerne': [('fo', False)],
          'foernes': [('fo', False)],
          'foers': [('fo', False)],
          'foet': [('fo', False)],
          'foets': [('fo', False)],
          'fogets': [('fog', True)],
          'foilerne': [('foil', False)],
          'foilernes': [('foil', False)],
          'foilers': [('foil', False)],
          'fokke': [('fok', False)],
          'fokken': [('fok', False)],
          'fokker': [('fok', True)],
          'fokkerne': [('fok', True)],
          'fokkernes': [('fok', False)],
          'fokkers': [('fok', False)],
          'fokkes': [('fok', True)],
          'folde': [('fold', False)],
          'folden': [('fold', False)],
          'foldene': [('fold', True)],
          'foldenes': [('fold', True)],
          'foldens': [('fold', False)],
          'folder': [('fold', True), ('folder', True)],
          'folderne': [('folder', True), ('fold', True)],
          'foldernes': [('folder', True), ('fold', True)],
          'folders': [('folder', True), ('fold', True)],
          'foldes': [('fold', False)],
          'fole': [('fole', True)],
          'folen': [('fole', True)],
          'folens': [('fole', True)],
          'folernes': [('fole', True)],
          'folers': [('fole', True)],
          'foles': [('fole', True)],
          'folien': [('folie', True)],
          'foliens': [('folie', True)],
          'folier': [('folie', True)],
          'folierne': [('folie', True)],
          'foliernes': [('folie', True)],
          'foliers': [('folie', False)],
          'folinger': [('foling', True)],
          'folingerne': [('foling', True)],
          'folingernes': [('foling', True)],
          'fomaner': [('foman', False)],
          'fomanerne': [('foman', False)],
          'fomanernes': [('foman', False)],
          'fomaners': [('foman', False)],
          'fonde': [('fond', False)],
          'fonden': [('fond', False)],
          'fondens': [('fond', False)],
          'fonder': [('fond', True)],
          'fonderne': [('fond', True)],
          'fondernes': [('fond', True)],
          'fonders': [('fond', True)],
          'fondes': [('fond', False)],
          'fondet': [('fond', True)],
          'fondets': [('fond', False)],
          'fonds': [('fonds', True), ('fond', True)],
          'fonien': [('foni', False)],
          'foniens': [('foni', False)],
          'fonier': [('foni', False)],
          'fonis': [('foni', False)],
          'fonomen': [('fonom', False)],
          'fons': [('fon', True)],
          "fons'": [('fons', False)],
          'fonsens': [('fons', False)],
          'fonte': [('font', True)],
          'fonten': [('font', True)],
          'fontens': [('font', True)],
          'fonterne': [('font', True)],
          'fonternes': [('font', True)],
          'fonters': [('font', True)],
          'fontes': [('font', False)],
          'fora': [('forum', True)],
          'foraene': [('forum', True)],
          'foraenes': [('forum', True)],
          'foras': [('forum', True)],
          'fordansernes': [('fordanser', True)],
          'fordansers': [('fordanser', True)],
          'fordelerne': [('fordeler', False)],
          'fordrer': [('fordrer', False)],
          'fordrerne': [('fordrer', False)],
          'fordrernes': [('fordrer', False)],
          'fordrers': [('fordrer', False)],
          'forender': [('forende', True)],
          'forenderne': [('forende', True)],
          'forendernes': [('forende', True)],
          'forenders': [('forende', True)],
          'forers': [('for', False)],
          'forhals': [('forhal', True)],
          'forien': [('fori', False)],
          'foriens': [('fori', False)],
          'forinter': [('forint', True)],
          'forinternes': [('forint', True)],
          'foris': [('fori', False)],
          'forken': [('fork', True)],
          'forlover': [('forlover', True)],
          'forloverne': [('forlover', True)],
          'forlovernes': [('forlover', True)],
          'forlovers': [('forlover', True)],
          'former': [('form', True), ('former', True)],
          'formerne': [('former', True), ('form', True)],
          'formernes': [('former', True), ('form', True)],
          'formers': [('former', True), ('form', True)],
          'fornemmelser': [('fornemmelse', True)],
          'fornemmelserne': [('fornemmelse', True)],
          'fornemmelsernes': [('fornemmelse', True)],
          'fornemmelsers': [('fornemmelse', False)],
          'forsager': [('forsager', True)],
          'forsagers': [('forsager', True)],
          'forsknings-': [('forskningsprogram', True), ('forskningsministerium', True)],
          'fortalens': [('fortale', True)],
          'fortaler': [('fortale', True), ('fortaler', True)],
          'fortalerne': [('fortale', True), ('fortaler', True)],
          'fortalernes': [('fortaler', True), ('fortale', True)],
          'fortalers': [('fortaler', True), ('fortale', True)],
          'forten': [('fort', False)],
          'fortens': [('fort', False)],
          'forter': [('fort', False)],
          'forterne': [('fort', True)],
          'forternes': [('fort', True)],
          'forters': [('fort', True)],
          'fortet': [('fort', True)],
          'fortets': [('fort', True)],
          'forts': [('fort', False)],
          'forummer': [('forum', True)],
          'forummerne': [('forum', True)],
          'forummernes': [('forum', True)],
          'forummers': [('forum', True)],
          'forummet': [('forum', True)],
          'forummets': [('forum', True)],
          'forums': [('forum', True)],
          'forvarer': [('forvarer', False)],
          'forvarerne': [('forvarer', False)],
          'forvarernes': [('forvarer', False)],
          'forældre': [('forælder', True)],
          'forældrene': [('forælder', False)],
          'forældrenes': [('forælder', False)],
          'forældres': [('forælder', False)],
          'fos': [('fos', True)],
          'fosen': [('fose', False)],
          'fosens': [('fose', False)],
          'foser': [('fose', False)],
          'foserne': [('fose', False)],
          'fosernes': [('fose', False)],
          'fosers': [('fose', False)],
          'fossen': [('fos', False)],
          'fossens': [('fos', True)],
          'fosser': [('fos', True)],
          'fosserne': [('fos', True)],
          'fotter': [('fot', False)],
          'fotterne': [('fot', False)],
          'fotternes': [('fot', False)],
          'fotters': [('fot', False)],
          "fours'": [('four', False)],
          'foyer': [('foyer', True)],
          'foyers': [('foyer', True)],
          'fposter': [('fpost', False)],
          'fposterne': [('fpost', False)],
          'fposternes': [('fpost', False)],
          'fposters': [('fpost', False)],
          'fpresser': [('fpresser', False)],
          'fpresserne': [('fpresser', False)],
          'fpressernes': [('fpresser', False)],
          'fpressers': [('fpresser', False)],
          'fragter': [('fragt', True)],
          'fragterne': [('fragt', True)],
          'fragternes': [('fragt', True)],
          'fragters': [('fragt', False)],
          'frais': [('frais', False)],
          'frakken': [('frakke', False)],
          'frakker': [('frakke', False)],
          'frakkerne': [('frakke', False)],
          'frakkernes': [('frakke', False)],
          'frakkers': [('frakke', False)],
          'frammen': [('framme', False)],
          'frammens': [('framme', False)],
          'frammernes': [('framme', False)],
          'franen': [('fran', False)],
          'franet': [('fran', False)],
          'franets': [('fran', False)],
          'franker': [('franker', True)],
          'frankerne': [('franker', True)],
          'frankernes': [('franker', True)],
          'frankers': [('franker', True)],
          'frans': [('frans', False)],
          'frater': [('frater', True)],
          'fraterne': [('frater', True)],
          'fraternes': [('frater', True)],
          'fraters': [('frater', True)],
          'fre': [('ffer', False)],
          'freden': [('fred', True)],
          'fredens': [('fred', False)],
          'freds': [('fred', False)],
          'fredsens': [('fredsens', True)],
          'fregnen': [('fregne', True)],
          'fregnens': [('fregne', True)],
          'fregner': [('fregne', True)],
          'fregnernes': [('fregne', True)],
          'frelser': [('frelser', True)],
          'frelserne': [('frelser', True)],
          'frelsernes': [('frelser', True)],
          'frelsers': [('frelser', True)],
          'fremme': [('fremme', False)],
          'fremmernes': [('fremmer', False)],
          'fremmes': [('fremme', False)],
          'frene': [('ffer', False)],
          'frenes': [('ffer', False)],
          'frenten': [('frente', False)],
          'frentens': [('frente', False)],
          'frenternes': [('frente', False)],
          'fres': [('ffer', False)],
          'fresierne': [('fresia', True)],
          'fret': [('ffer', False)],
          'frets': [('ffer', False)],
          'fretter': [('fretter', False)],
          'fretterne': [('fretter', False)],
          'fretternes': [('fretter', False)],
          'fretters': [('fretter', False)],
          'frider': [('frider', False)],
          'friderne': [('frider', False)],
          'fridernes': [('frider', False)],
          'friders': [('frider', False)],
          'frier': [('frier', True)],
          'frierne': [('frier', False)],
          'friernes': [('frier', False)],
          'friers': [('frier', False)],
          'frille': [('frille', True)],
          'frillen': [('frille', True)],
          'frillerne': [('frille', True)],
          'frillernes': [('frille', True)],
          'fringer': [('fring', False)],
          'fringerne': [('fring', False)],
          'fringernes': [('fring', False)],
          'fringers': [('fring', False)],
          'fris': [('fri', False)],
          'frisen': [('frise', True)],
          'frisens': [('frise', True)],
          'friser': [('friser', True), ('frise', True)],
          'friserne': [('frise', True), ('friser', True)],
          'frisernes': [('friser', True), ('frise', True)],
          'frisers': [('friser', True), ('frise', True)],
          'frister': [('frister', True), ('frist', True)],
          'fristerne': [('frister', True), ('frist', True)],
          'fristernes': [('frister', True), ('frist', True)],
          'fristers': [('frist', True), ('frister', True)],
          'friten': [('frite', False)],
          'fritens': [('frite', False)],
          'fritten': [('fritte', True)],
          'frittens': [('fritte', True)],
          'fritter': [('fritte', True)],
          'fritterne': [('fritte', True)],
          'fritternes': [('fritte', True)],
          'fritters': [('fritte', True)],
          'fromager': [('fromage', False)],
          'fromagerne': [('fromage', True)],
          'fromagers': [('fromage', True)],
          'fronter': [('front', False)],
          'froschen': [('frosch', True)],
          'froschens': [('frosch', True)],
          'froscherne': [('frosch', True)],
          'fruen': [('frue', False)],
          'fruens': [('frue', False)],
          'fruer': [('frue', False)],
          'fruerne': [('frue', True)],
          'fruernes': [('frue', False)],
          'fruers': [('frue', True)],
          'frus': [('fru', False)],
          'fryden': [('fryd', False)],
          'frydens': [('fryd', False)],
          'fryds': [('fryd', True)],
          'frynsen': [('frynse', True), ('fryns', True)],
          'frynsens': [('frynse', True), ('fryns', True)],
          'frynser': [('frynse', True), ('fryns', True)],
          'frynserne': [('frynse', True), ('fryns', True)],
          'frynsernes': [('frynse', True), ('fryns', True)],
          'frynsers': [('frynse', True), ('fryns', True)],
          'frys': [('frys', True)],
          'frås': [('frås', True)],
          'fråser': [('fråser', True)],
          'fråserne': [('fråser', True)],
          'fråsernes': [('fråser', True)],
          'frænder': [('frænde', False)],
          'frænderne': [('frænde', True)],
          'frændernes': [('frænde', True)],
          'fræner': [('fræn', False)],
          'frænerne': [('fræn', False)],
          'frænernes': [('fræn', False)],
          'fræners': [('fræn', False)],
          'frøret': [('frør', False)],
          'frørets': [('frør', False)],
          'fs': [('f', False)],
          "fs'": [('f', False)],
          'fset': [('fset', False)],
          'fsets': [('fset', False)],
          'fskeden': [('fsked', False)],
          'fskedens': [('fsked', False)],
          'fskeder': [('fsked', False)],
          'fskederne': [('fsked', False)],
          'fskedernes': [('fsked', False)],
          'fskeders': [('fsked', False)],
          'fskifte': [('fskifte', False)],
          'fskiftes': [('fskifte', False)],
          'fskiftet': [('fskifte', False)],
          'fskiftets': [('fskifte', False)],
          'fskos': [('fsko', False)],
          'fslags': [('fslag', False)],
          'fstabe': [('fstab', False)],
          'fstikker': [('fstikker', False)],
          'fstikkere': [('fstikker', False)],
          'fstikkeren': [('fstikker', False)],
          'fstikkeres': [('fstikker', False)],
          'fstikkerne': [('fstikker', False)],
          'fstikkernes': [('fstikker', False)],
          'fstikkers': [('fstikker', False)],
          'ftagere': [('ftager', False)],
          'ftageren': [('ftager', False)],
          'ftagerens': [('ftager', False)],
          'ftageres': [('ftager', False)],
          'ftaler': [('ftale', False)],
          'ftalerne': [('ftale', False)],
          'ftalernes': [('ftale', False)],
          'ftalers': [('ftale', False)],
          'ftan': [('ftan', False)],
          'ftanen': [('ftan', False)],
          'ftaner': [('ftan', False)],
          'ftaners': [('ftan', False)],
          'ftanke': [('ftank', False)],
          'ftanken': [('ftank', False)],
          'ftankens': [('ftank', False)],
          'ftankes': [('ftank', False)],
          'ftans': [('ftan', False)],
          'ftarternes': [('ftart', False)],
          'ftarters': [('ftart', False)],
          'ftas': [('fta', False)],
          'fte': [('ft', False)],
          'ftefaderen': [('ftefader', False)],
          'ftefaderens': [('ftefader', False)],
          'ftefædrene': [('ftefader', False)],
          'ftefædres': [('ftefader', False)],
          'ften': [('ft', False)],
          'ftene': [('ft', False)],
          'ftener': [('ften', False)],
          'ftenerne': [('ften', False)],
          'fteners': [('ften', False)],
          'ftenes': [('ft', False)],
          'ftens': [('ft', False)],
          'fterne': [('ft', False)],
          'fternes': [('ft', False)],
          'fterrets': [('fterret', False)],
          'fters': [('ft', False)],
          'ftes': [('ft', False)],
          "ftes'": [('ftes', False)],
          'ftet': [('ft', False)],
          'ftets': [('ft', False)],
          'fticene': [('ftice', False)],
          'fticenes': [('ftice', False)],
          'ftier': [('fti', False)],
          'ftierne': [('fti', False)],
          'ftiernes': [('fti', False)],
          'ftiers': [('fti', False)],
          'ftis': [('fti', False)],
          'ftnerne': [('ften', False)],
          'ftningen': [('ftning', False)],
          'ftninger': [('ftning', False)],
          'ftningerne': [('ftning', False)],
          'ftningernes': [('ftning', False)],
          'ftrum': [('ftrum', False)],
          'ftrums': [('ftrum', False)],
          'fts': [('ft', False)],
          'fuen': [('fu', False)],
          'fuens': [('fu', False)],
          'fuge': [('fuge', True)],
          'fugen': [('fuge', False)],
          'fugers': [('fuge', False)],
          'fuges': [('fuge', True)],
          'fugle': [('fugl', False)],
          'fuglen': [('fugl', False)],
          'fuglens': [('fugl', False)],
          'fugles': [('fugl', False)],
          'fugters': [('fugter', False)],
          'fuks': [('fuks', True)],
          'fukserne': [('fuks', True)],
          'fuksernes': [('fuks', True)],
          'fuksers': [('fuks', True)],
          'fulde': [('fuld', False)],
          'fuldes': [('fuld', False)],
          'fulosen': [('fulose', False)],
          'fulosens': [('fulose', False)],
          'fumen': [('fume', False)],
          'fumens': [('fume', False)],
          'funken': [('funk', True), ('funke', True)],
          'funkens': [('funke', True), ('funk', True)],
          'funker': [('funke', True)],
          'funkernes': [('funke', True)],
          'funkers': [('funke', True)],
          'fuppen': [('fup', True)],
          'fuppens': [('fup', True)],
          'fupperne': [('fup', True)],
          'fuppers': [('fup', True)],
          'fure': [('fure', False)],
          'furen': [('fure', False)],
          'furens': [('fure', True)],
          'furer': [('fure', False)],
          'furerne': [('fure', True)],
          'furernes': [('fure', True)],
          'furers': [('fure', True)],
          'fures': [('fure', False)],
          'furet': [('fur', False)],
          'furets': [('fur', False)],
          'furiers': [('furie', True)],
          'furs': [('fur', False)],
          'furter': [('furter', False)],
          'furterne': [('furter', False)],
          'furternes': [('furter', False)],
          'furters': [('furter', False)],
          'fus': [('fu', False)],
          'fusen': [('fusen', True)],
          'fuserne': [('fuser', True)],
          'fusker': [('fusker', True)],
          'fuskerne': [('fusker', True)],
          'fuslen': [('fusel', True)],
          'fussen': [('fus', False)],
          'fussens': [('fus', False)],
          'fusser': [('fus', False)],
          'fusserne': [('fus', False)],
          'fustage': [('fustage', True)],
          'futagen': [('futage', False)],
          'future': [('future', True)],
          'fvejen': [('fvej', False)],
          'fvikler': [('fvikler', False)],
          'fviklerne': [('fvikler', False)],
          'fviklernes': [('fvikler', False)],
          'fviklers': [('fvikler', False)],
          'fylden': [('fylde', True), ('fyld', True)],
          'fyldens': [('fylde', True), ('fyld', True)],
          'fylderne': [('fylde', False)],
          'fyldernes': [('fylde', False)],
          'fyrerne': [('fyr', False)],
          'fyrernes': [('fyr', False)],
          'fyres': [('fyr', True)],
          'fysen': [('fyse', False)],
          'fysens': [('fyse', False)],
          'fyser': [('fyse', False)],
          'fyserne': [('fyse', False)],
          'fysernes': [('fyse', False)],
          'fytten': [('fyt', False)],
          'fyttens': [('fyt', False)],
          'fytternes': [('fyt', False)],
          'fytters': [('fyt', False)],
          'fædre': [('far', True)],
          'fædrene': [('far', True)],
          'fædrenes': [('far', True)],
          'fædres': [('far', False)],
          'fæer': [('fæ', False)],
          'fæerne': [('fæ', False)],
          'fæernes': [('fæ', False)],
          'fæers': [('fæ', False)],
          'fæet': [('fæ', False)],
          'fæets': [('fæ', False)],
          'fægters': [('fægter', False)],
          'fældene': [('fælde', False)],
          'fælderne': [('fælde', False)],
          'fældernes': [('fælde', False)],
          'fællens': [('fælle', False)],
          'fællerne': [('fælle', False)],
          'fællernes': [('fælle', False)],
          'fængernes': [('fænger', False)],
          'fængers': [('fænger', False)],
          'færden': [('færden', True), ('færd', True)],
          'færdens': [('færden', True), ('færd', True)],
          'færderne': [('færd', False)],
          'færders': [('færd', False)],
          'færdet': [('færd', False)],
          'færdets': [('færd', False)],
          'fære': [('fære', False)],
          'færen': [('fære', False)],
          'færens': [('fære', False)],
          'færer': [('fære', False)],
          'færerne': [('fære', False)],
          'færernes': [('fære', False)],
          'færers': [('fære', False)],
          'færgens': [('færge', False)],
          'færten': [('fært', True)],
          'fæs': [('fæ', False)],
          'fæster': [('fæster', True), ('fæste', True)],
          'fæsterne': [('fæster', True), ('fæste', True)],
          'fæsternes': [('fæster', True), ('fæste', True)],
          'fæsters': [('fæste', True), ('fæster', True)],
          'fæstet': [('fæste', False)],
          'fæstets': [('fæste', False)],
          'fætter': [('fætter', False)],
          'fætters': [('fætter', False)],
          'fødder': [('fod', True)],
          'føden': [('føde', True)],
          'fødens': [('føde', False)],
          'føder': [('føder', False)],
          'føderne': [('føder', False)],
          'fødernes': [('føder', False)],
          'føders': [('føder', False)],
          'føjes': [('føje', True)],
          'følger': [('følger', True), ('følge', True)],
          'følgerne': [('følge', True), ('følger', True)],
          'følgernes': [('følge', True), ('følger', True)],
          'følgers': [('følger', True), ('følge', True)],
          'fønerne': [('føn', True)],
          'føners': [('føn', True)],
          'føre': [('føre', True)],
          'føren': [('før', False)],
          'førens': [('før', False)],
          'fører': [('fører', False)],
          'førerne': [('fører', True)],
          'førernes': [('fører', False)],
          'førers': [('fører', False)],
          'føres': [('føre', False)],
          'føret': [('føre', False)],
          'førets': [('føre', False)],
          'førne': [('førne', True)],
          'førnen': [('førne', True), ('førn', True)],
          'førnens': [('førne', True), ('førn', True)],
          'førnes': [('førne', True)],
          'førstningen': [('førstningen', True)],
          'g': [('g', True)],
          "g'er": [('g', True)],
          "g'erne": [('g', True)],
          "g'ernes": [('g', True)],
          "g'ers": [('g', True)],
          'g.': [('gram', True)],
          'ga': [('ga', False)],
          'gabe': [('gabe', False)],
          'gaben': [('gabe', False)],
          'gabens': [('gabe', False)],
          'gaberne': [('gabe', False)],
          'gabernes': [('gabe', False)],
          'gabers': [('gabe', False)],
          'gabes': [('gabe', False)],
          'gabet': [('gab', True)],
          'gabs': [('gab', False)],
          'gade': [('gade', False)],
          'gaden': [('gade', False)],
          'gadens': [('gade', False)],
          'gader': [('gade', True)],
          'gaderer': [('gader', False)],
          'gaderers': [('gader', False)],
          'gaderne': [('gade', False)],
          'gaders': [('gade', True)],
          'gades': [('gade', False)],
          'gadget': [('gadget', True)],
          'gadgets': [('gadget', True)],
          'gaen': [('ga', False)],
          'gaens': [('ga', False)],
          'gaer': [('ga', False)],
          'gaerne': [('ga', False)],
          'gaernes': [('ga', False)],
          'gaers': [('ga', False)],
          'gaffen': [('gaf', True)],
          'gaffer': [('gaf', True)],
          'gaffernes': [('gaf', True)],
          'gaffers': [('gaf', True)],
          'gaflen': [('gaffel', False)],
          'gaflens': [('gaffel', False)],
          'gafler': [('gaffel', False)],
          'gaflerne': [('gaffel', False)],
          'gaflernes': [('gaffel', False)],
          'gaflers': [('gaffel', False)],
          'gage': [('gage', False)],
          'gagen': [('gage', False)],
          'gagens': [('gage', False)],
          'gager': [('gage', True)],
          'gagers': [('gage', True)],
          'gages': [('gage', True)],
          'gaks': [('gak', True)],
          'galaner': [('galan', True)],
          'galanerne': [('galan', True)],
          'galanernes': [('galan', True)],
          'gale': [('gal', False)],
          'galen': [('gal', False)],
          'galene': [('gal', False)],
          'galenes': [('gal', True)],
          'galens': [('gal', False)],
          'galeoner': [('galeon', True)],
          'galeonerne': [('galeon', True)],
          'galeonernes': [('galeon', True)],
          'galeoners': [('galeon', True)],
          'gales': [('gale', False)],
          'galet': [('gal', True)],
          'galets': [('gal', True)],
          'galien': [('gali', False)],
          'galiens': [('gali', False)],
          'galiernes': [('galier', False)],
          'galis': [('gali', False)],
          'gallens': [('galle', True)],
          'galler': [('galler', True), ('galle', True)],
          'gallerne': [('galle', True), ('galler', True)],
          'gallernes': [('galle', True), ('galler', True)],
          'gallers': [('galle', True), ('galler', True)],
          'galte': [('galt', True)],
          'galtes': [('galt', True)],
          'gamben': [('gambe', True)],
          'gambens': [('gambe', True)],
          'gambler': [('gambler', True)],
          'gamblerne': [('gambler', True)],
          'gamblernes': [('gambler', True)],
          'gamblers': [('gambler', True)],
          'gamen': [('gam', False)],
          'gamenes': [('game', True)],
          'gamens': [('gam', False)],
          'gamenter': [('gament', False)],
          'gamenterne': [('gament', False)],
          'gamentet': [('gament', False)],
          'gamentets': [('gament', False)],
          'gamers': [('gam', False)],
          'gamet': [('game', True), ('gamet', True)],
          'gameter': [('gamet', True)],
          'gameters': [('gamet', True)],
          'gamets': [('game', True), ('gamet', True)],
          'gammen': [('gammen', True)],
          'gammens': [('gammen', True)],
          'gana': [('gana', False)],
          'ganden': [('gand', False)],
          'gandens': [('gand', False)],
          'gander': [('gander', False)],
          'ganen': [('gane', True)],
          'ganens': [('gane', True)],
          'ganer': [('gane', True)],
          'ganerne': [('gane', True)],
          'ganernes': [('gane', True)],
          'ganers': [('gane', True)],
          'ganes': [('gane', True)],
          'gange': [('gang', False)],
          'gangen': [('gang', False)],
          'gangens': [('gang', False)],
          'gangerne': [('ganger', True)],
          'ganges': [('gang', False)],
          'ganister': [('ganist', False)],
          'ganisters': [('ganist', False)],
          'ganten': [('gant', False)],
          'gantens': [('gant', False)],
          'ganterne': [('gant', False)],
          'ganternes': [('gant', False)],
          'ganters': [('gant', False)],
          'gantier': [('gantier', False)],
          'gantiers': [('gantier', False)],
          'gantinerne': [('gantine', False)],
          'gantiners': [('gantine', False)],
          'gants': [('gant', False)],
          'garbejder': [('garbejder', False)],
          'garbejderne': [('garbejder', False)],
          'garbejdernes': [('garbejde', False)],
          'garbejders': [('garbejder', False)],
          'garden': [('garde', False)],
          'gardens': [('garde', False)],
          'garder': [('garder', True), ('garde', True)],
          'garderne': [('garder', True), ('garde', True)],
          'gardernes': [('garder', True), ('garde', True)],
          'garders': [('garder', True), ('garde', True)],
          'gardiner': [('gardin', False)],
          'gardinernes': [('gardin', False)],
          'gardinet': [('gardin', True)],
          'gardinets': [('gardin', False)],
          'garer': [('garer', False)],
          'garerne': [('gar', False)],
          'garernes': [('garer', False)],
          'garers': [('gar', False)],
          'garet': [('garet', False)],
          'garets': [('garet', False)],
          'garinen': [('garine', False)],
          'garinens': [('garine', False)],
          'garinerne': [('garine', False)],
          'garinernes': [('garine', False)],
          'garker': [('gark', False)],
          'garkerne': [('gark', False)],
          'garme': [('garm', False)],
          'garmens': [('garm', False)],
          'garmes': [('garm', False)],
          'garner': [('garn', False)],
          'garnerne': [('garn', False)],
          'garnernes': [('garn', False)],
          'garners': [('garn', False)],
          'garten': [('gart', False)],
          'garter': [('gart', False)],
          'garterne': [('gart', False)],
          'garver': [('garver', True)],
          'garverne': [('garver', True)],
          'garvernes': [('garver', True)],
          'garvers': [('garver', True)],
          'gas': [('gas', True)],
          "gas'": [('gas', True)],
          'gase': [('gase', True)],
          'gasen': [('gase', True)],
          'gasens': [('gase', True)],
          'gaser': [('gase', True)],
          'gaserne': [('gase', True)],
          'gasernes': [('gase', True)],
          'gasers': [('gase', True)],
          'gases': [('gase', True)],
          'gasker': [('gasker', False)],
          'gaskerne': [('gasker', False)],
          'gaskernes': [('gasker', False)],
          'gaskers': [('gasker', False)],
          'gassen': [('gas', False)],
          'gassens': [('gas', False)],
          'gasser': [('gas', False)],
          'gasserne': [('gas', False)],
          'gassernes': [('gas', True)],
          'gassers': [('gas', True)],
          'gasten': [('gast', True)],
          'gastens': [('gast', False)],
          'gaster': [('gast', False)],
          'gasterne': [('gast', True)],
          'gasternes': [('gast', False)],
          'gasters': [('gast', True)],
          'gatarerne': [('gatar', False)],
          'gatarers': [('gatar', False)],
          'gatellen': [('gatel', False)],
          'gaten': [('gate', True)],
          'gatens': [('gate', True)],
          'gaternes': [('gat', False)],
          'gates': [('gate', True)],
          "gates'": [('gate', True)],
          'gatten': [('gat', False)],
          'gattens': [('gat', False)],
          'gatter': [('gat', True)],
          'gatterne': [('gat', True)],
          'gatternes': [('gat', False)],
          'gatters': [('gat', True)],
          'gave': [('gave', False)],
          'gaven': [('gave', False)],
          'gavens': [('gave', False)],
          'gaver': [('gave', False)],
          'gaverne': [('gave', True)],
          'gavernes': [('gave', False)],
          'gavers': [('gave', False)],
          'gaves': [('gave', False)],
          'gavle': [('gavl', False)],
          'gavlen': [('gavl', False)],
          'gavlene': [('gavl', True)],
          'gavlenes': [('gavl', False)],
          'gavlens': [('gavl', False)],
          'gavlers': [('gavler', False)],
          'gavles': [('gavl', False)],
          'gazerne': [('gaze', True)],
          'gazernes': [('gaze', True)],
          'gbas': [('gbas', False)],
          'gbassen': [('gbas', False)],
          'gbassens': [('gbas', False)],
          'gbirkes': [('gbirk', False)],
          'gboer': [('gbo', False)],
          'gboerne': [('gbo', False)],
          'gboernes': [('gbo', False)],
          'gboers': [('gbo', False)],
          'gbomber': [('gbombe', False)],
          'gbomberne': [('gbombe', False)],
          'gbombernes': [('gbombe', False)],
          'gbombers': [('gbombe', False)],
          'gboret': [('gbor', False)],
          'gborets': [('gbor', False)],
          'gbroder': [('gbroder', False)],
          'gbroderen': [('gbror', False)],
          'gbroderens': [('gbror', False)],
          'gbroders': [('gbroder', False)],
          'gbroer': [('gbro', False)],
          'gbroers': [('gbro', False)],
          'gbrokken': [('gbrok', False)],
          'gbrokkens': [('gbrok', False)],
          'gbrugs': [('gbrug', False)],
          'gbrødens': [('gbrøde', False)],
          'gbrødre': [('gbroder', False)],
          'gbrødrene': [('gbroder', False)],
          'gbrødrenes': [('gbroder', False)],
          'gbrødres': [('gbroder', False)],
          'gbønnen': [('gbønne', False)],
          'gbønnens': [('gbønne', False)],
          'gbønner': [('gbønne', False)],
          'gbønnerne': [('gbønne', False)],
          'gbønnernes': [('gbønne', False)],
          'gbønners': [('gbønne', False)],
          'gcellen': [('gcelle', False)],
          'gceller': [('gcelle', False)],
          'gcellers': [('gcelle', False)],
          'gcenter': [('gcenter', False)],
          'gcenters': [('gcenter', False)],
          'gcentre': [('gcenter', False)],
          'gcentrene': [('gcenter', False)],
          'gcentrenes': [('gcenter', False)],
          'gcentres': [('gcenter', False)],
          'gcentret': [('gcenter', False)],
          'gcentrets': [('gcenter', False)],
          'gd': [('gd', False)],
          'gdage': [('gdag', False)],
          'gdagene': [('gdag', False)],
          'gdagenes': [('gdag', False)],
          'gdages': [('gdag', False)],
          'gdelene': [('gdel', False)],
          'gden': [('gd', False)],
          'gdene': [('gd', False)],
          'gdenes': [('gd', False)],
          'gdens': [('gd', False)],
          'gder': [('gde', False)],
          'gderne': [('gde', False)],
          'gdernes': [('gd', False)],
          'gders': [('gd', False)],
          'gdes': [('gde', False)],
          'gdet': [('gd', False)],
          'gdets': [('gd', False)],
          'gdomme': [('gdom', False)],
          'gdriver': [('gdriver', False)],
          'gdriverne': [('gdriver', False)],
          'gdrivernes': [('gdriver', False)],
          'gdrivers': [('gdriver', False)],
          'gds': [('gd', False)],
          'gduerne': [('gdue', False)],
          'gduers': [('gdue', False)],
          'gdækker': [('gdækker', False)],
          'gdækkerne': [('gdækker', False)],
          'gdækkernes': [('gdækker', False)],
          'gdækkers': [('gdækker', False)],
          'gdækket': [('gdæk', False)],
          'gdækkets': [('gdæk', False)],
          'gdømmer': [('gdømme', False)],
          'gdømmerne': [('gdømme', False)],
          'ge': [('ge', False)],
          'geader': [('geade', False)],
          'geadernes': [('geade', False)],
          'gearskifter': [('gearskifter', True), ('gearskifte', True)],
          'gearskifterne': [('gearskifter', True), ('gearskifte', True)],
          'gearskifternes': [('gearskifte', True), ('gearskifter', True)],
          'gearskifters': [('gearskifter', True), ('gearskifte', True)],
          'geaske': [('geask', False)],
          'geaskens': [('geask', False)],
          'gebakker': [('gebakke', False)],
          'gebakkernes': [('gebakke', False)],
          'gebakkers': [('gebakke', False)],
          'gebanken': [('gebanke', False)],
          'gebankens': [('gebanke', False)],
          'gebankerne': [('gebanke', False)],
          'gebankernes': [('gebanke', False)],
          'gebens': [('geben', False)],
          'gebet': [('gebet', True)],
          'gebets': [('gebet', True)],
          'gebirkes': [('gebirk', False)],
          'geboer': [('gebo', False)],
          'geboerne': [('gebo', False)],
          'geboers': [('gebo', False)],
          'gebroderens': [('gebror', False)],
          'gebroerne': [('gebro', False)],
          'gebroernes': [('gebro', False)],
          'gebrødre': [('gebror', False)],
          'gebrødrene': [('gebror', False)],
          'gebrødrenes': [('gebror', False)],
          'gebrødres': [('gebror', False)],
          'gebuks': [('gebuks', False)],
          'gedagens': [('gedag', False)],
          'gedans': [('gedans', False)],
          'gedder': [('gedde', True)],
          'gedderne': [('gedde', True)],
          'geddernes': [('gedde', True)],
          'gedders': [('gedde', True)],
          'geden': [('ged', False)],
          'gedens': [('ged', False)],
          'gedisen': [('gedis', False)],
          'gedisens': [('gedis', False)],
          'gedrets': [('gedret', False)],
          'gedømmernes': [('gedømme', False)],
          'gedømmers': [('gedømme', False)],
          'gefinger': [('gefinger', False)],
          'gefingers': [('gefinger', False)],
          'gegaver': [('gegave', False)],
          'gegaverne': [('gegave', False)],
          'gegavernes': [('gegave', False)],
          'gegavers': [('gegave', False)],
          'gegrevers': [('gegreve', False)],
          'gejlen': [('gejl', False)],
          'gejlens': [('gejl', False)],
          'gejser': [('gejser', True)],
          'gejserne': [('gejser', True)],
          'gejsernes': [('gejser', True)],
          'gekors': [('gekors', False)],
          'gekunsterne': [('gekunst', False)],
          'gekunsters': [('gekunst', False)],
          'gelerne': [('gel', False)],
          'gelets': [('gel', False)],
          'gelier': [('gelie', False)],
          'gelierne': [('gelie', False)],
          'geliers': [('gelie', False)],
          'gelisten': [('gelist', False)],
          'gelistens': [('gelist', False)],
          'gelister': [('gelist', False)],
          'gelisterne': [('gelist', False)],
          'gelisternes': [('geliste', False)],
          'gelisters': [('geliste', False)],
          'gelium': [('gelie', False)],
          'geliums': [('gelie', False)],
          'gels': [('gel', True)],
          "gels'": [('gels', False)],
          'gelsers': [('gelse', False)],
          'gelænder': [('gelænder', True)],
          'gelænderne': [('gelænder', False)],
          'gelændernes': [('gelænder', True)],
          'gelænders': [('gelænder', False)],
          'gemagerne': [('gemager', False)],
          'gemagernes': [('gemager', False)],
          'gemagers': [('gemager', False)],
          'gemanden': [('gemand', False)],
          'gemandens': [('gemand', False)],
          'gemarchen': [('gemarch', False)],
          'gemarcher': [('gemarch', False)],
          'gemarchernes': [('gemarch', False)],
          'gemer': [('geme', False)],
          'gemerne': [('geme', False)],
          'gemernes': [('geme', False)],
          'gemers': [('geme', False)],
          'gemet': [('geme', False)],
          'gemets': [('geme', False)],
          'gemmen': [('gemme', True)],
          'gemmens': [('gemme', True)],
          'gemmer': [('gemme', True)],
          'gemmerne': [('gemme', True)],
          'gemmernes': [('gemme', True)],
          'gemmers': [('gemme', True)],
          'gemmet': [('gemme', True)],
          'gemmets': [('gemme', True)],
          'gemoden': [('gemode', False)],
          'gemodens': [('gemode', False)],
          'gemoder': [('gemor', False)],
          'gemoders': [('gemode', False)],
          'gemærker': [('gemærke', False)],
          'gen': [('gen', True)],
          'gender': [('gende', False)],
          'genderne': [('gende', False)],
          'gendernes': [('gende', False)],
          'gene': [('gene', True)],
          'genen': [('gene', True)],
          'genens': [('gene', True)],
          'gener': [('gene', True), ('gen', True)],
          'generne': [('gene', True), ('gen', True)],
          'genernes': [('gene', True), ('gen', True)],
          'geners': [('gene', True), ('gen', True)],
          'genes': [('gene', True)],
          'geneser': [('genese', False)],
          'geneserne': [('genese', False)],
          'genesernes': [('genese', False)],
          'genet': [('gen', True)],
          'genets': [('gen', True)],
          'genier': [('genius', True), ('geni', True)],
          'genierne': [('genius', True), ('geni', True)],
          'geniernes': [('genius', True), ('geni', True)],
          'geniers': [('genius', True), ('geni', True)],
          'geniet': [('geni', True)],
          'geniets': [('geni', True)],
          'genis': [('geni', False)],
          'gens': [('gen', False)],
          "gens'": [('gens', False)],
          'gensen': [('gens', False)],
          'gensens': [('gens', False)],
          'genser': [('genser', True)],
          'genserne': [('genser', False)],
          'gensernes': [('genser', True)],
          'gensers': [('genser', True)],
          'gensianer': [('gensianer', False)],
          'gensianerne': [('gensianer', False)],
          'gensianernes': [('gensianer', False)],
          'gensianers': [('gensianer', False)],
          'genten': [('gent', False)],
          'gentens': [('gent', False)],
          'genter': [('gent', False)],
          'genterne': [('gent', False)],
          'genternes': [('gent', False)],
          'genters': [('gent', False)],
          'gentet': [('gent', False)],
          'gentets': [('gent', False)],
          'gentiner': [('gentiner', False)],
          'gentinerne': [('gentiner', False)],
          'gentinernes': [('gentiner', False)],
          'gentiners': [('gentiner', False)],
          'geomkostninger': [('geomkostning', False)],
          'geomkostningerne': [('geomkostning', False)],
          'geomkostningernes': [('geomkostning', False)],
          'geomkostningers': [('geomkostning', False)],
          'geoner': [('geon', False)],
          'geonerne': [('geon', False)],
          'geonernes': [('geon', False)],
          'geoners': [('geon', False)],
          'geplejer': [('geplejer', False)],
          'geplejerne': [('geplejer', False)],
          'geposen': [('gepose', False)],
          'geposens': [('gepose', False)],
          'geposer': [('gepose', False)],
          'geposerne': [('gepose', False)],
          'geposernes': [('gepose', False)],
          'gerarbejder': [('gerarbejder', False)],
          'gerarbejderne': [('gerarbejder', False)],
          'gerbassen': [('gerbas', False)],
          'gerbassernes': [('gerbas', False)],
          'gerbassers': [('gerbas', False)],
          'gerbørn': [('gerbørn', False)],
          'gerbørnene': [('gerbørn', False)],
          'gerbørnenes': [('gerbørn', False)],
          'gerbørns': [('gerbørn', False)],
          'gerede': [('geret', False)],
          'geredernes': [('gerede', False)],
          'geredes': [('gerede', False)],
          'gerenter': [('gerente', False)],
          'gerenters': [('gerente', False)],
          'gerer': [('gerer', False)],
          'gererne': [('gerer', False)],
          'gerers': [('gerer', False)],
          'geret': [('geret', False)],
          'gerets': [('geret', False)],
          'geretten': [('geret', False)],
          'gerettens': [('geret', False)],
          'geretterne': [('geret', False)],
          'geretternes': [('geret', False)],
          'geretters': [('geret', False)],
          'gergenser': [('gergenser', False)],
          'gergensernes': [('gergenser', False)],
          'gergis': [('ergi', False)],
          'gerianerne': [('gerianer', False)],
          'gerianernes': [('gerianer', False)],
          'gerier': [('geri', False)],
          'gerierne': [('geri', False)],
          'geriernes': [('geri', False)],
          'geriers': [('geri', False)],
          'geriet': [('geri', False)],
          'geriets': [('geri', False)],
          'geriget': [('gerige', False)],
          'gerigets': [('gerige', False)],
          'geris': [('geri', False)],
          'geritterne': [('gerit', False)],
          'gernernes': [('gern', False)],
          'gernet': [('gern', False)],
          'gernets': [('gern', False)],
          'gerret': [('gerret', False)],
          'gerser': [('gers', False)],
          'gerserne': [('gers', False)],
          'gersernes': [('gers', False)],
          'gersers': [('gers', False)],
          'gersken': [('gerske', False)],
          'gersker': [('gerske', False)],
          'gerskerne': [('gerske', False)],
          'gerskers': [('gerske', False)],
          'gerten': [('gert', False)],
          'gertens': [('gert', False)],
          'gerter': [('gert', False)],
          'gerterne': [('gert', False)],
          'gerters': [('gert', False)],
          'gerts': [('gert', False)],
          'gervanten': [('gervante', False)],
          'gervanterne': [('gervante', False)],
          'gervanternes': [('gervante', False)],
          'gervanters': [('gervante', False)],
          'ges': [('ges', True)],
          "ges'": [('ges', True)],
          'gesagernes': [('gesager', False)],
          'gesagers': [('gesager', False)],
          'gese': [('gese', False)],
          'gesen': [('gese', False)],
          'gesens': [('gese', False)],
          'geser': [('ges', False)],
          'geserne': [('ges', False)],
          'gesernes': [('ges', False)],
          'gesers': [('geser', False)],
          'geses': [('gese', False)],
          'gesidens': [('geside', False)],
          'geskifte': [('geskifte', False)],
          'geskifter': [('geskifte', False)],
          'geskifterne': [('geskifte', False)],
          'geskifternes': [('geskifte', False)],
          'geskiftes': [('geskifte', False)],
          'geskiftet': [('geskifte', False)],
          'geskiftets': [('geskifte', False)],
          'gesmækker': [('gesmæk', False)],
          'gesmækkerne': [('gesmæk', False)],
          'gesmækkernes': [('gesmæk', False)],
          'gesmækkers': [('gesmæk', False)],
          'gespids': [('gespid', False)],
          'gesser': [('ges', True)],
          'gesserne': [('ges', True)],
          'gessernes': [('ges', True)],
          'gessers': [('ges', True)],
          'gesten': [('gest', True)],
          'gestens': [('gest', True)],
          'gester': [('gest', False)],
          'gesterne': [('gest', False)],
          'gesternes': [('gest', False)],
          'gesters': [('gest', False)],
          'get': [('', False)],
          'getages': [('getage', False)],
          'getanke': [('getank', False)],
          'geter': [('get', False)],
          'geters': [('get', False)],
          'getiden': [('getid', False)],
          'getogets': [('getog', False)],
          'getonen': [('getone', False)],
          'getonens': [('getone', False)],
          'getoner': [('getone', False)],
          'getonerne': [('getone', False)],
          'getonernes': [('getone', False)],
          'getoners': [('getone', False)],
          'gets': [('', False)],
          'getter': [('gette', False)],
          'getterne': [('get', False)],
          'getternes': [('get', False)],
          'getters': [('get', False)],
          'gettet': [('get', False)],
          'gettets': [('get', False)],
          'geure': [('geur', False)],
          'geures': [('geur', False)],
          'geurets': [('geur', False)],
          'geviser': [('gevise', False)],
          'geviserne': [('gevise', False)],
          'gfarternes': [('gfart', False)],
          'gfinker': [('gfinke', False)],
          'gfinkerne': [('gfinke', False)],
          'gfinkernes': [('gfinke', False)],
          'gfinkers': [('gfinke', False)],
          'gfladen': [('gflade', False)],
          'gfladens': [('gflade', False)],
          'gflisen': [('gflise', False)],
          'gflisens': [('gflise', False)],
          'gfliser': [('gflise', False)],
          'gfliserne': [('gflise', False)],
          'gflisernes': [('gflise', False)],
          'gflisers': [('gflise', False)],
          'gfylden': [('gfylde', False)],
          'gfyldens': [('gfylde', False)],
          'gfærden': [('gfærd', False)],
          'gfærdens': [('gfærd', False)],
          'gfølger': [('gfølge', False)],
          'gfølgerne': [('gfølge', False)],
          'gfølgernes': [('gfølge', False)],
          'gfølgers': [('gfølge', False)],
          'gførerne': [('gfører', False)],
          'gg': [('gg', False)],
          'ggaen': [('ggae', False)],
          'ggaens': [('ggae', False)],
          'gganen': [('ggan', False)],
          'gganens': [('ggan', False)],
          'gganer': [('ggan', False)],
          'gganerne': [('ggan', False)],
          'gganernes': [('ggan', False)],
          'gganers': [('ggan', False)],
          'gge': [('g', False)],
          'ggelisten': [('ggeliste', False)],
          'ggelistens': [('ggeliste', False)],
          'ggelister': [('ggeliste', False)],
          'ggelisterne': [('ggeliste', False)],
          'ggen': [('g', False)],
          'ggene': [('g', False)],
          'ggenes': [('gg', False)],
          'ggenet': [('ggenet', False)],
          'ggenets': [('ggenet', False)],
          'ggens': [('g', False)],
          'ggere': [('gger', False)],
          'ggeren': [('gger', False)],
          'ggerens': [('gger', False)],
          'ggeres': [('gger', False)],
          'ggeret': [('gger', False)],
          'ggerets': [('gger', False)],
          "ggers'": [('gger', False)],
          'gges': [('g', False)],
          'ggesten': [('ggesten', False)],
          'ggestens': [('ggesten', False)],
          'ggings': [('ggings', False)],
          'ggler': [('ggler', False)],
          'gglerne': [('ggler', False)],
          'gglernes': [('ggler', False)],
          'gglers': [('ggler', False)],
          'ggrøden': [('ggrød', False)],
          'ggrødens': [('ggrød', False)],
          'ggs': [('gg', False)],
          'ggylte': [('ggylte', False)],
          'ggyltes': [('ggylte', False)],
          'ggys': [('ggy', False)],
          'ggænger': [('ggænger', False)],
          'ggængerne': [('ggænger', False)],
          'ggængernes': [('ggænger', False)],
          'ggængers': [('ggænger', False)],
          'gh': [('gh', False)],
          'ghallen': [('ghal', False)],
          'ghals': [('ghals', False)],
          'ghaner': [('ghaner', False)],
          'ghanerne': [('ghaner', False)],
          'ghanernes': [('ghaner', False)],
          'ghaners': [('ghaner', False)],
          'ghave': [('ghave', False)],
          'ghaves': [('ghave', False)],
          'gheden': [('ghed', False)],
          'ghedens': [('ghede', False)],
          'gheder': [('ghed', False)],
          'ghederne': [('ghed', False)],
          'ghedernes': [('ghed', False)],
          'gheders': [('ghed', False)],
          'ghen': [('gh', False)],
          'ghens': [('gh', False)],
          'ghinde': [('ghinde', False)],
          'ghinden': [('ghinde', False)],
          'ghindens': [('ghinde', False)],
          'ghinder': [('ghinde', False)],
          'ghinderne': [('ghinde', False)],
          'ghindernes': [('ghinde', False)],
          'ghinders': [('ghinde', False)],
          'ghindes': [('ghinde', False)],
          'ghus': [('ghus', False)],
          'ghvarren': [('ghvar', False)],
          'ghvarrens': [('ghvar', False)],
          'ghvarrer': [('ghvar', False)],
          'ghvarrerne': [('ghvar', False)],
          'ghvarrernes': [('ghvar', False)],
          'ghvarrers': [('ghvar', False)],
          'ghvirvler': [('ghvirvel', False)],
          'ghvirvlerne': [('ghvirvel', False)],
          'ghvirvlernes': [('ghvirvel', False)],
          'ghvirvlers': [('ghvirvel', False)],
          'ghylden': [('ghylde', False)],
          'ghyldens': [('ghylde', False)],
          'gi': [('gi', False)],
          'gianerne': [('gianer', False)],
          'gianernes': [('gianer', False)],
          'giater': [('giat', False)],
          'giaterne': [('giat', False)],
          'giaters': [('giat', False)],
          'gide': [('gide', False)],
          'giden': [('gide', False)],
          'gidens': [('gide', False)],
          'gider': [('gide', False)],
          'giderne': [('gide', False)],
          'gidernes': [('gide', False)],
          'giders': [('gide', False)],
          'gides': [('gide', False)],
          'gien': [('gie', True), ('gi', True)],
          'giens': [('gie', True), ('gi', True)],
          'gier': [('gie', True), ('gi', True)],
          'giere': [('gier', False)],
          'gieren': [('gier', False)],
          'gierens': [('gier', False)],
          'gieres': [('gier', False)],
          'gierne': [('gie', True), ('gi', True)],
          'giernes': [('gie', True), ('gi', True)],
          'giers': [('gie', True), ('gi', True)],
          'giets': [('gi', False)],
          'gifte': [('gift', False)],
          'giften': [('gift', False)],
          'giftens': [('gift', False)],
          'gifterne': [('gift', False)],
          'gifternes': [('gift', False)],
          'gifters': [('gift', False)],
          'giftes': [('gift', False)],
          'gige': [('gige', True)],
          'gigen': [('gige', True)],
          'gigens': [('gige', True)],
          'giger': [('gige', True)],
          'giges': [('gige', True)],
          'giggerne': [('gig', True)],
          'giggernes': [('gig', True)],
          'gigten': [('gigt', False)],
          'gigtens': [('gigt', False)],
          'gikken': [('gik', False)],
          'gikkerne': [('gik', False)],
          'gikum': [('gikum', False)],
          'gikums': [('gikum', False)],
          'gilden': [('gilde', False)],
          'gildens': [('gilde', False)],
          'gilder': [('gilde', False)],
          'gilderne': [('gilde', False)],
          'gildernes': [('gilde', True)],
          'gilders': [('gilde', False)],
          'gilier': [('gilie', False)],
          'gilierne': [('gilie', False)],
          'giliers': [('gilie', False)],
          'gime': [('gime', False)],
          'gimer': [('gime', False)],
          'gimerne': [('gime', False)],
          'gimernes': [('gime', False)],
          'gimes': [('gime', False)],
          'gimet': [('gime', False)],
          'gimets': [('gime', False)],
          'giministeriet': [('giministerie', False)],
          'gims': [('gims', False)],
          'gina': [('gina', False)],
          'ginalens': [('ginal', False)],
          'ginas': [('gina', False)],
          'ginder': [('ginde', False)],
          'ginderne': [('ginde', False)],
          'gindernes': [('ginde', False)],
          'ginders': [('ginde', False)],
          'gine': [('gine', False)],
          'ginen': [('gine', False)],
          'ginens': [('gine', False)],
          'giner': [('gine', True)],
          'ginerne': [('gine', True)],
          'ginernes': [('gine', False)],
          'giners': [('gine', True)],
          'gines': [('gine', False)],
          'gingen': [('ging', False)],
          'gingens': [('ging', False)],
          'gings': [('ging', False)],
          'ginnen': [('gin', True)],
          'ginnens': [('gin', True)],
          'ginner': [('gin', True)],
          'ginnerne': [('gin', True)],
          'ginnernes': [('gin', True)],
          'ginners': [('gin', True)],
          'gioner': [('gion', False)],
          'gionernes': [('gion', False)],
          'gioners': [('gion', False)],
          'gions': [('gion', False)],
          'gips': [('gips', True)],
          "gips'": [('gips', True)],
          'gipsen': [('gips', True)],
          'gipsens': [('gips', True)],
          'gipser': [('gipser', True)],
          'gipsernes': [('gipser', True)],
          'gipsers': [('gipser', True)],
          'gis': [('gis', True), ('gi', True)],
          'giser': [('giser', False)],
          'giserne': [('giser', False)],
          'gisernes': [('giser', False)],
          'gisers': [('giser', False)],
          'gismen': [('gisme', False)],
          'gismens': [('gisme', False)],
          'gisser': [('gis', True)],
          'gisserne': [('gis', True)],
          'gissernes': [('gis', True)],
          'gissers': [('gis', True)],
          'gisten': [('gist', False)],
          'gistens': [('gist', False)],
          'gister': [('gister', False)],
          'gisterne': [('gist', False)],
          'gisternes': [('gist', False)],
          'gisters': [('gist', False)],
          'gitrene': [('gitter', True)],
          'gitrenes': [('gitter', True)],
          'gitres': [('gitter', True)],
          'gitter': [('gitter', False)],
          'gitteret': [('gitter', False)],
          'gitterets': [('gitter', False)],
          'gium': [('gie', False)],
          'giums': [('gie', False)],
          'giver': [('giver', False)],
          'givernes': [('giver', False)],
          'gjorden': [('gjord', False)],
          'gjordens': [('gjord', False)],
          'gkagen': [('gkage', False)],
          'gkagens': [('gkage', False)],
          'gkilder': [('gkilde', False)],
          'gkilderne': [('gkilde', False)],
          'gkildernes': [('gkilde', False)],
          'gkilders': [('gkilde', False)],
          'gkisten': [('gkiste', False)],
          'gkistens': [('gkiste', False)],
          'gkisterne': [('gkiste', False)],
          'gkisternes': [('gkiste', False)],
          'gklapper': [('gklapper', False)],
          'gklapperne': [('gklap', False)],
          'gklappernes': [('gklap', False)],
          'gklappers': [('gklapper', False)],
          'gklaps': [('gklap', False)],
          'gkoders': [('gkode', False)],
          'gkoks': [('gkok', False)],
          'gkornet': [('gkorn', False)],
          'gkornets': [('gkorn', False)],
          'gkors': [('gkor', False)],
          'gkreds': [('gkreds', False)],
          'gkundens': [('gkunde', False)],
          'gkurs': [('gkurs', False)],
          'gkurser': [('gkurs', False)],
          'gkurserne': [('gkurs', False)],
          'gkursernes': [('gkurs', False)],
          'gkursers': [('gkurs', False)],
          'gkvarter': [('gkvarter', False)],
          'gkvarters': [('gkvarter', False)],
          'gkøer': [('gko', False)],
          'gkøerne': [('gko', False)],
          'gkøernes': [('gko', False)],
          'gkøers': [('gko', False)],
          'gl': [('gl', False)],
          'glader': [('glader', False)],
          'gladerne': [('glade', False)],
          'gladernes': [('glader', False)],
          'gladers': [('glade', False)],
          'glagen': [('glagen', False)],
          'glagens': [('glagen', False)],
          'glans': [('glans', True)],
          'glansen': [('glans', False)],
          'glansens': [('glans', False)],
          'glas': [('glas', False)],
          'gle': [('gl', False)],
          'glege': [('gleg', False)],
          'gleges': [('gleg', False)],
          'glemme': [('glemme', True)],
          'glemmers': [('glem', False)],
          'glen': [('gl', False)],
          'glene': [('gl', False)],
          'glenes': [('gl', False)],
          'glens': [('gle', False)],
          'glenten': [('glente', True)],
          'glentens': [('glente', True)],
          'glenter': [('glente', True)],
          'glenterne': [('glente', True)],
          'glenternes': [('glente', True)],
          'glenters': [('glente', True)],
          'gler': [('gle', False)],
          'glere': [('gler', False)],
          'gleren': [('gler', False)],
          'glerens': [('gler', False)],
          'gleres': [('gler', False)],
          'glerne': [('gle', False)],
          'glernes': [('gel', False)],
          'glers': [('gel', False)],
          'gles': [('gl', False)],
          'glesten': [('glesten', False)],
          'glet': [('gel', False)],
          'gletonen': [('gleton', False)],
          'gletonens': [('gleton', False)],
          'gletoner': [('gleton', False)],
          'gletonerne': [('gleton', False)],
          'gletonernes': [('gleton', False)],
          'gletoners': [('gleton', False)],
          'glets': [('gl', False)],
          'glias': [('glia', False)],
          'glids': [('glid', True)],
          'glier': [('glie', False)],
          'glierne': [('glie', False)],
          'gliernes': [('glie', False)],
          'gliers': [('glie', False)],
          'glies': [('glie', False)],
          'gliet': [('gliet', False)],
          'gliets': [('glie', False)],
          'glikanerne': [('glikaner', False)],
          'glikanernes': [('glikaner', False)],
          'glimmers': [('glimmer', True)],
          'gliner': [('gline', False)],
          'glinerne': [('gline', False)],
          'glinernes': [('gline', False)],
          'gliners': [('gline', False)],
          'glingers': [('gling', False)],
          'glisers': [('glise', False)],
          'glitters': [('glitter', True)],
          'glomme': [('glomme', False)],
          'glommen': [('glomme', False)],
          'glommens': [('glomme', False)],
          'glommer': [('glomme', False)],
          'glommerne': [('glomme', False)],
          'glommernes': [('glomme', False)],
          'glommers': [('glomme', False)],
          'glommes': [('glomme', False)],
          'gloppen': [('gloppe', False)],
          'gloppens': [('gloppe', False)],
          'glopper': [('gloppe', False)],
          'glos': [('glo', False)],
          'glossen': [('glosse', True)],
          'glossens': [('glosse', True)],
          'glosser': [('glosse', True)],
          'glosserne': [('glosse', True)],
          'glossernes': [('glosse', True)],
          'glossers': [('glosse', True)],
          'glotten': [('glot', False)],
          'glottens': [('glot', False)],
          'glotter': [('glot', False)],
          'glotterne': [('glot', False)],
          'glotternes': [('glot', False)],
          'glotters': [('glot', False)],
          'gls': [('gl', False)],
          'glugger': [('glug', True)],
          'gluggerne': [('glug', True)],
          'gluggernes': [('glug', True)],
          'gluggers': [('glug', True)],
          'glusens': [('glus', False)],
          'glyde': [('glyd', False)],
          'glyden': [('glyd', False)],
          'glydens': [('glyd', False)],
          'glydes': [('glyd', False)],
          'glys': [('glys', False)],
          'glås': [('glås', False)],
          'glæber': [('glæbe', False)],
          'glæbernes': [('glæbe', False)],
          'glæder': [('glæde', True)],
          'glæderne': [('glæde', False)],
          'glædernes': [('glæde', True)],
          'glæders': [('glæde', False)],
          'glænder': [('glænder', False)],
          'glænderne': [('glænder', False)],
          'glændernes': [('glænder', False)],
          'glænders': [('glænder', False)],
          'glærer': [('glærer', False)],
          'glærerne': [('glære', False)],
          'glærernes': [('glære', False)],
          'glærers': [('glærer', False)],
          'glærke': [('glærke', False)],
          'glærken': [('glærke', False)],
          'glærkens': [('glærke', False)],
          'glærkes': [('glærke', False)],
          'gløden': [('glød', True)],
          'glødens': [('glød', True)],
          'gløfterne': [('gløfte', False)],
          'gløfternes': [('gløfte', False)],
          'gløftet': [('gløfte', False)],
          'gløftets': [('gløfte', False)],
          'glører': [('glør', False)],
          'glørernes': [('glør', False)],
          'gmager': [('gmager', False)],
          'gmagerne': [('gmager', False)],
          'gmagernes': [('gmager', False)],
          'gmagers': [('gmager', False)],
          'gmarker': [('gmark', False)],
          'gmarkerne': [('gmark', False)],
          'gmarkernes': [('gmark', False)],
          'gmarkers': [('gmark', False)],
          'gmas': [('gma', False)],
          'gmasken': [('gmaske', False)],
          'gmaskens': [('gmaske', False)],
          'gmasker': [('gmaske', False)],
          'gmaskers': [('gmaske', False)],
          'gmassens': [('gmasse', False)],
          'gmejsen': [('gmejse', False)],
          'gmejsens': [('gmejse', False)],
          'gmejser': [('gmejse', False)],
          'gmejserne': [('gmejse', False)],
          'gmejsernes': [('gmejse', False)],
          'gmejsers': [('gmejse', False)],
          'gmelet': [('gmel', False)],
          'gmenter': [('gment', False)],
          'gmenterne': [('gment', False)],
          'gmenternes': [('gment', False)],
          'gmenters': [('gment', False)],
          'gmers': [('gme', False)],
          'gmet': [('gme', False)],
          'gmets': [('gme', False)],
          'gminister': [('gminister', False)],
          'gministers': [('gminister', False)],
          'gmitten': [('gmit', False)],
          'gmittens': [('gmit', False)],
          'gmitter': [('gmit', False)],
          'gmitterne': [('gmit', False)],
          'gmitternes': [('gmit', False)],
          'gmitters': [('gmit', False)],
          'gmæers': [('gmæ', False)],
          'gmænd': [('gmand', False)],
          'gmændene': [('gmand', False)],
          'gmændenes': [('gmand', False)],
          'gmænds': [('gmand', False)],
          'gmærkernes': [('gmærke', False)],
          'gmærkers': [('gmærke', False)],
          'gn': [('gn', False)],
          'gnaler': [('gnal', False)],
          'gnalerne': [('gnal', False)],
          'gnalernes': [('gnal', False)],
          'gnalers': [('gnal', False)],
          'gnalet': [('gnal', False)],
          'gnalets': [('gnal', False)],
          'gnaten': [('gnat', False)],
          'gnatens': [('gnat', False)],
          'gnater': [('gnat', False)],
          'gnaterne': [('gnat', False)],
          'gnaters': [('gnat', False)],
          'gnaver': [('gnaver', True)],
          'gnaverne': [('gnaver', False)],
          'gnavers': [('gnaver', False)],
          'gne': [('gn', False)],
          'gnejs': [('gnejs', True)],
          'gnen': [('gn', False)],
          'gnene': [('gn', False)],
          'gnenes': [('gn', False)],
          'gnens': [('gn', False)],
          'gner': [('gen', False)],
          'gnerne': [('gne', False)],
          'gnernes': [('gner', False)],
          'gners': [('gen', False)],
          'gnes': [('gn', False)],
          'gneseriers': [('gneserie', False)],
          'gnet': [('gn', False)],
          'gneterne': [('gnet', False)],
          'gneternes': [('gnet', False)],
          'gnets': [('gn', False)],
          'gnfluens': [('gnflue', False)],
          'gnier': [('gnier', False)],
          'gnierne': [('gnier', False)],
          'gniernes': [('gnier', True)],
          'gniers': [('gnier', True)],
          'gningers': [('gning', False)],
          'gnomen': [('gnome', True), ('gnom', True)],
          'gnomens': [('gnom', True), ('gnome', True)],
          'gnomer': [('gnom', True), ('gnome', True)],
          'gnomerne': [('gnom', True), ('gnome', True)],
          'gnomernes': [('gnom', True), ('gnome', True)],
          'gnomers': [('gnom', True), ('gnome', True)],
          'gnomiet': [('gnomi', False)],
          'gnonen': [('gnon', False)],
          'gnonens': [('gnon', False)],
          'gnoner': [('gnon', False)],
          'gnonerne': [('gnon', False)],
          'gnonernes': [('gnon', False)],
          'gnoners': [('gnon', False)],
          'gns': [('gn', False)],
          'gntiden': [('gntid', False)],
          'gnummer': [('gnum', False)],
          'gnummers': [('gnummer', False)],
          'gnus': [('gnu', True)],
          'gnys': [('gny', False)],
          'gnøren': [('gnør', False)],
          'gnører': [('gnør', False)],
          'gnørernes': [('gnør', False)],
          'gnørers': [('gnør', False)],
          'go': [('go', False)],
          'goders': [('gode', True)],
          'godet': [('gode', False)],
          'godets': [('gode', False)],
          'gods': [('gods', False)],
          'goen': [('go', False)],
          'goens': [('go', False)],
          'goer': [('go', False)],
          'goerne': [('go', False)],
          'goernes': [('go', False)],
          'goers': [('go', False)],
          'goet': [('go', False)],
          'goets': [('go', False)],
          'goge': [('goge', False)],
          'goges': [('goge', False)],
          'gogien': [('gogi', False)],
          'goler': [('gol', False)],
          'golerne': [('gol', False)],
          'golfen': [('golf', False)],
          'golfens': [('golf', False)],
          'golfer': [('golf', True), ('golfer', True)],
          'golferne': [('golf', True), ('golfer', True)],
          'golfernes': [('golfer', True), ('golf', True)],
          'golfers': [('golf', True), ('golfer', True)],
          'goliner': [('goliner', False)],
          'golinerne': [('goliner', False)],
          'golinernes': [('goliner', False)],
          'goliners': [('goliner', False)],
          'golos': [('golo', False)],
          'gomme': [('gom', False)],
          'gommen': [('gom', False)],
          'gommens': [('gom', False)],
          'gommer': [('gom', False)],
          'gommerne': [('gom', False)],
          'gommernes': [('gom', False)],
          'gommers': [('gom', False)],
          'gommes': [('gom', False)],
          'gongen': [('gong', True)],
          'gongens': [('gong', True)],
          'gonger': [('gong', False)],
          'gongerne': [('gong', True)],
          'gongernes': [('gong', True)],
          'gonien': [('goni', False)],
          'goniens': [('goni', False)],
          'gonier': [('gonie', False)],
          'gonierne': [('gonie', False)],
          'goniernes': [('gonie', False)],
          'goniers': [('gonie', False)],
          'gonis': [('goni', False)],
          'gonomen': [('gonom', False)],
          'gora': [('gora', False)],
          'goraner': [('goraner', False)],
          'goraners': [('goraner', False)],
          'goras': [('gora', False)],
          'gordnernes': [('gorden', False)],
          'gorien': [('gori', False)],
          'goriens': [('gori', False)],
          'gorier': [('gori', False)],
          'gorierne': [('gori', False)],
          'goriernes': [('gori', False)],
          'goris': [('gori', False)],
          'gos': [('go', False)],
          'goten': [('gote', False)],
          'gotens': [('gote', False)],
          'goter': [('goter', True)],
          'goterne': [('goter', True)],
          'goternes': [('goter', True)],
          'goters': [('goter', True)],
          'gotes': [('gote', False)],
          'gother': [('goth', True)],
          'gotherne': [('goth', True)],
          'gothernes': [('goth', True)],
          'gothers': [('goth', True)],
          'gotten': [('got', False)],
          'gottens': [('got', False)],
          'gotter': [('got', False)],
          'gotterne': [('got', False)],
          'gotternes': [('got', False)],
          'gotters': [('got', False)],
          'gotypen': [('gotype', False)],
          'gotyper': [('gotype', False)],
          'gotyperne': [('gotype', False)],
          'gouten': [('gout', False)],
          'goutens': [('gout', False)],
          'gouterne': [('gout', False)],
          'gouternes': [('gout', False)],
          'gouters': [('gout', False)],
          'gper': [('gper', False)],
          'gperens': [('gper', False)],
          'gpeter': [('gpeter', False)],
          'gpeters': [('gpeter', False)],
          'gpiber': [('gpibe', False)],
          'gpiberne': [('gpibe', False)],
          'gpibernes': [('gpibe', False)],
          'gpibers': [('gpiber', False)],
          'gpils': [('gpil', False)],
          'gplanet': [('gplanet', False)],
          'gplanets': [('gplanet', False)],
          'gplanter': [('gplante', False)],
          'gplanterne': [('gplante', False)],
          'gplanternes': [('gplante', False)],
          'gplanters': [('gplante', False)],
          'gposers': [('gpose', False)],
          'gpotens': [('gpote', False)],
          'gps': [('gps', True)],
          'grabben': [('grab', True), ('grabbe', True)],
          'grabbens': [('grabbe', True), ('grab', True)],
          'grabber': [('grabbe', True), ('grab', True)],
          'grabberne': [('grab', True), ('grabbe', True)],
          'grabbernes': [('grabbe', True), ('grab', True)],
          'grabbers': [('grabbe', True), ('grab', True)],
          'graden': [('grad', False)],
          'gradens': [('grad', False)],
          'graderne': [('grad', False)],
          'graders': [('grad', True)],
          'grads': [('grad', False)],
          'grafferne': [('graf', False)],
          'graffers': [('graf', False)],
          'gralen': [('gral', True)],
          'graler': [('gral', False)],
          'gralerne': [('gral', False)],
          'gralernes': [('gral', False)],
          'gralers': [('gral', False)],
          'gralet': [('gral', False)],
          'gralets': [('gral', False)],
          'grammer': [('gram', False)],
          'grammerne': [('gram', False)],
          'grammernes': [('gram', False)],
          'grammers': [('gram', False)],
          'grams': [('grams', True), ('gram', True)],
          'grande': [('grande', True)],
          'granden': [('grande', True), ('grand', True)],
          'grandens': [('grande', True), ('grand', True)],
          'grander': [('grande', True), ('grand', True)],
          'granderne': [('grande', True), ('grand', True)],
          'grandernes': [('grande', True), ('grand', True)],
          'granders': [('grande', True), ('grand', True)],
          'grandes': [('grande', True)],
          'granen': [('gran', False)],
          'graner': [('gran', False)],
          'graners': [('gran', False)],
          'granet': [('gran', False)],
          'granets': [('gran', True)],
          'grans': [('gran', False)],
          'graren': [('grar', False)],
          'grarens': [('grar', False)],
          'gras': [('gras', False)],
          'grasen': [('gras', False)],
          'grasens': [('gras', False)],
          'graser': [('gras', False)],
          'graserne': [('gras', False)],
          'grasernes': [('gras', False)],
          'grasers': [('gras', False)],
          'gratas': [('grata', False)],
          'graten': [('grat', True)],
          'gratens': [('grat', True)],
          'grater': [('grat', True)],
          'graterne': [('grat', True)],
          'graternes': [('grat', True)],
          'graters': [('grat', True)],
          'gratier': [('gratie', True)],
          'gratierne': [('gratie', True)],
          'gratiernes': [('gratie', True)],
          'gratiers': [('gratie', True)],
          'grave': [('grav', False)],
          'graven': [('grav', False)],
          'gravene': [('grav', False)],
          'gravenes': [('grav', False)],
          'gravens': [('grav', False)],
          'graver': [('graver', False)],
          'graverne': [('graver', False)],
          'gravernes': [('graver', False)],
          'gravers': [('graver', False)],
          'graves': [('grav', False)],
          'gravstikken': [('gravstikke', True), ('gravstik', True)],
          'gravstikkens': [('gravstik', True), ('gravstikke', True)],
          'gravstikker': [('gravstik', True), ('gravstikke', True)],
          'gravstikkerne': [('gravstik', True), ('gravstikke', True)],
          'gravstikkernes': [('gravstikke', True), ('gravstik', True)],
          'gravstikkers': [('gravstik', True), ('gravstikke', True)],
          'gre': [('ger', False)],
          'grebens': [('greb', True)],
          'grebs': [('greb', False)],
          'green': [('green', True)],
          'greens': [('green', True)],
          'grejer': [('grej', False)],
          'grejerne': [('grej', False)],
          'grejernes': [('grej', False)],
          'grejers': [('grej', False)],
          'grejet': [('grej', False)],
          'grejets': [('grej', False)],
          'grejser': [('grejse', False)],
          'grelser': [('grelse', False)],
          'grelserne': [('grelse', False)],
          'grelsernes': [('grelse', False)],
          'gren': [('gren', False)],
          'grenaders': [('grenader', True)],
          'grendens': [('grende', False)],
          'grenderne': [('grende', False)],
          'grene': [('gren', False)],
          'grenen': [('gren', False)],
          'grenes': [('gren', False)],
          'grens': [('gren', False)],
          'greolens': [('greol', False)],
          'greolerne': [('greol', False)],
          'grer': [('grer', False)],
          'grerne': [('grer', False)],
          'grernes': [('grer', False)],
          "gres'": [('gres', False)],
          'gressen': [('gres', False)],
          'gressens': [('gres', False)],
          'gresser': [('gres', False)],
          'gresserne': [('gres', False)],
          'gret': [('ger', False)],
          'grets': [('ger', False)],
          'gretter': [('gret', False)],
          'grever': [('greve', True)],
          'greverne': [('greve', True)],
          'grevernes': [('greve', True)],
          'grevers': [('greve', True)],
          'grias': [('gria', False)],
          'gribbe': [('grib', False)],
          'gribben': [('grib', False)],
          'gribbens': [('grib', True)],
          'gribbes': [('grib', False)],
          'gribers': [('griber', True)],
          'gribs': [('grib', False)],
          'griden': [('grid', False)],
          'gridens': [('grid', False)],
          'grider': [('grid', False)],
          'griderne': [('grid', False)],
          'gridernes': [('grider', False)],
          'griders': [('grid', False)],
          'grids': [('grid', False)],
          'grille': [('grille', True)],
          'grillen': [('grille', True), ('grill', True)],
          'grillens': [('grille', True), ('grill', True)],
          'griller': [('grille', True), ('grill', True)],
          'grillerne': [('grille', True), ('grill', True)],
          'grillernes': [('grille', True), ('grill', True)],
          'grillers': [('grille', True), ('grill', True)],
          'grimassens': [('grimasse', True)],
          'grimasserne': [('grimasse', True)],
          'grimen': [('grime', True)],
          'grimens': [('grime', True)],
          'grimers': [('grime', True)],
          'grinder': [('grind', True)],
          'grinderne': [('grind', True)],
          'grindernes': [('grind', True)],
          'grinders': [('grind', True)],
          'griner': [('griner', False)],
          'griners': [('griner', False)],
          'grinet': [('grin', True)],
          'grinets': [('grin', False)],
          'gringer': [('gring', False)],
          'gringerne': [('gring', False)],
          'gringernes': [('gring', False)],
          'gringers': [('gring', False)],
          'grins': [('grin', False)],
          'gripper': [('grip', True)],
          'gripperne': [('grip', True)],
          'gris': [('gris', False)],
          'grise': [('gris', True)],
          'grisen': [('gris', False)],
          'grises': [('gris', False)],
          'grister': [('grist', False)],
          'gristerne': [('grist', False)],
          'gristernes': [('grist', False)],
          'gristers': [('grist', False)],
          'groden': [('grod', False)],
          'grodens': [('grod', False)],
          'grods': [('grod', False)],
          'groen': [('gro', False)],
          'groens': [('gro', False)],
          'groer': [('gro', False)],
          'groerne': [('gro', False)],
          'groernes': [('gro', False)],
          'groers': [('gro', False)],
          'gromer': [('grom', False)],
          'gromerne': [('grom', False)],
          'gromernes': [('grom', False)],
          'gromers': [('grom', False)],
          'gronomens': [('gronom', False)],
          'gros': [('gros', True)],
          'grosen': [('grose', False)],
          'grosens': [('grose', False)],
          'grossene': [('gros', True)],
          'grossenes': [('gros', True)],
          'grotesken': [('groteske', True), ('grotesk', True)],
          'groteskens': [('grotesk', True), ('groteske', True)],
          'grotesker': [('groteske', True), ('grotesk', True)],
          'groteskerne': [('groteske', True), ('grotesk', True)],
          'groteskernes': [('grotesk', True), ('groteske', True)],
          'groteskers': [('groteske', True), ('grotesk', True)],
          'grotter': [('grotte', False)],
          'grotternes': [('grotte', True)],
          'grotters': [('grotte', False)],
          'groupiers': [('groupie', True)],
          'grubber': [('grubber', True)],
          'gruben': [('grube', False)],
          'grubens': [('grube', False)],
          'gruber': [('grube', False)],
          'gruberne': [('grube', False)],
          'grubernes': [('grube', True)],
          'grubler': [('grubler', True)],
          'grublerne': [('grubler', True)],
          'grublernes': [('grubler', True)],
          'grublers': [('grubler', True)],
          'gruder': [('grude', False)],
          'gruderne': [('grude', False)],
          'grudernes': [('grude', False)],
          'gruders': [('grude', False)],
          'gruens': [('gru', True)],
          'gruks': [('gruk', True)],
          'grums': [('grums', False)],
          'grunde': [('grund', False)],
          'grunden': [('grund', False)],
          'grundens': [('grund', False)],
          'grunder': [('grunder', True)],
          'grunderne': [('grunder', True)],
          'grundernes': [('grunder', True)],
          'grunders': [('grunder', True)],
          'grundes': [('grund', False)],
          'gruppe': [('gruppe', False)],
          'gruppen': [('gruppe', False)],
          'gruppens': [('gruppe', False)],
          'grupperne': [('gruppe', False)],
          'gruppers': [('gruppe', False)],
          'grus': [('gru', True), ('grus', True)],
          'gryder': [('gryde', False)],
          'gryderne': [('gryde', False)],
          'grynen': [('gryn', False)],
          'grynens': [('gryn', False)],
          'gryner': [('gryn', False)],
          'grynernes': [('gryn', False)],
          'gryns': [('gryn', False)],
          'gråden': [('gråd', False)],
          'grådens': [('gråd', True)],
          'grådet': [('gråd', False)],
          'grænerne': [('græne', False)],
          'græners': [('græne', False)],
          'græs': [('græs', False)],
          'grøden': [('grøde', True), ('grød', True)],
          'grødens': [('grøde', True), ('grød', True)],
          'grønnen': [('grøn', False)],
          'grønnens': [('grøn', False)],
          'grønthandler': [('grønthandler', True), ('grønthandel', True)],
          'grønthandlerne': [('grønthandel', True), ('grønthandler', True)],
          'grønthandlernes': [('grønthandel', True), ('grønthandler', True)],
          'grønthandlers': [('grønthandler', True), ('grønthandel', True)],
          'grøret': [('grør', False)],
          'grørets': [('grør', False)],
          'gsaften': [('gsaften', False)],
          'gsaftens': [('gsaften', False)],
          'gsarbejder': [('gsarbejde', False)],
          'gsarbejderne': [('gsarbejde', False)],
          'gsarbejdernes': [('gsarbejde', False)],
          'gsarbejders': [('gsarbejder', False)],
          'gsbo': [('gsbo', False)],
          'gsboen': [('gsbo', False)],
          'gsboens': [('gsbo', False)],
          'gsboer': [('gsbo', False)],
          'gsboerne': [('gsbo', False)],
          'gsbos': [('gsbo', False)],
          'gsbroderens': [('gsbror', False)],
          'gsbrødre': [('gsbror', False)],
          'gsbrødrene': [('gsbror', False)],
          'gsbrødrenes': [('gsbror', False)],
          'gsbrødres': [('gsbror', False)],
          'gsbønnen': [('gsbøn', False)],
          'gsbønnerne': [('gsbøn', False)],
          'gsbønners': [('gsbøn', False)],
          'gsen': [('gs', False)],
          'gsene': [('gs', False)],
          'gsenes': [('gs', False)],
          'gsens': [('gs', False)],
          'gser': [('gs', False)],
          'gserne': [('gs', False)],
          'gsernes': [('gs', False)],
          'gsers': [('gs', False)],
          'gshandler': [('gshandel', False)],
          'gshandlerne': [('gshandler', False)],
          'gshandlernes': [('gshandler', False)],
          'gshandlers': [('gshandel', False)],
          'gskallen': [('gskalle', False)],
          'gskallens': [('gskalle', False)],
          'gskaller': [('gskalle', False)],
          'gskallerne': [('gskalle', False)],
          'gskallernes': [('gskalle', False)],
          'gskallers': [('gskalle', False)],
          'gskos': [('gsko', False)],
          'gskreds': [('gskreds', False)],
          'gskrige': [('gskrig', False)],
          'gskrigen': [('gskrig', False)],
          'gskrigens': [('gskrig', False)],
          'gskriges': [('gskrig', False)],
          'gskræfter': [('gskraft', False)],
          'gskræfterne': [('gskraft', False)],
          'gskræfters': [('gskraft', False)],
          'gskure': [('gskur', False)],
          'gskuren': [('gskur', False)],
          'gskurens': [('gskur', False)],
          'gskures': [('gskur', False)],
          'gskurs': [('gskur', False)],
          'gskytter': [('gskytte', False)],
          'gskytterne': [('gskytte', False)],
          'gslags': [('gslag', False)],
          'gslens': [('gsel', False)],
          'gsler': [('gsel', False)],
          'gslinger': [('gsling', False)],
          'gslingerne': [('gsling', False)],
          'gslingernes': [('gsling', False)],
          'gslingers': [('gsling', False)],
          'gslisten': [('gslist', False)],
          'gslistens': [('gslist', False)],
          'gsnarrens': [('gsnarre', False)],
          'gsnet': [('gsnet', False)],
          'gsnets': [('gsnet', False)],
          'gsomkostningerne': [('gsomkostning', False)],
          'gsorden': [('gsorden', False)],
          'gsordens': [('gsorden', False)],
          'gspressen': [('gspresse', False)],
          'gspresser': [('gspresser', False)],
          'gspressernes': [('gspresser', False)],
          'gsretterne': [('gsret', False)],
          'gsretternes': [('gsret', False)],
          'gsretters': [('gsret', False)],
          'gssagens': [('gssag', False)],
          'gssager': [('gssag', False)],
          'gssagerne': [('gssag', False)],
          'gssagernes': [('gssag', False)],
          'gsskifte': [('gsskift', False)],
          'gsskifter': [('gsskift', False)],
          'gsskifterne': [('gsskift', False)],
          'gsskifters': [('gsskift', False)],
          'gsskiftets': [('gsskift', False)],
          'gstager': [('gstager', False)],
          'gstagerne': [('gstager', False)],
          'gstagernes': [('gstager', False)],
          'gstagers': [('gstager', False)],
          'gstalen': [('gstale', False)],
          'gstalens': [('gstale', False)],
          'gstaler': [('gstale', False)],
          'gstalers': [('gstale', False)],
          'gstammen': [('gstamme', False)],
          'gstammens': [('gstamme', False)],
          'gstammer': [('gstamme', False)],
          'gstammerne': [('gstamme', False)],
          'gstammernes': [('gstamme', False)],
          'gstammers': [('gstamme', False)],
          'gstanke': [('gstanke', False)],
          'gstanken': [('gstanke', False)],
          'gstankens': [('gstanke', False)],
          'gstankerne': [('gstanke', False)],
          'gstankes': [('gstanke', False)],
          'gstaver': [('gstav', False)],
          'gstaverne': [('gstav', False)],
          'gstavernes': [('gstav', False)],
          'gstavers': [('gstav', False)],
          'gstemmer': [('gstemme', False)],
          'gstemmerne': [('gstemme', False)],
          'gstemmernes': [('gstemme', False)],
          'gstemmers': [('gstemme', False)],
          'gsten': [('gsten', False)],
          'gstene': [('gst', False)],
          'gstenes': [('gst', False)],
          'gstens': [('gsten', False)],
          'gster': [('gster', False)],
          'gsterne': [('gster', False)],
          'gsternes': [('gster', False)],
          'gsters': [('gster', False)],
          'gstiens': [('gsti', False)],
          'gstierne': [('gsti', False)],
          'gstiers': [('gsti', False)],
          'gstifter': [('gstift', False)],
          'gstifterne': [('gstift', False)],
          'gstifternes': [('gstift', False)],
          'gstifters': [('gstift', False)],
          'gstis': [('gsti', False)],
          'gstonen': [('gstone', False)],
          'gstonens': [('gstone', False)],
          'gstoner': [('gstone', False)],
          'gstonerne': [('gstone', False)],
          'gstonernes': [('gstone', False)],
          'gstoners': [('gstone', False)],
          'gstykkernes': [('gstykke', False)],
          'gstykkers': [('gstykke', False)],
          'gstænger': [('gstang', False)],
          'gstængerne': [('gstang', False)],
          'gstængernes': [('gstang', False)],
          'gstængers': [('gstang', False)],
          'gstævne': [('gstævn', False)],
          'gstævnes': [('gstævn', False)],
          'gsværker': [('gsværk', False)],
          'gsværkerne': [('gsværk', False)],
          'gsværkernes': [('gsværk', False)],
          'gsværkers': [('gsværk', False)],
          'gsæder': [('gsæde', False)],
          'gsæderne': [('gsæde', False)],
          'gsædernes': [('gsæde', False)],
          'gsæders': [('gsæde', False)],
          'gsætter': [('gsætter', False)],
          'gsætternes': [('gsætter', False)],
          'gsøer': [('gso', False)],
          'gsøerne': [('gso', False)],
          'gsøernes': [('gso', False)],
          'gsøers': [('gso', False)],
          'gtagen': [('gtagen', False)],
          'gtagere': [('gtager', False)],
          'gtageren': [('gtager', False)],
          'gtagerens': [('gtager', False)],
          'gtageres': [('gtager', False)],
          'gtaler': [('gtaler', False)],
          'gtalerne': [('gtaler', False)],
          'gtalernes': [('gtaler', False)],
          'gtalers': [('gtaler', False)],
          'gtanden': [('gtand', False)],
          'gtandens': [('gtand', False)],
          'gtanke': [('gtanke', False)],
          'gtanken': [('gtanke', False)],
          'gtankens': [('gtanke', False)],
          'gtanker': [('gtanke', False)],
          'gtankerne': [('gtanke', False)],
          'gtankernes': [('gtanke', False)],
          'gtankers': [('gtanke', False)],
          'gtankes': [('gtanke', False)],
          'gtarbejdernes': [('gtarbejde', False)],
          'gtarbejders': [('gtarbejde', False)],
          'gtavlen': [('gtavl', False)],
          'gtavlens': [('gtavl', False)],
          'gtavler': [('gtavler', False)],
          'gtavlerne': [('gtavler', False)],
          'gtavlernes': [('gtavler', False)],
          'gtavlers': [('gtavler', False)],
          'gtcyklens': [('gtcyklus', False)],
          'gtcykler': [('gtcyklus', False)],
          'gtcyklerne': [('gtcyklus', False)],
          'gtcyklernes': [('gtcyklus', False)],
          'gtcyklers': [('gtcyklus', False)],
          'gte': [('gt', False)],
          'gtelen': [('gtel', False)],
          'gtelens': [('gtel', False)],
          'gtemagerne': [('gtemage', False)],
          'gtemagernes': [('gtemage', False)],
          'gtemagers': [('gtemage', False)],
          'gten': [('gt', False)],
          'gtene': [('gt', False)],
          'gtenes': [('gt', False)],
          'gtens': [('gt', False)],
          'gters': [('gter', False)],
          'gtes': [('gt', False)],
          'gtet': [('gt', False)],
          'gtets': [('gt', False)],
          'gtfanger': [('gtfange', False)],
          'gtfangernes': [('gtfange', False)],
          'gtfangers': [('gtfange', False)],
          'gthandlerne': [('gthandler', False)],
          'gthandlernes': [('gthandler', False)],
          'gthaver': [('gthave', False)],
          'gthaverne': [('gthave', False)],
          'gthavernes': [('gthave', False)],
          'gthavers': [('gthave', False)],
          'gthuset': [('gthus', False)],
          'gtige': [('gtig', False)],
          'gtigen': [('gtig', False)],
          'gtigens': [('gtig', False)],
          'gtiges': [('gtig', False)],
          'gtimer': [('gtime', False)],
          'gtimerne': [('gtime', False)],
          'gtimernes': [('gtime', False)],
          'gtimers': [('gtime', False)],
          'gtlens': [('gtel', False)],
          'gtler': [('gtel', False)],
          'gtningen': [('gtning', False)],
          'gtninger': [('gtning', False)],
          'gtningerne': [('gtning', False)],
          'gtningernes': [('gtning', False)],
          'gtoffer': [('gtoffer', False)],
          'gtoffers': [('gtoffer', False)],
          'gtoget': [('gtog', False)],
          'gtraten': [('gtrate', False)],
          'gtratens': [('gtrate', False)],
          'gtrater': [('gtrate', False)],
          'gtraterne': [('gtrate', False)],
          'gtraternes': [('gtrate', False)],
          'gtraters': [('gtrate', False)],
          'gtres': [('gtres', False)],
          'gtret': [('gtret', False)],
          'gtrets': [('gtret', False)],
          'gtringens': [('gtring', False)],
          'gtropper': [('gtrop', False)],
          'gtropperne': [('gtrop', False)],
          'gtroppernes': [('gtrop', False)],
          'gtroppers': [('gtrop', False)],
          'gts': [('gt', False)],
          'gture': [('gtur', False)],
          'gturen': [('gtur', False)],
          'gturene': [('gtur', False)],
          'gturenes': [('gtur', False)],
          'gtures': [('gtur', False)],
          'gtyre': [('gtyr', False)],
          'gtænder': [('gtand', False)],
          'gtænderne': [('gtand', False)],
          'gtændernes': [('gtand', False)],
          'gtænders': [('gtand', False)],
          'gtømmer': [('gtømmer', False)],
          'gtømmers': [('gtømmer', False)],
          'guaner': [('guan', False)],
          'guanerne': [('guan', False)],
          'guanernes': [('guan', False)],
          'guaners': [('guan', False)],
          'gubben': [('gubbe', True)],
          'gubber': [('gubbe', True)],
          'gubberne': [('gubbe', True)],
          'guder': [('gud', False)],
          'gudernes': [('gud', True)],
          'guetten': [('guette', False)],
          'guettens': [('guette', False)],
          'guetterne': [('guette', False)],
          'guetternes': [('guette', False)],
          'guetters': [('guette', False)],
          'guffet': [('guf', True)],
          'gulaks': [('gulaks', True)],
          'gulens': [('gul', False)],
          'guler': [('gul', False)],
          'gulerne': [('gul', False)],
          'gulernes': [('gul', False)],
          'gulsten': [('gulsten', True)],
          'gulstens': [('gulsten', True)],
          'gummer': [('gumme', True)],
          'gummerne': [('gumme', True)],
          'gummers': [('gumme', True)],
          'gumpe': [('gump', True)],
          'gumpen': [('gump', True)],
          'gumpens': [('gump', True)],
          'gumpes': [('gump', True)],
          'gunderne': [('gunder', False)],
          'gunders': [('gunder', False)],
          'gunen': [('gune', False)],
          'gunens': [('gune', False)],
          'guner': [('gune', False)],
          'gunernes': [('gune', False)],
          'guns': [('gun', False)],
          'guret': [('gur', False)],
          'gurets': [('gur', False)],
          'gurs': [('gur', False)],
          'guruer': [('guru', False)],
          'guruerne': [('guru', False)],
          'guruernes': [('guru', True)],
          'gurus': [('guru', True)],
          'gussen': [('gus', False)],
          'gussens': [('gus', False)],
          'gusserne': [('gus', False)],
          'gusters': [('guster', False)],
          'gutten': [('gut', True)],
          'guttens': [('gut', True)],
          'gutterne': [('gut', True)],
          'gutternes': [('gut', True)],
          'gutters': [('gut', True)],
          'gvanter': [('gvante', False)],
          'gvanterne': [('gvante', False)],
          'gvanternes': [('gvante', False)],
          'gvanters': [('gvante', False)],
          'gvarers': [('gvare', False)],
          'gvejene': [('gvej', False)],
          'gvejens': [('gvej', False)],
          'gvejes': [('gvej', False)],
          'gvinen': [('gvin', False)],
          'gvinens': [('gvin', False)],
          'gvinernes': [('gvin', False)],
          'gvins': [('gvin', False)],
          'gvortes': [('gvorte', False)],
          'gyde': [('gyde', False)],
          'gyden': [('gyde', True)],
          'gydens': [('gyde', True)],
          'gyder': [('gyde', True)],
          'gyderne': [('gyde', True)],
          'gydernes': [('gyde', False)],
          'gyders': [('gyde', True)],
          'gydes': [('gyde', False)],
          'gyen': [('gy', False)],
          'gyens': [('gy', False)],
          'gyer': [('gy', False)],
          'gyerne': [('gy', False)],
          'gyernes': [('gy', False)],
          'gyers': [('gy', False)],
          'gylden': [('gylden', True)],
          'gyldens': [('gylden', True)],
          'gyllens': [('gylle', True)],
          'gylte': [('gylt', True)],
          'gylten': [('gylt', False)],
          'gyltens': [('gylt', False)],
          'gylter': [('gylt', True)],
          'gylterne': [('gylt', True)],
          'gylternes': [('gylt', False)],
          'gylters': [('gylt', False)],
          'gyltes': [('gylt', True)],
          'gynder': [('gynder', False)],
          'gynderne': [('gynder', False)],
          'gyndernes': [('gynder', False)],
          'gynders': [('gynder', False)],
          'gynerne': [('gyn', False)],
          'gyners': [('gyn', False)],
          'gyngernes': [('gynge', False)],
          'gyngers': [('gynge', True)],
          'gypter': [('gypter', False)],
          'gyros': [('gyros', True), ('gyro', True)],
          'gys': [('gys', True)],
          'gysers': [('gyser', True)],
          'gysserne': [('gysser', True)],
          'gyssernes': [('gysser', True)],
          'gyssers': [('gysser', True)],
          'gåben': [('gåben', True)],
          'gåde': [('gåde', False)],
          'gåden': [('gåde', True)],
          'gådens': [('gåde', True)],
          'gåders': [('gåde', True)],
          'gådes': [('gåde', True)],
          'gånden': [('gånd', False)],
          'gåndens': [('gånd', False)],
          'gårde': [('gård', False)],
          'gården': [('gård', False)],
          'gårdens': [('gård', False)],
          'gårdes': [('gård', False)],
          'gårs': [('gårs', False)],
          'gås': [('gås', False)],
          'gæbler': [('gæble', False)],
          'gække': [('gæk', True)],
          'gækken': [('gæk', False)],
          'gækker': [('gæk', False)],
          'gækkerne': [('gæk', False)],
          'gækkes': [('gæk', True)],
          'gælden': [('gæld', False)],
          'gældenes': [('gæld', False)],
          'gældens': [('gæld', False)],
          'gældet': [('gæld', False)],
          'gældets': [('gæld', False)],
          'gæler': [('gæler', True)],
          'gælerne': [('gæler', True)],
          'gælernes': [('gæler', True)],
          'gælers': [('gæler', True)],
          'gællens': [('gælle', True)],
          'gællerne': [('gælle', True)],
          'gællernes': [('gælle', True)],
          'gænders': [('gand', False)],
          'gænger': [('gænge', True)],
          'gængerne': [('gænge', True)],
          'gængernes': [('gænge', True)],
          'gængers': [('gænge', True)],
          'gænget': [('gæng', True)],
          'gængets': [('gæng', True)],
          'gærder': [('gærde', True)],
          'gærdernes': [('gærde', True)],
          'gære': [('gære', False)],
          'gæren': [('gær', False)],
          'gærens': [('gær', True)],
          'gærer': [('gære', False)],
          'gærerne': [('gære', False)],
          'gærernes': [('gære', False)],
          'gærers': [('gære', False)],
          'gæs': [('gås', False)],
          "gæs'": [('gås', False)],
          'gæstens': [('gæst', False)],
          'gæster': [('gæst', False)],
          'gæsterne': [('gæst', False)],
          'gæsternes': [('gæst', False)],
          'gæsters': [('gæst', False)],
          'gøen': [('gøen', True)],
          'gøens': [('gøen', True)],
          'gøgler': [('gøgler', True)],
          'gøglerne': [('gøgler', True)],
          'gøglernes': [('gøgler', True)],
          'gøglers': [('gøgler', True)],
          'gøglet': [('gøgl', True)],
          'gøglets': [('gøgl', True)],
          'gøje': [('gøje', False)],
          'gøjen': [('gøje', False)],
          'gøjens': [('gøje', False)],
          'gøjerne': [('gøje', False)],
          'gøjernes': [('gøje', False)],
          'gøjers': [('gøje', False)],
          'gøre': [('gøre', False)],
          'gøren': [('gør', False)],
          'gørene': [('gør', False)],
          'gørenes': [('gør', False)],
          'gørens': [('gør', False)],
          'gører': [('gører', False)],
          'gørerne': [('gør', False)],
          'gørernes': [('gører', False)],
          'gørers': [('gører', False)],
          'gøres': [('gøre', False)],
          'gøret': [('gør', False)],
          'gørets': [('gøre', False)],
          'gørtlerne': [('gørtler', True)],
          'gørtlernes': [('gørtler', True)],
          'gørtlers': [('gørtler', True)],
          'gøs': [('gøs', True)],
          'gøse': [('gøs', True)],
          'gøsen': [('gøs', True)],
          'gøsens': [('gøs', True)],
          'gøses': [('gøs', True)],
          'h': [('h', True)],
          "h'er": [('h', True)],
          "h'erne": [('h', False)],
          "h'ernes": [('h', True)],
          "h'ers": [('h', True)],
          'h.': [('h.', False)],
          'ha': [('ha', False)],
          'hacker': [('hacker', True)],
          'hackernes': [('hacker', True)],
          'hader': [('hader', False)],
          'haderne': [('hader', False)],
          'hadernes': [('hader', False)],
          'haders': [('hader', False)],
          'haen': [('ha', False)],
          'haens': [('ha', False)],
          'haer': [('ha', False)],
          'haerne': [('ha', False)],
          'haernes': [('ha', False)],
          'haers': [('ha', False)],
          'hage': [('hage', False)],
          'hagen': [('hage', False)],
          'hagens': [('hage', False)],
          'hager': [('hage', False)],
          'hagers': [('hage', False)],
          'hages': [('hage', False)],
          'haggen': [('hag', False)],
          'haggens': [('hag', False)],
          'haglen': [('hagel', False)],
          'haglene': [('hagl', True)],
          'haglenes': [('hagl', True)],
          'haglernes': [('hagel', False)],
          'haglers': [('hagel', False)],
          'hais': [('hai', False)],
          'haiser': [('haise', False)],
          'haisers': [('haise', False)],
          'haken': [('hake', False)],
          'hakene': [('hake', False)],
          'hakenes': [('hake', False)],
          'hakens': [('hake', False)],
          'hakes': [('hake', False)],
          "hakes'": [('hake', False)],
          'hakkens': [('hakke', True)],
          'hakker': [('hakke', True)],
          'hakkerne': [('hakke', True)],
          'hakkernes': [('hakke', True)],
          'hakkers': [('hakke', True)],
          'haks': [('hak', False)],
          'hale': [('hale', False)],
          'halen': [('hale', False)],
          'halens': [('hale', False)],
          'haler': [('hale', False)],
          'halerne': [('hale', True)],
          'halernes': [('hale', False)],
          'halers': [('hale', False)],
          'hales': [('hale', False)],
          'hallen': [('hall', True), ('hal', True)],
          'hallens': [('hall', True), ('hal', True)],
          'haller': [('hall', True), ('hal', True)],
          'hallerne': [('hall', True), ('hal', True)],
          'hallernes': [('hall', True), ('hal', True)],
          'hallers': [('hall', True), ('hal', True)],
          'halmen': [('halm', False)],
          'halmens': [('halm', False)],
          'halmpresser': [('halmpresse', True), ('halmpresser', True)],
          'halmpresserne': [('halmpresser', True), ('halmpresse', True)],
          'halmpressernes': [('halmpresser', True), ('halmpresse', True)],
          'halmpressers': [('halmpresse', True), ('halmpresser', True)],
          'haloen': [('halo', True)],
          'haloens': [('halo', True)],
          'haloer': [('halo', True)],
          'haloerne': [('halo', True)],
          'haloernes': [('halo', True)],
          'haloers': [('halo', True)],
          'halogen': [('halogen', True)],
          'hals': [('hal', True), ('hals', True)],
          "hals'": [('hals', False)],
          'halse': [('hals', False)],
          'halsen': [('hals', False)],
          'halsens': [('hals', False)],
          'halses': [('hals', False)],
          'hamaner': [('hamaner', False)],
          'hamanerne': [('haman', False)],
          'hamanernes': [('haman', False)],
          'hamaners': [('haman', False)],
          'hamler': [('hammel', True)],
          'hamlerne': [('hammel', True)],
          'hamlernes': [('hammel', True)],
          'hamlers': [('hammel', True)],
          'hamme': [('ham', True)],
          'hammen': [('ham', True)],
          'hammens': [('ham', True)],
          'hammer': [('hammer', False)],
          'hammerne': [('hammer', False)],
          'hammernes': [('hammer', False)],
          'hammers': [('hammer', False)],
          'hammes': [('ham', True)],
          'hampen': [('hamp', False)],
          'hampens': [('hamp', True)],
          'hams': [('ham', True)],
          "hams'": [('hams', False)],
          'hamse': [('hams', False)],
          'hamsen': [('hams', False)],
          'hamsens': [('hams', False)],
          'hamses': [('hams', False)],
          'handler': [('handler', True), ('handel', True)],
          'handlerne': [('handel', True), ('handler', True)],
          'handlernes': [('handel', True), ('handler', True)],
          'handlers': [('handler', True), ('handel', True)],
          'hane': [('hane', False)],
          'hanen': [('hane', True)],
          'hanens': [('hane', False)],
          'haner': [('hane', False)],
          'hanerne': [('hane', False)],
          'hanernes': [('hane', False)],
          'haners': [('hane', False)],
          'hanes': [('hane', False)],
          'hangerne': [('hanger', False)],
          'hanke': [('hank', False)],
          'hanken': [('hank', True)],
          'hankens': [('hank', True)],
          'hanker': [('hanker', False)],
          'hankerne': [('hanker', False)],
          'hankernes': [('hanker', False)],
          'hankers': [('hanker', False)],
          'hankes': [('hank', False)],
          'hanks': [('hank', False)],
          'hannen': [('han', True)],
          'hannens': [('han', False)],
          'hanner': [('han', False)],
          'hanners': [('han', True)],
          'hans': [('han', True)],
          "hans'": [('hans', False)],
          'hanse': [('hans', False)],
          'hansen': [('hans', False)],
          'hansenes': [('hans', False)],
          'hansens': [('hans', False)],
          'hanser': [('hans', False)],
          'hansernes': [('hans', False)],
          'hansers': [('hans', False)],
          'hanses': [('hans', False)],
          'haps': [('haps', True)],
          "haps'": [('haps', True)],
          'hapse': [('haps', True)],
          'hapsen': [('haps', True)],
          'hapsens': [('haps', True)],
          'hapser': [('haps', True)],
          'hapserne': [('haps', True)],
          'hapsernes': [('haps', True)],
          'hapses': [('haps', True)],
          'haren': [('hare', False)],
          'harens': [('hare', True)],
          'harer': [('hare', True)],
          'harerne': [('hare', True)],
          'harernes': [('hare', True)],
          'harers': [('hare', True)],
          'hargen': [('harge', False)],
          'hargens': [('harge', False)],
          'hargerne': [('harge', False)],
          'harges': [('harge', False)],
          'harkets': [('hark', True)],
          'harme': [('harme', False)],
          'harmen': [('harme', True)],
          'harmens': [('harme', True)],
          'harmes': [('harme', True)],
          'harmonier': [('harmonium', True), ('harmoni', True)],
          'harmonierne': [('harmonium', True), ('harmoni', True)],
          'harmoniernes': [('harmonium', True), ('harmoni', True)],
          'harmoniers': [('harmoni', True), ('harmonium', True)],
          'harpen': [('harpe', False)],
          'harpens': [('harpe', True)],
          'harpernes': [('harpe', True)],
          'harpers': [('harpe', False)],
          'harpes': [('harpe', False)],
          'harpuner': [('harpun', True), ('harpuner', True)],
          'harpuners': [('harpuner', True), ('harpun', True)],
          'harter': [('harter', False)],
          'harters': [('harter', False)],
          'harven': [('harve', True)],
          'harvens': [('harve', False)],
          'has': [('hase', True)],
          "has'": [('hase', True)],
          'hase': [('hase', True)],
          'hasen': [('hase', True)],
          'hasens': [('hase', False)],
          'haser': [('hase', True)],
          'haserne': [('hase', False)],
          'hasernes': [('hase', False)],
          'hasers': [('hase', True)],
          'hases': [('hase', True)],
          'haslens': [('hassel', True)],
          'haslerne': [('hassel', True)],
          'haslernes': [('hassel', True)],
          'haspe': [('haspe', True)],
          'haspen': [('haspe', True)],
          'haspens': [('haspe', True)],
          'haspes': [('haspe', True)],
          'hatte': [('hat', False)],
          'hatten': [('hat', False)],
          'hattens': [('hat', False)],
          'hatter': [('hatter', False)],
          'hatterne': [('hatter', False)],
          'hattes': [('hat', False)],
          'have': [('hav', True), ('have', True)],
          'haven': [('have', False)],
          'havene': [('hav', False)],
          'havenes': [('hav', True)],
          'havens': [('have', False)],
          'haver': [('have', False)],
          'haverne': [('have', False)],
          'havernes': [('have', False)],
          'havers': [('have', False)],
          'haves': [('have', True), ('hav', True)],
          'havet': [('hav', False)],
          'havets': [('hav', True)],
          'havne': [('havn', False)],
          'havnen': [('havn', True)],
          'havnens': [('havn', False)],
          'havner': [('havner', False)],
          'havnerne': [('havner', False)],
          'havnernes': [('havner', False)],
          'havners': [('havner', False)],
          'havnes': [('havn', False)],
          'havren': [('havre', False)],
          'havrens': [('havre', False)],
          'havres': [('havre', False)],
          'havsens': [('havsens', True)],
          'hbukser': [('hbukser', False)],
          'hbuksers': [('hbukser', False)],
          "hd'er": [("hd'er", True)],
          "hd'erne": [("hd'er", True)],
          "hd'ernes": [("hd'er", True)],
          "hd'ers": [("hd'er", True)],
          'he': [('he', False)],
          'headen': [('head', False)],
          'headens': [('head', False)],
          'hede': [('hede', False)],
          'heden': [('hede', False)],
          'hedens': [('hede', True)],
          'heder': [('hede', True)],
          'hederne': [('hede', True)],
          'hedernes': [('hede', False)],
          'heders': [('hede', True)],
          'hedes': [('hede', False)],
          'heglen': [('hegle', True)],
          'heglens': [('hegle', True)],
          'hegler': [('hegle', True)],
          'heglerne': [('hegle', True)],
          'hegnet': [('hegn', False)],
          'hegnets': [('hegn', False)],
          'hejrers': [('hejre', False)],
          'hejs': [('hejs', False)],
          'hejsen': [('hejs', False)],
          'hejsens': [('hejs', True)],
          'hejser': [('hejs', False)],
          'hejserne': [('hejs', False)],
          'hejsernes': [('hejs', False)],
          'hejsers': [('hejs', False)],
          'heks': [('heks', False)],
          'hele': [('hele', True)],
          'heles': [('hele', True)],
          'helflugterne': [('helflugter', True)],
          'helgen': [('helgen', False)],
          'helgens': [('helgen', False)],
          'helle': [('helle', True)],
          'hellen': [('helle', True)],
          'hellens': [('helle', True)],
          'heller': [('helle', True)],
          'hellerne': [('helle', True)],
          'hellernes': [('helle', True)],
          'hellers': [('helle', True)],
          'helles': [('helle', True)],
          'helsen': [('helsen', True)],
          'helsens': [('helsen', True)],
          'helten': [('helt', False)],
          'heltenes': [('helt', False)],
          'heltens': [('helt', False)],
          'helters': [('helter', False)],
          'hemen': [('heman', True)],
          'hemens': [('heman', True)],
          'hemer': [('heme', False)],
          'hemerne': [('heme', False)],
          'hemernes': [('heme', False)],
          'hemers': [('heme', False)],
          'hemisen': [('hemise', False)],
          'hemisens': [('hemise', False)],
          'hemiser': [('hemise', False)],
          'hemiserne': [('hemise', False)],
          'hemisernes': [('hemise', False)],
          'hems': [('hems', True)],
          "hems'": [('hems', True)],
          'hemse': [('hems', True)],
          'hemsen': [('hems', True)],
          'hemsene': [('hems', True)],
          'hemsenes': [('hems', True)],
          'hemsens': [('hems', True)],
          'hemses': [('hems', True)],
          'henden': [('hend', False)],
          'hendens': [('hend', False)],
          'hender': [('hend', False)],
          'henderne': [('hend', False)],
          'hendernes': [('hend', False)],
          'henders': [('hend', False)],
          'hene': [('h', False)],
          'hener': [('hener', False)],
          'henerne': [('hener', False)],
          'henernes': [('hener', False)],
          'heners': [('hener', False)],
          'henes': [('h', False)],
          'henienser': [('henienser', False)],
          'heniensernes': [('henienser', False)],
          'heniensers': [('henienser', False)],
          'henten': [('hent', False)],
          'hentens': [('hent', False)],
          'henter': [('hent', False)],
          'henterne': [('hent', False)],
          'henternes': [('henter', False)],
          'henters': [('hent', False)],
          'heraner': [('heraner', False)],
          'heraners': [('heraner', False)],
          'hermer': [('herme', True)],
          'heroen': [('hero', True), ('heros', True)],
          'heroens': [('hero', True), ('heros', True)],
          'heroer': [('heros', True), ('hero', True)],
          'heroerne': [('heros', True), ('hero', True)],
          'heroernes': [('heros', True), ('hero', True)],
          'heroers': [('heros', True), ('hero', True)],
          'heros': [('hero', True), ('heros', True)],
          'herreder': [('herred', True)],
          'herrederne': [('herred', True)],
          'herredernes': [('herred', True)],
          'herreders': [('herred', True)],
          'herren': [('herre', False)],
          'herrens': [('herre', False)],
          'herret': [('herret', False)],
          'herskernes': [('hersker', True)],
          "hes'": [('h', False)],
          'hessens': [('hesse', False)],
          'hesser': [('hesse', False)],
          'hesserne': [('hesse', False)],
          'hessernes': [('hesse', False)],
          'hessers': [('hesse', False)],
          'heste': [('hest', False)],
          'hesten': [('hest', False)],
          'hestenes': [('hest', False)],
          'hestens': [('hest', False)],
          'hestes': [('hest', False)],
          'heten': [('hete', False)],
          'hetens': [('hete', False)],
          'heter': [('hete', False)],
          'heterne': [('hete', False)],
          'heternes': [('hete', False)],
          'heters': [('hete', False)],
          'hetes': [('hete', False)],
          'hetten': [('het', False)],
          'hettens': [('het', False)],
          'hetter': [('het', False)],
          'hetterne': [('het', False)],
          'hetternes': [('het', False)],
          'hetters': [('het', False)],
          'hetæren': [('hetære', True)],
          'hetærerne': [('hetære', True)],
          'hetærernes': [('hetære', True)],
          "hf'er": [("hf'er", True)],
          "hf'erne": [("hf'er", True)],
          "hf'ernes": [("hf'er", True)],
          "hf'ers": [("hf'er", True)],
          'hh': [('højere_handelseksamen', True)],
          "hh'er": [("hh'er", True)],
          "hh'erne": [("hh'er", True)],
          "hh'ernes": [("hh'er", True)],
          "hh'ers": [("hh'er", True)],
          'hi': [('hi', False)],
          'hianerne': [('hianer', False)],
          'hianernes': [('hianer', False)],
          'hiater': [('hiat', True)],
          'hiaterne': [('hiat', True)],
          'hiaters': [('hiat', True)],
          'hicen': [('hice', False)],
          'hicens': [('hice', False)],
          'hices': [('hice', False)],
          'hien': [('hi', False)],
          'hiene': [('hi', False)],
          'hienes': [('hi', False)],
          'hiens': [('hi', False)],
          'hier': [('hi', False)],
          'hierne': [('hi', False)],
          'hiernes': [('hi', False)],
          'hiers': [('hi', True)],
          "hies'": [('hie', False)],
          'hiet': [('hi', True)],
          'hiets': [('hi', False)],
          'hikanen': [('hikane', False)],
          'hikaner': [('hikaner', False)],
          'hikanerne': [('hikane', False)],
          'hikanernes': [('hikane', False)],
          'hikaners': [('hikane', False)],
          'hiken': [('hike', True)],
          'hikens': [('hike', True)],
          'hiker': [('hike', True)],
          'hikerne': [('hike', True)],
          'hikernes': [('hike', True)],
          'hikers': [('hike', True)],
          'hikkens': [('hikke', True)],
          'hiklerne': [('hikel', False)],
          'hiklernes': [('hikel', False)],
          'hiklers': [('hikel', False)],
          'hiklet': [('hikel', False)],
          'hiklets': [('hikel', False)],
          'hilien': [('hili', False)],
          'hiliens': [('hili', False)],
          'hilier': [('hili', False)],
          'hilierne': [('hili', False)],
          'hiliernes': [('hili', False)],
          'hiliers': [('hili', False)],
          'hilis': [('hili', False)],
          'hilisten': [('hilist', False)],
          'hilistens': [('hilist', False)],
          'hilister': [('hilist', False)],
          'hilisterne': [('hilist', False)],
          'hilsnerne': [('hilsen', True)],
          'himmeriget': [('himmerig', True), ('himmerige', True)],
          'himmerigets': [('himmerig', True), ('himmerige', True)],
          'hina': [('hina', False)],
          'hinas': [('hina', False)],
          'hinde': [('hinde', True), ('hind', True)],
          'hinden': [('hinde', True), ('hind', True)],
          'hindens': [('hind', True), ('hinde', True)],
          'hinder': [('hinde', True), ('hind', True), ('hinder', True)],
          'hinderne': [('hind', True), ('hinde', True)],
          'hindernes': [('hind', True), ('hinde', True)],
          'hinders': [('hind', True), ('hinde', True)],
          'hindes': [('hinde', True), ('hind', True)],
          'hine': [('hine', False)],
          'hiner': [('hin', False)],
          'hinerne': [('hin', False)],
          'hiners': [('hin', False)],
          'hines': [('hine', False)],
          'hingen': [('hing', False)],
          'hingens': [('hing', False)],
          'hings': [('hing', False)],
          'hini': [('hini', False)],
          'hinien': [('hini', False)],
          'hiniens': [('hini', False)],
          'hinier': [('hini', False)],
          'hinierne': [('hini', False)],
          'hinis': [('hini', False)],
          'hinsten': [('hinsten', False)],
          'hinstens': [('hinsten', False)],
          'hippen': [('hip', False)],
          'hippens': [('hip', False)],
          'hippernes': [('hippe', False)],
          'hippers': [('hippe', False)],
          'hippes': [('hippe', False)],
          'hirts': [('hirt', False)],
          "hirts'": [('hirt', False)],
          'his': [('his', True), ('hi', True)],
          'hise': [('hise', False)],
          'hisene': [('hise', False)],
          'hisenes': [('hise', False)],
          'hiser': [('hise', False)],
          'hiserne': [('hise', False)],
          'hisernes': [('hise', False)],
          'hises': [('hise', False)],
          'hiskerne': [('hiskers', False)],
          'hiskernes': [('hiskers', False)],
          'hiskers': [('hiskers', False)],
          'hismen': [('hisme', False)],
          'hismens': [('hisme', False)],
          'hisser': [('his', True)],
          'hisserne': [('his', True)],
          'hissernes': [('his', True)],
          'hissers': [('his', True)],
          'histen': [('hist', False)],
          'histens': [('hist', False)],
          'hister': [('hist', False)],
          'histerne': [('hist', False)],
          'histernes': [('hist', False)],
          'histers': [('hist', False)],
          'historien': [('historie', False)],
          'historiens': [('historie', True)],
          'historier': [('historie', False)],
          'historierne': [('historie', False)],
          'historiernes': [('historie', False)],
          'historiers': [('historie', False)],
          'hjerne': [('hjerne', False)],
          'hjerner': [('hjerne', False)],
          'hjernerne': [('hjerne', True)],
          'hjernernes': [('hjerne', True)],
          'hjernes': [('hjerne', False)],
          'hjerpen': [('hjerpe', True)],
          'hjerpens': [('hjerpe', True)],
          'hjerte': [('hjerte', True)],
          'hjerten': [('hjerte', False)],
          'hjertens': [('hjerte', False)],
          'hjerter': [('hjerter', True), ('hjerte', True)],
          'hjerterne': [('hjerter', True), ('hjerte', True)],
          'hjerternes': [('hjerter', True), ('hjerte', True)],
          'hjerters': [('hjerter', True), ('hjerte', True)],
          'hjertes': [('hjerte', True)],
          'hjorden': [('hjord', True)],
          'hjordens': [('hjord', True)],
          'hjuleger': [('hjulege', True), ('hjuleger', True)],
          'hjulegerne': [('hjulege', True), ('hjuleger', True)],
          'hjulegernes': [('hjuleger', True), ('hjulege', True)],
          'hjulegers': [('hjulege', True), ('hjuleger', True)],
          'hjælpearbejder': [('hjælpearbejde', True), ('hjælpearbejder', True)],
          'hjælpearbejderne': [('hjælpearbejde', True), ('hjælpearbejder', True)],
          'hjælpearbejdernes': [('hjælpearbejder', True), ('hjælpearbejde', True)],
          'hjælpearbejders': [('hjælpearbejder', True), ('hjælpearbejde', True)],
          'hjørne': [('hjørne', True)],
          'hjørnes': [('hjørne', False)],
          'hk': [('hestekraft', True)],
          'hkøer': [('hko', False)],
          'hkøerne': [('hko', False)],
          'hkøernes': [('hko', False)],
          'hkøers': [('hko', False)],
          'hlen': [('hl', False)],
          'hlens': [('hl', False)],
          'hler': [('hl', False)],
          'hlerne': [('hl', False)],
          'hlernes': [('hl', False)],
          'hlers': [('hl', False)],
          'hlias': [('hlia', False)],
          'hlinene': [('hline', False)],
          'hlinenes': [('hline', False)],
          'hls': [('hl', False)],
          'hlæger': [('hlæger', False)],
          'hlægerne': [('hlæger', False)],
          'hlægernes': [('hlæger', False)],
          'hlægers': [('hlæger', False)],
          'hm': [('hm', False)],
          'hman': [('hman', False)],
          'hmanens': [('hman', False)],
          'hmaners': [('hman', False)],
          'hmene': [('hm', False)],
          'hmenes': [('hm', False)],
          'hmer': [('hmer', False)],
          'hmere': [('hmer', False)],
          'hmeren': [('hmer', False)],
          'hmerens': [('hmer', False)],
          'hmerer': [('hmer', False)],
          'hmererne': [('hmer', False)],
          'hmerernes': [('hmer', False)],
          'hmerers': [('hmer', False)],
          'hmeres': [('hmer', False)],
          'hmerne': [('hmer', False)],
          'hmernes': [('hmer', False)],
          'hmers': [('hmer', False)],
          'hms': [('hm', False)],
          'hmænd': [('hmand', False)],
          'hnen': [('hn', False)],
          'hnens': [('hn', False)],
          'hner': [('hn', False)],
          'hnerne': [('hn', False)],
          'hnernes': [('hn', False)],
          'hners': [('hn', False)],
          'hningers': [('hning', False)],
          'hns': [('hn', False)],
          'ho': [('ho', False)],
          'hoben': [('hoben', True), ('hob', True)],
          'hobens': [('hoben', True), ('hob', True)],
          'hobroers': [('hobroer', True)],
          'hobs': [('hob', True)],
          'hoen': [('ho', False)],
          'hoens': [('ho', False)],
          'hoer': [('ho', False)],
          'hoerne': [('ho', False)],
          'hoernes': [('ho', False)],
          'hoers': [('ho', False)],
          'hoet': [('ho', False)],
          'hoets': [('ho', False)],
          'hoffer': [('hof', True)],
          'hoffers': [('hof', True)],
          'hoffet': [('hof', True)],
          'hofret': [('hofret', True)],
          'hofrets': [('hofret', True)],
          'hofter': [('hofte', True)],
          'holdene': [('hold', False)],
          'holdenes': [('hold', False)],
          'holders': [('holder', False)],
          'holer': [('hol', False)],
          'holerne': [('hol', False)],
          'holme': [('holm', True)],
          'holmen': [('holm', True)],
          'holmens': [('holm', True)],
          'holmer': [('holmer', False)],
          'holmere': [('holmer', False)],
          'holmeren': [('holmer', False)],
          'holmerens': [('holmer', False)],
          'holmeres': [('holmer', False)],
          'holmernes': [('holmer', False)],
          'holmers': [('holmer', False)],
          'holmes': [('holm', True)],
          'holten': [('holt', False)],
          'holtens': [('holt', False)],
          'holter': [('holt', False)],
          'holterne': [('holter', False)],
          'holternes': [('holt', False)],
          'holters': [('holter', False)],
          'honen': [('hone', False)],
          'honens': [('hone', False)],
          'honer': [('honer', False)],
          'honerne': [('honer', False)],
          'honernes': [('honer', False)],
          'honers': [('honer', False)],
          'honier': [('honie', False)],
          'honierne': [('honie', False)],
          'honiernes': [('honie', False)],
          'honiers': [('honie', False)],
          'hoppen': [('hoppe', True)],
          'hoppens': [('hoppe', True)],
          'hopper': [('hoppe', False)],
          'hopperne': [('hoppe', False)],
          'hoppernes': [('hoppe', True)],
          'hoppers': [('hoppe', True)],
          'hoppes': [('hoppe', False)],
          'hora': [('hora', True)],
          'horas': [('hora', True)],
          'horden': [('horde', True)],
          'hordens': [('horde', True)],
          'horder': [('horde', True)],
          'horderne': [('horde', True)],
          'hordernes': [('horde', True)],
          'horders': [('horde', True)],
          'hore': [('hore', True)],
          'horen': [('hore', True)],
          'horens': [('hore', True)],
          'horer': [('hore', True)],
          'horerne': [('hore', True)],
          'horernes': [('hore', True)],
          'horkens': [('hork', True)],
          'horker': [('hork', True)],
          'horkerne': [('hork', True)],
          'horkernes': [('hork', True)],
          'hornen': [('horn', False)],
          'hornens': [('horn', False)],
          'hornet': [('horn', False)],
          'hornets': [('horn', False)],
          'horstene': [('horst', False)],
          'horter': [('horte', False)],
          'horternes': [('horte', False)],
          'horters': [('horte', False)],
          'hos': [('ho', False)],
          'hosen': [('hose', True)],
          'hosens': [('hose', True)],
          'hoser': [('hose', True)],
          'hoserne': [('hose', True)],
          'hosernes': [('hose', True)],
          'hosers': [('hose', True)],
          'hosser': [('hosser', False)],
          'hosserne': [('hosser', False)],
          'hossernes': [('hosser', False)],
          'hossers': [('hosser', False)],
          'hoste': [('hoste', False)],
          'hosten': [('hoste', False)],
          'hostens': [('hoste', False)],
          'hostes': [('hoste', False)],
          'hotten': [('hot', False)],
          'hottens': [('hot', False)],
          'hotter': [('hot', False)],
          'hotterne': [('hot', False)],
          'hotternes': [('hot', False)],
          'hotters': [('hot', False)],
          'hpiber': [('hpibe', False)],
          'hpiberne': [('hpibe', False)],
          'hpibernes': [('hpibe', False)],
          'hpibers': [('hpibe', False)],
          'hrainerne': [('hrainer', False)],
          'hrainernes': [('hrainer', False)],
          'hrainers': [('hrainer', False)],
          'hriller': [('hriller', False)],
          'hrillerne': [('hriller', False)],
          'hrillernes': [('hriller', False)],
          'hrillers': [('hriller', False)],
          'hs': [('h', False)],
          "hs'": [('h', False)],
          'hsias': [('hsia', False)],
          'hsier': [('hsia', False)],
          'hsierne': [('hsia', False)],
          'hsiernes': [('hsia', False)],
          'hsiers': [('hsia', False)],
          'hten': [('ht', False)],
          'htene': [('ht', False)],
          'htenes': [('ht', False)],
          'htens': [('ht', False)],
          'hterne': [('ht', False)],
          "hters'": [('hter', False)],
          'htet': [('ht', False)],
          'htets': [('ht', False)],
          'htningen': [('htning', False)],
          'htninger': [('htning', False)],
          'htningerne': [('htning', False)],
          'htningernes': [('htning', False)],
          'hts': [('ht', False)],
          'hubbens': [('hub', True)],
          'hubber': [('hub', True)],
          'hubbernes': [('hub', True)],
          'hubbers': [('hub', True)],
          'huder': [('hud', False)],
          'hudernes': [('hud', True)],
          'huen': [('hue', True), ('hu', True)],
          'huens': [('hue', True), ('hu', True)],
          'huet': [('huet', False)],
          'huets': [('huet', False)],
          'huetter': [('huet', False)],
          'hugger': [('hugger', False)],
          'huggerne': [('hugger', False)],
          'hukke': [('huk', True)],
          'hukken': [('huk', True)],
          'hukkes': [('huk', True)],
          'hula': [('hula', False)],
          'hulas': [('hula', False)],
          'huldre': [('huldre', True)],
          'hule': [('hule', False)],
          'hulen': [('hule', True)],
          'hulens': [('hule', True)],
          'hulers': [('hule', False)],
          'hules': [('hule', False)],
          'huller': [('hul', False)],
          'hullers': [('hul', False)],
          'hummer': [('hummer', True)],
          'hummerne': [('hummer', False)],
          'hummernes': [('hummer', True)],
          'hunde': [('hund', False)],
          'hunden': [('hund', False)],
          'hundens': [('hund', False)],
          'hundes': [('hund', False)],
          'hunger': [('hunger', True)],
          'hungers': [('hunger', True)],
          'hunnen': [('hun', True)],
          'hunnens': [('hun', True)],
          'hunner': [('hun', True), ('hunner', True)],
          'hunnerne': [('hunner', True), ('hun', True)],
          'hunnernes': [('hunner', True), ('hun', True)],
          'hunners': [('hun', True), ('hunner', True)],
          'huns': [('hun', True)],
          'hunten': [('hunt', False)],
          'huntens': [('hunt', False)],
          'hunter': [('hunter', False)],
          'hunterne': [('hunter', False)],
          'hunternes': [('hunt', False)],
          'hunters': [('hunter', False)],
          'huppen': [('hup', False)],
          'huppens': [('hup', False)],
          'hupperne': [('hup', False)],
          'huppers': [('hup', False)],
          'hure': [('hure', False)],
          'huren': [('hure', False)],
          'hurens': [('hure', False)],
          'hurer': [('hure', False)],
          'hurerne': [('hure', False)],
          'hurernes': [('hure', False)],
          'hurers': [('hure', False)],
          'hures': [('hure', False)],
          'hurien': [('huri', True)],
          'huriens': [('huri', True)],
          'hurier': [('huri', True)],
          'hurierne': [('huri', True)],
          'huriernes': [('huri', True)],
          'hus': [('hus', True), ('hu', True)],
          'huset': [('hus', True)],
          'husker': [('husker', True)],
          'huskerne': [('husker', True)],
          'hustages': [('hustag', True)],
          'hutaner': [('hutaner', False)],
          'hutaners': [('hutaner', False)],
          'huter': [('huter', False)],
          'huterne': [('huter', False)],
          'huternes': [('huter', False)],
          'huters': [('huter', False)],
          'hvalen': [('hval', False)],
          'hvalens': [('hval', False)],
          'hvaler': [('hval', False)],
          'hvalerne': [('hval', False)],
          'hvalernes': [('hval', False)],
          'hvalers': [('hval', False)],
          'hvals': [('hval', False)],
          'hvarren': [('hvarre', True)],
          'hvarrens': [('hvarre', False)],
          'hvarrer': [('hvarre', True)],
          'hvarrerne': [('hvarre', False)],
          'hvarrernes': [('hvarre', True)],
          'hvarrers': [('hvarre', True)],
          'hveder': [('hvede', True)],
          'hvederne': [('hvede', False)],
          'hvedernes': [('hvede', False)],
          'hvenes': [('hvene', True)],
          'hvide': [('hvid', True), ('hvide', True)],
          'hviden': [('hvide', True)],
          'hvidens': [('hvide', True)],
          'hviderne': [('hvide', False)],
          'hviders': [('hvide', False)],
          'hvides': [('hvid', True), ('hvide', True)],
          'hviler': [('hviler', False)],
          'hvilerne': [('hvile', False)],
          'hvilernes': [('hvile', False)],
          'hvilers': [('hvile', False)],
          'hvinder': [('hvinder', False)],
          'hvinderne': [('hvinder', False)],
          'hvindernes': [('hvinder', False)],
          'hvinders': [('hvinder', False)],
          'hvins': [('hvin', True)],
          'hvirvler': [('hvirvler', True), ('hvirvel', True)],
          'hvirvlerne': [('hvirvler', True), ('hvirvel', True)],
          'hvirvlernes': [('hvirvler', True), ('hvirvel', True)],
          'hvirvlers': [('hvirvler', True), ('hvirvel', True)],
          "hx'er": [("hx'er", False)],
          "hx'erne": [("hx'er", False)],
          "hx'ernes": [("hx'er", False)],
          "hx'ers": [("hx'er", False)],
          'hyben': [('hyben', True)],
          'hybens': [('hyben', True)],
          'hybo': [('hybo', False)],
          'hyboen': [('hybo', False)],
          'hyboens': [('hybo', False)],
          'hyboer': [('hybo', False)],
          'hyboernes': [('hybo', False)],
          'hybos': [('hybo', False)],
          'hyder': [('hyd', False)],
          'hyderne': [('hyd', False)],
          'hydernes': [('hyd', False)],
          'hyders': [('hyd', False)],
          'hyfens': [('hyfe', True)],
          'hyfernes': [('hyfe', True)],
          'hyfers': [('hyfe', True)],
          'hykler': [('hykler', True)],
          'hyklernes': [('hykler', True)],
          'hylden': [('hylde', True), ('hyld', True)],
          'hyldens': [('hyld', True), ('hylde', True)],
          'hylderne': [('hylde', False)],
          'hyldernes': [('hylde', False)],
          'hylenes': [('hyl', True)],
          'hyler': [('hyler', False)],
          'hylerne': [('hyler', False)],
          'hylernes': [('hyler', True)],
          'hylers': [('hyler', False)],
          'hymens': [('hymen', True)],
          'hynder': [('hynde', True)],
          'hynderne': [('hynde', True)],
          'hyndernes': [('hynde', True)],
          'hynders': [('hynde', True)],
          'hypen': [('hype', True)],
          'hyrder': [('hyrde', True)],
          'hyrdernes': [('hyrde', True)],
          'hyre': [('hyre', True)],
          'hyren': [('hyre', True)],
          'hyrens': [('hyre', True)],
          'hyrer': [('hyre', True)],
          'hyrerne': [('hyre', True)],
          'hyrernes': [('hyre', False)],
          'hyrers': [('hyre', True)],
          'hyret': [('hyre', False)],
          'hyrets': [('hyre', False)],
          'hytten': [('hytte', True)],
          'hyttens': [('hytte', True)],
          'hytter': [('hytte', False)],
          'hytterne': [('hytte', True)],
          'hytternes': [('hytte', True)],
          'hytters': [('hytte', True)],
          'hånden': [('hånd', False)],
          'håndens': [('hånd', True)],
          'håren': [('hår', False)],
          'hårens': [('hår', False)],
          'hæer': [('hæ', False)],
          'hæerne': [('hæ', False)],
          'hæernes': [('hæ', False)],
          'hæers': [('hæ', False)],
          'hæet': [('hæ', False)],
          'hæets': [('hæ', False)],
          'hæfter': [('hæfte', False)],
          'hæfterne': [('hæfte', False)],
          'hægens': [('hæg', True)],
          'hæges': [('hæg', True)],
          'hægge': [('hæg', True)],
          'hæggens': [('hæg', True)],
          'hægges': [('hæg', True)],
          'hægter': [('hægte', True)],
          'hægterne': [('hægte', True)],
          'hægternes': [('hægte', True)],
          'hække': [('hæk', True)],
          'hækken': [('hæk', False)],
          'hækker': [('hæk', True)],
          'hækkerne': [('hæk', True)],
          'hækkes': [('hæk', False)],
          'hældenes': [('hæld', True)],
          'hældet': [('hæld', True)],
          'hældets': [('hæld', True)],
          'hæler': [('hæler', True)],
          'hælerne': [('hæler', True)],
          'hælernes': [('hæler', True)],
          'hælers': [('hæler', True)],
          'hæmmernes': [('hæmme', True)],
          'hæmmers': [('hæmme', True)],
          'hænder': [('hånd', False)],
          'hænderne': [('hånd', False)],
          'hændernes': [('hånd', False)],
          'hænders': [('hånd', False)],
          'hænge': [('hæng', False)],
          'hængen': [('hæng', False)],
          'hængens': [('hæng', False)],
          'hængernes': [('hænger', False)],
          'hængers': [('hænger', False)],
          'hænges': [('hæng', False)],
          'hænget': [('hæng', False)],
          'hængets': [('hæng', False)],
          'hære': [('hær', False)],
          'hæren': [('hær', True)],
          'hærens': [('hær', True)],
          'hæres': [('hær', False)],
          'hæs': [('hæs', True)],
          'hæssene': [('hæs', True)],
          'hæssenes': [('hæs', True)],
          'hætten': [('hætte', False)],
          'hættens': [('hætte', False)],
          'hætter': [('hætte', False)],
          'hætterne': [('hætte', False)],
          'hætternes': [('hætte', False)],
          'hætters': [('hætte', False)],
          'hævnerne': [('hævner', True)],
          'hævnernes': [('hævner', True)],
          'højder': [('højder', True), ('højde', True)],
          'højderne': [('højder', True), ('højde', True)],
          'højdernes': [('højder', True), ('højde', True)],
          'højders': [('højder', True), ('højde', True)],
          'høje': [('høj', True)],
          'højes': [('høj', False)],
          'høker': [('høker', False)],
          'hønen': [('høne', False)],
          'hønens': [('høne', False)],
          'høner': [('høne', False)],
          'hønernes': [('høne', False)],
          'høns': [('høne', False)],
          'høren': [('hør', False)],
          'hørene': [('hør', False)],
          'hørenes': [('hør', False)],
          'hørens': [('hør', False)],
          'hører': [('hører', True)],
          'hørerne': [('hører', True)],
          'hørernes': [('hører', True)],
          'hørers': [('hører', True)],
          'høret': [('hør', False)],
          'hørets': [('hør', False)],
          'høs': [('hø', True)],
          'høsten': [('høst', False)],
          'høstens': [('høst', False)],
          'høster': [('høst', False)],
          'høsterne': [('høst', True)],
          'høsternes': [('høst', False)],
          'høsters': [('høst', False)],
          'høvle': [('høvl', False)],
          'høvlen': [('høvl', False)],
          'høvlens': [('høvl', False)],
          'høvles': [('høvl', False)],
          'i': [('i', True)],
          'i grossi': [('o grosso', False)],
          'i grossis': [('o grosso', False)],
          "i'erne": [('i', True)],
          'i/s': [('interessentskab', True)],
          'ia': [('ia', False)],
          'iabasers': [('iabas', False)],
          'iabler': [('iabel', False)],
          'iablerne': [('iabel', False)],
          'iablernes': [('iabel', False)],
          'iablers': [('iabel', False)],
          'iables': [('iabel', False)],
          'iade': [('iade', False)],
          'iaden': [('iade', False)],
          'iadens': [('iade', False)],
          'iaderne': [('iade', False)],
          'iaders': [('iade', False)],
          'iades': [('iade', False)],
          'iaen': [('ia', False)],
          'iaene': [('ia', False)],
          'iaenes': [('ia', False)],
          'iaens': [('ia', False)],
          'iaer': [('ia', False)],
          'iaerne': [('ia', False)],
          'iaernes': [('ia', False)],
          'iaers': [('ia', False)],
          'iaftalens': [('iaftale', False)],
          'iaftens': [('iaften', False)],
          'iaka': [('iakum', False)],
          'iakas': [('iakum', False)],
          'iakken': [('iak', False)],
          'iaks': [('iak', False)],
          'iale': [('iale', False)],
          'ialen': [('ial', False)],
          'ialene': [('ial', False)],
          'ialenes': [('ial', False)],
          'ialens': [('ial', False)],
          'iales': [('iale', False)],
          'ialet': [('iale', False)],
          'ialets': [('iale', False)],
          'ialogens': [('ialog', False)],
          'ianderne': [('iand', False)],
          'iandernes': [('iand', False)],
          'iane': [('ian', False)],
          'ianen': [('ian', False)],
          'ianens': [('ian', False)],
          'ianer': [('ianer', False)],
          'ianerne': [('ian', False)],
          'ianernes': [('ian', False)],
          'ianers': [('ianer', False)],
          'ianes': [('ian', False)],
          'ianglens': [('iangel', False)],
          'iangler': [('iangel', False)],
          'ianglerne': [('iangel', False)],
          'ianglernes': [('iangel', False)],
          'ianglers': [('iangel', False)],
          'ianister': [('ianist', False)],
          'ianisters': [('ianist', False)],
          "ians'": [('ians', False)],
          'iansen': [('ians', False)],
          'iansens': [('ians', False)],
          'ianser': [('ians', False)],
          'iansernes': [('ians', False)],
          'iansers': [('ians', False)],
          'ianten': [('iant', False)],
          'iantens': [('iant', False)],
          'ianterne': [('iant', False)],
          'ianternes': [('iant', False)],
          'ianters': [('iant', False)],
          'iants': [('iant', False)],
          'iarbejder': [('iarbejder', False)],
          'iarbejderne': [('iarbejder', False)],
          'iarbejdernes': [('iarbejder', False)],
          'iarbejders': [('iarbejder', False)],
          'iarden': [('iard', False)],
          'iardens': [('iard', False)],
          'iarderne': [('iard', False)],
          'iardernes': [('iard', False)],
          'iarders': [('iard', False)],
          'iarerne': [('iar', False)],
          'iarers': [('iar', False)],
          'iarker': [('iark', False)],
          'iarkerne': [('iark', False)],
          'iarmens': [('iarm', False)],
          'iarmes': [('iarm', False)],
          'ias': [('ia', False)],
          'iassen': [('ias', False)],
          'iassens': [('ias', False)],
          'iasser': [('ias', False)],
          'iasserne': [('ias', False)],
          'iasten': [('iast', False)],
          'iastens': [('iast', False)],
          'iaster': [('iast', False)],
          'iasterne': [('iast', False)],
          'iasternes': [('iast', False)],
          'iasters': [('iast', False)],
          'iatellens': [('iatelle', False)],
          'iater': [('iater', False)],
          'iaterne': [('iater', False)],
          'iaternes': [('iat', False)],
          'iaters': [('iater', False)],
          'iatos': [('iato', False)],
          'iatrier': [('iatri', False)],
          'iatrierne': [('iatri', False)],
          'iatriernes': [('iatri', False)],
          'iatriers': [('iatri', False)],
          'iatten': [('iat', False)],
          'iattens': [('iat', False)],
          'iatternes': [('iat', False)],
          'iatters': [('iat', False)],
          'iaturen': [('iature', False)],
          'iaturens': [('iature', False)],
          'iaturer': [('iature', False)],
          'iaturerne': [('iature', False)],
          'iaturernes': [('iature', False)],
          'iaturers': [('iature', False)],
          'iauernes': [('iau', False)],
          'iavlens': [('iavl', False)],
          'ibalen': [('ibal', False)],
          'ibalens': [('ibal', False)],
          'ibaler': [('ibal', False)],
          'ibalerne': [('ibal', False)],
          'ibalernes': [('ibal', False)],
          'ibalers': [('ibal', False)],
          'ibars': [('ibar', False)],
          'ibber': [('ibbe', False)],
          'ibbernes': [('ibbe', False)],
          'ibbers': [('ibbe', False)],
          'ibe': [('ib', False)],
          'ibeboer': [('ibebo', False)],
          'ibeboerne': [('ibebo', False)],
          'ibeboernes': [('ibebo', False)],
          'ibeboers': [('ibebo', False)],
          'ibellen': [('ibelle', False)],
          'ibeller': [('ibelle', False)],
          'ibellers': [('ibelle', False)],
          'iben': [('ibe', False)],
          'ibene': [('ib', False)],
          'ibenes': [('ib', False)],
          'ibens': [('ibe', False)],
          'iber': [('ibe', False)],
          'iberet': [('iber', False)],
          'iberets': [('iber', False)],
          'iberiers': [('iberi', False)],
          'iberis': [('iberis', True)],
          'iberne': [('ibe', False)],
          'ibernes': [('ibe', False)],
          'ibers': [('iber', False)],
          'ibes': [('ib', False)],
          'ibesten': [('ibesten', False)],
          'ibet': [('ib', False)],
          'ibets': [('ib', False)],
          'ibier': [('ibier', False)],
          'ibierne': [('ibier', False)],
          'ibiernes': [('ibium', False)],
          'ibiers': [('ibier', False)],
          'ibiet': [('ibium', False)],
          'ibiets': [('ibi', False)],
          'ibilen': [('ibil', False)],
          'ibilens': [('ibil', False)],
          'ibilerne': [('ibil', False)],
          'ibilernes': [('ibil', False)],
          'ibilers': [('ibil', False)],
          'ibis': [('ibis', True)],
          'ibissen': [('ibis', True)],
          'ibissens': [('ibis', True)],
          'ibisser': [('ibis', True)],
          'ibisserne': [('ibis', True)],
          'ibissernes': [('ibis', True)],
          'ibissers': [('ibis', True)],
          'ible': [('ible', False)],
          'iblens': [('ibel', False)],
          'ibler': [('ibel', False)],
          'ibles': [('ible', False)],
          'iboer': [('iboer', False)],
          'iboerne': [('iboer', False)],
          'iboernes': [('iboer', False)],
          'iboers': [('iboer', False)],
          'ibondens': [('ibonde', False)],
          'ibres': [('iber', False)],
          'ibrien': [('ibri', False)],
          'ibriens': [('ibri', False)],
          'ibrier': [('ibri', False)],
          'ibrierne': [('ibri', False)],
          'ibriernes': [('ibri', False)],
          'ibriers': [('ibri', False)],
          'ibs': [('ib', False)],
          'ibukser': [('ibukser', False)],
          'ibukserne': [('ibukser', False)],
          'ibuksernes': [('ibukser', False)],
          'ibuksers': [('ibukser', False)],
          'ibus': [('ibus', False)],
          'ibuster': [('ibuster', False)],
          'ibusterne': [('ibuster', False)],
          'ibusternes': [('ibuster', False)],
          'ibusters': [('ibuster', False)],
          'ibutter': [('ibut', False)],
          'ibyer': [('ibyer', False)],
          'ibyerne': [('ibyer', False)],
          'ibyernes': [('ibyer', False)],
          'ibyers': [('ibyer', False)],
          'ibønnen': [('ibønne', False)],
          'ibønnens': [('ibønne', False)],
          'ibønner': [('ibønne', False)],
          'ibønnerne': [('ibønne', False)],
          'ibønnernes': [('ibønne', False)],
          'ibønners': [('ibønne', False)],
          'icaler': [('ical', False)],
          'icalerne': [('ical', False)],
          'icalernes': [('ical', False)],
          'icalers': [('ical', False)],
          'icen': [('ic', False)],
          'icene': [('ice', False)],
          'icenes': [('ice', False)],
          'icens': [('ic', False)],
          'icentre': [('icenter', False)],
          'icentrene': [('icenter', False)],
          'icentrenes': [('icenter', False)],
          'icentres': [('icenter', False)],
          'icentret': [('icenter', False)],
          'icentrets': [('icenter', False)],
          'icentrum': [('icenter', False)],
          'icentrummer': [('icenter', False)],
          'icentrummerne': [('icenter', False)],
          'icentrummernes': [('icenter', False)],
          'icentrummers': [('icenter', False)],
          'icentrummet': [('icenter', False)],
          'icentrummets': [('icenter', False)],
          'icentrums': [('icenter', False)],
          'icerne': [('ic', False)],
          'icers': [('ic', False)],
          'icet': [('ic', False)],
          'icets': [('ic', False)],
          'iche': [('iche', False)],
          'ichen': [('iche', False)],
          'ichens': [('iche', False)],
          'icher': [('iche', False)],
          'icherne': [('iche', False)],
          'ichernes': [('ich', False)],
          'ichers': [('iche', False)],
          'iches': [('iche', False)],
          'ici': [('ikus', False)],
          'icider': [('icid', False)],
          'iciderne': [('icid', False)],
          'icidernes': [('icid', False)],
          'iciders': [('icid', False)],
          'iciens': [('iciens', False)],
          'icier': [('icie', False)],
          'icierne': [('icier', False)],
          'iciernes': [('icier', False)],
          'iciers': [('icie', False)],
          'icies': [('icie', False)],
          'icillens': [('icil', False)],
          'icillernes': [('icil', False)],
          'icillers': [('icil', False)],
          'icinen': [('icin', False)],
          'icinens': [('icin', False)],
          'icinerne': [('icin', False)],
          'icinernes': [('icin', False)],
          'icis': [('ikus', False)],
          'icisterne': [('icist', False)],
          'icisternes': [('icist', False)],
          'icits': [('icit', False)],
          'icitter': [('icit', False)],
          'icitterne': [('icit', False)],
          'icium': [('icium', False)],
          'iciums': [('icium', False)],
          'icker': [('ick', False)],
          'ickerne': [('icker', False)],
          'ickernes': [('ick', False)],
          'ickers': [('icker', False)],
          'icyklen': [('icykel', False)],
          'icyklens': [('icykel', False)],
          'icykler': [('icykel', False)],
          'icyklerne': [('icykel', False)],
          'icyklernes': [('icykel', False)],
          'icyklers': [('icykel', False)],
          'id': [('id', False)],
          "id'er": [('id', False)],
          "id'ers": [('id', False)],
          'ida': [('idum', False)],
          'idaene': [('idum', False)],
          'idaenes': [('idum', False)],
          'idage': [('idag', False)],
          'idagen': [('idag', False)],
          'idagene': [('idag', False)],
          'idages': [('idag', False)],
          'idanter': [('idant', False)],
          'idas': [('idum', False)],
          'idaten': [('idat', False)],
          'idatens': [('idat', False)],
          'idater': [('idat', False)],
          'idaterne': [('idat', False)],
          'idaters': [('idat', False)],
          'idats': [('idat', False)],
          'idde': [('idde', False)],
          'idden': [('idde', False)],
          'iddens': [('idde', False)],
          'idderne': [('idder', False)],
          'iddernes': [('idder', False)],
          'iddes': [('idde', False)],
          'ide': [('id', False)],
          'idealer': [('ideal', True)],
          'idealerne': [('ideal', True)],
          'idealernes': [('ideal', True)],
          'idealers': [('ideal', True)],
          'iden': [('id', False)],
          'idenden': [('idende', False)],
          'idendens': [('idende', False)],
          'idender': [('idend', False)],
          'idenderne': [('idend', False)],
          'idendernes': [('idend', False)],
          'idenders': [('idend', False)],
          'idene': [('id', False)],
          'idenes': [('id', False)],
          'idenserne': [('idens', False)],
          'identen': [('ident', False)],
          'identens': [('ident', False)],
          'identer': [('ident', False)],
          'identerne': [('ident', False)],
          'identernes': [('ident', False)],
          'identers': [('ident', False)],
          'ider': [('id', False)],
          'idere': [('ider', False)],
          'ideren': [('ider', False)],
          'iderens': [('ider', False)],
          'ideres': [('ider', False)],
          'iderhandler': [('iderhandel', False)],
          'iderhandlerne': [('iderhandel', False)],
          'iderhandlers': [('iderhandel', False)],
          'iderne': [('id', False)],
          'idernes': [('id', False)],
          'iders': [('id', False)],
          'ides': [('id', False)],
          "ides'": [('ide', False)],
          'idet': [('id', False)],
          'idets': [('id', False)],
          'idianerne': [('idian', False)],
          'idianernes': [('idian', False)],
          'idiernes': [('idi', False)],
          'idiet': [('idie', False)],
          'idiets': [('idie', False)],
          'idinen': [('idin', False)],
          'idinens': [('idin', False)],
          'idinet': [('idin', False)],
          'idinets': [('idin', False)],
          'idis': [('idi', False)],
          'idissen': [('idisse', False)],
          'idissens': [('idisse', False)],
          'idisser': [('idisse', False)],
          'idisserne': [('idisse', False)],
          'idissernes': [('idisse', False)],
          'idissers': [('idisse', False)],
          'idium': [('idium', False)],
          'idiums': [('idium', False)],
          'idiver': [('idiv', False)],
          'idivernes': [('idiv', False)],
          'idner': [('idne', False)],
          'idnernes': [('idne', False)],
          'idners': [('idne', False)],
          'idnet': [('idnet', False)],
          'idnets': [('idne', False)],
          'idolers': [('idol', True)],
          'idomme': [('idom', False)],
          'idonen': [('idon', False)],
          'idonens': [('idon', False)],
          'idoner': [('idon', False)],
          'idonerne': [('idon', False)],
          'idonernes': [('idon', False)],
          'idoners': [('idon', False)],
          'idoren': [('idor', False)],
          'idorens': [('idor', False)],
          'idorer': [('idor', False)],
          'idorerne': [('idor', False)],
          'idorernes': [('idor', False)],
          'idorers': [('idor', False)],
          'idrikke': [('idrik', False)],
          'idrikkerne': [('idrik', False)],
          'idrikkers': [('idrik', False)],
          'idrætter': [('idræt', True)],
          'idrætternes': [('idræt', False)],
          'idrætters': [('idræt', True)],
          'ids': [('id', False)],
          'idsarbejders': [('idsarbejde', False)],
          'idse': [('idse', False)],
          'idses': [('idse', False)],
          'idte': [('idte', False)],
          'idten': [('idte', False)],
          'idtens': [('idte', False)],
          'idtes': [('idte', False)],
          'idus': [('idus', False)],
          'idusen': [('idus', False)],
          'idvandet': [('idvand', True), ('idvande', True)],
          'idvandets': [('idvand', True), ('idvande', True)],
          'idvisen': [('idvise', False)],
          'idvisens': [('idvise', False)],
          'idviser': [('idvise', False)],
          'idviserne': [('idvise', False)],
          'ie': [('ie', False)],
          'iebakker': [('iebakke', False)],
          'iebakkernes': [('iebakke', False)],
          'iebakkers': [('iebakke', False)],
          'iecen': [('iece', False)],
          'iecens': [('iece', False)],
          'iecer': [('iece', False)],
          'iecerne': [('iece', False)],
          'iecernes': [('iece', False)],
          'iecers': [('iece', False)],
          'ieces': [('iece', False)],
          'ieden': [('ied', False)],
          'iedens': [('ied', False)],
          'iefaderen': [('iefar', False)],
          'iefaderens': [('iefar', False)],
          'iefaren': [('iefar', False)],
          'iefarer': [('iefarer', False)],
          'iefarers': [('iefarer', False)],
          'iefædrene': [('iefar', False)],
          'iefædres': [('iefar', False)],
          'iejerne': [('iejer', False)],
          'ielerne': [('iel', False)],
          'ielets': [('iel', False)],
          'ieller': [('iel', False)],
          'iellers': [('iel', False)],
          'ielsers': [('ielse', False)],
          'ielærerne': [('ielærer', False)],
          'ielærernes': [('ielærer', False)],
          'iemen': [('ieme', False)],
          'iemer': [('ieme', False)],
          'iemerne': [('ieme', False)],
          'iemernes': [('ieme', False)],
          'iemers': [('ieme', False)],
          'iemmer': [('iem', False)],
          'iemmerne': [('iem', False)],
          'iemmernes': [('iem', False)],
          'iemmers': [('iem', False)],
          'iendernes': [('iende', False)],
          'iene': [('o', False)],
          'iener': [('iener', False)],
          'ienerne': [('iener', False)],
          'ienernes': [('iener', False)],
          'ieners': [('iener', False)],
          'ienes': [('o', False)],
          'iennerne': [('ienne', False)],
          "iens'": [('iens', False)],
          'iensen': [('iens', False)],
          'iensens': [('iens', False)],
          'ienser': [('iens', False)],
          'ienserne': [('ienser', False)],
          'iensernes': [('iens', False)],
          'iensers': [('iens', False)],
          'ientaler': [('ientaler', False)],
          'ientalerne': [('ientaler', False)],
          'ientalernes': [('ientaler', False)],
          'ientalers': [('ientaler', False)],
          'ienten': [('ient', False)],
          'ientens': [('ient', False)],
          'ienter': [('ient', False)],
          'ienterne': [('ient', False)],
          'ienternes': [('ient', False)],
          'ienters': [('ient', False)],
          'ieplejernes': [('iepleje', False)],
          'ieplejers': [('iepleje', False)],
          'ieprisernes': [('iepris', False)],
          'iera': [('iera', False)],
          'ieras': [('iera', False)],
          'ierer': [('iere', False)],
          'iererne': [('iere', False)],
          'ierernes': [('iere', False)],
          'ierers': [('iere', False)],
          'ieretten': [('ieret', False)],
          'ierettens': [('ieret', False)],
          'ierier': [('ieri', False)],
          'ierierne': [('ieri', False)],
          'ieriernes': [('ieri', False)],
          'ieriers': [('ieri', False)],
          'ieriet': [('ieri', False)],
          'ieriets': [('ieri', False)],
          'ieris': [('ieri', False)],
          'ierministers': [('ierminister', False)],
          'ierne': [('ier', False)],
          'iernes': [('ier', False)],
          'ies': [('ie', False)],
          "ies'": [('y', False)],
          'iesager': [('iesag', False)],
          'iesagerne': [('iesag', False)],
          'ieselen': [('iesel', False)],
          'ieselens': [('iesel', False)],
          'iestarterne': [('iestart', False)],
          'iestarters': [('iestart', False)],
          'iet': [('ie', False)],
          'ietager': [('ietager', False)],
          'ietagere': [('ietager', False)],
          'ietageren': [('ietager', False)],
          'ietagerens': [('ietager', False)],
          'ietageres': [('ietager', False)],
          'ietagerne': [('ietager', False)],
          'ietagernes': [('ietager', False)],
          'ietagers': [('ietager', False)],
          'ietet': [('ietet', False)],
          'ietets': [('ietet', False)],
          'ietiden': [('ietid', False)],
          'iets': [('ie', False)],
          'ietten': [('iet', False)],
          'iettens': [('iet', False)],
          'ietter': [('iet', False)],
          'ietterne': [('iet', False)],
          'ietternes': [('iet', False)],
          'ietters': [('iet', False)],
          'ietærens': [('ietær', False)],
          'ietærer': [('ietær', False)],
          'ietærers': [('ietær', False)],
          'iever': [('iever', False)],
          'ievers': [('iever', False)],
          'ieværter': [('ievært', False)],
          'ieværterne': [('ievært', False)],
          'ieværters': [('ievært', False)],
          'if': [('idrætsforening', True)],
          'ifer': [('ifer', False)],
          'ifere': [('iffer', False)],
          'iferen': [('ifer', False)],
          'iferens': [('iffer', False)],
          'iferes': [('iffer', False)],
          'iferne': [('iffer', False)],
          'ifernes': [('iffer', False)],
          'ifers': [('iffer', False)],
          'iffen': [('if', False)],
          'iffene': [('if', False)],
          'iffenes': [('if', False)],
          'iffens': [('if', False)],
          'iffer': [('iffer', False)],
          'ifferens': [('iffer', False)],
          'ifferne': [('if', False)],
          'iffernes': [('iffer', False)],
          'iffers': [('iffer', False)],
          'iffet': [('iff', False)],
          'iffets': [('iff', False)],
          'iflis': [('ifli', False)],
          'ifolien': [('ifolie', False)],
          'ifoliernes': [('ifolie', False)],
          'ifonds': [('ifond', False)],
          'iformer': [('iform', False)],
          'iformerne': [('iform', False)],
          'iformernes': [('iform', False)],
          'iformers': [('iform', False)],
          'ifte': [('ifte', False)],
          'iften': [('ifte', False)],
          'iftens': [('ifte', False)],
          'ifter': [('ift', False)],
          'ifterne': [('ifte', False)],
          'ifternes': [('ifte', False)],
          'iftes': [('ifte', False)],
          'iftet': [('ifte', False)],
          'iftets': [('ifte', False)],
          'ig': [('ig', False)],
          'ig.': [('igur', False)],
          'igaler': [('igal', False)],
          'igalerne': [('igal', False)],
          'igalernes': [('igal', False)],
          'igalers': [('igal', False)],
          'iganen': [('igan', False)],
          'iganens': [('igan', False)],
          'iganer': [('igan', False)],
          'iganerne': [('igan', False)],
          'iganernes': [('igan', False)],
          'iganers': [('igan', False)],
          'igarer': [('igar', False)],
          'igarernes': [('igar', False)],
          'igas': [('iga', False)],
          'ige': [('ig', False)],
          'igejer': [('igej', False)],
          'igejerne': [('igej', False)],
          'igejernes': [('igejer', False)],
          'igejers': [('igejer', False)],
          'igels': [('igel', False)],
          'igen': [('ig', False)],
          'igene': [('ig', False)],
          'igenen': [('igen', False)],
          'igenens': [('igen', False)],
          'igener': [('igen', False)],
          'igenerne': [('igen', False)],
          'igenernes': [('igen', False)],
          'igeners': [('igen', False)],
          'igenes': [('ig', False)],
          'igens': [('ig', False)],
          'igenser': [('igens', False)],
          'igenserne': [('igens', False)],
          'igensernes': [('igens', False)],
          'igensers': [('igens', False)],
          'iger': [('iger', False)],
          'igere': [('iger', False)],
          'igeren': [('iger', False)],
          'igerens': [('iger', False)],
          'igerernes': [('igerer', False)],
          'igeres': [('iger', False)],
          'igeret': [('iger', False)],
          'igerets': [('iger', False)],
          'igerne': [('ige', False)],
          'igernes': [('ige', False)],
          'igers': [('ige', False)],
          'iges': [('ig', False)],
          'iget': [('ig', False)],
          'igets': [('ig', False)],
          'iggenes': [('ig', False)],
          'igger': [('ig', False)],
          'iggerne': [('igger', False)],
          'iggernes': [('igger', False)],
          'iggers': [('ig', False)],
          'ighedens': [('ighed', False)],
          'ights': [('ight', False)],
          "ights'": [('ight', False)],
          'iginer': [('iginer', False)],
          'iginerne': [('iginer', False)],
          'iginernes': [('iginer', False)],
          'iginers': [('iginer', False)],
          'igle': [('igle', True)],
          'iglen': [('igle', True)],
          'iglens': [('igle', True)],
          'igler': [('igle', True)],
          'iglerne': [('igle', True)],
          'iglernes': [('igle', True)],
          'iglers': [('igle', False)],
          'igles': [('igle', True)],
          'igner': [('igner', False)],
          'ignerne': [('igner', False)],
          'ignernes': [('igen', False)],
          'igners': [('igner', False)],
          'ignet': [('ignet', False)],
          'ignets': [('ignet', False)],
          'igrams': [('igram', False)],
          'igre': [('igre', False)],
          'igren': [('igre', False)],
          'igrene': [('iger', False)],
          'igrenes': [('iger', False)],
          'igrens': [('igre', False)],
          'igres': [('iger', False)],
          'igret': [('igret', False)],
          'igrets': [('igret', False)],
          'igretten': [('igret', False)],
          'igrettens': [('igret', False)],
          'igs': [('ig', False)],
          'igshandlerne': [('igshandel', False)],
          'igshandlernes': [('igshandel', False)],
          'igte': [('igte', False)],
          'igter': [('igter', False)],
          'igterne': [('igter', False)],
          'igternes': [('igter', False)],
          'igters': [('igt', False)],
          'igtes': [('igte', False)],
          'iguaner': [('iguaner', False)],
          'iguanerne': [('iguaner', False)],
          'iguanernes': [('iguaner', False)],
          'iguaners': [('iguaner', False)],
          'igænger': [('igænger', False)],
          'igængerne': [('igænger', False)],
          'igængernes': [('igænger', False)],
          'igængers': [('igænger', False)],
          'igører': [('igør', False)],
          'igørernes': [('igør', False)],
          'igørers': [('igør', False)],
          'ihave': [('ihave', False)],
          'ihaves': [('ihave', False)],
          'iheden': [('ihed', False)],
          'ihedens': [('ihed', False)],
          'iheder': [('ihed', False)],
          'ihederne': [('ihed', False)],
          'ihedernes': [('ihed', False)],
          'iheders': [('ihed', False)],
          'iholterne': [('iholt', False)],
          'iholters': [('iholt', False)],
          'ihopper': [('ihopper', False)],
          'ihopperne': [('ihopper', False)],
          'ihoppernes': [('ihopper', False)],
          'ihoppers': [('ihopper', False)],
          'ihus': [('ihus', False)],
          'ihøjder': [('ihøjde', False)],
          'ihøjderne': [('ihøjde', False)],
          'ihøjdernes': [('ihøjde', False)],
          'ihøjders': [('ihøjde', False)],
          'iianerne': [('iianer', False)],
          'iianernes': [('iianer', False)],
          'iingen': [('iing', False)],
          'iingens': [('iing', False)],
          'iings': [('iing', False)],
          'iismen': [('iisme', False)],
          'iismens': [('iisme', False)],
          'iitten': [('iit', False)],
          'iittens': [('iit', False)],
          'iitternes': [('iit', False)],
          'iitters': [('iit', False)],
          'ijorden': [('ijord', False)],
          'ijordens': [('ijord', False)],
          'ik': [('ik', False)],
          'ika': [('ika', False)],
          'ikaene': [('ikon', False)],
          'ikaenes': [('ikon', False)],
          'ikagen': [('ikage', False)],
          'ikagens': [('ikage', False)],
          'ikaler': [('ikal', False)],
          'ikalerne': [('ikal', False)],
          'ikalernes': [('ikal', False)],
          'ikalers': [('ikal', False)],
          'ikalet': [('ikal', False)],
          'ikalets': [('ikal', False)],
          'ikalier': [('ikalier', False)],
          'ikalierne': [('ikalier', False)],
          'ikaliernes': [('ikalie', False)],
          'ikaliers': [('ikalier', False)],
          'ikaliet': [('ikalie', False)],
          'ikaliets': [('ikalie', False)],
          'ikanden': [('ikand', False)],
          'ikandens': [('ikand', False)],
          'ikander': [('ikand', False)],
          'ikanderne': [('ikand', False)],
          'ikandernes': [('ikand', False)],
          'ikanders': [('ikand', False)],
          'ikanen': [('ikan', False)],
          'ikanens': [('ikane', False)],
          'ikanerne': [('ikaner', False)],
          'ikanernes': [('ikaner', False)],
          'ikans': [('ikan', False)],
          'ikapper': [('ikapper', False)],
          'ikapperne': [('ikapper', False)],
          'ikappernes': [('ikapper', False)],
          'ikappers': [('ikapper', False)],
          'ikaren': [('ikar', False)],
          'ikarens': [('ikar', False)],
          'ikarer': [('ikar', False)],
          'ikarernes': [('ikar', False)],
          'ikas': [('ika', False)],
          'ikater': [('ikat', False)],
          'ikaterne': [('ikat', False)],
          'ikaters': [('ikat', False)],
          'ikene': [('ike', False)],
          'ikenes': [('ike', False)],
          'ikens': [('ik', False)],
          'iker': [('iker', False)],
          'ikere': [('iker', False)],
          'ikeren': [('iker', False)],
          'ikerens': [('iker', False)],
          'ikeres': [('iker', False)],
          'ikerne': [('iker', False)],
          'ikernes': [('iker', False)],
          'ikers': [('iker', False)],
          'iket': [('ike', False)],
          'ikets': [('ike', False)],
          'iketter': [('iket', False)],
          'ikherne': [('ikh', False)],
          'ikier': [('ikier', False)],
          'ikierne': [('ikier', False)],
          'ikiernes': [('ikier', False)],
          'ikiers': [('ikier', False)],
          'ikinen': [('ikin', False)],
          'ikinens': [('ikin', False)],
          'ikiner': [('ikin', False)],
          'ikinernes': [('ikin', False)],
          'ikis': [('iki', False)],
          'ikke': [('ikke', False)],
          'ikken': [('ikke', False)],
          'ikkens': [('ik', False)],
          'ikker': [('ik', False)],
          'ikkerne': [('ikker', False)],
          'ikkernes': [('ik', False)],
          'ikkers': [('ik', False)],
          'ikkes': [('ikke', False)],
          'ikket': [('ik', False)],
          'ikkets': [('ik', False)],
          'iklagen': [('iklagen', False)],
          'iklagens': [('iklagen', False)],
          'iklen': [('ikkel', False)],
          'iklens': [('ikel', False)],
          'ikler': [('ikel', False)],
          'iklerne': [('ikkel', False)],
          'iklers': [('ikkel', False)],
          'iklet': [('ikkel', False)],
          'iklets': [('ikkel', False)],
          'iklingen': [('ikling', False)],
          'iklingens': [('ikling', False)],
          'iklinger': [('ikling', False)],
          'iklingerne': [('ikling', False)],
          'iklingernes': [('ikling', False)],
          'iklingers': [('ikling', False)],
          'ikolien': [('ikolie', False)],
          'ikoliens': [('ikolie', False)],
          'ikolier': [('ikolie', False)],
          'ikolierne': [('ikolie', False)],
          'ikoliernes': [('ikolie', False)],
          'ikon': [('ikon', False)],
          'ikonen': [('ikon', True)],
          'ikonens': [('ikon', True)],
          'ikoner': [('ikon', False)],
          'ikonerne': [('ikon', False)],
          'ikonernes': [('ikon', False)],
          'ikoners': [('ikon', False)],
          'ikonet': [('ikon', True)],
          'ikonets': [('ikon', False)],
          'ikons': [('ikon', False)],
          'ikos': [('ikos', False)],
          'ikosen': [('ikos', False)],
          'ikosens': [('ikos', False)],
          'ikoserne': [('ikos', False)],
          'ikosernes': [('ikos', False)],
          'ikosers': [('ikos', False)],
          'ikoten': [('ikot', False)],
          'ikotens': [('ikot', False)],
          'ikoter': [('ikot', False)],
          'ikoterne': [('ikot', False)],
          'ikoternes': [('ikot', False)],
          'ikoters': [('ikot', False)],
          'ikreds': [('ikreds', False)],
          'ikronen': [('ikrone', False)],
          'ikroner': [('ikrone', False)],
          'ikronerne': [('ikron', False)],
          'ikronernes': [('ikrone', False)],
          'ikroners': [('ikron', False)],
          'iks': [('ik', False)],
          'ikser': [('iks', False)],
          'ikserne': [('ikser', False)],
          'iksernes': [('ikse', False)],
          'iksers': [('ikser', False)],
          'ikshandlerne': [('ikshandel', False)],
          'ikshandlernes': [('ikshandel', False)],
          'iksis': [('iksis', False)],
          'ikstet': [('ikst', False)],
          'ikstets': [('ikst', False)],
          'ikstiden': [('ikstid', False)],
          'ikte': [('ikte', True)],
          'ikten': [('ikte', True)],
          'iktens': [('ikte', True)],
          'ikter': [('ikte', True)],
          'ikterne': [('ikte', True)],
          'ikternes': [('ikte', True)],
          'ikters': [('ikte', True)],
          'iktes': [('ikte', True)],
          'iktiner': [('iktiner', False)],
          'iktinerne': [('iktiner', False)],
          'iktinernes': [('iktiner', False)],
          'iktiners': [('iktiner', False)],
          'ikulærer': [('ikulær', False)],
          'ikulærernes': [('ikulær', False)],
          'ikulærers': [('ikulær', False)],
          'ikummen': [('ikum', False)],
          'ikummens': [('ikum', False)],
          'ikummer': [('ikum', False)],
          'ikummerne': [('ikum', False)],
          'ikummers': [('ika', False)],
          'ikummet': [('ikum', False)],
          'ikummets': [('ikum', False)],
          'ikus': [('ikus', False)],
          'ikussen': [('ikus', False)],
          'ikussens': [('ikus', False)],
          'ikusser': [('ikus', False)],
          'ikusserne': [('ikus', False)],
          'ikussernes': [('ikus', False)],
          'ikussers': [('ikus', False)],
          'ikvaren': [('ikvare', False)],
          'ikvarens': [('ikvare', False)],
          'ikvarer': [('ikvare', False)],
          'ikvarerne': [('ikvare', False)],
          'ikvarernes': [('ikvare', False)],
          'ikvarers': [('ikvar', False)],
          'ikvarter': [('ikvarter', False)],
          'ikvarters': [('ikvarter', False)],
          'ikvas': [('ikva', False)],
          'ikviden': [('ikvid', False)],
          'ikvidens': [('ikvid', False)],
          'ikæmper': [('ikæmper', False)],
          'ikæmperne': [('ikæmper', False)],
          'ikæmpernes': [('ikæmper', False)],
          'ikæmpers': [('ikæmper', False)],
          'ikærten': [('ikært', False)],
          'ikærtens': [('ikært', False)],
          'ikærter': [('ikært', False)],
          'ikærterne': [('ikært', False)],
          'ikærternes': [('ikært', False)],
          'ikærters': [('ikært', False)],
          'ikøren': [('ikør', False)],
          'ikører': [('ikør', False)],
          'ikørerne': [('ikør', False)],
          'ikørernes': [('ikør', False)],
          'ikørers': [('ikør', False)],
          'il': [('il', False)],
          'il.': [('il.', False)],
          'ilaffer': [('ilaf', False)],
          'ilafferne': [('ilaf', False)],
          'ilagen': [('ilage', False)],
          'ilagens': [('ilage', False)],
          'ilager': [('ilager', False)],
          'ilageret': [('ilager', False)],
          'ilagerne': [('ilager', False)],
          'ilagernes': [('ilager', False)],
          'ilagers': [('ilager', False)],
          'ilaks': [('ilak', False)],
          'ilanter': [('ilant', False)],
          'ilanterne': [('ilant', False)],
          'ilanternes': [('ilant', False)],
          'ilanters': [('ilant', False)],
          'ilarer': [('ilar', False)],
          'ilarernes': [('ilar', False)],
          'ilars': [('ilar', False)],
          'ilas': [('ila', False)],
          'ilaster': [('ilaster', False)],
          'ilasters': [('ilaster', False)],
          'ild': [('ild', True)],
          'ilde': [('ilde', False)],
          'ilden': [('ild', True)],
          'ildene': [('ild', False)],
          'ildens': [('ild', True)],
          'ilder': [('ilder', True)],
          'ilderne': [('ilder', True)],
          'ildernes': [('ilder', False)],
          'ilders': [('ilder', True)],
          'ildes': [('ilde', False)],
          'ildet': [('ilde', False)],
          'ildets': [('ilde', False)],
          'ildrer': [('ildrer', False)],
          'ildrerne': [('ildrer', False)],
          'ildrernes': [('ildrer', False)],
          'ilds': [('ild', True)],
          'ile': [('il', False)],
          'iledernes': [('ileder', False)],
          'ilegier': [('ilegie', False)],
          'ilegierne': [('ilegie', False)],
          'ilegiernes': [('ilegie', False)],
          'ilegiers': [('ilegie', False)],
          'ilegiet': [('ilegie', False)],
          'ilejer': [('ilejer', False)],
          'ilejerne': [('ilejer', False)],
          'ilejernes': [('ilejer', False)],
          'ilejers': [('ilejer', False)],
          'ilen': [('il', False)],
          'ilene': [('il', False)],
          'ilenes': [('il', False)],
          'ilens': [('il', False)],
          'ilenserne': [('ilens', False)],
          'iler': [('iler', False)],
          'ilere': [('iler', False)],
          'ileren': [('iler', False)],
          'ilerens': [('iler', False)],
          'ileres': [('iler', False)],
          'ilerne': [('il', False)],
          'ilernes': [('il', False)],
          'ilers': [('il', False)],
          'iles': [('il', False)],
          'ilet': [('il', False)],
          'ilets': [('ilet', False)],
          'iletten': [('ilet', False)],
          'ilettens': [('ilette', False)],
          'iletter': [('ilet', False)],
          'iletterne': [('ilet', False)],
          'iletternes': [('ilet', False)],
          'ilflugterne': [('ilflugt', False)],
          'ilhedens': [('ilhed', False)],
          'ilianer': [('ilianer', False)],
          'ilianerne': [('ilianer', False)],
          'ilianernes': [('ilianer', False)],
          'ilianers': [('ilianer', False)],
          'ilias': [('ilia', False)],
          'ilien': [('ilie', False)],
          'iliens': [('ilie', False)],
          'ilier': [('ilium', False)],
          'ilieret': [('ilieret', False)],
          'ilierets': [('ilieret', False)],
          'ilierne': [('ilium', False)],
          'iliernes': [('ilie', False)],
          'iliers': [('ilium', False)],
          'ilies': [('ilie', False)],
          'iliet': [('ilium', False)],
          'iliker': [('ilika', False)],
          'ilikerne': [('ilika', False)],
          'ilikernes': [('ilika', False)],
          'ilikummer': [('ilikum', False)],
          'ilikummerne': [('ilikum', False)],
          'ilikummers': [('ilikum', False)],
          'ilinen': [('ilin', False)],
          'ilinens': [('ilin', False)],
          'iliner': [('ilin', False)],
          'ilinerne': [('ilin', False)],
          'ilinernes': [('ilin', False)],
          'iliners': [('ilin', False)],
          'ilinet': [('ilin', False)],
          'ilingers': [('iling', False)],
          'iliskens': [('ilisk', False)],
          'ilisker': [('ilisk', False)],
          'iliskerne': [('ilisk', False)],
          'iliskernes': [('ilisk', False)],
          'iliskers': [('ilisk', False)],
          'ilismen': [('ilisme', False)],
          'ilisten': [('iliste', False)],
          'ilistens': [('iliste', False)],
          'ilister': [('iliste', False)],
          'ilisterne': [('iliste', False)],
          'ilisternes': [('ilist', False)],
          'ilisters': [('ilist', False)],
          'iliter': [('iliter', False)],
          'iliters': [('iliter', False)],
          'ilium': [('ilium', False)],
          'iliums': [('ilium', False)],
          'iljen': [('ilje', False)],
          'ilke': [('ilke', False)],
          'ilken': [('ilke', False)],
          'ilkens': [('ilke', False)],
          'ilker': [('ilke', False)],
          'ilkerne': [('ilke', False)],
          'ilkes': [('ilke', False)],
          'illans': [('illans', False)],
          'ille': [('ille', False)],
          'illedernes': [('illede', False)],
          'illemanden': [('illemand', False)],
          'illemandens': [('illemand', False)],
          'illen': [('ille', False)],
          'illene': [('il', False)],
          'illenes': [('il', False)],
          'illernes': [('il', False)],
          'illes': [('ille', False)],
          'illet': [('il', False)],
          'illetten': [('illette', False)],
          'illettens': [('illet', False)],
          'illetter': [('illette', False)],
          'illetterne': [('illette', False)],
          'illetternes': [('illette', False)],
          'illetters': [('illet', False)],
          'illinger': [('illing', False)],
          'illingerne': [('illing', False)],
          'illingernes': [('illing', False)],
          'illisten': [('illist', False)],
          'illistens': [('illist', False)],
          'illister': [('illiste', False)],
          'illisterne': [('illist', False)],
          'illisternes': [('illiste', False)],
          'illisters': [('illiste', False)],
          'illos': [('illo', False)],
          'illærer': [('illærer', False)],
          'illærerne': [('illærer', False)],
          'illærernes': [('illærer', False)],
          'ilogen': [('ilog', False)],
          'ilogens': [('ilog', False)],
          'iloger': [('ilog', False)],
          'ilogerne': [('ilog', False)],
          'ilogernes': [('ilog', False)],
          'ilogers': [('ilog', False)],
          'ilopens': [('ilope', False)],
          'ilopers': [('ilope', False)],
          'ilopper': [('ilopper', False)],
          'ilopperne': [('ilopper', False)],
          'iloppernes': [('ilopper', False)],
          'iloppers': [('ilopper', False)],
          'ilos': [('ilos', False)],
          "ilos'": [('ilos', False)],
          'ilosen': [('ilos', False)],
          'ilosens': [('ilos', False)],
          'ils': [('il', False)],
          "ils'": [('il', False)],
          'ilsen': [('ilsen', False)],
          'ilsens': [('ilsen', False)],
          'ilsner': [('ilsen', False)],
          'ilsnerne': [('ilsner', False)],
          'ilsnernes': [('ilsen', False)],
          'ilsners': [('ilsen', False)],
          'ilstyrer': [('ilstyrer', False)],
          'ilstyrerne': [('ilstyrer', False)],
          'ilstyrernes': [('ilstyrer', False)],
          'ilte': [('ilte', False)],
          'ilten': [('ilt', True), ('ilte', True)],
          'iltene': [('ilt', False)],
          'iltens': [('ilt', True), ('ilte', True)],
          'ilter': [('ilte', True)],
          'ilterne': [('ilte', True)],
          'ilternes': [('ilte', False)],
          'ilters': [('ilte', True)],
          'iltes': [('ilte', False)],
          'iltet': [('ilte', False)],
          'iltets': [('ilte', False)],
          'ilurens': [('ilur', False)],
          'ilurer': [('ilur', False)],
          'ilurerne': [('ilur', False)],
          'ilurernes': [('ilur', False)],
          'ilurers': [('ilur', False)],
          'ilus': [('ilus', False)],
          'ilyde': [('ilyd', False)],
          'ilyden': [('ilyd', False)],
          'ilydens': [('ilyd', False)],
          'ilydes': [('ilyd', False)],
          'ilæer': [('ilæer', False)],
          'ilæerne': [('ilæer', False)],
          'ilæernes': [('ilæer', False)],
          'ilæers': [('ilæum', False)],
          'ilæet': [('ilæum', False)],
          'ilæets': [('ilæum', False)],
          'ilænder': [('ilænder', False)],
          'ilænderne': [('ilænder', False)],
          'ilændernes': [('ilænder', False)],
          'ilænders': [('ilænder', False)],
          'ilærer': [('ilære', False)],
          'ilærerne': [('ilære', False)],
          'ilærernes': [('ilære', False)],
          'ilærers': [('ilære', False)],
          'iløberne': [('iløber', False)],
          'im': [('im', False)],
          'ima': [('imum', False)],
          'imaene': [('imum', False)],
          'imaenes': [('imum', False)],
          'imager': [('image', True)],
          'imagerne': [('image', True)],
          'imagernes': [('image', True)],
          'imagers': [('image', True)],
          'imaks': [('imaks', False)],
          'imaler': [('imal', False)],
          'imalerne': [('imal', False)],
          'imalernes': [('imal', False)],
          'imalers': [('imal', False)],
          'imanden': [('imande', False)],
          'imandens': [('imande', False)],
          'imander': [('imande', False)],
          'imanderne': [('imande', False)],
          'imandernes': [('imande', False)],
          'imanders': [('imande', False)],
          'imas': [('imum', False)],
          'imediciner': [('imedicin', False)],
          'imedicinerne': [('imedicin', False)],
          'imedicinernes': [('imedicin', False)],
          'imediciners': [('imedicin', False)],
          'imelser': [('imelse', False)],
          'imelserne': [('imelse', False)],
          'imelsernes': [('imelse', False)],
          'imen': [('im', False)],
          'imene': [('im', False)],
          'imenes': [('im', False)],
          'imens': [('im', False)],
          'imentarierne': [('imentarie', False)],
          'imentariernes': [('imentarie', False)],
          'imentariers': [('imentarie', False)],
          'imentarium': [('imentarie', False)],
          'imentariums': [('imentarie', False)],
          'imenten': [('iment', False)],
          'imentens': [('iment', False)],
          'imenter': [('iment', False)],
          'imenternes': [('iment', False)],
          'imenters': [('iment', False)],
          'imer': [('im', False)],
          'imere': [('imer', False)],
          'imeren': [('imer', False)],
          'imerens': [('imer', False)],
          'imeres': [('imer', False)],
          'imerne': [('im', False)],
          'imernes': [('im', False)],
          'imers': [('ime', False)],
          'imet': [('im', False)],
          'imeter': [('imeter', False)],
          'imeters': [('imeter', False)],
          'imetre': [('imeter', False)],
          'imetrene': [('imeter', False)],
          'imetrenes': [('imeter', False)],
          'imetres': [('imeter', False)],
          'imetret': [('imeter', False)],
          'imetrets': [('imeter', False)],
          'imets': [('im', False)],
          'imiks': [('imik', False)],
          'imilen': [('imile', False)],
          'imilens': [('imile', False)],
          'imilers': [('imile', False)],
          'iminister': [('iminister', False)],
          'iministers': [('iminister', False)],
          'imis': [('imi', False)],
          'imissioner': [('imission', False)],
          'imissionerne': [('imission', False)],
          'imitten': [('imit', False)],
          'imittens': [('imit', False)],
          'imitter': [('imit', False)],
          'imitterne': [('imit', False)],
          'imitternes': [('imit', False)],
          'imitters': [('imit', False)],
          'imler': [('immel', False)],
          'immerne': [('im', False)],
          'immernes': [('immer', False)],
          'immers': [('immer', False)],
          'immet': [('im', False)],
          'immets': [('im', False)],
          'immortellen': [('immortelle', True), ('immortel', True)],
          'immortellens': [('immortel', True), ('immortelle', True)],
          'immorteller': [('immortelle', True), ('immortel', True)],
          'immortellerne': [('immortel', True), ('immortelle', True)],
          'immortellernes': [('immortel', True), ('immortelle', True)],
          'immortellers': [('immortelle', True), ('immortel', True)],
          'imoner': [('imon', False)],
          'imonerne': [('imon', False)],
          'imonernes': [('imon', False)],
          'imoners': [('imon', False)],
          'imonier': [('imonium', False)],
          'imoniet': [('imonium', False)],
          'imoniets': [('imonium', False)],
          'imos': [('imo', False)],
          'imosen': [('imose', False)],
          'imosens': [('imose', False)],
          'impe': [('impe', False)],
          'impen': [('impe', False)],
          'impens': [('impe', False)],
          'imper': [('impe', False)],
          'imperier': [('imperie', True)],
          'imperierne': [('imperie', True)],
          'imperiernes': [('imperie', True)],
          'imperiers': [('imperie', True)],
          'imperiet': [('imperie', True)],
          'imperiets': [('imperie', True)],
          'imperne': [('impe', False)],
          'impes': [('impe', False)],
          'implerne': [('impel', False)],
          'implernes': [('impel', False)],
          'implers': [('impel', False)],
          'impuls': [('impuls', True)],
          'ims': [('im', False)],
          'imser': [('ims', False)],
          'imsers': [('ims', False)],
          'imsten': [('imsten', False)],
          'imten': [('imte', False)],
          'imtens': [('imte', False)],
          'imter': [('imte', False)],
          'imterne': [('imte', False)],
          'imternes': [('imte', False)],
          'imters': [('imte', False)],
          'imus': [('imus', False)],
          'imutter': [('imut', False)],
          'imutters': [('imut', False)],
          'imælken': [('imælk', False)],
          'imælkens': [('imælk', False)],
          'imænd': [('imand', False)],
          'imære': [('imære', False)],
          'imæren': [('imære', False)],
          'imærens': [('imære', False)],
          'imæres': [('imære', False)],
          'imærkerne': [('imærke', False)],
          'imærkernes': [('imærke', False)],
          'imærkers': [('imærke', False)],
          'in': [('in', False)],
          'in.': [('inut', False)],
          'ina': [('inum', False)],
          'ina actionis': [('en actionis', False)],
          "ina actionis'": [('en actionis', False)],
          'ina agentis': [('en agentis', False)],
          "ina agentis'": [('en agentis', False)],
          'inader': [('inade', False)],
          'inakken': [('inak', False)],
          'inakkens': [('inak', False)],
          'inakker': [('inak', False)],
          'inakkerne': [('inak', False)],
          'inakkernes': [('inak', False)],
          'inakkers': [('inak', False)],
          'inalen': [('inal', False)],
          'inalens': [('inale', False)],
          'inaler': [('inal', False)],
          'inalerne': [('inal', False)],
          'inalernes': [('inal', False)],
          'inalers': [('inal', False)],
          'inalet': [('inal', False)],
          'inalets': [('inal', False)],
          'inanser': [('inanser', False)],
          'inanserne': [('inans', False)],
          'inansernes': [('inans', False)],
          'inansers': [('inanser', False)],
          'inanter': [('inant', False)],
          'inarbejderne': [('inarbejder', False)],
          'inarbejdernes': [('inarbejder', False)],
          'inaren': [('inar', False)],
          'inarens': [('inar', False)],
          'inarer': [('inar', False)],
          'inarernes': [('inar', False)],
          'inas': [('inum', False)],
          'inaten': [('inat', False)],
          'inatens': [('inat', False)],
          'inater': [('inat', False)],
          'inaterne': [('inat', False)],
          'inaters': [('inat', False)],
          'inatorier': [('inatorium', False)],
          'inatoriernes': [('inatorium', False)],
          'inatorium': [('inatorium', False)],
          'inatoriums': [('inatorium', False)],
          'inaver': [('inav', False)],
          'inaverne': [('inav', False)],
          'inavernes': [('inav', False)],
          'inavers': [('inav', False)],
          'inavlen': [('inavl', False)],
          'inavlens': [('inavl', False)],
          'inavler': [('inavler', False)],
          'inavlerne': [('inavler', False)],
          'inavlernes': [('inavler', False)],
          'inavlers': [('inavler', False)],
          'inde': [('inde', False)],
          'inden': [('inde', False)],
          'indens': [('inde', False)],
          'inder': [('inder', False)],
          'inderne': [('inder', True)],
          'indernes': [('inder', False)],
          'inders': [('inder', False)],
          'indes': [('inde', False)],
          'indestens': [('indesten', False)],
          'indet': [('inde', False)],
          'indets': [('inde', False)],
          'indis': [('indi', False)],
          'indler': [('indler', False)],
          'indlers': [('indler', False)],
          'indolens': [('indolens', True)],
          'indre': [('indre', True)],
          'indres': [('indre', True)],
          'indskifter': [('indskifter', True)],
          'indskifterne': [('indskifter', True)],
          'indskifternes': [('indskifter', True)],
          'indskifters': [('indskifter', True)],
          'indsøer': [('indsø', True)],
          'indsøerne': [('indsø', True)],
          'indsøernes': [('indsø', True)],
          'indsøers': [('indsø', True)],
          'induer': [('indu', False)],
          'induerne': [('indu', False)],
          'induernes': [('indu', False)],
          'induers': [('indu', False)],
          'inearbejder': [('inearbejder', False)],
          'inearbejderne': [('inearbejder', False)],
          'inearbejdernes': [('inearbejde', False)],
          'inearbejders': [('inearbejde', False)],
          'inellen': [('inelle', False)],
          'ineller': [('inelle', False)],
          'inellers': [('inelle', False)],
          'inen': [('in', False)],
          'inenes': [('in', False)],
          'inens': [('in', False)],
          'inerier': [('ineri', False)],
          'inerierne': [('ineri', False)],
          'ineriernes': [('ineri', False)],
          'ineriers': [('ineri', False)],
          'inernes': [('in', False)],
          'ineser': [('ineser', False)],
          'ineserier': [('ineseri', False)],
          'ineserierne': [('ineseri', False)],
          'ineseriernes': [('ineseri', False)],
          'ineserne': [('ineser', False)],
          'inesernes': [('ineser', False)],
          'inessen': [('inesse', False)],
          'inessens': [('inesse', False)],
          'inet': [('in', False)],
          'inets': [('in', False)],
          'inetten': [('inette', False)],
          'inettens': [('inette', False)],
          'inetter': [('inette', False)],
          'inetterne': [('inette', False)],
          'inetternes': [('inette', False)],
          'inetters': [('inette', False)],
          'infølgerne': [('infølge', False)],
          'infølgernes': [('infølge', False)],
          'infølgers': [('infølge', False)],
          'inge': [('inge', False)],
          'ingels': [('ingels', False)],
          'ingenser': [('ingens', False)],
          'ingenserne': [('ingenser', False)],
          'ingensernes': [('ingens', False)],
          'ingensers': [('ingenser', False)],
          'ingers': [('ing', False)],
          'inges': [('inge', False)],
          'inglen': [('ingel', False)],
          'inglens': [('ingle', False)],
          'ingler': [('ingle', False)],
          'inglerne': [('ingle', False)],
          'inglernes': [('ingel', False)],
          'inglers': [('ingel', False)],
          'ingles': [('ingle', False)],
          'inglisten': [('ingliste', False)],
          'inglistens': [('ingliste', False)],
          'inglister': [('ingliste', False)],
          'inglisterne': [('ingliste', False)],
          'ingordner': [('ingordner', False)],
          'ingordnerne': [('ingordner', False)],
          'ingordners': [('ingordner', False)],
          "ings'": [('ings', False)],
          'ingsteder': [('ingsteder', False)],
          'ingstederne': [('ingsteder', False)],
          'ingstedernes': [('ingsteder', False)],
          'ingsteders': [('ingsteder', False)],
          'inien': [('inie', False)],
          'iniens': [('inie', False)],
          'inienserne': [('inienser', False)],
          'inier': [('inie', False)],
          'inierne': [('inier', False)],
          'iniernes': [('ini', False)],
          'iniers': [('ini', False)],
          'iniker': [('iniker', False)],
          'inikerne': [('iniker', False)],
          'inikernes': [('iniker', False)],
          'inikers': [('iniker', False)],
          'iniks': [('inik', False)],
          'inima': [('inimum', False)],
          'inimas': [('inimum', False)],
          'ininen': [('inin', False)],
          'ininens': [('inin', False)],
          'ininer': [('ininum', False)],
          'ininerne': [('ininum', False)],
          'ininernes': [('ininum', False)],
          'ininers': [('ininum', False)],
          'iningers': [('ining', False)],
          'initter': [('init', False)],
          'initterne': [('init', False)],
          'initternes': [('init', False)],
          'initters': [('init', False)],
          'inium': [('inium', False)],
          'iniums': [('inium', False)],
          'inke': [('inke', False)],
          'inken': [('inke', False)],
          'inkens': [('ink', False)],
          'inker': [('inke', False)],
          'inkerne': [('inke', False)],
          'inkernes': [('inker', False)],
          'inkers': [('inker', False)],
          'inkes': [('inke', False)],
          'inket': [('ink', False)],
          'inkets': [('ink', False)],
          'inkler': [('inkler', False)],
          'inklerne': [('inkel', False)],
          'inklernes': [('inkel', False)],
          'inklers': [('inkel', False)],
          'inks': [('inks', False)],
          "inks'": [('inks', False)],
          'inne': [('inne', False)],
          'innen': [('inne', False)],
          'innens': [('inne', False)],
          'inner': [('inne', False)],
          'innerne': [('inne', False)],
          'innernes': [('inne', False)],
          'inners': [('inne', False)],
          'innes': [('inne', False)],
          'innier': [('innia', False)],
          'innierne': [('innia', False)],
          'inomer': [('inom', False)],
          'inomerne': [('inom', False)],
          'inomernes': [('inom', False)],
          'inomers': [('inom', False)],
          'inpressers': [('inpresse', False)],
          'ins': [('in', False)],
          "ins'": [('in', False)],
          'insarbejders': [('insarbejde', False)],
          'insbo': [('insboer', False)],
          'insboen': [('insboer', False)],
          'insboens': [('insboer', False)],
          'insboer': [('insboer', False)],
          'insboerne': [('insboer', False)],
          'insbos': [('insboer', False)],
          'inse': [('inse', False)],
          'insen': [('inse', False)],
          'insene': [('in', False)],
          'insenes': [('in', False)],
          'insens': [('inse', False)],
          'inser': [('inse', False)],
          'inserne': [('inse', False)],
          'insernes': [('inse', False)],
          'insers': [('inse', False)],
          'inses': [('inse', False)],
          'insianerne': [('insianer', False)],
          'insianernes': [('insianer', False)],
          'inslerne': [('insel', False)],
          'inslernes': [('insel', False)],
          'inslers': [('insel', False)],
          'insorter': [('insort', False)],
          'insorterne': [('insort', False)],
          'insorternes': [('insort', False)],
          'insorters': [('insort', False)],
          'inster': [('inst', False)],
          'insterne': [('inst', False)],
          'insternes': [('inst', False)],
          'insters': [('inst', False)],
          'inte': [('inte', False)],
          'inten': [('inte', False)],
          'intens': [('inte', False)],
          'interne': [('inte', False)],
          'inters': [('inte', False)],
          'intes': [('inte', False)],
          'intet': [('intet', True)],
          'intets': [('intet', True)],
          'intingens': [('inting', False)],
          'intre': [('inter', False)],
          'inuet': [('inuum', False)],
          'inuets': [('inuum', False)],
          'inummer': [('inum', False)],
          'inummers': [('inummer', False)],
          'inus': [('inus', False)],
          'inussernes': [('inus', False)],
          'inussers': [('inus', False)],
          'inveje': [('inveje', False)],
          'inyen': [('inye', False)],
          'inyens': [('inye', False)],
          'inyer': [('inye', False)],
          'inyerne': [('inye', False)],
          'inyernes': [('inye', False)],
          'inyers': [('inye', False)],
          'inylen': [('inyl', False)],
          'inylens': [('inyl', False)],
          'inyler': [('inyl', False)],
          'inylerne': [('inyl', False)],
          'inylernes': [('inyl', False)],
          'inylers': [('inyl', False)],
          'inærens': [('inær', False)],
          'inøren': [('inør', False)],
          'inører': [('inør', False)],
          'inørernes': [('inør', False)],
          'inørers': [('inør', False)],
          'io': [('io', False)],
          'io.': [('illion', False)],
          'iobiler': [('iobil', False)],
          'ioden': [('iode', False)],
          'iodens': [('iode', False)],
          'ioders': [('iode', False)],
          'ioen': [('io', False)],
          'ioens': [('io', False)],
          'ioer': [('io', False)],
          'ioerne': [('io', False)],
          'ioernes': [('io', False)],
          'ioers': [('io', False)],
          'ioet': [('io', False)],
          'ioets': [('io', False)],
          'iofonier': [('iofoni', False)],
          'iokken': [('iok', False)],
          'iokker': [('iok', False)],
          'iokkerne': [('iok', False)],
          'iokkernes': [('iok', False)],
          'iokkers': [('iok', False)],
          'ioler': [('iol', False)],
          'iolerne': [('iol', False)],
          'ioli': [('ioli', False)],
          'iolien': [('ioli', False)],
          'iolienes': [('ioli', False)],
          'ioliens': [('ioli', False)],
          'iolier': [('ioli', False)],
          'iolierne': [('ioli', False)],
          'ioliernes': [('ioli', False)],
          'ioliers': [('ioli', False)],
          'ioliner': [('iolin', False)],
          'iolis': [('ioli', False)],
          'iolytter': [('iolytter', False)],
          'iolytterne': [('iolytter', False)],
          'iolytters': [('iolytter', False)],
          'iomaner': [('ioman', False)],
          'iomanerne': [('ioman', False)],
          'iomanernes': [('ioman', False)],
          'iomaners': [('ioman', False)],
          'ionaternes': [('ionat', False)],
          'ioner': [('ion', True)],
          'ionerne': [('ion', True)],
          'ionernes': [('ion', True)],
          'ioners': [('ion', True)],
          'ions': [('ion', True)],
          'iopier': [('iopier', False)],
          'iopierne': [('iopier', False)],
          'iopiernes': [('iopier', False)],
          'iopiers': [('iopier', False)],
          'iora': [('iora', False)],
          'ioras': [('iora', False)],
          'iorers': [('ior', False)],
          'iores': [('iores', False)],
          'ios': [('io', False)],
          'iosa': [('iosa', False)],
          'iosas': [('iosa', False)],
          'iosen': [('iose', False)],
          'iosens': [('iose', False)],
          'ioser': [('iose', False)],
          'ioserne': [('iose', False)],
          'iosernes': [('iose', False)],
          'iosers': [('iose', False)],
          'iosken': [('iosk', False)],
          'ioskerne': [('iosk', False)],
          'ioskers': [('iosk', False)],
          'iota': [('iota', True)],
          'iotas': [('iota', True)],
          'iotiet': [('ioti', False)],
          'iotiets': [('ioti', False)],
          'iotten': [('iot', False)],
          'iottens': [('iot', False)],
          "ip'ers": [('ip', False)],
          'ipakker': [('ipakke', False)],
          'ipakkerne': [('ipakke', False)],
          'ipakkernes': [('ipakke', False)],
          'ipakkers': [('ipakke', False)],
          'ipalet': [('ipal', False)],
          'ipalets': [('ipal', False)],
          'ipande': [('ipande', False)],
          'ipandes': [('ipande', False)],
          'ipaner': [('ipan', False)],
          'ipaners': [('ipan', False)],
          'ipans': [('ipan', False)],
          'ipanter': [('ipant', False)],
          'ipanterne': [('ipant', False)],
          'ipanternes': [('ipant', False)],
          'ipanters': [('ipant', False)],
          'ipas': [('ipas', False)],
          'ipasen': [('ipase', False)],
          'ipastis': [('ipasto', False)],
          'ipatiens': [('ipati', False)],
          'ipels': [('ipel', False)],
          'ipen': [('ipe', False)],
          'ipendierne': [('ipendie', False)],
          'ipendium': [('ipendie', False)],
          'ipendiums': [('ipendie', False)],
          'ipene': [('ipe', False)],
          'ipenes': [('ipe', False)],
          'ipens': [('ipe', False)],
          'ipensen': [('ipens', False)],
          'ipensens': [('ipens', False)],
          'ipenser': [('ipenser', False)],
          'ipenserne': [('ipens', False)],
          'ipensernes': [('ipenser', False)],
          'ipensers': [('ipenser', False)],
          'iper': [('iper', False)],
          'ipernes': [('ipe', False)],
          'ipers': [('ipe', False)],
          'ipes': [('ipe', False)],
          'ipet': [('ipe', False)],
          'ipets': [('ipe', False)],
          'ipetten': [('ipette', False)],
          'ipettens': [('ipette', False)],
          'ipetterne': [('ipette', False)],
          'ipetternes': [('ipette', False)],
          'ipetters': [('ipette', False)],
          'ipids': [('ipid', False)],
          'ipien': [('ipi', False)],
          'ipiens': [('ipi', False)],
          'ipier': [('ipi', False)],
          'ipierne': [('ipium', False)],
          'ipiernes': [('ipi', False)],
          'ipiers': [('ipium', False)],
          'ipiet': [('ipium', False)],
          'ipiets': [('ipium', False)],
          'ipis': [('ipi', False)],
          'iplen': [('ipel', False)],
          'iplenes': [('ipel', False)],
          'iplens': [('ipel', False)],
          'ipler': [('ippel', False)],
          'iplerne': [('ippel', False)],
          'iplernes': [('ippel', False)],
          'iplers': [('ippel', False)],
          'iplet': [('iplum', False)],
          'iplets': [('iplum', False)],
          'ipoden': [('ipode', False)],
          'ipodens': [('ipode', False)],
          'ipoderne': [('ipode', False)],
          'ipodernes': [('ipode', False)],
          'ipolernes': [('ipol', False)],
          'ipolers': [('ipol', False)],
          'iposter': [('ipost', False)],
          'iposterne': [('ipost', False)],
          'iposternes': [('ipost', False)],
          'iposters': [('ipost', False)],
          'ipotens': [('ipotens', False)],
          'ipovernes': [('ipover', False)],
          'ipovers': [('ipover', False)],
          'ippe': [('ippe', False)],
          'ippen': [('ippe', False)],
          'ippens': [('ippe', False)],
          'ipper': [('ippe', False)],
          'ipperne': [('ippe', False)],
          'ippernes': [('ipper', False)],
          'ippers': [('ipper', False)],
          'ippes': [('ip', False)],
          'ippet': [('ip', False)],
          'ippets': [('ip', False)],
          'ips': [('ip', False)],
          "ips'": [('ip', False)],
          'ipse': [('ipse', False)],
          'ipser': [('ipse', False)],
          'ipserne': [('ipser', False)],
          'ipsernes': [('ipse', False)],
          'ipsers': [('ipse', False)],
          'ipses': [('ipse', False)],
          'iptet': [('ipt', False)],
          'iputten': [('iput', False)],
          'iputtens': [('iput', False)],
          'iputter': [('iput', False)],
          'iputterne': [('iput', False)],
          'iputternes': [('iput', False)],
          'iputters': [('iput', False)],
          'ir': [('ir', False)],
          'ira': [('irus', False)],
          'irade': [('irade', False)],
          'iraden': [('irade', False)],
          'iradens': [('irade', False)],
          'irader': [('irade', False)],
          'iraderne': [('irade', False)],
          'iradernes': [('irade', False)],
          'iraders': [('irade', False)],
          'irades': [('irade', False)],
          'iraenes': [('irus', False)],
          'irafferne': [('iraf', False)],
          'iraffers': [('iraf', False)],
          'irakkens': [('irak', False)],
          'irakler': [('irakel', False)],
          'iraklerne': [('irakel', False)],
          'iraklernes': [('irakel', False)],
          'iraklers': [('irakel', False)],
          'iralen': [('iral', False)],
          'iraler': [('iral', False)],
          'iralerne': [('iral', False)],
          'iralernes': [('iral', False)],
          'iralers': [('iral', False)],
          'iranerne': [('iraner', True)],
          'iranernes': [('iraner', True)],
          'iras': [('irus', False)],
          'iraten': [('irat', False)],
          'iratens': [('irat', False)],
          'irater': [('irat', False)],
          'iraterne': [('irat', False)],
          'iraternes': [('irat', False)],
          'iraters': [('irat', False)],
          'irbens': [('irben', False)],
          'irdier': [('irdie', False)],
          'irdiernes': [('irdie', False)],
          'iren': [('ire', False)],
          'irene': [('ir', False)],
          'irenen': [('irene', False)],
          'irenens': [('irene', False)],
          'irener': [('irene', False)],
          'irenerne': [('irene', False)],
          'irenernes': [('irene', False)],
          'ireners': [('irene', False)],
          'irenes': [('ir', False)],
          'irens': [('ir', False)],
          'irenten': [('irent', False)],
          'irentens': [('irent', False)],
          'irenter': [('irent', False)],
          'irenterne': [('irent', False)],
          'irenternes': [('irent', False)],
          'irenters': [('irent', False)],
          'irer': [('irer', True)],
          'irerne': [('irer', True)],
          'irernes': [('irer', True)],
          'irers': [('irer', True)],
          'ires': [('ire', False)],
          "ires'": [('ires', False)],
          'iresen': [('ires', False)],
          'iresens': [('ires', False)],
          'ireser': [('ires', False)],
          'ireserne': [('ires', False)],
          'iresernes': [('ires', False)],
          'iret': [('ir', False)],
          'iretiden': [('iretiden', False)],
          'irets': [('ir', False)],
          'irier': [('irium', False)],
          'irierne': [('irium', False)],
          'iriernes': [('irium', False)],
          'iriet': [('irium', False)],
          'iriets': [('irium', False)],
          'iringer': [('iring', False)],
          'iringerne': [('iring', False)],
          'iringernes': [('iring', False)],
          'iringers': [('iring', False)],
          'iris': [('iris', True)],
          'irisen': [('iris', False)],
          'irissers': [('iris', True)],
          'irister': [('irist', False)],
          'iristerne': [('irist', False)],
          'iristernes': [('irist', False)],
          'iristers': [('irist', False)],
          'irium': [('irium', False)],
          'iriums': [('irium', False)],
          'irke': [('irke', False)],
          'irken': [('irke', False)],
          'irkens': [('irk', False)],
          'irker': [('irke', False)],
          'irkerne': [('irke', False)],
          'irkernes': [('irke', False)],
          'irkers': [('irke', False)],
          'irkes': [('irke', False)],
          'irket': [('irke', False)],
          'irkets': [('irke', False)],
          'irmasterne': [('irmaster', False)],
          'irmasternes': [('irmaster', False)],
          'irnussernes': [('irnusser', False)],
          'irnussers': [('irnusser', False)],
          'iroen': [('iro', False)],
          'iroens': [('iro', False)],
          'iroer': [('iro', False)],
          'iroerne': [('iro', False)],
          'iroernes': [('iro', False)],
          'iroers': [('iro', False)],
          'irolen': [('irol', False)],
          'irolens': [('irol', False)],
          'iroler': [('irol', False)],
          'irolernes': [('irol', False)],
          'irolers': [('irol', False)],
          'iroller': [('irolle', False)],
          'irollerne': [('irolle', False)],
          'iros': [('iro', False)],
          'irren': [('ir', False)],
          'irrens': [('ir', True)],
          'irret': [('ir', False)],
          'irrets': [('ir', False)],
          'irs': [('ir', False)],
          "irs'": [('ir', False)],
          'irsen': [('irse', False)],
          'irsens': [('irse', False)],
          'irser': [('irser', False)],
          'irserne': [('irser', False)],
          'irsernes': [('irser', False)],
          'irsers': [('irser', False)],
          'irses': [('irse', False)],
          'irternes': [('irt', False)],
          'irtiden': [('irtiden', False)],
          'irtlerne': [('irtel', False)],
          'irtlernes': [('irtel', False)],
          'irtlers': [('irtel', False)],
          'irts': [('irts', False)],
          "irts'": [('irts', False)],
          'iruet': [('iruet', False)],
          'iruets': [('iruet', False)],
          'irummet': [('irum', False)],
          'irummets': [('irum', False)],
          'irupper': [('irup', False)],
          'iruppernes': [('irup', False)],
          'irus': [('irus', False)],
          'irusser': [('irus', False)],
          'irusserne': [('irus', False)],
          'irussernes': [('irus', False)],
          'irussers': [('irus', False)],
          'is': [('is', False)],
          "is'": [('is', False)],
          'isa': [('isum', False)],
          'isaene': [('isum', False)],
          'isaenes': [('isum', False)],
          'isander': [('isand', False)],
          'isanderne': [('isand', False)],
          'isandernes': [('isand', False)],
          'isanders': [('isander', False)],
          'isanger': [('isang', False)],
          'isangerne': [('isang', False)],
          'isangernes': [('isang', False)],
          'isangers': [('isang', False)],
          'isans': [('isan', False)],
          'isas': [('isum', False)],
          'ischen': [('isch', False)],
          'ischens': [('isch', False)],
          'ischer': [('isch', False)],
          'ischerne': [('isch', False)],
          'ischers': [('isch', False)],
          'isdækket': [('isdække', True)],
          'isdækkets': [('isdække', True)],
          'ise': [('is', False)],
          'iselen': [('isel', False)],
          'iselens': [('isel', False)],
          'iselører': [('iselør', False)],
          'iselørernes': [('iselør', False)],
          'isen': [('is', False)],
          'isene': [('is', False)],
          'isenes': [('is', False)],
          'isens': [('is', False)],
          'isentens': [('isent', False)],
          'iser': [('is', False)],
          'isere': [('iser', False)],
          'iseren': [('iser', False)],
          'iserens': [('iser', False)],
          'iserer': [('isere', False)],
          'isererne': [('isere', False)],
          'iserernes': [('isere', False)],
          'iseres': [('iser', False)],
          'iserier': [('iseri', False)],
          'iserierne': [('iseri', False)],
          'iseriernes': [('iseri', False)],
          'iseriers': [('iseri', False)],
          'iserne': [('is', False)],
          'isernes': [('is', False)],
          'isers': [('ise', False)],
          'ises': [('is', False)],
          'iset': [('is', False)],
          'isets': [('is', False)],
          'ishandlerne': [('ishandler', False)],
          'ishandlernes': [('ishandler', False)],
          'ishave': [('ishav', True)],
          'ishaves': [('ishav', True)],
          'isicienes': [('isiko', False)],
          'isiet': [('isi', False)],
          'isingers': [('ising', False)],
          'isitter': [('isit', False)],
          'isitterne': [('isit', False)],
          'iskaber': [('iskab', False)],
          'iskaberne': [('iskab', False)],
          'iskabernes': [('iskab', False)],
          'iskabers': [('iskab', False)],
          'iskaffer': [('iskaffe', True)],
          'iskafferne': [('iskaffe', True)],
          'iskaffernes': [('iskaffe', True)],
          'iskaffers': [('iskaffe', True)],
          'iske': [('iske', False)],
          'iskene': [('isk', False)],
          'iskens': [('isk', False)],
          'isker': [('isk', False)],
          'iskeris': [('iskeri', False)],
          'iskerne': [('isk', False)],
          'iskernes': [('isk', False)],
          'iskers': [('isker', False)],
          'iskes': [('isk', False)],
          'isket': [('isk', False)],
          'iskets': [('isk', False)],
          'isketter': [('iskette', False)],
          'iskner': [('isken', False)],
          'isknernes': [('isken', False)],
          'iskners': [('isken', False)],
          'iskos': [('isko', False)],
          'iskossen': [('iskos', False)],
          'iskossens': [('iskos', False)],
          'iskosser': [('iskos', False)],
          'iskosserne': [('iskos', False)],
          'iskossernes': [('iskos', False)],
          'iskossers': [('iskos', False)],
          'iskrige': [('iskrig', False)],
          'iskrigen': [('iskrig', False)],
          'iskrigens': [('iskrig', False)],
          'iskriges': [('iskrig', False)],
          'iskurs': [('iskurs', False)],
          'iskytter': [('iskytte', False)],
          'islags': [('islag', False)],
          'islen': [('issel', False)],
          'islens': [('isel', False)],
          'isler': [('issel', False)],
          'islerne': [('issel', False)],
          'islernes': [('issel', False)],
          'islers': [('issel', False)],
          'islinger': [('isling', False)],
          'islingerne': [('isling', False)],
          'islingernes': [('isling', False)],
          'islingers': [('isling', False)],
          'islommen': [('islom', True)],
          'islommens': [('islom', True)],
          'islommerne': [('islom', True)],
          'ismen': [('isme', True)],
          'ismens': [('isme', True)],
          'ismer': [('isme', False)],
          'ismerne': [('isme', False)],
          'ismernes': [('isme', False)],
          'ismers': [('isme', True)],
          'ismutten': [('ismut', False)],
          'ismuttens': [('ismut', False)],
          'isoden': [('isode', False)],
          'isodens': [('isode', False)],
          'isole': [('isol', False)],
          'isolen': [('isol', False)],
          'isolens': [('isole', False)],
          'isoler': [('isole', False)],
          'isolerne': [('isole', False)],
          'isolernes': [('isole', False)],
          'isolers': [('isole', False)],
          'isoles': [('isol', False)],
          'isoner': [('ison', False)],
          'isonerne': [('ison', False)],
          'isonernes': [('ison', False)],
          'isoners': [('ison', False)],
          'isonet': [('ison', False)],
          'isonets': [('ison', False)],
          'isoriers': [('isorium', False)],
          'isorium': [('isorium', False)],
          'isoriums': [('isorium', False)],
          'ispicen': [('ispice', False)],
          'ispicens': [('ispice', False)],
          'issagen': [('issage', False)],
          'issagers': [('issage', False)],
          'issarier': [('issarius', False)],
          'issariers': [('issarius', False)],
          'issen': [('isse', False)],
          'issene': [('is', False)],
          'issenes': [('is', False)],
          'issens': [('isse', False)],
          'isser': [('isse', False)],
          'isserne': [('isse', False)],
          'issernes': [('isse', False)],
          'issers': [('isse', True)],
          'isset': [('is', False)],
          'issets': [('is', False)],
          'issinier': [('issini', False)],
          'issinierne': [('issini', False)],
          'issioner': [('ission', False)],
          'issionerne': [('ission', False)],
          'issionernes': [('ission', False)],
          'issioners': [('ission', False)],
          'istads': [('istad', False)],
          'istager': [('istager', False)],
          'istagerne': [('istager', False)],
          'istagernes': [('istager', False)],
          'istagers': [('istager', False)],
          'istanke': [('istanke', False)],
          'istanken': [('istanke', False)],
          'istankens': [('istanke', False)],
          'istankes': [('istanke', False)],
          'istans': [('istans', False)],
          'istansen': [('istans', False)],
          'istansens': [('istans', False)],
          'istanser': [('istans', False)],
          'istanserne': [('istans', False)],
          'istansernes': [('istans', False)],
          'istansers': [('istans', False)],
          'istave': [('istav', False)],
          'istaven': [('istav', False)],
          'istavens': [('istav', False)],
          'istaves': [('istav', False)],
          'iste': [('iste', False)],
          'istelen': [('istel', False)],
          'istelens': [('istel', False)],
          'istempler': [('istempel', False)],
          'istemplerne': [('istempel', False)],
          'istemplernes': [('istempel', False)],
          'istemplers': [('istempel', False)],
          'istene': [('ist', False)],
          'istenes': [('ist', False)],
          'istenten': [('istent', False)],
          'istentens': [('istent', False)],
          'istenter': [('istent', False)],
          'istenterne': [('istent', False)],
          'istenternes': [('istent', False)],
          'istenters': [('istent', False)],
          'isterier': [('isteri', False)],
          'isterierne': [('isteri', False)],
          'isteriernes': [('isteri', False)],
          'isteriers': [('isteri', False)],
          'isteriet': [('isteri', False)],
          'isteriets': [('isteri', False)],
          'istes': [('iste', False)],
          'isti': [('isti', False)],
          'istiens': [('isti', False)],
          'istierne': [('isti', False)],
          'istiernes': [('isti', False)],
          'istiers': [('isti', False)],
          'istiet': [('isti', False)],
          'istiets': [('isti', False)],
          'istika': [('istikon', False)],
          'istikaene': [('istikum', False)],
          'istikaenes': [('istikum', False)],
          'istikas': [('istikon', False)],
          'istikken': [('istik', False)],
          'istikker': [('istik', False)],
          'istikkerne': [('istik', False)],
          'istikkernes': [('istik', False)],
          'istikkers': [('istik', False)],
          'istikon': [('istikum', False)],
          'istikons': [('istikum', False)],
          'istiller': [('istil', False)],
          'istillerne': [('istil', False)],
          'istillernes': [('istil', False)],
          'istillers': [('istil', False)],
          'istillids': [('istillid', False)],
          'istis': [('isti', False)],
          'istlerne': [('istel', False)],
          'istlernes': [('istel', False)],
          'istlers': [('istel', False)],
          'istningers': [('istning', False)],
          'istorier': [('istorium', False)],
          'istorierne': [('istorium', False)],
          'istoriernes': [('istorium', False)],
          'istoriers': [('istorium', False)],
          'istoris': [('istori', False)],
          'istraten': [('istrat', False)],
          'istratens': [('istrat', False)],
          'istrater': [('istrat', False)],
          'istraterne': [('istrat', False)],
          'istraternes': [('istrat', False)],
          'istraters': [('istrat', False)],
          'istre': [('ister', False)],
          'istringens': [('istring', False)],
          'istyrer': [('istyre', False)],
          'istyrerne': [('istyre', False)],
          'istyrernes': [('istyre', False)],
          'istyrers': [('istyre', False)],
          'istyret': [('istyre', False)],
          'istyrets': [('istyre', False)],
          'istøvler': [('istøvle', False)],
          'istøvlerne': [('istøvle', False)],
          'istøvlernes': [('istøvle', False)],
          'isummer': [('isum', False)],
          'isummerne': [('isum', False)],
          'isummernes': [('isum', False)],
          'isummers': [('isum', False)],
          'isus': [('isu', False)],
          'isværker': [('isværk', True)],
          'isværkerne': [('isværk', True)],
          'isværkernes': [('isværk', True)],
          'isværkers': [('isværk', True)],
          'isøren': [('isør', False)],
          'isørens': [('isør', False)],
          'isører': [('isør', False)],
          'isørernes': [('isør', False)],
          'ita': [('itum', False)],
          'itaene': [('itum', False)],
          'itaenes': [('itum', False)],
          'itafet': [('itaf', False)],
          'itafets': [('itaf', False)],
          'itage': [('itage', False)],
          'itagens': [('itage', False)],
          'itager': [('itage', False)],
          'itagerne': [('itage', False)],
          'itagernes': [('itage', False)],
          'itagers': [('itage', False)],
          'itages': [('itage', False)],
          'italen': [('ital', False)],
          'italens': [('ital', False)],
          'italer': [('italer', True)],
          'italerne': [('italer', True)],
          'italernes': [('italer', True)],
          'italers': [('italer', True)],
          'itallerne': [('ital', False)],
          'itallernes': [('ital', False)],
          'itamenterne': [('itament', False)],
          'itamenternes': [('itament', False)],
          'itamenters': [('itament', False)],
          'itan': [('itan', False)],
          'itanen': [('itan', False)],
          'itanens': [('itaner', False)],
          'itaner': [('itan', False)],
          'itanerne': [('itaner', False)],
          'itanernes': [('itaner', False)],
          'itaners': [('itan', False)],
          'itanet': [('itan', False)],
          'itanets': [('itan', False)],
          'itanierne': [('itani', False)],
          'itaniers': [('itani', False)],
          'itans': [('itaner', False)],
          'itanten': [('itant', False)],
          'itantens': [('itant', False)],
          'itanter': [('itant', False)],
          'itanterne': [('itant', False)],
          'itanternes': [('itant', False)],
          'itanters': [('itant', False)],
          'itarer': [('itar', False)],
          'itarernes': [('itar', False)],
          'itas': [('itum', False)],
          "itas'": [('itas', False)],
          'itater': [('itat', False)],
          'itaterne': [('itat', False)],
          'itaternes': [('itat', False)],
          'itaters': [('itat', False)],
          'itats': [('itat', False)],
          'itauer': [('itauer', False)],
          'itauerne': [('itauer', False)],
          'itauernes': [('itauer', False)],
          'itauers': [('itauer', False)],
          'itbo': [('itbo', False)],
          'itboer': [('itbo', False)],
          'itbos': [('itbo', False)],
          'itches': [('itch', False)],
          'iteater': [('iteater', False)],
          'iteler': [('itel', False)],
          'itelernes': [('itel', False)],
          'itelers': [('itel', False)],
          'itelet': [('itel', False)],
          'iten': [('it', False)],
          'itene': [('it', False)],
          'itenes': [('ite', False)],
          'itens': [('it', False)],
          'itensen': [('itense', False)],
          'itensens': [('itense', False)],
          'itenter': [('itent', False)],
          'iter': [('iter', False)],
          'iterier': [('iterie', False)],
          'iterierne': [('iterie', False)],
          'iteriernes': [('iterie', False)],
          'iteriers': [('iterie', False)],
          'iteriet': [('iterie', False)],
          'iteriets': [('iterie', False)],
          'iternes': [('iter', False)],
          'iters': [('iter', False)],
          'itesernes': [('itese', False)],
          'itet': [('itet', False)],
          'iteten': [('itet', False)],
          'itetens': [('itet', False)],
          'iteterne': [('itet', False)],
          'iteternes': [('itet', False)],
          'itets': [('itet', False)],
          'ithandler': [('ithandel', False)],
          'ithandlers': [('ithandel', False)],
          'iti': [('itus', False)],
          'itiden': [('itid', False)],
          'itids': [('itid', False)],
          'itiene': [('itus', False)],
          'itienes': [('itus', False)],
          'itier': [('itier', False)],
          'itierne': [('itier', False)],
          'itiernes': [('itier', False)],
          'itiers': [('itier', False)],
          'itikkens': [('itik', False)],
          'itikker': [('itik', False)],
          'itikkernes': [('itik', False)],
          'itikkers': [('itik', False)],
          'itiks': [('itik', False)],
          'itimer': [('itime', False)],
          'itimerne': [('itime', False)],
          'itimernes': [('itime', False)],
          'itimers': [('itime', False)],
          'itinen': [('itin', False)],
          'itinens': [('itin', False)],
          'itiner': [('itin', False)],
          'itinerne': [('itin', False)],
          'itinernes': [('itin', False)],
          'itiners': [('itin', False)],
          'itinet': [('itin', False)],
          'itinets': [('itin', False)],
          'itis': [('itis', False)],
          'itium': [('itium', False)],
          'itiums': [('itium', False)],
          'itiver': [('itiv', False)],
          'itivernes': [('itiv', False)],
          'itlen': [('ittel', False)],
          'itlens': [('itel', False)],
          'itler': [('itel', False)],
          'itlerne': [('ittel', False)],
          'itlernes': [('ittel', False)],
          'itlers': [('ittel', False)],
          'itlet': [('itel', False)],
          'itlærerne': [('itlærer', False)],
          'itlærernes': [('itlærer', False)],
          'itmappen': [('itmap', False)],
          'itningen': [('itning', False)],
          'itninger': [('itning', False)],
          'itningerne': [('itning', False)],
          'itningernes': [('itning', False)],
          'itoer': [('ito', False)],
          'itoerne': [('ito', False)],
          'itoernes': [('ito', False)],
          'itoers': [('ito', False)],
          'itonen': [('iton', False)],
          'itonens': [('iton', False)],
          'itoner': [('iton', False)],
          'itonerne': [('iton', False)],
          'itonernes': [('iton', False)],
          'itoners': [('iton', False)],
          'itorier': [('itorie', False)],
          'itorierne': [('itorie', False)],
          'itoriernes': [('itorie', False)],
          'itoriers': [('itorie', False)],
          'itoriet': [('itorie', False)],
          'itoriets': [('itorie', False)],
          'itoris': [('itoris', False)],
          'itra': [('itra', False)],
          'itras': [('itra', False)],
          'itraten': [('itrate', False)],
          'itratens': [('itrate', False)],
          'itrater': [('itrate', False)],
          'itraterne': [('itrate', False)],
          'itraternes': [('itrate', False)],
          'itraters': [('itrate', False)],
          'itraven': [('itrav', False)],
          'itravens': [('itrav', False)],
          'itraver': [('itrav', False)],
          'itraverne': [('itrav', False)],
          'itravernes': [('itrav', False)],
          'itravers': [('itrav', False)],
          'itre': [('itter', False)],
          'itrene': [('iter', False)],
          'itrenes': [('iter', False)],
          'itres': [('iter', False)],
          'itresser': [('itresse', False)],
          'itresserne': [('itresse', False)],
          'itressernes': [('itresse', False)],
          'itressers': [('itresse', False)],
          'itricen': [('itrice', False)],
          'itricens': [('itrice', False)],
          'itricerne': [('itrice', False)],
          'itricernes': [('itrice', False)],
          'itricers': [('itrice', False)],
          'itrinen': [('itrine', False)],
          'itrinens': [('itrine', False)],
          'itriner': [('itrin', False)],
          'itrinerne': [('itrine', False)],
          'itrinernes': [('itrine', False)],
          'itriners': [('itrin', False)],
          'itringens': [('itring', False)],
          'itronen': [('itron', False)],
          'itronens': [('itron', False)],
          'itroner': [('itron', False)],
          'itronerne': [('itron', False)],
          'itronernes': [('itron', False)],
          'itroners': [('itron', False)],
          'itrosen': [('itrose', False)],
          'itrosens': [('itrose', False)],
          'itroser': [('itrose', False)],
          'itroserne': [('itrose', False)],
          'itrosernes': [('itrose', False)],
          'itrosers': [('itrose', False)],
          'itrusser': [('itrusse', False)],
          'itrusserne': [('itrusse', False)],
          'itrussernes': [('itrusse', False)],
          'itrussers': [('itrusse', False)],
          'its': [('it', False)],
          "its'": [('it', False)],
          'itse': [('itse', False)],
          'itsen': [('itse', False)],
          'itsens': [('itse', False)],
          'itser': [('itse', False)],
          'itserne': [('itse', False)],
          'itsernes': [('itse', False)],
          'itsers': [('itse', False)],
          'itses': [('itse', False)],
          'itte': [('itte', False)],
          'itter': [('it', False)],
          'itterede': [('itteret', False)],
          'itteret': [('itteret', False)],
          'itterets': [('itteret', False)],
          'itterne': [('it', False)],
          'itters': [('itter', False)],
          'ittes': [('itte', False)],
          'itude': [('itude', False)],
          'ituden': [('itude', False)],
          'itudens': [('itude', False)],
          'itudes': [('itude', False)],
          'iture': [('iture', False)],
          'ituren': [('itur', False)],
          'iturens': [('itur', False)],
          'iturer': [('itur', False)],
          'iturerne': [('itur', False)],
          'iturernes': [('itur', False)],
          'iturers': [('itur', False)],
          'itures': [('iture', False)],
          'ituret': [('itur', False)],
          'iturets': [('iture', False)],
          'itus': [('itus', False)],
          'itusinder': [('itusinder', False)],
          'itusinders': [('itusinder', False)],
          'ituts': [('itut', False)],
          'itører': [('itør', False)],
          'itørerne': [('itøre', False)],
          'itørernes': [('itøre', False)],
          'itørers': [('itøre', False)],
          'ium': [('ium', False)],
          'iummen': [('ium', False)],
          'iummens': [('ium', False)],
          'iummernes': [('ium', False)],
          'iummers': [('ium', False)],
          'iums': [('ium', False)],
          'iurger': [('iurg', False)],
          'iurgernes': [('iurg', False)],
          'iurgers': [('iurg', False)],
          'iussen': [('ius', False)],
          'iussens': [('ius', False)],
          'iusser': [('ius', False)],
          'iusserne': [('ius', False)],
          'ivalen': [('ival', False)],
          'ivalens': [('ival', False)],
          'ivaler': [('ival', False)],
          'ivalerne': [('ival', False)],
          'ivalernes': [('ival', False)],
          'ivalers': [('ival', False)],
          'ivals': [('ival', False)],
          "ivals'": [('ival', False)],
          'ivanen': [('ivan', False)],
          'ivanens': [('ivan', False)],
          'ivaner': [('ivan', False)],
          'ivanerne': [('ivan', False)],
          'ivanernes': [('ivan', False)],
          'ivaners': [('ivan', False)],
          'ivankers': [('ivanker', False)],
          'ivans': [('ivan', False)],
          'ivanten': [('ivant', False)],
          'ivantens': [('ivant', False)],
          'ivanter': [('ivant', False)],
          'ivanterne': [('ivant', False)],
          'ivanternes': [('ivant', False)],
          'ivanters': [('ivant', False)],
          'ivarbejder': [('ivarbejde', False)],
          'ivarbejderne': [('ivarbejde', False)],
          'ivarbejders': [('ivarbejde', False)],
          'ivaren': [('ivar', False)],
          'ivarens': [('ivar', False)],
          'ivarerne': [('ivar', False)],
          'ivarier': [('ivarium', False)],
          'ivarierne': [('ivarium', False)],
          'ivariernes': [('ivarium', False)],
          'ivariers': [('ivarium', False)],
          'ivarium': [('ivarium', False)],
          'ivariums': [('ivarium', False)],
          'ivater': [('ivat', False)],
          'ive': [('iv', False)],
          'ivejene': [('ivej', False)],
          'iven': [('iv', False)],
          'ivende': [('ivende', False)],
          'ivender': [('ivende', False)],
          'ivenderne': [('ivende', False)],
          'ivendernes': [('ivende', False)],
          'ivenders': [('ivende', False)],
          'ivendes': [('ivende', False)],
          'ivene': [('iv', False)],
          'ivenen': [('iven', False)],
          'ivenens': [('iven', False)],
          'ivenerne': [('iven', False)],
          'ivenernes': [('iven', False)],
          'ivenes': [('iv', False)],
          'ivens': [('iv', False)],
          'iver': [('iver', True)],
          'iverens': [('iver', False)],
          'iverne': [('iver', False)],
          'ivernes': [('iv', False)],
          'ivers': [('iver', False)],
          'iverter': [('ivert', False)],
          'iverternes': [('ivert', False)],
          'ives': [('iv', False)],
          'ivesager': [('ivesager', False)],
          'ivesagerne': [('ivesager', False)],
          'ivet': [('iv', False)],
          'ivets': [('iv', False)],
          'ivgassen': [('ivgas', False)],
          'ivgassens': [('ivgas', False)],
          'ivgasser': [('ivgas', False)],
          'ivgasserne': [('ivgas', False)],
          'ivgassers': [('ivgas', False)],
          'ivianer': [('ivianer', False)],
          'ivianers': [('ivianer', False)],
          'ivider': [('ivid', False)],
          'ividerne': [('ivid', False)],
          'ividernes': [('ivid', False)],
          'ividers': [('ivid', False)],
          'ivien': [('ivie', False)],
          'iviens': [('ivie', False)],
          'ivier': [('ivie', False)],
          'ivierne': [('ivie', False)],
          'iviernes': [('ivie', False)],
          'iviers': [('ivie', False)],
          'ivinernes': [('ivin', False)],
          'ivingen': [('iving', False)],
          'ivingens': [('iving', False)],
          'ivinger': [('iving', False)],
          'ivingerne': [('iving', False)],
          'ivingernes': [('iving', False)],
          'ivingers': [('iving', False)],
          'ivins': [('ivin', False)],
          'ivisen': [('ivis', False)],
          'ivisens': [('ivis', False)],
          'ivitas': [('ivitas', False)],
          'ivler': [('ivler', False)],
          'ivlerne': [('ivler', False)],
          'ivlernes': [('ivler', False)],
          'ivnet': [('ivnet', False)],
          'ivnets': [('ivnet', False)],
          'ivoksen': [('ivoks', False)],
          'ivoksens': [('ivoks', False)],
          'ivoten': [('ivot', False)],
          'ivotens': [('ivot', False)],
          'ivoter': [('ivot', False)],
          'ivoterne': [('ivot', False)],
          'ivoternes': [('ivot', False)],
          'ivoters': [('ivot', False)],
          'ivre': [('ivre', False)],
          'ivs': [('iv', False)],
          'ivstikkers': [('ivstikker', False)],
          'iwiers': [('iwi', False)],
          'ixer': [('ix', False)],
          'ixerne': [('ix', False)],
          'ixernes': [('ix', False)],
          'ixers': [('ix', False)],
          'izen': [('iz', False)],
          'izens': [('iz', False)],
          'izer': [('iz', False)],
          'izerne': [('izer', False)],
          'izernes': [('izer', False)],
          'izers': [('iz', False)],
          'izoens': [('izo', False)],
          'izzen': [('iz', False)],
          'izzens': [('iz', False)],
          'iæder': [('iæder', False)],
          'iæderne': [('iæder', False)],
          'iænders': [('iand', False)],
          'iøje': [('iøje', False)],
          'iøjen': [('iøje', False)],
          'iøjens': [('iøje', False)],
          'iøjers': [('iøje', False)],
          'iøjes': [('iøje', False)],
          'iøren': [('iør', False)],
          'iørens': [('iør', False)],
          'iører': [('iøre', False)],
          'iørerne': [('iør', False)],
          'iørernes': [('iør', False)],
          'iørers': [('iør', False)],
          'iøret': [('iør', False)],
          'iørets': [('iør', False)],
          "j'erne": [('j', True)],
          'ja': [('ja', False)],
          'jabbens': [('jab', False)],
          'jabber': [('jab', False)],
          'jabbernes': [('jab', False)],
          'jabbers': [('jab', False)],
          'jabs': [('jab', False)],
          "jabs'": [('jab', True)],
          'jacks': [('jack', False)],
          'jadder': [('jadder', False)],
          'jadders': [('jadder', False)],
          'jade': [('jade', False)],
          'jaden': [('jade', True)],
          'jadens': [('jade', True)],
          'jadere': [('jadere', False)],
          'jaderen': [('jadere', False)],
          'jaderens': [('jadere', False)],
          'jadererne': [('jadere', False)],
          'jaderernes': [('jadere', False)],
          'jaderes': [('jadere', False)],
          'jaderne': [('jade', False)],
          'jaders': [('jade', False)],
          'jades': [('jade', False)],
          'jadlen': [('jadel', False)],
          'jads': [('jads', False)],
          "jads'": [('jads', False)],
          'jadser': [('jads', False)],
          'jadserne': [('jads', False)],
          'jadsernes': [('jads', False)],
          'jadsers': [('jads', False)],
          'jaen': [('ja', False)],
          'jaens': [('ja', False)],
          'jaer': [('ja', False)],
          'jaerne': [('ja', True)],
          'jaernes': [('ja', False)],
          'jaers': [('ja', True)],
          'jagerne': [('jager', True)],
          'jagernes': [('jager', True)],
          'jagger': [('jagger', False)],
          'jagter': [('jagt', False)],
          'jagterne': [('jagt', False)],
          'jagternes': [('jagt', False)],
          'jaketten': [('jaket', True)],
          'jakettens': [('jaket', True)],
          'jaketterne': [('jaket', True)],
          'jaketternes': [('jaket', True)],
          'jaketters': [('jaket', True)],
          'jakken': [('jakke', True)],
          'jakkens': [('jakke', False)],
          'jakker': [('jakke', False)],
          'jakkerne': [('jakke', True)],
          'jakkernes': [('jakke', False)],
          'jakkers': [('jakke', False)],
          'jakroers': [('jakroer', False)],
          'jaks': [('jak', False)],
          'jalde': [('jald', False)],
          'jalden': [('jald', False)],
          'jaldens': [('jald', False)],
          'jaldes': [('jald', False)],
          'jalken': [('jalk', False)],
          'jalkes': [('jalk', False)],
          'jaller': [('jaller', False)],
          'jallerne': [('jaller', False)],
          'jallernes': [('jaller', False)],
          'jalte': [('jalt', False)],
          'jalten': [('jalt', False)],
          'jaltens': [('jalt', False)],
          'jalter': [('jalter', False)],
          'jalternes': [('jalt', False)],
          'jalters': [('jalter', False)],
          'jaltes': [('jalt', False)],
          'jamas': [('jamas', False)],
          'jamben': [('jambe', True)],
          'jambens': [('jambe', True)],
          'jammer': [('jammer', False)],
          'jammers': [('jammer', True)],
          'janen': [('jan', False)],
          'janens': [('jan', False)],
          'janer': [('janer', False)],
          'janerne': [('janer', False)],
          'janers': [('janer', False)],
          'jangen': [('jang', False)],
          'jangens': [('jang', False)],
          'janks': [('jank', False)],
          'jans': [('jan', True)],
          "jans'": [('jans', False)],
          'jansen': [('jans', False)],
          'jansens': [('jans', False)],
          'janser': [('jans', False)],
          'jansernes': [('jans', False)],
          'jansers': [('jans', False)],
          'janter': [('jante', False)],
          'jantet': [('jant', False)],
          'jantets': [('jant', False)],
          'jants': [('jant', False)],
          'japis': [('japis', False)],
          'jarbejder': [('jarbejde', False)],
          'jarbejderne': [('jarbejde', False)],
          'jarbejdernes': [('jarbejde', False)],
          'jarbejders': [('jarbejde', False)],
          'jardiniere': [('jardiniere', True)],
          'jardinieren': [('jardiniere', True)],
          'jardinierens': [('jardiniere', True)],
          'jardinieres': [('jardiniere', True)],
          'jas': [('jas', True), ('ja', True)],
          'jasket': [('jask', False)],
          'jaskets': [('jask', False)],
          'jasters': [('jaster', False)],
          'jatten': [('jat', False)],
          'jattens': [('jat', False)],
          'jatternes': [('jat', False)],
          'jatters': [('jat', False)],
          'javanerne': [('javaner', True)],
          'javanernes': [('javaner', True)],
          'javaners': [('javaner', True)],
          'javs': [('javs', False)],
          'jbede': [('jbed', False)],
          'jbedes': [('jbed', False)],
          'jborgen': [('jborg', False)],
          'jborgens': [('jborg', False)],
          'jbroers': [('jbro', False)],
          'jd': [('jd', False)],
          'jdammer': [('jdammer', False)],
          'jdammerne': [('jdammer', False)],
          'jdammernes': [('jdammer', False)],
          'jdammers': [('jdammer', False)],
          'jden': [('jd', False)],
          'jdens': [('jd', False)],
          'jdere': [('jder', False)],
          'jderen': [('jder', False)],
          'jderens': [('jder', False)],
          'jderes': [('jder', False)],
          'jdes': [('jde', False)],
          'jdets': [('jde', False)],
          'jdlærerne': [('jdlærer', False)],
          'jdlærernes': [('jdlærer', False)],
          'jdrikke': [('jdrik', False)],
          'jds': [('jd', False)],
          'jdsdage': [('jdsdag', False)],
          'jdsdagene': [('jdsdag', False)],
          'jdsdagenes': [('jdsdag', False)],
          'jdsdages': [('jdsdag', False)],
          'jdse': [('jdse', False)],
          'jdsen': [('jdse', False)],
          'jdsens': [('jdse', False)],
          'jdser': [('jdse', False)],
          'jdserne': [('jdse', False)],
          'jdsernes': [('jdse', False)],
          'jdsers': [('jdse', False)],
          'jdses': [('jdse', False)],
          'jdukken': [('jduk', False)],
          'jdukkens': [('jduk', False)],
          'jdukker': [('jduk', False)],
          'jdukkerne': [('jduk', False)],
          'jdukkernes': [('jduk', False)],
          'jdukkers': [('jduk', False)],
          'jduks': [('jduk', False)],
          'je': [('je', False)],
          'jebakker': [('jebakke', False)],
          'jebakkernes': [('jebakke', False)],
          'jebakkers': [('jebakke', False)],
          'jecen': [('jece', False)],
          'jecens': [('jece', False)],
          'jecer': [('jece', False)],
          'jecerne': [('jece', False)],
          'jecernes': [('jece', False)],
          'jecers': [('jece', False)],
          'jeces': [('jece', False)],
          'jedagen': [('jedagen', False)],
          'jede': [('jede', False)],
          'jeden': [('jede', False)],
          'jedens': [('jede', False)],
          'jeder': [('jeder', False)],
          'jederne': [('jede', False)],
          'jedernes': [('jede', False)],
          'jeders': [('jeder', False)],
          'jedes': [('jede', False)],
          'jeepernes': [('jeep', True)],
          'jeepers': [('jeep', True)],
          'jefaderen': [('jefar', False)],
          'jefaderens': [('jefar', False)],
          'jefaren': [('jefar', False)],
          'jefædrene': [('jefar', False)],
          'jefædres': [('jefar', False)],
          'jeger': [('jeg', True)],
          'jegerne': [('jeg', False)],
          'jegernes': [('jeg', False)],
          'jegers': [('jeg', True)],
          'jejlerne': [('jejle', False)],
          'jejlernes': [('jejle', False)],
          'jejlers': [('jejle', False)],
          'jek': [('jek', False)],
          'jekerne': [('jekerne', False)],
          'jekernes': [('jekerne', False)],
          'jekker': [('jekke', False)],
          'jekkernes': [('jekke', False)],
          'jekkers': [('jekke', False)],
          'jeks': [('jek', False)],
          'jekter': [('jekt', False)],
          'jekterne': [('jekt', False)],
          'jekternes': [('jekt', False)],
          'jekters': [('jekt', False)],
          'jekturen': [('jektur', False)],
          'jekturens': [('jektur', False)],
          'jekturer': [('jektur', False)],
          'jekturerne': [('jektur', False)],
          'jekturernes': [('jektur', False)],
          'jekturers': [('jektur', False)],
          'jelisternes': [('jeliste', False)],
          'jelisters': [('jeliste', False)],
          'jelsers': [('jelse', False)],
          'jemanden': [('jemand', False)],
          'jemandens': [('jemand', False)],
          'jen': [('je', False)],
          'jender': [('jende', False)],
          'jendernes': [('jende', False)],
          'jenders': [('jende', False)],
          'jener': [('jener', False)],
          'jenerne': [('jener', False)],
          'jenernes': [('jener', False)],
          'jeners': [('jener', False)],
          'jenes': [('j', False)],
          'jens': [('jens', True)],
          "jens'": [('jens', True)],
          'jenser': [('jens', True)],
          'jensernes': [('jens', True)],
          'jensers': [('jens', True)],
          'jente': [('jent', False)],
          'jenten': [('jent', False)],
          'jentens': [('jent', False)],
          'jentes': [('jent', False)],
          'jer': [('jer', False)],
          'jerene': [('jer', False)],
          'jerenes': [('jer', False)],
          'jerge': [('jerg', False)],
          'jergenser': [('jergenser', False)],
          'jergensernes': [('jergenser', False)],
          'jerges': [('jerg', False)],
          'jerier': [('jeri', False)],
          'jerierne': [('jeri', False)],
          'jeriernes': [('jeri', False)],
          'jeriers': [('jeri', False)],
          'jeriet': [('jeri', False)],
          'jeriets': [('jeri', False)],
          'jeris': [('jeri', False)],
          'jermænd': [('jermand', False)],
          'jermændene': [('jermand', False)],
          'jermændenes': [('jermand', False)],
          'jermænds': [('jermand', False)],
          'jerne': [('je', False)],
          'jerner': [('jerner', False)],
          'jernerne': [('jerner', False)],
          'jernernes': [('jerner', False)],
          'jerners': [('jerne', False)],
          'jernes': [('je', False)],
          'jernet': [('jern', False)],
          'jernets': [('jern', False)],
          'jerpen': [('jerpen', False)],
          'jerpens': [('jerpen', False)],
          'jerpernes': [('jerpe', False)],
          'jerpers': [('jerpe', False)],
          'jerpes': [('jerpe', False)],
          'jerrotten': [('jerrot', False)],
          'jerrotterne': [('jerrot', False)],
          'jers': [('je', False)],
          'jersken': [('jerske', False)],
          'jersker': [('jerske', False)],
          'jerskerne': [('jerske', False)],
          'jerskers': [('jerske', False)],
          'jerte': [('jert', False)],
          'jerten': [('jert', False)],
          'jertens': [('jert', False)],
          'jerter': [('jert', False)],
          'jertes': [('jert', False)],
          'jertets': [('jerte', False)],
          'jerts': [('jert', False)],
          'jes': [('je', False)],
          'jesken': [('jesk', False)],
          'jesker': [('jesk', False)],
          'jeskerne': [('jesk', False)],
          'jeskers': [('jesk', False)],
          'jeskifters': [('jeskift', False)],
          'jespids': [('jespid', False)],
          'jestene': [('jesten', False)],
          'jestens': [('jesten', False)],
          'jestudies': [('jestudie', False)],
          'jet': [('jet', True)],
          'jetager': [('jetager', False)],
          'jetagere': [('jetager', False)],
          'jetageren': [('jetager', False)],
          'jetagerens': [('jetager', False)],
          'jetageres': [('jetager', False)],
          'jetagerne': [('jetager', False)],
          'jetagernes': [('jetager', False)],
          'jetagers': [('jetager', False)],
          'jets': [('jet', True)],
          'jetten': [('jet', True)],
          'jettens': [('jet', False)],
          'jetter': [('jet', True)],
          'jetterne': [('jet', True)],
          'jetternes': [('jet', False)],
          'jetters': [('jet', True)],
          'jettet': [('jet', False)],
          'jettets': [('jet', False)],
          'jevikken': [('jevik', False)],
          'jevikker': [('jevik', False)],
          'jevinders': [('jevinder', False)],
          'jevs': [('jevs', False)],
          'jevser': [('jevs', False)],
          'jevserne': [('jevs', False)],
          'jevsernes': [('jevs', False)],
          'jevsers': [('jevs', False)],
          'jfen': [('jfe', False)],
          'jfene': [('jf', False)],
          'jfenes': [('jf', False)],
          'jfens': [('jfe', False)],
          'jferes': [('jfer', False)],
          'jfes': [('jfe', False)],
          'jfet': [('jf', False)],
          'jfets': [('jf', False)],
          'jfilter': [('jfilter', False)],
          'jfilters': [('jfilter', False)],
          'jflys': [('jflys', False)],
          'jgas': [('jga', False)],
          'jheden': [('jhed', False)],
          'jhedens': [('jhed', False)],
          'jheder': [('jhed', False)],
          'jhederne': [('jhed', False)],
          'jhedernes': [('jhed', False)],
          'jheders': [('jhed', False)],
          'jhus': [('jhus', False)],
          'ji': [('ji', False)],
          'jianerne': [('jianer', False)],
          'jianernes': [('jianer', False)],
          'jien': [('ji', False)],
          'jiene': [('ji', False)],
          'jienes': [('ji', False)],
          'jiens': [('ji', False)],
          'jier': [('ji', False)],
          'jierne': [('ji', False)],
          'jiernes': [('ji', False)],
          'jiers': [('ji', False)],
          'jigger': [('jigger', True)],
          'jiggers': [('jigger', True)],
          'jinglen': [('jingle', True)],
          'jinglernes': [('jingle', True)],
          'jinglers': [('jingle', True)],
          'jis': [('ji', False)],
          "jis'": [('ji', False)],
          'jive': [('jive', True)],
          'jiven': [('jive', True)],
          'jivens': [('jive', True)],
          'jives': [('jive', True)],
          'jka': [('jka', False)],
          'jkas': [('jka', False)],
          'jkens': [('jke', False)],
          'jkerne': [('jke', False)],
          'jkernes': [('jke', False)],
          'jkers': [('jke', False)],
          'jkilder': [('jkilde', False)],
          'jkilderne': [('jkilde', False)],
          'jkildernes': [('jkilde', False)],
          'jkilders': [('jkilde', False)],
          'jl': [('jl', False)],
          'jlads': [('jlads', False)],
          'jleder': [('jleder', False)],
          'jledernes': [('jleder', False)],
          'jlemærkerne': [('jlemærke', False)],
          'jlemærkernes': [('jlemærke', False)],
          'jlemærkers': [('jlemærke', False)],
          'jlene': [('jl', False)],
          'jlenes': [('jl', False)],
          'jlenser': [('jlenser', False)],
          'jlensernes': [('jlenser', False)],
          'jlensers': [('jlenser', False)],
          'jlere': [('jler', False)],
          'jleren': [('jler', False)],
          'jlerens': [('jler', False)],
          'jleres': [('jler', False)],
          'jlet': [('jl', False)],
          'jlets': [('jl', False)],
          'jlingers': [('jling', False)],
          'jls': [('jl', False)],
          'jlys': [('jlys', False)],
          'jlænder': [('jlænder', False)],
          'jlænderne': [('jlænder', False)],
          'jlændernes': [('jlænder', False)],
          'jlænders': [('jlænder', False)],
          'jmadders': [('jmad', False)],
          'jmads': [('jmad', False)],
          'jmer': [('jmer', False)],
          'jmere': [('jmer', False)],
          'jmeren': [('jmer', False)],
          'jmerens': [('jmer', False)],
          'jmeres': [('jmer', False)],
          'jmerne': [('jmer', False)],
          'jmernes': [('jmer', False)],
          'jmers': [('jmer', False)],
          'jmosen': [('jmose', False)],
          'jmosens': [('jmose', False)],
          'jmænd': [('jmand', False)],
          'jn': [('jn', False)],
          'jnen': [('jn', False)],
          'jnens': [('jn', False)],
          'jner': [('jn', False)],
          'jnerne': [('jn', False)],
          'jnernes': [('jn', False)],
          'jners': [('jn', False)],
          'jningers': [('jning', False)],
          'jns': [('jn', False)],
          'jobs': [('job', False)],
          'jodder': [('jod', True)],
          'jodderne': [('jod', True)],
          'joddernes': [('jod', True)],
          'jodders': [('jod', True)],
          'joden': [('jod', True)],
          'jodens': [('jod', True)],
          'joen': [('jo', False)],
          'joens': [('jo', False)],
          'joer': [('jo', False)],
          'joerne': [('jo', False)],
          'joernes': [('jo', False)],
          'joers': [('jo', False)],
          'jogets': [('jog', False)],
          'jogger': [('jogger', True)],
          'joggerne': [('jogger', True)],
          'joggers': [('jogger', True)],
          'joken': [('joke', True)],
          'jolde': [('jold', False)],
          'jolden': [('jold', False)],
          'joldene': [('jold', False)],
          'joldenes': [('jold', False)],
          'joldens': [('jold', False)],
          'jolder': [('jold', False)],
          'jolderne': [('jold', False)],
          'joldernes': [('jold', False)],
          'joldes': [('jold', False)],
          'jole': [('jole', False)],
          'jolen': [('jole', False)],
          'jolens': [('jole', False)],
          'jolernes': [('jole', False)],
          'jolers': [('jole', False)],
          'joles': [('jole', False)],
          'jollens': [('jolle', False)],
          'jollerne': [('jolle', True)],
          'jollernes': [('jolle', False)],
          'jollers': [('jolle', False)],
          'jols': [('jols', False)],
          "jols'": [('jols', False)],
          'jonet': [('jonet', False)],
          'jonets': [('jonet', False)],
          'jorde': [('jord', True)],
          'jorden': [('jorden', True), ('jord', True)],
          'jordens': [('jorden', True), ('jord', True)],
          'jorderiget': [('jorderig', True), ('jorderige', True)],
          'jorderigets': [('jorderig', True), ('jorderige', True)],
          'jorderne': [('jord', False)],
          'jordernes': [('jord', False)],
          'jorders': [('jord', True)],
          'jordes': [('jord', False)],
          'jorers': [('jor', False)],
          'jorte': [('jort', False)],
          'jorten': [('jort', False)],
          'jortens': [('jort', False)],
          'jorter': [('jorte', False)],
          'jorternes': [('jorte', False)],
          'jorters': [('jorte', False)],
          'jortes': [('jort', False)],
          'jorts': [('jort', False)],
          'jos': [('jo', False)],
          'joser': [('jos', False)],
          'joserne': [('jos', False)],
          'josernes': [('jos', False)],
          'josers': [('jos', False)],
          'jota': [('jota', True)],
          'jotas': [('jota', True)],
          'jotes': [('jote', False)],
          'jove': [('jove', False)],
          'joven': [('jove', False)],
          'jovens': [('jove', False)],
          'jover': [('jover', False)],
          'joverne': [('jover', False)],
          'jovernes': [('jove', False)],
          'jovers': [('jove', False)],
          'joves': [('jove', False)],
          'jpande': [('jpande', False)],
          'jpanden': [('jpande', False)],
          'jpandes': [('jpande', False)],
          'jpen': [('jpe', False)],
          'jpens': [('jpe', False)],
          'jpernes': [('jpe', False)],
          'jpers': [('jpe', False)],
          'jpes': [('jpe', False)],
          'jr': [('jr', False)],
          'jreben': [('jreben', False)],
          'jrebs': [('jreb', False)],
          'jrene': [('jr', False)],
          'jrenes': [('jr', False)],
          'jret': [('jr', False)],
          'jrets': [('jr', False)],
          'jringer': [('jring', False)],
          'jringerne': [('jring', False)],
          'jringernes': [('jring', False)],
          'jringers': [('jring', False)],
          'jroen': [('jroe', False)],
          'jroens': [('jroe', False)],
          'jroer': [('jroe', False)],
          'jroerne': [('jroe', False)],
          'jroernes': [('jroe', False)],
          'jroers': [('jroe', False)],
          'jrs': [('jr', False)],
          'jrturens': [('jrtur', False)],
          "js'": [('js', False)],
          'jsen': [('js', False)],
          'jsene': [('js', False)],
          'jsenes': [('js', False)],
          'jsens': [('js', False)],
          'jser': [('js', False)],
          'jsere': [('jser', False)],
          'jseren': [('jser', False)],
          'jserens': [('jser', False)],
          'jseres': [('jser', False)],
          'jserne': [('jser', False)],
          'jsernes': [('js', False)],
          'jslaver': [('jslave', False)],
          'jslaverne': [('jslave', False)],
          'jslavernes': [('jslave', False)],
          'jslavers': [('jslave', False)],
          'jslens': [('jsel', False)],
          'jsler': [('jsel', False)],
          'jslinger': [('jsling', False)],
          'jslingerne': [('jsling', False)],
          'jslingernes': [('jsling', False)],
          'jslingers': [('jsling', False)],
          'jstemmer': [('jstemme', False)],
          'jstemmerne': [('jstemme', False)],
          'jstemmernes': [('jstemme', False)],
          'jstemmers': [('jstemme', False)],
          'jsten': [('jst', False)],
          'jstens': [('jst', False)],
          'jstringens': [('jstring', False)],
          'jstænger': [('jstang', False)],
          'jstængerne': [('jstang', False)],
          'jstængernes': [('jstang', False)],
          'jstængers': [('jstang', False)],
          'jsæder': [('jsæde', False)],
          'jsæderne': [('jsæde', False)],
          'jsædernes': [('jsæde', False)],
          'jsæders': [('jsæde', False)],
          'jtaler': [('jtaler', False)],
          'jtalerne': [('jtaler', False)],
          'jtalernes': [('jtaler', False)],
          'jtalers': [('jtaler', False)],
          'jtanden': [('jtand', False)],
          'jtandens': [('jtand', False)],
          'jtelen': [('jtel', False)],
          'jtelens': [('jtel', False)],
          'jteløberne': [('jteløber', False)],
          'jteløbers': [('jteløber', False)],
          'jtene': [('jt', False)],
          'jtenes': [('jt', False)],
          'jtet': [('jt', False)],
          'jtets': [('jt', False)],
          'jtiderne': [('jtid', False)],
          'jtidernes': [('jtid', False)],
          'jtids': [('jtid', False)],
          'jtjerne': [('jtj', False)],
          'jtjernes': [('jtj', False)],
          'jtlens': [('jtel', False)],
          'jtler': [('jtel', False)],
          'jtningen': [('jtning', False)],
          'jtninger': [('jtning', False)],
          'jtningerne': [('jtning', False)],
          'jtningernes': [('jtning', False)],
          'jts': [('jt', False)],
          'jttalerne': [('jttaler', False)],
          'jttalernes': [('jttaler', False)],
          'jtænder': [('jtand', False)],
          'jtænderne': [('jtand', False)],
          'jtændernes': [('jtand', False)],
          'jtænders': [('jtand', False)],
          'juaner': [('juan', False)],
          'juanerne': [('juan', False)],
          'juanernes': [('juan', False)],
          'juaners': [('juan', False)],
          'jublen': [('jubel', True)],
          'jugoslaver': [('jugoslav', True), ('jugoslaver', True)],
          'jugoslaverne': [('jugoslav', True), ('jugoslaver', True)],
          'jugoslavernes': [('jugoslaver', True), ('jugoslav', True)],
          'jugoslavers': [('jugoslaver', True), ('jugoslav', True)],
          'juicer': [('juicer', True), ('juice', True)],
          'juicerne': [('juicer', True), ('juice', True)],
          'juicernes': [('juicer', True), ('juice', True)],
          'juicers': [('juicer', True), ('juice', True)],
          'jukken': [('juk', False)],
          'jukkerne': [('juk', False)],
          'jukkers': [('juk', False)],
          'juks': [('juks', True)],
          'julens': [('jul', True)],
          'juler': [('juler', False)],
          'julerne': [('juler', False)],
          'julernes': [('juler', False)],
          'julers': [('juler', False)],
          'julet': [('jul', False)],
          'juli': [('juli', True)],
          'julis': [('juli', True)],
          'jumper': [('jumper', True)],
          'jumperne': [('jumper', True)],
          'jungers': [('junge', True)],
          'junken': [('junk', True), ('junke', True)],
          'junkens': [('junke', True), ('junk', True)],
          'junker': [('junke', True), ('junker', True)],
          'junkerne': [('junke', True), ('junker', True)],
          'junkernes': [('junke', True), ('junker', True)],
          'junkers': [('junker', True), ('junke', True)],
          "junkers'": [('junker', True)],
          'juns': [('jun', False)],
          'juriers': [('jurie', False)],
          'jurs': [('jur', False)],
          'juskens': [('juske', False)],
          'juskernes': [('juske', False)],
          'juskers': [('juske', False)],
          'juskes': [('juske', False)],
          'jussen': [('jus', False)],
          'jussens': [('jus', False)],
          'jusser': [('jus', False)],
          'jusserne': [('jus', False)],
          'juten': [('jute', True)],
          'jutens': [('jute', True)],
          'juveler': [('juveler', True), ('juvel', True)],
          'juvelers': [('juveler', True), ('juvel', True)],
          'jvande': [('jvande', False)],
          'jvander': [('jvande', False)],
          'jvanderne': [('jvande', False)],
          'jvandernes': [('jvande', False)],
          'jvanders': [('jvande', False)],
          'jvandes': [('jvande', False)],
          'jvandet': [('jvande', False)],
          'jvandets': [('jvande', False)],
          'jviser': [('jviser', False)],
          'jviserne': [('jviser', False)],
          'jvisernes': [('jviser', False)],
          'jvisers': [('jviser', False)],
          'jyde': [('jyde', False)],
          'jyden': [('jyde', True)],
          'jydens': [('jyde', False)],
          'jyder': [('jyde', False)],
          'jyderne': [('jyde', False)],
          'jydernes': [('jyde', False)],
          'jyders': [('jyde', False)],
          'jydes': [('jyde', False)],
          'jæfterne': [('jæft', False)],
          'jæfternes': [('jæft', False)],
          'jæfters': [('jæft', False)],
          'jægerne': [('jæger', False)],
          'jægernes': [('jæger', False)],
          'jægers': [('jæger', False)],
          'jægte': [('jægt', False)],
          'jægten': [('jægt', False)],
          'jægtens': [('jægt', False)],
          'jægter': [('jægt', False)],
          'jægterne': [('jægt', False)],
          'jægternes': [('jægt', False)],
          'jægters': [('jægt', False)],
          'jægtes': [('jægt', False)],
          'jældenes': [('jæld', False)],
          'jælderne': [('jælde', False)],
          'jældernes': [('jælde', False)],
          'jældet': [('jæld', False)],
          'jældets': [('jæld', False)],
          'jæler': [('jæler', False)],
          'jælerne': [('jæler', False)],
          'jælernes': [('jæler', False)],
          'jælers': [('jæler', False)],
          'jælmer': [('jælme', False)],
          'jæren': [('jære', False)],
          'jærens': [('jære', False)],
          'jærer': [('jære', False)],
          'jærerne': [('jære', False)],
          'jærernes': [('jære', False)],
          'jærers': [('jære', False)],
          'jærte': [('jært', False)],
          'jærten': [('jært', False)],
          'jærtes': [('jært', False)],
          'jærve': [('jærv', True)],
          'jærven': [('jærv', True)],
          'jærvens': [('jærv', True)],
          'jærves': [('jærv', True)],
          'jætten': [('jætte', True)],
          'jættens': [('jætte', True)],
          'jætter': [('jætte', True)],
          'jætterne': [('jætte', True)],
          'jætternes': [('jætte', True)],
          'jætters': [('jætte', True)],
          'jævlen': [('jævel', False)],
          'jævnerne': [('jævner', False)],
          'jævnernes': [('jævner', False)],
          'jøden': [('jøde', True)],
          'jødens': [('jøde', True)],
          'jøer': [('jø', False)],
          'jøerne': [('jø', False)],
          'jøernes': [('jø', False)],
          'jøren': [('jør', False)],
          'jørens': [('jør', False)],
          'jører': [('jør', False)],
          'jørerne': [('jør', False)],
          'jørernes': [('jør', False)],
          'jørers': [('jør', False)],
          'jørgen': [('jørgen', False)],
          'jørn': [('jørn', False)],
          'jørne': [('jørn', False)],
          'jørnen': [('jørn', False)],
          'jørnenes': [('jørn', False)],
          'jørnens': [('jørn', False)],
          'jørnerne': [('jørne', False)],
          'jørners': [('jørne', False)],
          'jørnes': [('jørn', False)],
          'jørns': [('jørn', False)],
          'jøs': [('jø', False)],
          'k': [('k', True)],
          "k'erne": [('k', True)],
          'k.': [('estekraft', False)],
          'kabe': [('kab', False)],
          'kaben': [('kab', False)],
          'kabens': [('kab', False)],
          'kabes': [('kab', False)],
          'kabet': [('kab', False)],
          'kabinen': [('kabine', False)],
          'kabinens': [('kabine', False)],
          'kabinerne': [('kabine', False)],
          'kabinernes': [('kabine', False)],
          'kabler': [('kabel', True)],
          'kablerne': [('kabel', False)],
          'kablernes': [('kabel', False)],
          'kablers': [('kabel', True)],
          'kablet': [('kabel', True)],
          'kablets': [('kabel', True)],
          'kabs': [('kab', False)],
          'kade': [('kade', False)],
          'kadellens': [('kadelle', False)],
          'kadeller': [('kadelle', False)],
          'kadellerne': [('kadelle', False)],
          'kadellernes': [('kadelle', False)],
          'kadellers': [('kadelle', False)],
          'kaden': [('kade', False)],
          'kadens': [('kade', False)],
          'kaderne': [('kade', False)],
          'kaders': [('kade', False)],
          'kades': [('kade', False)],
          'kadet': [('kadet', True)],
          'kadets': [('kadet', True)],
          'kadien': [('kadi', True)],
          'kadiens': [('kadi', True)],
          'kadier': [('kadi', True)],
          'kadierne': [('kadi', True)],
          'kadiernes': [('kadi', True)],
          'kadiers': [('kadi', True)],
          'kados': [('kado', False)],
          'kadres': [('kadre', False)],
          'kads': [('kads', False)],
          "kads'": [('kads', False)],
          'kadser': [('kads', False)],
          'kadserne': [('kads', False)],
          'kadsernes': [('kads', False)],
          'kadsers': [('kads', False)],
          'kadset': [('kads', False)],
          'kadsets': [('kads', False)],
          'kaen': [('ka', False)],
          'kaene': [('ka', False)],
          'kaenes': [('ka', False)],
          'kaens': [('ka', False)],
          'kaer': [('ka', False)],
          'kaerne': [('ka', False)],
          'kaernes': [('ka', False)],
          'kaers': [('ka', False)],
          'kaffe': [('kaffe', False)],
          'kaffens': [('kaffe', False)],
          'kaffer': [('kaffe', True), ('kaffer', True)],
          'kafferne': [('kaffer', True), ('kaffe', True)],
          'kaffernes': [('kaffer', True), ('kaffe', True)],
          'kaffers': [('kaffer', True), ('kaffe', True)],
          'kafterne': [('kaft', False)],
          'kafternes': [('kaft', False)],
          'kafters': [('kaft', False)],
          'kage': [('kage', False)],
          'kagen': [('kag', True), ('kage', True)],
          'kagens': [('kag', True), ('kage', True)],
          'kager': [('kage', False)],
          'kagers': [('kage', False)],
          'kages': [('kage', False)],
          'kaglene': [('kagl', True)],
          'kaglenes': [('kagl', True)],
          'kaglens': [('kagle', False)],
          'kagler': [('kagle', False)],
          'kaglerne': [('kagle', False)],
          'kainen': [('kain', False)],
          'kainens': [('kain', False)],
          'kajen': [('kaje', True), ('kaj', True)],
          'kajens': [('kaje', True), ('kaj', True)],
          'kajer': [('kaje', True), ('kaj', True)],
          'kajerne': [('kaje', True), ('kaj', True)],
          'kajernes': [('kaje', True), ('kaj', True)],
          'kajers': [('kaje', True), ('kaj', True)],
          'kakken': [('kak', False)],
          'kakkerne': [('kak', False)],
          'kaklens': [('kakkel', True)],
          'kakler': [('kakkel', True)],
          'kaks': [('kak', False)],
          'kakter': [('kakt', False)],
          'kakterne': [('kakt', False)],
          'kakternes': [('kakt', False)],
          'kakters': [('kakt', False)],
          'kalas': [('kalas', True)],
          'kalders': [('kalder', False)],
          'kale': [('kal', False)],
          'kalen': [('kal', False)],
          'kalene': [('kal', False)],
          'kalenes': [('kal', False)],
          'kalens': [('kal', False)],
          'kales': [('kale', False)],
          'kalet': [('kale', False)],
          'kalets': [('kale', False)],
          'kaliernes': [('kalier', False)],
          'kaliet': [('kali', False)],
          'kaliets': [('kali', False)],
          'kalis': [('kali', False)],
          'kaliser': [('kalise', False)],
          'kaliserne': [('kalise', False)],
          'kalisernes': [('kalise', False)],
          'kalke': [('kalk', True), ('kalke', True)],
          'kalken': [('kalk', True), ('kalke', True)],
          'kalkens': [('kalke', True), ('kalk', True)],
          'kalker': [('kalke', True)],
          'kalkerne': [('kalke', True)],
          'kalkernes': [('kalke', True)],
          'kalkers': [('kalke', True)],
          'kalkes': [('kalke', True), ('kalk', True)],
          'kallys': [('kallys', False)],
          'kalpe': [('kalp', False)],
          'kalpen': [('kalp', False)],
          'kalpens': [('kalp', False)],
          'kalpes': [('kalp', False)],
          'kalve': [('kalv', False)],
          'kalven': [('kalv', False)],
          'kalvens': [('kalv', False)],
          'kalves': [('kalv', False)],
          'kamenter': [('kament', False)],
          'kamenterne': [('kament', False)],
          'kamentet': [('kament', False)],
          'kamentets': [('kament', False)],
          'kameterne': [('kameter', False)],
          'kameternes': [('kameter', False)],
          'kaminer': [('kamin', True)],
          'kaminerne': [('kamin', True)],
          'kaminernes': [('kamin', True)],
          'kaminers': [('kamin', True)],
          'kamler': [('kammel', False)],
          'kamlerne': [('kammel', False)],
          'kamlernes': [('kammel', False)],
          'kamlers': [('kammel', False)],
          'kamme': [('kam', True)],
          'kammen': [('kam', False)],
          'kammens': [('kam', False)],
          'kammer': [('kammer', False)],
          'kammers': [('kammer', False)],
          'kammes': [('kam', False)],
          'kampe': [('kamp', False)],
          'kampen': [('kamp', False)],
          'kampens': [('kamp', True)],
          'kampes': [('kamp', False)],
          'kanas': [('kanum', False)],
          'kandalen': [('kandale', False)],
          'kandalens': [('kandale', False)],
          'kandalerne': [('kandale', False)],
          'kandalernes': [('kandale', False)],
          'kanden': [('kande', True)],
          'kandens': [('kande', False)],
          'kander': [('kande', False)],
          'kanderne': [('kande', False)],
          'kandernes': [('kande', True)],
          'kanders': [('kande', True)],
          'kandis': [('kandis', True)],
          'kane': [('kane', True)],
          'kanen': [('kane', True)],
          'kanens': [('kane', True)],
          'kaner': [('kane', True)],
          'kanerne': [('kane', True)],
          'kanernes': [('kane', True)],
          'kaners': [('kane', True)],
          'kanes': [('kane', True)],
          'kanke': [('kank', False)],
          'kanken': [('kank', False)],
          'kankens': [('kank', False)],
          'kanker': [('kanker', False)],
          'kankerne': [('kanker', False)],
          'kankernes': [('kanker', False)],
          'kankers': [('kanker', False)],
          'kankes': [('kank', False)],
          'kanks': [('kank', False)],
          'kannerne': [('kanner', False)],
          'kannernes': [('kanner', False)],
          'kanners': [('kanner', False)],
          'kanoner': [('kanoner', True), ('kanon', True)],
          'kanoners': [('kanoner', True), ('kanon', True)],
          "kans'": [('kans', False)],
          'kansen': [('kans', False)],
          'kansens': [('kans', False)],
          'kanser': [('kanse', False)],
          'kanserne': [('kanse', False)],
          'kansers': [('kanse', False)],
          'kanslerne': [('kansler', False)],
          'kanslernes': [('kansler', False)],
          'kanslers': [('kansler', True)],
          'kantater': [('kantate', True)],
          'kantaternes': [('kantate', True)],
          'kanten': [('kant', False)],
          'kantens': [('kant', False)],
          'kanterne': [('kant', False)],
          'kanternes': [('kant', False)],
          'kanters': [('kant', False)],
          'kantinerne': [('kantine', True)],
          'kantiners': [('kantine', True)],
          'kants': [('kant', False)],
          'kaos': [('kaos', True)],
          'kapernes': [('kaper', True)],
          'kapers': [('kapers', True), ('kaper', True)],
          'kapiens': [('kapi', False)],
          'kappen': [('kappe', False)],
          'kappens': [('kappe', False)],
          'kapper': [('kappe', True)],
          'kapperne': [('kappe', False)],
          'kappernes': [('kappe', True)],
          'kappers': [('kappe', False)],
          'kappes': [('kappe', False)],
          'karambolen': [('karambol', True), ('karambole', True)],
          'karambolens': [('karambol', True), ('karambole', True)],
          'karavanen': [('karavane', True)],
          'karavanens': [('karavane', True)],
          'karavaner': [('karavane', True)],
          'karavanernes': [('karavane', True)],
          'karavaners': [('karavane', True)],
          'karbejder': [('karbejder', False)],
          'karbejderne': [('karbejder', False)],
          'karbejdernes': [('karbejder', False)],
          'karbejders': [('karbejder', False)],
          'karden': [('karde', False)],
          'kardens': [('karde', False)],
          'karder': [('karde', False)],
          'karderne': [('karde', False)],
          'kardernes': [('karde', False)],
          'karders': [('karde', False)],
          'karen': [('kare', False)],
          'karens': [('karens', True)],
          'karer': [('kare', False)],
          'karerne': [('kar', False)],
          'karernes': [('kare', False)],
          'karers': [('kar', False)],
          'karet': [('karet', True)],
          'karets': [('karet', True)],
          'karies': [('karies', True)],
          'karmes': [('karm', True)],
          'karotten': [('karotte', True)],
          'karottens': [('karotte', True)],
          'karotterne': [('karotte', True)],
          'karotters': [('karotte', True)],
          'karpen': [('karpe', True)],
          'karpens': [('karpe', True)],
          'karpernes': [('karpe', True)],
          'karpers': [('karpe', True)],
          'karpes': [('karpe', True)],
          'karrieren': [('karriere', False)],
          'karrierens': [('karriere', False)],
          'karsen': [('karse', False)],
          'karsens': [('karse', True)],
          'karses': [('karse', False)],
          'karten': [('karte', True)],
          'kartens': [('karte', True)],
          'karter': [('karte', True)],
          'karterne': [('karte', True)],
          'karternes': [('karte', True)],
          'karters': [('karte', True)],
          'kartet': [('karte', True)],
          'kartets': [('karte', True)],
          'kartoffelskræller': [('kartoffelskræller', True), ('kartoffelskræl', True)],
          'kartoffelskrællerne': [('kartoffelskræller', True), ('kartoffelskræl', True)],
          'kartoffelskrællernes': [('kartoffelskræller', True), ('kartoffelskræl', True)],
          'kartoffelskrællers': [('kartoffelskræller', True), ('kartoffelskræl', True)],
          'kartofler': [('kartoffel', True)],
          'kartoflerne': [('kartoffel', True)],
          'kartoflernes': [('kartoffel', True)],
          'kartoflers': [('kartoffel', True)],
          'kartonen': [('karton', True)],
          'kartonens': [('karton', True)],
          'kartonernes': [('karton', False)],
          "karts'": [('kart', False)],
          'karussernes': [('karusse', True)],
          'karussers': [('karusse', True)],
          'karve': [('karv', False)],
          'karven': [('karv', False)],
          'karvens': [('karv', False)],
          'karver': [('karv', False)],
          'karverne': [('karv', False)],
          'karvernes': [('karv', False)],
          'karvers': [('karv', False)],
          'karves': [('karv', False)],
          'kaserne': [('kaserne', False)],
          'kasernes': [('kaserne', False)],
          'kasier': [('kasier', False)],
          'kasierne': [('kasier', False)],
          'kasiernes': [('kasier', False)],
          'kasiers': [('kasier', False)],
          'kasser': [('kasse', False)],
          'kasserne': [('kasse', False)],
          'kassernes': [('kasse', False)],
          'kassers': [('kasse', False)],
          'kassetten': [('kassette', True)],
          'kassettens': [('kassette', False)],
          'kassetterne': [('kassette', False)],
          'kassetternes': [('kassette', False)],
          'kassetters': [('kassette', False)],
          'kastens': [('kaste', True)],
          'kaster': [('kaster', True), ('kaste', True)],
          'kasterne': [('kaste', True), ('kaster', True)],
          'kasternes': [('kaster', True), ('kaste', True)],
          'kasters': [('kaste', True), ('kaster', True)],
          'kataene': [('kat', False)],
          'kataenes': [('kat', False)],
          'katarerne': [('katar', False)],
          'katarers': [('katar', False)],
          'katas': [('kat', False)],
          'kateket': [('kateket', True)],
          'katekets': [('kateket', True)],
          'kater': [('kater', False)],
          'katerne': [('kater', False)],
          'katernes': [('kat', False)],
          'katers': [('kater', False)],
          'kateter': [('kateter', True), ('katete', True)],
          'kateters': [('kateter', True), ('katete', True)],
          'katiden': [('katid', False)],
          'katidens': [('katid', False)],
          'katider': [('katid', False)],
          'katiderne': [('katid', False)],
          'katidernes': [('katid', False)],
          'katte': [('kat', False)],
          'katten': [('kat', False)],
          'kattens': [('kat', False)],
          'katternes': [('kat', False)],
          'katters': [('kat', False)],
          'kattes': [('kat', False)],
          'kaverne': [('kaverne', True)],
          'kavernes': [('kaverne', True)],
          'kayer': [('kayer', False)],
          'kayerne': [('kayer', False)],
          'kayernes': [('kayer', False)],
          'kayers': [('kayer', False)],
          'kazerne': [('kaze', False)],
          'kazernes': [('kaze', False)],
          'kbars': [('kbar', False)],
          'kbilens': [('kbil', False)],
          'kbilernes': [('kbil', False)],
          'kbilers': [('kbil', False)],
          'kbomber': [('kbombe', False)],
          'kbomberne': [('kbombe', False)],
          'kbombernes': [('kbombe', False)],
          'kbombers': [('kbombe', False)],
          'kbriks': [('kbrik', False)],
          'kbrædder': [('kbrædder', False)],
          'kbrædderne': [('kbrædder', False)],
          'kbræddernes': [('kbrædder', False)],
          'kbrædders': [('kbrædder', False)],
          'kbuster': [('kbuster', False)],
          'kbusterne': [('kbuster', False)],
          'kbusternes': [('kbuster', False)],
          'kbusters': [('kbuster', False)],
          'kbælter': [('kbælte', False)],
          'kbælterne': [('kbælte', False)],
          'kbælternes': [('kbælte', False)],
          'kbælters': [('kbælte', False)],
          'kbæltet': [('kbælte', False)],
          'kbæltets': [('kbælte', False)],
          'kdele': [('kdel', False)],
          'kdømmer': [('kdømme', False)],
          'kdømmerne': [('kdømme', False)],
          'ke': [('ke', False)],
          'kebakker': [('kebakke', False)],
          'kebakkernes': [('kebakke', False)],
          'kebakkers': [('kebakke', False)],
          'keballer': [('kebal', False)],
          'keballers': [('kebal', False)],
          'kebanken': [('kebanke', False)],
          'kebankens': [('kebanke', False)],
          'kebankerne': [('kebanke', False)],
          'kebankernes': [('kebanke', False)],
          'kebens': [('keben', False)],
          'keboer': [('kebo', False)],
          'keboerne': [('kebo', False)],
          'keboers': [('kebo', False)],
          'kebroderens': [('kebror', False)],
          'kebrødre': [('kebror', False)],
          'kebrødrene': [('kebror', False)],
          'kebrødrenes': [('kebror', False)],
          'kebrødres': [('kebror', False)],
          'kebuks': [('kebuks', False)],
          'kedagens': [('kedag', False)],
          'kedans': [('kedans', False)],
          'kedarer': [('kedarer', False)],
          'kedarernes': [('kedarer', False)],
          'kede': [('kede', False)],
          'kedes': [('kede', False)],
          'kedlen': [('kedel', False)],
          'kedlerne': [('kedel', True)],
          'kedlernes': [('kedel', False)],
          'kedoner': [('kedoner', False)],
          'kedonerne': [('kedoner', False)],
          'kedonernes': [('kedoner', False)],
          'kedoners': [('kedoner', False)],
          'kedorer': [('kedor', False)],
          'kedorerne': [('kedor', False)],
          'kedorernes': [('kedor', False)],
          'kedorers': [('kedor', False)],
          'keen': [('ke', False)],
          'keens': [('ke', False)],
          'keeper': [('keeper', True)],
          'keeperne': [('keeper', False)],
          'keer': [('ke', False)],
          'keerne': [('ke', False)],
          'keernes': [('ke', False)],
          'keers': [('ke', False)],
          'kefars': [('kefars', False)],
          'kefædre': [('kefader', False)],
          'kefædrenes': [('kefader', False)],
          'kege': [('keg', False)],
          'kegen': [('keg', False)],
          'kegens': [('keg', False)],
          'keges': [('keg', False)],
          'keglen': [('kegle', True)],
          'keglens': [('kegle', True)],
          'kegler': [('kegle', True)],
          'keglerne': [('kegle', True)],
          'kegrøden': [('kegrød', False)],
          'kegrødens': [('kegrød', False)],
          'kehals': [('kehals', False)],
          'kehandlerne': [('kehandler', False)],
          'kehandlernes': [('kehandler', False)],
          'kejer': [('kejer', False)],
          'kejerne': [('kejer', False)],
          'kejs': [('kejs', False)],
          'kejser': [('kejser', True)],
          'kejserne': [('kejser', True)],
          'kejsernes': [('kejser', True)],
          'kejsers': [('kejser', True)],
          'kekender': [('kekender', False)],
          'kekenders': [('kekender', False)],
          'kekerne': [('kekerne', False)],
          'kekernes': [('kekerne', False)],
          'kekonger': [('kekonge', False)],
          'kekongers': [('kekonge', False)],
          'kekrige': [('kekrig', False)],
          'kekrigen': [('kekrig', False)],
          'kekrigens': [('kekrig', False)],
          'kekriges': [('kekrig', False)],
          'kekurs': [('kekur', False)],
          'kekutter': [('kekutter', False)],
          'kekutterne': [('kekutte', False)],
          'kekutternes': [('kekutte', False)],
          'kekutters': [('kekutte', False)],
          'kelagens': [('kelage', False)],
          'kelagerne': [('kelage', False)],
          'kelen': [('kel', True)],
          'kelens': [('kel', True)],
          'keler': [('keler', False)],
          'kelerne': [('keler', False)],
          'kelernes': [('keler', False)],
          'kelers': [('keler', False)],
          'kelet': [('kelet', False)],
          'kelets': [('kel', False)],
          'kelever': [('kelever', False)],
          'keleverne': [('kelev', False)],
          'kelevernes': [('kelev', False)],
          'kelevers': [('kelever', False)],
          'kelinen': [('keline', False)],
          'kelinens': [('keline', False)],
          'kelinerne': [('keline', False)],
          'keliners': [('keline', False)],
          'kelisternes': [('keliste', False)],
          'kelisters': [('keliste', False)],
          'kelle': [('kel', False)],
          'kellen': [('kel', False)],
          'kelles': [('kel', False)],
          'kelsers': [('kelse', False)],
          'kelters': [('kelter', True)],
          'keløber': [('keløber', False)],
          'keløbernes': [('keløber', False)],
          'kemagerne': [('kemager', False)],
          'kemagernes': [('kemager', False)],
          'kemagers': [('kemager', False)],
          'kemanden': [('kemand', False)],
          'kemandens': [('kemand', False)],
          'kemaster': [('kemast', False)],
          'kemasters': [('kemast', False)],
          'keminister': [('keminister', False)],
          'ken': [('ke', False)],
          'kenden': [('kend', False)],
          'kendens': [('kend', False)],
          'kender': [('kender', False)],
          'kenderne': [('kender', True)],
          'kendernes': [('kender', True)],
          'kenders': [('kender', False)],
          'kene': [('', False)],
          'kenelliker': [('kenelliker', False)],
          'kenellikernes': [('kenelliker', False)],
          'kenen': [('ken', False)],
          'kenens': [('ken', False)],
          'kener': [('ken', False)],
          'kenerne': [('ken', False)],
          'kenernes': [('ken', False)],
          'keners': [('ken', False)],
          'kenes': [('', False)],
          'kenet': [('kenet', False)],
          'kenets': [('kenet', False)],
          "kens'": [('kens', False)],
          'kentinerne': [('kentine', False)],
          'kentiners': [('kentine', False)],
          'kepotten': [('kepot', False)],
          'kepotternes': [('kepot', False)],
          'kepotters': [('kepot', False)],
          'kepsis': [('kepsis', False)],
          'ker': [('ke', False)],
          'keraden': [('kerade', False)],
          'keradens': [('kerade', False)],
          'kerader': [('kerad', False)],
          'keraderne': [('kerade', False)],
          'keradernes': [('kerad', False)],
          'keraders': [('kerade', False)],
          'kerenser': [('kerenser', False)],
          'kerenserne': [('kerenser', False)],
          'kerer': [('kerer', False)],
          'kererne': [('kerer', False)],
          'kerernes': [('kerer', False)],
          'kerers': [('kerer', False)],
          'keret': [('keret', False)],
          'kerets': [('keret', False)],
          'keretten': [('keret', False)],
          'kerettens': [('keret', False)],
          'keretterne': [('keret', False)],
          'keretternes': [('keret', False)],
          'keretters': [('keret', False)],
          'kerheden': [('kerhed', False)],
          'kerier': [('keri', False)],
          'kerierne': [('keri', False)],
          'keriernes': [('keri', False)],
          'keriers': [('keri', False)],
          'keriet': [('keri', False)],
          'keriets': [('keri', False)],
          'keris': [('keri', False)],
          'kermænd': [('kermand', False)],
          'kermændene': [('kermand', False)],
          'kermændenes': [('kermand', False)],
          'kermænds': [('kermand', False)],
          'kerne': [('kerne', True)],
          'kernerne': [('kerne', False)],
          'kerners': [('kerne', False)],
          'kernes': [('kerne', True)],
          'kerotten': [('kerotte', False)],
          'kerottens': [('kerotte', False)],
          'kerotter': [('kerot', False)],
          'kerotterne': [('kerotte', False)],
          'kerotternes': [('kerot', False)],
          'kerotters': [('kerot', False)],
          "kers'": [('kers', False)],
          'kersen': [('kers', False)],
          'kersens': [('kers', False)],
          'kerserne': [('kers', False)],
          'kersernes': [('kers', False)],
          'kerten': [('kerte', True)],
          'kertens': [('kerte', True)],
          'kerter': [('kerte', True)],
          'kerterne': [('kerte', True)],
          'kerternes': [('kerte', True)],
          'kerters': [('kerte', True)],
          'kerts': [('kert', False)],
          'keruse': [('kerus', False)],
          'kes': [('ke', False)],
          "kes'": [('ke', False)],
          'kesager': [('kesag', False)],
          'kesagerne': [('kesag', False)],
          'kese': [('kese', False)],
          'kesen': [('kese', False)],
          'kesene': [('ke', False)],
          'kesenes': [('ke', False)],
          'kesens': [('kese', False)],
          'kesers': [('keser', False)],
          'keses': [('kese', False)],
          'kesidens': [('keside', False)],
          'keskød': [('keskød', False)],
          'keskøder': [('keskød', False)],
          'keskødernes': [('keskød', False)],
          'keskøders': [('keskød', False)],
          'keskøds': [('keskød', False)],
          'kespiller': [('kespiller', False)],
          'kespillerne': [('kespiller', False)],
          'kespillernes': [('kespiller', False)],
          'kespillers': [('kespiller', False)],
          'kestene': [('kesten', False)],
          'kestens': [('kesten', False)],
          'kester': [('kester', False)],
          'kesteret': [('kester', False)],
          'kesterets': [('kester', False)],
          'kestilens': [('kestil', False)],
          'kestyrers': [('kestyre', False)],
          'kestyret': [('kestyr', False)],
          'kestyrets': [('kestyr', False)],
          'ketabs': [('ketabs', False)],
          'ketaler': [('ketale', False)],
          'ketalers': [('ketale', False)],
          'ketanke': [('ketank', False)],
          'keter': [('ket', False)],
          'keters': [('ket', False)],
          'ketiden': [('ketid', False)],
          'ketten': [('ket', False)],
          'kettens': [('ket', False)],
          'ketterne': [('ket', False)],
          'ketternes': [('ket', False)],
          'ketters': [('ket', False)],
          'kettet': [('ket', False)],
          'kettets': [('ket', False)],
          'keure': [('keur', False)],
          'keures': [('keur', False)],
          'keurets': [('keur', False)],
          'keve': [('keve', False)],
          'keves': [('keve', False)],
          'keviser': [('kevise', False)],
          'keviserne': [('kevise', False)],
          'kfaren': [('kfar', False)],
          'kfarens': [('kfar', False)],
          'kfars': [('kfar', False)],
          'kflipper': [('kflip', False)],
          'kflipperne': [('kflip', False)],
          'kflippernes': [('kflip', False)],
          'kflippers': [('kflip', False)],
          'kflisen': [('kflis', False)],
          'kflisens': [('kflis', False)],
          'kfløjten': [('kfløjte', False)],
          'kfædre': [('kfar', False)],
          'kførerne': [('kfører', False)],
          'kg': [('kilo', True)],
          'kg.': [('kilo', True)],
          'kh': [('kh', False)],
          'khalerne': [('khale', False)],
          'khandler': [('khandel', False)],
          'khandlerne': [('khandel', False)],
          'khandlernes': [('khandel', False)],
          'khandlers': [('khandel', False)],
          'khanen': [('khan', True)],
          'khanens': [('khan', True)],
          'khaner': [('khan', True)],
          'khanerne': [('khan', True)],
          'khanernes': [('khan', True)],
          'khaners': [('khan', True)],
          'khans': [('khan', True)],
          'khas': [('kha', False)],
          'khaser': [('khaser', False)],
          'khaserne': [('khaser', False)],
          'khasernes': [('khaser', False)],
          'khasers': [('khaser', False)],
          'kheden': [('khed', False)],
          'khedens': [('khed', False)],
          'kheder': [('khed', False)],
          'khederne': [('khed', False)],
          'khedernes': [('khed', False)],
          'kheders': [('khed', False)],
          'khen': [('kh', False)],
          'khens': [('kh', False)],
          'kher': [('kh', False)],
          'kherne': [('kher', False)],
          'khernes': [('kh', False)],
          'khers': [('kh', False)],
          'khinde': [('khinde', False)],
          'khinden': [('khinde', False)],
          'khindens': [('khinde', False)],
          'khinder': [('khinde', False)],
          'khinderne': [('khinde', False)],
          'khindernes': [('khinde', False)],
          'khinders': [('khinde', False)],
          'khindes': [('khinde', False)],
          'khis': [('khi', True)],
          'khjerter': [('khjerte', False)],
          'khjerterne': [('khjerte', False)],
          'khjerternes': [('khjerte', False)],
          'khjerters': [('khjerte', False)],
          'khos': [('khos', False)],
          'khosen': [('khos', False)],
          'khosens': [('khos', False)],
          'khoser': [('khos', False)],
          'khoserne': [('khos', False)],
          'khosernes': [('khos', False)],
          'khosers': [('khos', False)],
          'khuen': [('khue', False)],
          'khuens': [('khue', False)],
          'khus': [('khus', False)],
          'ki': [('ki', False)],
          'kias': [('kias', False)],
          'kiaternes': [('kiater', False)],
          'kiber': [('kiber', False)],
          'kiberne': [('kiber', False)],
          'kibernes': [('kiber', False)],
          'kicket': [('kick', True)],
          'kickets': [('kick', True)],
          'kickstarter': [('kickstarter', True), ('kickstart', True)],
          'kickstarterne': [('kickstart', True), ('kickstarter', True)],
          'kickstarternes': [('kickstart', True), ('kickstarter', True)],
          'kickstarters': [('kickstart', True), ('kickstarter', True)],
          'kidens': [('kid', False)],
          'kien': [('ki', False)],
          'kiene': [('ki', False)],
          'kienes': [('ki', False)],
          'kiens': [('ki', False)],
          'kier': [('ki', False)],
          'kiere': [('kier', False)],
          'kieren': [('kier', False)],
          'kierens': [('kier', False)],
          'kierer': [('kier', False)],
          'kiererne': [('kier', False)],
          'kierernes': [('kier', False)],
          'kierers': [('kier', False)],
          'kieres': [('kier', False)],
          'kierne': [('ki', False)],
          'kiernes': [('ki', False)],
          'kiers': [('ki', False)],
          "kies'": [('kie', False)],
          'kiet': [('ki', False)],
          'kiets': [('ki', False)],
          'kifer': [('kiffer', False)],
          'kiferen': [('kiffer', False)],
          'kifferne': [('kiffer', False)],
          'kigger': [('kigger', False)],
          'kiggers': [('kigger', False)],
          'kikke': [('kik', False)],
          'kikken': [('kik', False)],
          'kikker': [('kikker', False)],
          'kikkere': [('kikker', False)],
          'kikkeren': [('kikker', True)],
          'kikkerens': [('kikker', False)],
          'kikkeres': [('kikker', True)],
          'kikkernes': [('kikker', False)],
          'kikkers': [('kikker', True)],
          'kikkes': [('kik', False)],
          'kiks': [('kik', True), ('kiks', True)],
          "kiks'": [('kiks', False)],
          'kiksen': [('kiks', False)],
          'kiksens': [('kiks', True)],
          'kikser': [('kikser', True)],
          'kiksernes': [('kikser', True)],
          'kilden': [('kilde', False)],
          'kildens': [('kilde', False)],
          'kilder': [('kilder', True), ('kilde', True)],
          'kilderne': [('kilder', True), ('kilde', True)],
          'kildernes': [('kilder', True), ('kilde', True)],
          'kilders': [('kilder', True), ('kilde', True)],
          'kile': [('kile', False)],
          'kilen': [('kile', False)],
          'kilens': [('kile', True)],
          'kiler': [('kile', False)],
          'kilerne': [('kile', False)],
          'kilernes': [('kile', True)],
          'kilers': [('kile', True)],
          'kiles': [('kile', False)],
          'killens': [('kille', False)],
          'killer': [('kille', False)],
          'killerne': [('kille', False)],
          'killernes': [('killer', False)],
          'killers': [('kille', False)],
          'killet': [('kille', False)],
          'killets': [('kille', False)],
          'killinger': [('killing', True)],
          'killingerne': [('killing', True)],
          'killingernes': [('killing', True)],
          'killingers': [('killing', False)],
          'kilos': [('kilo', False)],
          'kilte': [('kilt', False)],
          'kilten': [('kilt', True)],
          'kiltens': [('kilt', True)],
          'kiltes': [('kilt', False)],
          'kiltet': [('kilt', False)],
          'kiltets': [('kilt', False)],
          'kinden': [('kind', True)],
          'kindens': [('kind', False)],
          'kinder': [('kind', False)],
          'kinderne': [('kind', False)],
          'kindernes': [('kind', True)],
          'kinders': [('kind', True)],
          'kindet': [('kind', False)],
          'kindets': [('kind', False)],
          'kine': [('kine', False)],
          'kinen': [('kine', False)],
          'kinens': [('kine', False)],
          'kiner': [('kine', False)],
          'kinerne': [('kin', False)],
          'kinernes': [('kine', False)],
          'kiners': [('kin', False)],
          'kines': [('kine', False)],
          'kineser': [('kinese', True), ('kineser', True)],
          'kineserne': [('kinese', True), ('kineser', True)],
          'kinesernes': [('kinese', True), ('kineser', True)],
          'kinesers': [('kineser', True), ('kinese', True)],
          'kingen': [('king', False)],
          'kingens': [('king', False)],
          'kinger': [('king', False)],
          'kingerne': [('king', False)],
          'kingernes': [('king', False)],
          'kings': [('king', False)],
          "kings'": [('king', False)],
          'kini': [('kini', False)],
          'kinien': [('kini', False)],
          'kiniens': [('kini', False)],
          'kinier': [('kini', False)],
          'kinierne': [('kini', False)],
          'kinis': [('kini', False)],
          'kinister': [('kinist', False)],
          'kinisters': [('kinist', False)],
          'kinkens': [('kinke', False)],
          'kinkernes': [('kinke', False)],
          'kinkers': [('kinke', False)],
          'kinkler': [('kinkel', False)],
          'kipers': [('kiper', True)],
          'kippen': [('kip', True)],
          'kippens': [('kip', True)],
          'kipper': [('kip', True)],
          'kipperne': [('kip', True)],
          'kippernes': [('kip', True)],
          'kippers': [('kippers', True), ('kip', True)],
          'kiren': [('kir', False)],
          'kirer': [('kir', False)],
          'kirerne': [('kir', False)],
          'kirernes': [('kir', False)],
          'kirers': [('kir', False)],
          'kiris': [('kiri', False)],
          'kirkens': [('kirke', False)],
          'kirrens': [('kir', True)],
          'kis': [('kis', True)],
          'kise': [('kise', False)],
          'kisen': [('kis', True)],
          'kisens': [('kis', True)],
          'kises': [('kise', False)],
          'kislen': [('kisel', True)],
          'kismen': [('kisme', False)],
          'kismens': [('kisme', False)],
          'kismer': [('kismus', False)],
          'kismerne': [('kismus', False)],
          'kismernes': [('kismus', False)],
          'kismers': [('kismus', False)],
          'kissen': [('kis', False)],
          'kissens': [('kis', False)],
          'kisten': [('kiste', True)],
          'kistens': [('kiste', True)],
          'kister': [('kiste', True)],
          'kisterne': [('kiste', True)],
          'kisternes': [('kiste', True)],
          'kisters': [('kiste', False)],
          'kitlens': [('kittel', True)],
          'kitler': [('kittel', True)],
          'kitten': [('kit', False)],
          'kittens': [('kit', False)],
          'kitternes': [('kit', False)],
          'kitters': [('kit', False)],
          'kivarer': [('kivar', False)],
          'kivarernes': [('kivar', False)],
          'kivarers': [('kivar', False)],
          'kive': [('kive', False)],
          'kiven': [('kiv', True)],
          'kivens': [('kiv', True)],
          'kiver': [('kive', False)],
          'kiverne': [('kiv', False)],
          'kivernes': [('kive', False)],
          'kivers': [('kive', False)],
          'kives': [('kive', False)],
          'kjorden': [('kjord', False)],
          'kjordens': [('kjord', False)],
          'kjorte': [('kjorte', False)],
          'kjorten': [('kjorte', False)],
          'kjortens': [('kjorte', False)],
          'kjortes': [('kjorte', False)],
          'kjover': [('kjove', True)],
          'kjoverne': [('kjove', True)],
          'kka': [('kka', False)],
          'kkaner': [('kkaner', False)],
          'kkanerne': [('kkaner', False)],
          'kkanernes': [('kkaner', False)],
          'kkaners': [('kkaner', False)],
          'kkaren': [('kkar', False)],
          'kkarens': [('kkar', False)],
          'kkartofler': [('kkartoffel', False)],
          'kkartoflerne': [('kkartoffel', False)],
          'kkartoflers': [('kkartoffel', False)],
          'kkas': [('kka', False)],
          'kkelen': [('kkel', False)],
          'kkelens': [('kkel', False)],
          'kkelet': [('kkel', False)],
          'kkenet': [('kken', False)],
          'kkenets': [('kken', False)],
          'kkens': [('kke', False)],
          'kkere': [('kker', False)],
          'kkeren': [('kker', False)],
          'kkerens': [('kker', False)],
          'kkeres': [('kker', False)],
          'kkeret': [('kker', False)],
          'kkerets': [('kker', False)],
          'kkerten': [('kkert', False)],
          'kkertens': [('kkert', False)],
          'kkerter': [('kkert', False)],
          'kkerterne': [('kkert', False)],
          'kkerternes': [('kkert', False)],
          'kkerters': [('kkert', False)],
          'kkorden': [('kkord', False)],
          'kkordens': [('kkord', False)],
          'kkorder': [('kkord', False)],
          'kkorderne': [('kkord', False)],
          'kkordernes': [('kkord', False)],
          'kkorders': [('kkord', False)],
          'kkurs': [('kkurs', False)],
          'kkurser': [('kkurs', False)],
          'kkurserne': [('kkurs', False)],
          'kkursernes': [('kkurs', False)],
          'kkursers': [('kkurs', False)],
          'kl': [('klokke', True)],
          'kl.': [('klokke', True)],
          'kladder': [('kladde', False)],
          'kladders': [('kladde', True)],
          'klader': [('klade', False)],
          'kladerne': [('klade', False)],
          'kladernes': [('klade', False)],
          'kladers': [('klade', False)],
          'klagen': [('klage', False)],
          'klagens': [('klage', True)],
          'klager': [('klage', True), ('klager', True)],
          'klageret': [('klageret', True)],
          'klagerets': [('klageret', True)],
          'klagerne': [('klager', True), ('klage', True)],
          'klagernes': [('klager', True), ('klage', True)],
          'klagers': [('klager', True), ('klage', True)],
          'klaks': [('klaks', False)],
          'klammens': [('klamme', False)],
          'klanens': [('klan', True)],
          'klaner': [('klan', True)],
          'klaners': [('klan', True)],
          'klange': [('klang', False)],
          'klangen': [('klang', False)],
          'klangens': [('klang', False)],
          'klanges': [('klang', False)],
          'klans': [('klan', True)],
          'klanternen': [('klantern', True)],
          'klanternens': [('klantern', True)],
          'klanterner': [('klantern', True)],
          'klanternerne': [('klantern', True)],
          'klanternernes': [('klantern', True)],
          'klanterners': [('klantern', True)],
          'klapper': [('klapper', True), ('klap', True)],
          'klapperne': [('klapper', True), ('klap', True)],
          'klappernes': [('klapper', True), ('klap', True)],
          'klappers': [('klap', True), ('klapper', True)],
          'klaps': [('klaps', True), ('klap', True)],
          'klasen': [('klase', True)],
          'klasens': [('klase', False)],
          'klaser': [('klase', True)],
          'klaserne': [('klase', False)],
          'klasernes': [('klase', False)],
          'klasers': [('klase', False)],
          'klassen': [('klasse', False)],
          'klassens': [('klasse', False)],
          'klasserne': [('klasse', False)],
          'klats': [('klat', True)],
          'klatten': [('klat', False)],
          'klattens': [('klat', True)],
          'klatter': [('klat', False)],
          'klatterne': [('klat', False)],
          'klatternes': [('klat', False)],
          'klatters': [('klat', True)],
          'klaven': [('klave', False)],
          'klaver': [('klaver', True)],
          'klaverne': [('klave', False)],
          'klavernes': [('klave', False)],
          'klavers': [('klaver', True)],
          'klavet': [('klave', False)],
          'klavets': [('klave', False)],
          'kledernes': [('kleder', False)],
          'klemme': [('klemme', True)],
          'klemmen': [('klemme', False)],
          'klemmens': [('klemme', False)],
          'klemmer': [('klemme', False)],
          'klemmerne': [('klemme', False)],
          'klemmernes': [('klemme', False)],
          'klemmers': [('klemme', False)],
          'klemmes': [('klemme', True)],
          'klen': [('kel', False)],
          'klens': [('kkel', False)],
          'klere': [('kler', False)],
          'kleren': [('kler', False)],
          'klerens': [('kler', False)],
          'kleres': [('kler', False)],
          'klerne': [('kel', False)],
          'klernes': [('kel', False)],
          'klers': [('kel', False)],
          'kles': [('kles', False)],
          "kles'": [('kles', False)],
          'klet': [('kel', False)],
          'klets': [('kel', False)],
          'kletten': [('klet', False)],
          'klettens': [('klet', False)],
          'kletter': [('klet', False)],
          'kletterne': [('klet', False)],
          'kletternes': [('klet', False)],
          'kletters': [('klet', False)],
          'klids': [('klid', True)],
          'klikers': [('klike', True)],
          'klinge': [('klinge', False)],
          'klingen': [('klinge', True)],
          'klingens': [('klinge', False)],
          'klinger': [('klinge', False)],
          'klingerne': [('klinge', False)],
          'klingernes': [('klinge', False)],
          'klingers': [('klinge', True)],
          'klinges': [('klinge', True)],
          'klinken': [('klinke', True)],
          'klinten': [('klinte', True), ('klint', True)],
          'klintens': [('klinte', True), ('klint', True)],
          'klippen': [('klippe', True)],
          'klippens': [('klippe', True)],
          'klipper': [('klippe', True), ('klipper', True)],
          'klipperne': [('klippe', True), ('klipper', True)],
          'klippernes': [('klippe', True), ('klipper', True)],
          'klippers': [('klippe', True), ('klipper', True)],
          'klips': [('klip', True), ('klips', True)],
          'klipsen': [('klips', True)],
          'klipsens': [('klips', True)],
          'kliren': [('klire', False)],
          'klirens': [('klire', True)],
          'klismen': [('klisme', False)],
          'klisten': [('kliste', False)],
          'klistens': [('kliste', False)],
          'klister': [('klister', True)],
          'klisterne': [('kliste', False)],
          'klisters': [('klister', True)],
          'klits': [('klit', True)],
          'klitter': [('klit', False)],
          'kloden': [('klode', False)],
          'klodens': [('klode', False)],
          'kloder': [('klode', False)],
          'kloderne': [('klode', False)],
          'klodernes': [('klode', True)],
          'kloders': [('klode', True)],
          'klods': [('klods', False)],
          'klokke': [('klokke', False)],
          'klokken': [('klokke', False)],
          'klokkens': [('klokke', False)],
          'klokker': [('klokker', True), ('klokke', True)],
          'klokkerne': [('klokker', True), ('klokke', True)],
          'klokkernes': [('klokker', True), ('klokke', True)],
          'klokkers': [('klokker', True), ('klokke', True)],
          'klokkes': [('klokke', False)],
          'klommen': [('klomme', False)],
          'klommens': [('klomme', False)],
          'klommer': [('klomme', False)],
          'klommerne': [('klomme', False)],
          'klommernes': [('klomme', False)],
          'klommers': [('klomme', False)],
          'klommes': [('klomme', False)],
          'klopen': [('klop', False)],
          'kloper': [('klop', False)],
          'kloperne': [('klop', False)],
          'klopernes': [('klop', False)],
          'klopers': [('klop', False)],
          'kloren': [('klor', True)],
          'klorens': [('klor', True)],
          'klos': [('klo', False)],
          'klove': [('klov', True)],
          'klubben': [('klub', False)],
          'klubbens': [('klub', False)],
          'klubber': [('klub', False)],
          'klubberne': [('klub', False)],
          'klubbernes': [('klub', False)],
          'klubbers': [('klub', False)],
          'klukket': [('kluk', True)],
          'klukkets': [('kluk', True)],
          'kluks': [('kluk', True)],
          'klummen': [('klumme', True)],
          'klummens': [('klumme', True)],
          'klummer': [('klumme', True)],
          'klummernes': [('klumme', True)],
          'klummers': [('klumme', True)],
          'klunken': [('klunke', True)],
          'klunser': [('klunser', True)],
          'klunserne': [('klunser', True)],
          'klunsernes': [('klunser', True)],
          'klunsers': [('klunser', True)],
          'klus': [('klus', False)],
          'klussen': [('klus', False)],
          'klussens': [('klus', False)],
          'klyde': [('klyde', True)],
          'klyden': [('klyde', True)],
          'klydens': [('klyde', True)],
          'klyder': [('klyde', True)],
          'klyderne': [('klyde', True)],
          'klydes': [('klyde', True)],
          'klyngen': [('klynge', True)],
          'klyngens': [('klynge', True)],
          'klynger': [('klynge', True), ('klynger', True)],
          'klyngerne': [('klynge', True), ('klynger', True)],
          'klyngernes': [('klynger', True), ('klynge', True)],
          'klyngers': [('klynger', True), ('klynge', True)],
          'klys': [('klys', True)],
          'klyster': [('klyster', True)],
          'klysters': [('klyster', True)],
          'klås': [('klås', False)],
          'klæber': [('klæber', False)],
          'klæberne': [('klæber', False)],
          'klæbernes': [('klæber', False)],
          'klæbers': [('klæber', False)],
          'klæder': [('klæder', False)],
          'klæderne': [('klæder', True)],
          'klædernes': [('klæder', True)],
          'klæders': [('klæder', False)],
          'klægen': [('klæg', True)],
          'klægens': [('klæg', True)],
          'klæger': [('klæg', True)],
          'klægerne': [('klæg', True)],
          'klægernes': [('klæg', True)],
          'klægers': [('klæg', True)],
          'klærer': [('klærer', False)],
          'klærerne': [('klærer', False)],
          'klærernes': [('klærer', False)],
          'klærers': [('klærer', False)],
          'kløben': [('kløben', True)],
          'kløbens': [('kløben', True)],
          'kløer': [('klo', True)],
          'kløerne': [('klo', False)],
          'kløfter': [('kløft', False)],
          'kløfterne': [('kløft', False)],
          'kløfternes': [('kløft', True)],
          'kløfters': [('kløft', True)],
          'kløver': [('kløver', False)],
          'kløverne': [('kløver', True)],
          'kløvernes': [('kløver', False)],
          'kløvers': [('kløver', False)],
          'km': [('kilometer', True)],
          'km.': [('kilometer', True)],
          'kmager': [('kmager', False)],
          'kmagerne': [('kmager', False)],
          'kmagernes': [('kmager', False)],
          'kmagers': [('kmager', False)],
          'kmarchen': [('kmarch', False)],
          'kmarchens': [('kmarch', False)],
          'kmarcher': [('kmarch', False)],
          'kmarker': [('kmark', False)],
          'kmarkerne': [('kmark', False)],
          'kmarkernes': [('kmark', False)],
          'kmarkers': [('kmark', False)],
          'kmen': [('kme', False)],
          'kmenernes': [('kmener', False)],
          'kmens': [('kme', False)],
          'kmers': [('kme', False)],
          'kmeter': [('kmeter', False)],
          'kmidler': [('kmiddel', False)],
          'kmidlerne': [('kmiddel', False)],
          'kmidlers': [('kmiddel', False)],
          'kministers': [('kminister', False)],
          'kmoler': [('kmole', False)],
          'kmolerne': [('kmole', False)],
          'kmolernes': [('kmole', False)],
          'kmolers': [('kmole', False)],
          'kmus': [('kmus', False)],
          'kmusen': [('kmus', False)],
          'kmusens': [('kmus', False)],
          'kmælken': [('kmælk', False)],
          'kmælkens': [('kmælk', False)],
          'kmænd': [('kmand', False)],
          'kmændene': [('kmand', False)],
          'kmærkerne': [('kmærke', False)],
          'kmærkernes': [('kmærke', False)],
          'kmærkers': [('kmærke', False)],
          'kmøller': [('kmølle', False)],
          'kmøllerne': [('kmølle', False)],
          'kmøllernes': [('kmølle', False)],
          'kmøllers': [('kmølle', False)],
          'knage': [('knag', True), ('knage', True)],
          'knagen': [('knag', True), ('knage', True)],
          'knagens': [('knag', True), ('knage', True)],
          'knagerne': [('knage', True)],
          'knagernes': [('knage', True)],
          'knagers': [('knage', True)],
          'knages': [('knag', True), ('knage', True)],
          'knapperne': [('knap', False)],
          'knappernes': [('knap', False)],
          'knaps': [('knap', False)],
          'knarren': [('knarr', True)],
          'knarrens': [('knarr', True)],
          'knarrers': [('knarr', True)],
          'knavlen': [('knavel', True)],
          'knavlens': [('knavel', True)],
          'knavler': [('knavel', True)],
          'knavlerne': [('knavel', True)],
          'knavlernes': [('knavel', True)],
          'knavlers': [('knavel', True)],
          'knepper': [('knepper', False)],
          'knepperne': [('knepper', False)],
          'kneppernes': [('knepper', False)],
          'kner': [('ken', False)],
          'knerier': [('kneri', False)],
          'knerierne': [('kneri', False)],
          'kneriernes': [('kneri', False)],
          'kneriers': [('kneri', False)],
          'knernes': [('ken', False)],
          'kners': [('ken', False)],
          'knikaene': [('knikum', False)],
          'kniker': [('kniker', False)],
          'knikerne': [('kniker', False)],
          'knikernes': [('kniker', False)],
          'knikers': [('kniker', False)],
          'kniks': [('kniks', True)],
          'kninen': [('knin', False)],
          'kninens': [('knin', False)],
          'kningers': [('kning', False)],
          'knipper': [('knippe', False)],
          'knipperne': [('knippe', False)],
          'knippet': [('knippe', True)],
          'knippets': [('knippe', False)],
          'knips': [('knips', True)],
          'knoklen': [('knokkel', True)],
          'knokler': [('knokkel', True)],
          'knoklerne': [('knokkel', True)],
          'knoklernes': [('knokkel', True)],
          'knoklers': [('knokkel', True)],
          'knoppen': [('knop', False)],
          'knoppens': [('knop', False)],
          'knopper': [('knop', True)],
          'knopperne': [('knop', True)],
          'knoppernes': [('knop', True)],
          'knoppers': [('knop', False)],
          'knus': [('knus', True)],
          'knuser': [('knuser', False)],
          'knusernes': [('knuser', False)],
          'knusers': [('knuser', False)],
          'knys': [('kny', True)],
          'knæs': [('knæ', False)],
          'knøs': [('knøs', True)],
          'knøse': [('knøs', True)],
          'ko': [('ko', False)],
          'koben': [('koben', True)],
          'kobens': [('koben', True)],
          'kobiner': [('kobiner', False)],
          'kobinerne': [('kobiner', False)],
          'kobiners': [('kobiner', False)],
          'koblerne': [('kobbel', True)],
          'koblernes': [('kobbel', True)],
          'koblers': [('kobbel', True)],
          'kodde': [('kodde', False)],
          'kodden': [('kodde', False)],
          'koddens': [('kodde', False)],
          'kodder': [('kodde', False)],
          'kodderne': [('kodde', False)],
          'koddernes': [('kodde', False)],
          'kodders': [('kodde', False)],
          'koddes': [('kodde', False)],
          'koder': [('kode', True)],
          'koderne': [('kode', True)],
          'kodernes': [('kode', True)],
          'koders': [('kode', True)],
          'koen': [('ko', False)],
          'koens': [('ko', False)],
          'koer': [('ko', False)],
          'koerne': [('ko', False)],
          'koernes': [('ko', False)],
          'koers': [('ko', False)],
          'koet': [('ko', False)],
          'koets': [('ko', False)],
          'kofonier': [('kofoni', False)],
          'kofter': [('kofte', True)],
          'kogen': [('kog', True)],
          'kogens': [('kog', True)],
          'koger': [('koger', False)],
          'kogerne': [('koger', False)],
          'kogernes': [('koger', False)],
          'kogers': [('koger', False)],
          'kogets': [('kog', False)],
          'kogger': [('kogge', True), ('kogger', True)],
          'koggerne': [('kogge', True), ('kogger', True)],
          'koggernes': [('kogge', True), ('kogger', True)],
          'koggers': [('kogger', True), ('kogge', True)],
          'koketter': [('kokette', True)],
          'kokke': [('kok', False)],
          'kokken': [('kok', False)],
          'kokker': [('kok', False)],
          'kokkerne': [('kok', False)],
          'kokkernes': [('kok', False)],
          'kokkers': [('kok', False)],
          'kokkes': [('kok', False)],
          'kokos': [('kokos', True)],
          'koks': [('koks', True), ('kok', True)],
          "koks'": [('koks', True)],
          'koksen': [('koks', True)],
          'koksens': [('koks', True)],
          'kokser': [('kokse', False)],
          'koktet': [('kokt', False)],
          'koktets': [('kokt', False)],
          'koladerne': [('kolade', False)],
          'kole': [('kole', False)],
          'kolen': [('kole', False)],
          'kolens': [('kole', False)],
          'koler': [('kol', False)],
          'koleret': [('koleret', False)],
          'kolerets': [('koleret', False)],
          'kolerne': [('kol', False)],
          'kolernes': [('kole', False)],
          'kolers': [('kole', False)],
          'koles': [('kole', False)],
          'koli': [('koli', False)],
          'kolien': [('koli', False)],
          'koliens': [('koli', False)],
          'kolier': [('koli', False)],
          'kolierne': [('koli', False)],
          'koliernes': [('koli', False)],
          'koliers': [('kolie', False)],
          'kolinger': [('koling', False)],
          'kolingerne': [('koling', False)],
          'kolingernes': [('koling', False)],
          'kolis': [('koli', False)],
          'kollagen': [('kollagen', True), ('kollage', True)],
          'kollagens': [('kollagen', True), ('kollage', True)],
          'kollats': [('kollats', True)],
          'kollegernes': [('kollega', True)],
          'kollegiet': [('kollegie', True)],
          'kollen': [('kol', False)],
          'koller': [('kol', False)],
          'kollerne': [('kolle', False)],
          'kollernes': [('kolle', False)],
          'kollers': [('kol', False)],
          'kollet': [('kolle', False)],
          'kolonialhandler': [('kolonialhandel', True), ('kolonialhandler', True)],
          'kolonialhandlerne': [('kolonialhandel', True), ('kolonialhandler', True)],
          'kolonialhandlernes': [('kolonialhandler', True), ('kolonialhandel', True)],
          'kolonialhandlers': [('kolonialhandel', True), ('kolonialhandler', True)],
          'komager': [('komager', False)],
          'komagerne': [('komager', False)],
          'komagers': [('komager', False)],
          'komaner': [('koman', False)],
          'komanerne': [('koman', False)],
          'komanernes': [('koman', False)],
          'komaners': [('koman', False)],
          'komber': [('kombe', False)],
          'komberne': [('kombe', False)],
          'kombernes': [('kombe', False)],
          'komet': [('komet', True)],
          'kometer': [('komet', True)],
          'kometers': [('komet', True)],
          'komets': [('komet', True)],
          'kommen': [('kommen', False)],
          'kommens': [('kommen', True)],
          'kommer': [('kommer', False)],
          'kommers': [('kommers', True)],
          'kommet': [('komme', False)],
          'kommets': [('komme', False)],
          'konaternes': [('konat', False)],
          'kondens': [('kondens', True)],
          'konder': [('konder', False)],
          'konderne': [('konder', False)],
          'kondernes': [('konder', False)],
          'konders': [('konder', False)],
          'konen': [('kone', False)],
          'konens': [('kone', False)],
          'koner': [('kone', False)],
          'konerne': [('kone', False)],
          'konernes': [('kone', False)],
          'koners': [('kone', False)],
          'konet': [('kum', False)],
          'konets': [('kum', False)],
          'konger': [('konge', False)],
          'kongers': [('konge', False)],
          'konien': [('koni', False)],
          'koniens': [('koni', False)],
          'konis': [('koni', False)],
          'konissen': [('konisse', False)],
          'konomen': [('konom', False)],
          'konti': [('konto', False)],
          'kontis': [('konto', False)],
          'kontroller': [('kontroller', True), ('kontrol', True)],
          'kontrollerne': [('kontroller', True), ('kontrol', True)],
          'kontrollernes': [('kontroller', True), ('kontrol', True)],
          'kontrollers': [('kontroller', True), ('kontrol', True)],
          'kopen': [('kope', False)],
          'koper': [('kope', False)],
          'koperne': [('kope', False)],
          'kopernes': [('kope', False)],
          'kopers': [('kope', False)],
          'koppen': [('kop', True)],
          'koppens': [('kop', False)],
          'kopper': [('kop', True), ('kopper', True)],
          'kopperne': [('kopper', True), ('kop', True)],
          'koppernes': [('kopper', True), ('kop', True)],
          'koppers': [('kop', True), ('kopper', True)],
          'koranerne': [('koran', True)],
          'koranernes': [('koran', True)],
          'kordanser': [('kordans', False)],
          'kordanserne': [('kordans', False)],
          'kordater': [('kordater', True)],
          'kordaterne': [('kordater', True)],
          'kordaternes': [('kordater', True)],
          'kordaters': [('kordater', True)],
          'kordeler': [('kordel', True)],
          'kordelernes': [('kordel', True)],
          'kordelers': [('kordel', True)],
          'korden': [('korde', True)],
          'kordens': [('korde', True)],
          'korder': [('korde', True)],
          'korderne': [('korde', True)],
          'kordernes': [('korde', True)],
          'korders': [('korde', True)],
          'kordrernes': [('kordre', False)],
          'korenden': [('korend', True), ('korende', True)],
          'korendens': [('korend', True), ('korende', True)],
          'korender': [('korende', True), ('korend', True)],
          'korenderne': [('korende', True), ('korend', True)],
          'korendernes': [('korende', True), ('korend', True)],
          'korenders': [('korende', True), ('korend', True)],
          'korers': [('kor', False)],
          'koriers': [('korie', False)],
          'korinterne': [('korinter', True)],
          'korinters': [('korinter', True)],
          'korkens': [('kork', True)],
          'kornet': [('kornet', True), ('korn', True)],
          'kornets': [('kornet', True), ('korn', True)],
          'korper': [('korpe', False)],
          'korpernes': [('korpe', False)],
          'korpers': [('korpe', False)],
          'kors': [('kor', True), ('kors', True)],
          "kors'": [('kors', False)],
          'korsagerne': [('korsage', True)],
          'korsagernes': [('korsage', True)],
          'korset': [('korset', True), ('kors', True)],
          'korsets': [('korset', True), ('kors', True)],
          'korsten': [('korsten', False)],
          'korstenes': [('korsten', False)],
          'korstens': [('korsten', False)],
          'korten': [('kort', False)],
          'kortens': [('kort', False)],
          'korter': [('korte', False)],
          'korterne': [('korter', False)],
          'korternes': [('korte', False)],
          'korters': [('kort', False)],
          'kortet': [('kort', False)],
          'kortets': [('kort', False)],
          'korts': [('kort', False)],
          'kos': [('ko', False)],
          'kosen': [('kose', False)],
          'kosens': [('kose', False)],
          'koser': [('kos', False)],
          'koserne': [('kose', False)],
          'kosernes': [('kose', False)],
          'kosers': [('kose', False)],
          'kossen': [('kos', False)],
          'kossens': [('kos', False)],
          'koste': [('kost', False)],
          'kosten': [('kost', False)],
          'kostens': [('kost', False)],
          'koster': [('koster', True)],
          'kosterne': [('koster', True)],
          'kosternes': [('koster', True)],
          'kosters': [('koster', True)],
          'kostes': [('kost', False)],
          'kostninger': [('kostning', False)],
          'kostningerne': [('kostning', False)],
          'kostningernes': [('kostning', False)],
          'kostumieren': [('kostumiere', True), ('kostumier', True)],
          'kostumierens': [('kostumiere', True), ('kostumier', True)],
          'kostumierer': [('kostumiere', True), ('kostumier', True)],
          'kostumiererne': [('kostumiere', True), ('kostumier', True)],
          'kostumierernes': [('kostumiere', True), ('kostumier', True)],
          'kostumierers': [('kostumiere', True), ('kostumier', True)],
          'koten': [('kote', True)],
          'kotens': [('kote', True)],
          'koter': [('kote', True)],
          'koterne': [('kote', True)],
          'koternes': [('kote', True)],
          'koters': [('kote', True)],
          'kotes': [('kote', True)],
          'kotten': [('kot', False)],
          'kottens': [('kot', False)],
          'kotter': [('kotte', False)],
          'kotterne': [('kotta', False)],
          'kotters': [('kotta', False)],
          'kotypen': [('kotype', False)],
          'kotyper': [('kotype', False)],
          'kotyperne': [('kotype', False)],
          'kouten': [('kout', False)],
          'koutens': [('kout', False)],
          'kouterne': [('kout', False)],
          'kouternes': [('kout', False)],
          'kouters': [('kout', False)],
          'kove': [('kove', False)],
          'koven': [('kove', False)],
          'kovens': [('kove', False)],
          'koverne': [('kove', False)],
          'kovernes': [('kove', False)],
          'koves': [('kove', False)],
          'kovs': [('kovs', False)],
          'kovsen': [('kovs', True)],
          'kovser': [('kovs', True)],
          'kovserne': [('kovs', True)],
          'kovsernes': [('kovs', True)],
          'kovsers': [('kovs', True)],
          'kpasser': [('kpasser', False)],
          'kpasserne': [('kpasser', False)],
          'kpassernes': [('kpasser', False)],
          'kpassers': [('kpasser', False)],
          'kpillen': [('kpille', False)],
          'kpillernes': [('kpille', False)],
          'kplanter': [('kplante', False)],
          'kplanterne': [('kplante', False)],
          'kplanternes': [('kplante', False)],
          'kplanters': [('kplante', False)],
          'kposter': [('kpost', False)],
          'kposterne': [('kpost', False)],
          'kposternes': [('kpost', False)],
          'kposters': [('kpost', False)],
          'kpotten': [('kpot', False)],
          'kpottens': [('kpot', False)],
          'kpressens': [('kpresse', False)],
          'kpresser': [('kpresse', False)],
          'kpresserne': [('kpresse', False)],
          'kpressernes': [('kpresse', False)],
          'kpressers': [('kpresse', False)],
          'kprisen': [('kpris', False)],
          'kprisens': [('kpris', False)],
          'kpriser': [('kpris', False)],
          'kpriserne': [('kpris', False)],
          'kprisernes': [('kpris', False)],
          'kprisers': [('kpris', False)],
          'kprocenter': [('kprocent', False)],
          'kprocenters': [('kprocent', False)],
          'kpumpen': [('kpumpe', False)],
          'kpumpens': [('kpumpe', False)],
          'kpumper': [('kpumpe', False)],
          'kpumperne': [('kpumpe', False)],
          'kr': [('krone', True)],
          'kr.': [('krone', True)],
          'krabbens': [('krabbe', False)],
          'krabber': [('krabbe', False)],
          'krabbernes': [('krabbe', False)],
          'krabbers': [('krabbe', False)],
          'kraberne': [('kraber', False)],
          'krads': [('krads', False)],
          'kradser': [('kradser', False)],
          'kradserne': [('kradser', True)],
          'kradsernes': [('kradser', False)],
          'kradsers': [('kradser', False)],
          'kraene': [('kra', False)],
          'krafte': [('kraft', False)],
          'kraften': [('kraft', False)],
          'kraftens': [('kraft', False)],
          'krafter': [('kraft', False)],
          'krafterne': [('kraft', False)],
          'krafternes': [('kraft', False)],
          'krafters': [('kraft', False)],
          'kraftes': [('kraft', False)],
          'krager': [('krage', False)],
          'kragerne': [('krage', False)],
          'kragernes': [('krage', False)],
          'kragers': [('krage', False)],
          'krainerne': [('krainer', False)],
          'krainernes': [('krainer', False)],
          'krainers': [('krainer', False)],
          'kramenter': [('kramente', False)],
          'kramenternes': [('kramente', False)],
          'kramentet': [('kramente', False)],
          'kramentets': [('kramente', False)],
          'krammen': [('kramme', False)],
          'krammens': [('kramme', False)],
          'krammer': [('krammer', True)],
          'krammerne': [('krammer', True)],
          'krammernes': [('krammer', True)],
          'krammers': [('krammer', True)],
          'krammes': [('kramme', False)],
          'krams': [('kram', False)],
          'kranen': [('kran', True)],
          'kraner': [('kran', False)],
          'kraners': [('kran', False)],
          'kranke': [('krank', True)],
          'kranken': [('krank', True)],
          'krankens': [('krank', True)],
          'kranker': [('kranke', False)],
          'krankernes': [('kranke', False)],
          'krankes': [('krank', True)],
          'krans': [('kran', True), ('krans', True)],
          'kraps': [('krap', True)],
          'krasier': [('krasi', False)],
          'krasierne': [('krasi', False)],
          'kraten': [('krat', False)],
          'kratens': [('krat', False)],
          'krater': [('krater', True)],
          'kraterne': [('krater', True)],
          'kraternes': [('krater', True)],
          'kraters': [('krater', True)],
          'kravene': [('krav', False)],
          'kravenes': [('krav', True)],
          'kraver': [('krave', False)],
          'kraverne': [('krave', False)],
          'kravernes': [('krave', False)],
          'kravers': [('krave', False)],
          'kravet': [('krav', False)],
          'kravets': [('krav', False)],
          'kre': [('kker', False)],
          'krebs': [('krebs', False)],
          'kreds': [('kreds', True)],
          'krejlerne': [('krejler', True)],
          'krejlernes': [('krejler', True)],
          'kren': [('kre', False)],
          'krene': [('kker', False)],
          'krenes': [('kker', False)],
          'krens': [('kre', False)],
          'kreol': [('kreoler', True)],
          'kreolen': [('kreoler', True)],
          'kreolens': [('kreoler', True)],
          'kreoler': [('kreoler', True)],
          'kreolerne': [('kreoler', True)],
          'kreolernes': [('kreoler', True)],
          'kreolers': [('kreoler', True)],
          'kreols': [('kreoler', True)],
          'krers': [('kre', False)],
          'kres': [('kker', False)],
          'kresers': [('krese', False)],
          'kreter': [('kreter', True)],
          'kreterne': [('kreter', True)],
          'kreternes': [('kreter', True)],
          'kreters': [('kreter', True)],
          'krets': [('kret', False)],
          'kricket': [('kricket', True)],
          'krickets': [('kricket', True)],
          'kriden': [('kriden', False)],
          'kridens': [('kriden', False)],
          'kridsen': [('krids', False)],
          'kridsens': [('krids', False)],
          'kridser': [('krids', False)],
          'kridserne': [('krids', False)],
          'kridsernes': [('krids', False)],
          'kridsers': [('krids', False)],
          'krige': [('krig', False)],
          'krigen': [('krig', False)],
          'krigens': [('krig', False)],
          'kriger': [('kriger', True)],
          'krigerne': [('kriger', True)],
          'krigernes': [('kriger', True)],
          'krigers': [('kriger', True)],
          'kriges': [('krig', False)],
          'kriget': [('krig', False)],
          'krigets': [('krig', False)],
          'krikke': [('krikke', True)],
          'krikken': [('krikke', True)],
          'krikker': [('krikke', True)],
          'krikkerne': [('krikke', True)],
          'krikkernes': [('krikke', True)],
          'krikkes': [('krikke', True)],
          'kriller': [('kriller', True)],
          'krillers': [('kriller', True)],
          'krinet': [('krin', False)],
          'krinets': [('krin', False)],
          'kringer': [('kring', False)],
          'kringerne': [('kring', False)],
          'kringernes': [('kring', False)],
          'kringers': [('kring', False)],
          'krins': [('krin', False)],
          'kripter': [('kript', False)],
          'kris': [('kris', True)],
          'krise': [('kris', True), ('krise', True)],
          'krisen': [('kris', True), ('krise', True)],
          'krisens': [('krise', True), ('kris', True)],
          'kriser': [('kris', True), ('krise', True)],
          'kriserne': [('kris', True), ('krise', True)],
          'krisernes': [('kris', True), ('krise', True)],
          'krisers': [('kris', True), ('krise', True)],
          'krises': [('kris', True), ('krise', True)],
          'krister': [('krist', False)],
          'kristerne': [('krist', False)],
          'kristernes': [('krist', False)],
          'kristers': [('krist', False)],
          'kriver': [('kriver', False)],
          'kriverne': [('kriver', False)],
          'krivernes': [('kriver', False)],
          'krivers': [('kriver', False)],
          'kroater': [('kroater', True), ('kroat', True)],
          'kroaterne': [('kroater', True), ('kroat', True)],
          'kroaternes': [('kroat', True), ('kroater', True)],
          'kroaters': [('kroater', True), ('kroat', True)],
          'krockeren': [('krocker', False)],
          'krockerne': [('krocker', False)],
          'kroden': [('krod', False)],
          'krodens': [('krod', False)],
          'krods': [('krod', False)],
          'kroen': [('kro', False)],
          'kroens': [('kro', False)],
          'kroer': [('kro', False)],
          'kroerne': [('kro', True)],
          'kroernes': [('kro', True)],
          'kroers': [('kro', True)],
          'kroge': [('krog', False)],
          'krogen': [('krog', False)],
          'krogens': [('krog', False)],
          'kroges': [('krog', False)],
          'kronen': [('krone', True)],
          'kronens': [('krone', True)],
          'kroner': [('krone', True)],
          'kronerne': [('krone', True)],
          'kronernes': [('krone', True)],
          'kroners': [('krone', True)],
          'krops': [('krop', False)],
          'kropsarbejder': [('kropsarbejder', True), ('kropsarbejde', True)],
          'kropsarbejderne': [('kropsarbejder', True), ('kropsarbejde', True)],
          'kropsarbejdernes': [('kropsarbejder', True), ('kropsarbejde', True)],
          'kropsarbejders': [('kropsarbejde', True), ('kropsarbejder', True)],
          'kros': [('kro', True)],
          'krosen': [('krose', False)],
          'krosens': [('krose', False)],
          'krotten': [('krot', False)],
          'krottens': [('krot', False)],
          'krubber': [('krubbe', False)],
          'krubberne': [('krubbe', False)],
          'krubbernes': [('krubbe', False)],
          'krubbers': [('krubbe', False)],
          'kruder': [('krude', False)],
          'kruderne': [('krude', False)],
          'krudernes': [('krude', False)],
          'kruders': [('krude', False)],
          'kruds': [('krud', False)],
          'kruen': [('krue', False)],
          'kruens': [('krue', False)],
          'kruer': [('krue', False)],
          'kruerne': [('krue', False)],
          'kruernes': [('krue', False)],
          'kruers': [('krue', False)],
          'kruks': [('kruk', True)],
          'krumme': [('krumme', True)],
          'krummen': [('krumme', True)],
          'krummens': [('krumme', True)],
          'krummer': [('krumme', True)],
          'krummerne': [('krumme', True)],
          'krummernes': [('krumme', True)],
          'krummers': [('krumme', True)],
          'krummes': [('krumme', True)],
          'krummet': [('krum', False)],
          'krummets': [('krum', False)],
          'krupler': [('krupler', False)],
          'kruplernes': [('krupler', False)],
          'krus': [('krus', True)],
          'krutten': [('krutten', False)],
          'krutter': [('krut', False)],
          'krydernes': [('kryder', False)],
          'kryders': [('kryder', False)],
          'krydser': [('kryds', True), ('krydser', True)],
          'krydserne': [('kryds', True), ('krydser', True)],
          'krydsernes': [('krydser', True), ('kryds', True)],
          'krydsers': [('kryds', True), ('krydser', True)],
          'krykken': [('krykke', True)],
          'krykker': [('krykke', True)],
          'krykkerne': [('krykke', True)],
          'krykkernes': [('krykke', True)],
          'krykkers': [('krykke', True)],
          'krylen': [('kryl', False)],
          'krylens': [('kryl', False)],
          'kryster': [('kryster', True)],
          'krysters': [('kryster', True)],
          'krålen': [('krål', True)],
          'krålens': [('krål', True)],
          'kråler': [('krål', True)],
          'krålernes': [('krål', True)],
          'krålers': [('krål', True)],
          'kråsers': [('kråse', True)],
          'kræfter': [('kraft', True)],
          'kræfterne': [('kraft', True)],
          'kræfternes': [('kraft', True)],
          'kræfters': [('kraft', False)],
          'krækken': [('kræk', False)],
          'krækkens': [('kræk', False)],
          'krækker': [('krækker', False)],
          'krækkerne': [('krækker', False)],
          'krækkernes': [('krækker', False)],
          'krækkers': [('krækker', False)],
          'kræmmernes': [('kræmmer', False)],
          'kræmmers': [('kræmmer', False)],
          'krænker': [('krænker', True)],
          'krænkerne': [('krænker', True)],
          'krænkernes': [('krænker', True)],
          'krænkers': [('krænker', True)],
          'kræs': [('kræs', True), ('kræ', True)],
          'krøllen': [('krølle', False)],
          'krøller': [('krølle', False)],
          'krøllers': [('krølle', False)],
          'krøret': [('krør', False)],
          'krørets': [('krør', False)],
          'krøs': [('krøs', False)],
          'krøver': [('krøver', False)],
          'krøverne': [('krøver', False)],
          'krøvernes': [('krøver', False)],
          "ks'": [('ks', False)],
          'ksagen': [('ksag', False)],
          'ksagernes': [('ksag', False)],
          'ksagers': [('ksag', False)],
          'ksaks': [('ksak', False)],
          'ksalver': [('ksalver', False)],
          'ksalverne': [('ksalver', False)],
          'ksalvernes': [('ksalver', False)],
          'ksalvers': [('ksalver', False)],
          'ksamen': [('ksamen', False)],
          'ksamens': [('ksamen', False)],
          'ksaminer': [('ksamen', False)],
          'ksaminerne': [('ksamen', False)],
          'ksaminernes': [('ksamen', False)],
          'ksaminers': [('ksamen', False)],
          'ksarbejders': [('ksarbejder', False)],
          'ksbønnens': [('ksbønne', False)],
          'ksbønner': [('ksbønne', False)],
          'ksbønnernes': [('ksbønne', False)],
          'kse': [('ks', False)],
          'ksejerne': [('ksej', False)],
          'kseksten': [('kseksten', False)],
          'ksekstens': [('kseksten', False)],
          'ksen': [('ks', False)],
          'ksene': [('ks', False)],
          'ksenes': [('ks', False)],
          'ksens': [('ks', False)],
          'ksere': [('kser', False)],
          'kseren': [('kser', False)],
          'kserens': [('kser', False)],
          'kseres': [('kser', False)],
          'kserier': [('kseri', False)],
          'kserierne': [('kseri', False)],
          'kseriernes': [('kseri', False)],
          'kseriers': [('kseri', False)],
          'kserne': [('ks', False)],
          'ksernes': [('ks', False)],
          'ksers': [('ks', False)],
          'kses': [('ks', False)],
          'kset': [('ks', False)],
          'ksets': [('ks', False)],
          'kshandler': [('kshandel', False)],
          'kshandlers': [('kshandel', False)],
          'ksier': [('ksi', False)],
          'ksierne': [('ksi', False)],
          'ksiet': [('ksi', True)],
          'ksima': [('ksimum', False)],
          'ksimas': [('ksimum', False)],
          'ksinernes': [('ksin', False)],
          'ksis': [('ksi', True)],
          'ksistens': [('ksistens', False)],
          'ksitet': [('ksitet', False)],
          'ksitets': [('ksitet', False)],
          'kskifte': [('kskifte', False)],
          'kskifter': [('kskifte', False)],
          'kskifterne': [('kskifte', False)],
          'kskifternes': [('kskifte', False)],
          'kskifters': [('kskifte', False)],
          'kskiftes': [('kskifte', False)],
          'kskiftet': [('kskifte', False)],
          'kskiftets': [('kskifte', False)],
          'kskos': [('ksko', False)],
          'kskurs': [('kskurs', False)],
          'kslens': [('ksel', False)],
          'ksler': [('ksel', False)],
          'kslinger': [('ksling', False)],
          'kslingerne': [('ksling', False)],
          'kslingernes': [('ksling', False)],
          'kslingers': [('ksling', False)],
          'kslips': [('kslip', False)],
          'ksne': [('ksen', False)],
          'ksnes': [('ksen', False)],
          'ksporerne': [('kspore', False)],
          'ksporernes': [('kspore', False)],
          'ksporter': [('ksport', False)],
          'kspressens': [('kspres', False)],
          'kspresser': [('kspres', False)],
          'kspresserne': [('kspres', False)],
          'kspressernes': [('kspres', False)],
          'kspressers': [('kspres', False)],
          'ksprutten': [('ksprutte', False)],
          'kspruttens': [('ksprutte', False)],
          'kstaller': [('kstal', False)],
          'kstallers': [('kstal', False)],
          'kstanke': [('kstank', False)],
          'kstarter': [('kstart', False)],
          'ksten': [('ksten', False)],
          'kstene': [('kst', False)],
          'kstenes': [('kst', False)],
          'kstens': [('ksten', False)],
          'ksteppen': [('kstep', False)],
          'ksteppens': [('kstep', False)],
          'kstepper': [('kstep', False)],
          'kstepperne': [('kstep', False)],
          'ksteppernes': [('kstep', False)],
          'ksteppers': [('kstep', False)],
          'kstet': [('kstet', False)],
          'kstets': [('kstet', False)],
          'kstilet': [('kstil', False)],
          'kstilets': [('kstil', False)],
          'kstningers': [('kstning', False)],
          'kstykkers': [('kstykke', False)],
          'ksus': [('ksus', False)],
          'ksvarer': [('ksvare', False)],
          'ksvarerne': [('ksvare', False)],
          'ksvarernes': [('ksvare', False)],
          'ksvarers': [('ksvare', False)],
          'ksætter': [('ksætter', False)],
          'kta': [('ktum', False)],
          'ktaene': [('ktum', False)],
          'ktaenes': [('ktum', False)],
          'ktakler': [('ktakel', False)],
          'ktalen': [('ktal', False)],
          'ktalens': [('ktal', False)],
          'ktaler': [('ktal', False)],
          'ktalerne': [('ktal', False)],
          'ktalernes': [('ktal', False)],
          'ktalers': [('ktal', False)],
          'ktan': [('ktan', False)],
          'ktanet': [('ktan', False)],
          'ktanets': [('ktan', False)],
          'ktanke': [('ktank', False)],
          'ktanken': [('ktank', False)],
          'ktankens': [('ktank', False)],
          'ktankes': [('ktank', False)],
          'ktans': [('ktan', False)],
          'ktanserne': [('ktans', False)],
          'ktanten': [('ktant', False)],
          'ktantens': [('ktant', False)],
          'ktanter': [('ktant', False)],
          'ktanterne': [('ktant', False)],
          'ktanternes': [('ktant', False)],
          'ktanters': [('ktant', False)],
          'ktarer': [('ktar', False)],
          'ktarernes': [('ktar', False)],
          'ktarternes': [('ktart', False)],
          'ktarters': [('ktart', False)],
          'ktas': [('ktum', False)],
          'ktaten': [('ktat', False)],
          'ktatens': [('ktat', False)],
          'ktater': [('ktat', False)],
          'ktaterne': [('ktat', False)],
          'ktaternes': [('ktat', False)],
          'ktaters': [('ktat', False)],
          'ktats': [('ktat', False)],
          'ktaven': [('ktav', False)],
          'ktavens': [('ktav', False)],
          'ktaver': [('ktav', False)],
          'ktaverne': [('ktav', False)],
          'ktavernes': [('ktav', False)],
          'ktavers': [('ktav', False)],
          'kte': [('kt', False)],
          'kteater': [('kteater', False)],
          'kteaters': [('kteater', False)],
          'kten': [('kt', False)],
          'ktene': [('kt', False)],
          'ktenes': [('kt', False)],
          'ktens': [('kt', False)],
          'kter': [('kt', False)],
          'kterer': [('kter', False)],
          'ktererne': [('kter', False)],
          'kterernes': [('kter', False)],
          'kterers': [('kter', False)],
          'kteret': [('kter', False)],
          'kterets': [('kter', False)],
          'kterien': [('kterie', False)],
          'kteriens': [('kterie', False)],
          'kterier': [('kterie', False)],
          'kterierne': [('kterie', False)],
          'kteriernes': [('kterie', False)],
          'kteriers': [('kterie', False)],
          'kteriet': [('kterie', False)],
          'kteriets': [('kterie', False)],
          'kterne': [('kt', False)],
          'kternen': [('ktern', False)],
          'kternens': [('ktern', False)],
          'kterner': [('ktern', False)],
          'kternerne': [('ktern', False)],
          'kternernes': [('ktern', False)],
          'kterners': [('ktern', False)],
          'kternes': [('kt', False)],
          'kters': [('kt', False)],
          'ktes': [('kt', False)],
          'ktet': [('kt', False)],
          'ktets': [('kt', False)],
          'kthuset': [('kthus', False)],
          'ktids': [('ktid', False)],
          'ktien': [('ktie', False)],
          'ktiens': [('ktie', False)],
          'ktier': [('ktie', False)],
          'ktierne': [('ktie', False)],
          'ktiernes': [('ktie', False)],
          'ktiers': [('ktie', False)],
          'kties': [('ktie', False)],
          'ktikkens': [('ktik', False)],
          'ktikker': [('ktik', False)],
          'ktikkernes': [('ktik', False)],
          'ktikkers': [('ktik', False)],
          'ktiks': [('ktik', False)],
          'ktilens': [('ktil', False)],
          'ktilet': [('ktil', False)],
          'ktinen': [('ktin', False)],
          'ktinens': [('ktin', False)],
          'ktiner': [('ktin', False)],
          'ktinerne': [('ktin', False)],
          'ktinernes': [('ktin', False)],
          'ktiners': [('ktin', False)],
          'ktinet': [('ktin', False)],
          'ktinets': [('ktin', False)],
          'ktiver': [('ktiv', False)],
          'ktivernes': [('ktiv', False)],
          'ktlærerne': [('ktlærer', False)],
          'ktlærernes': [('ktlærer', False)],
          'ktonet': [('kton', False)],
          'ktonets': [('kton', False)],
          'ktopperne': [('ktopper', False)],
          "ktops'": [('ktop', False)],
          'ktorier': [('ktorium', False)],
          'ktoriernes': [('ktorium', False)],
          'ktorium': [('ktorium', False)],
          'ktoriums': [('ktorium', False)],
          'ktrene': [('kter', False)],
          'ktrenes': [('kter', False)],
          'ktres': [('kter', False)],
          'ktricen': [('ktrice', False)],
          'ktricens': [('ktrice', False)],
          'ktricerne': [('ktrice', False)],
          'ktricernes': [('ktrice', False)],
          'ktricers': [('ktrice', False)],
          'ktrikken': [('ktrik', False)],
          'ktriner': [('ktrin', False)],
          'ktriners': [('ktrin', False)],
          'ktronen': [('ktron', False)],
          'ktronens': [('ktron', False)],
          'ktroner': [('ktron', False)],
          'ktronerne': [('ktron', False)],
          'ktronernes': [('ktron', False)],
          'ktroners': [('ktron', False)],
          'kts': [('kt', False)],
          'ktudens': [('ktud', False)],
          'kture': [('kture', False)],
          'kturen': [('ktur', False)],
          'kturens': [('ktur', False)],
          'kturer': [('ktur', False)],
          'kturerne': [('ktur', False)],
          'kturernes': [('ktur', False)],
          'kturers': [('ktur', False)],
          'ktures': [('ktur', False)],
          'kturet': [('ktur', False)],
          'ktus': [('ktus', False)],
          'ktylen': [('ktyl', False)],
          'ktylens': [('ktyl', False)],
          'ktyve': [('ktyv', False)],
          'ktæderne': [('ktæder', False)],
          'ktædernes': [('ktæder', False)],
          'ktæders': [('ktæder', False)],
          'ktøjers': [('ktøj', False)],
          'ktører': [('ktør', False)],
          'kubberne': [('kubber', False)],
          'kubbernes': [('kubber', False)],
          'kubbers': [('kubber', False)],
          'kubers': [('kube', True)],
          'kubinen': [('kubine', False)],
          'kubinens': [('kubine', False)],
          'kubinerne': [('kubine', False)],
          'kubinernes': [('kubine', False)],
          'kuchens': [('kuchen', False)],
          'kude': [('kude', False)],
          'kuden': [('kude', False)],
          'kudens': [('kude', False)],
          'kuderne': [('kude', False)],
          'kuders': [('kude', False)],
          'kudes': [('kude', False)],
          'kuen': [('ku', False)],
          'kuens': [('ku', False)],
          'kuer': [('ku', False)],
          'kuers': [('ku', False)],
          'kuet': [('ku', False)],
          'kuets': [('ku', False)],
          'kuffen': [('kuf', True)],
          'kuffens': [('kuf', True)],
          'kuffer': [('kuf', True)],
          'kufferne': [('kuf', True)],
          'kuffernes': [('kuf', True)],
          'kuffers': [('kuf', True)],
          'kuglens': [('kugle', False)],
          'kugler': [('kugle', False)],
          'kuglerne': [('kugle', False)],
          'kuglers': [('kugle', False)],
          'kuiten': [('kuit', False)],
          'kuitens': [('kuit', False)],
          'kuiter': [('kuit', False)],
          'kuiters': [('kuit', False)],
          'kukker': [('kukker', True)],
          'kukkernes': [('kukker', True)],
          'kulden': [('kulde', True)],
          'kuldens': [('kulde', True)],
          'kuldres': [('kulder', False)],
          'kule': [('kule', False)],
          'kulen': [('kule', False)],
          'kulens': [('kule', False)],
          'kulers': [('kule', False)],
          'kules': [('kule', True)],
          'kuli': [('kuli', True)],
          'kuliers': [('kuli', True)],
          'kulis': [('kuli', True)],
          'kulker': [('kulker', False)],
          'kulkerne': [('kulker', False)],
          'kulkers': [('kulker', False)],
          'kuller': [('kuller', True)],
          'kullerne': [('kuller', True)],
          'kullernes': [('kuller', True)],
          'kullers': [('kuller', False)],
          'kulosen': [('kulos', True)],
          'kulosens': [('kulos', True)],
          'kulten': [('kult', True)],
          'kultens': [('kult', True)],
          'kulter': [('kult', True)],
          'kulterne': [('kult', True)],
          'kulternes': [('kult', True)],
          'kulærer': [('kulære', False)],
          'kulærerne': [('kulær', False)],
          'kulærernes': [('kulære', False)],
          'kulærers': [('kulære', False)],
          'kum': [('kum', False)],
          'kummen': [('kumme', True)],
          'kummens': [('kumme', True)],
          'kummer': [('kummer', True), ('kumme', True)],
          'kummerne': [('kumme', True)],
          'kummernes': [('kumme', True)],
          'kummers': [('kummer', True), ('kumme', True)],
          'kums': [('kum', False)],
          'kunden': [('kunde', True)],
          'kundens': [('kunde', True)],
          'kunder': [('kunde', False)],
          'kunderne': [('kunde', False)],
          'kundernes': [('kunde', False)],
          'kunders': [('kunde', True)],
          'kunen': [('kune', False)],
          'kunens': [('kune', False)],
          'kuner': [('kune', False)],
          'kunerne': [('kun', False)],
          'kunernes': [('kune', False)],
          'kuners': [('kun', False)],
          'kunke': [('kunk', False)],
          'kunken': [('kunk', False)],
          'kunker': [('kunk', False)],
          'kunkerne': [('kunk', False)],
          'kunkernes': [('kunk', False)],
          'kunkes': [('kunk', False)],
          'kuns': [('kun', False)],
          'kunster': [('kunst', True)],
          'kunsterne': [('kunst', True)],
          'kunsternes': [('kunst', True)],
          'kunsters': [('kunst', True)],
          'kunsthandler': [('kunsthandler', True), ('kunsthandel', True)],
          'kunsthandlerne': [('kunsthandel', True), ('kunsthandler', True)],
          'kunsthandlernes': [('kunsthandel', True), ('kunsthandler', True)],
          'kunsthandlers': [('kunsthandler', True), ('kunsthandel', True)],
          'kuplen': [('kuppel', True)],
          'kuplens': [('kuppel', False)],
          'kuplers': [('kuppel', True)],
          'kuppen': [('kup', False)],
          'kuppens': [('kup', False)],
          'kupperne': [('kup', False)],
          'kuppers': [('kup', False)],
          'kurans': [('kurans', False)],
          'kure': [('kur', True)],
          'kuren': [('kur', True)],
          'kurens': [('kur', True)],
          'kurer': [('kurer', True)],
          'kurerne': [('kure', False)],
          'kurernes': [('kure', False)],
          'kurers': [('kurer', True)],
          'kures': [('kur', True)],
          'kuret': [('kur', False)],
          'kurets': [('kur', False)],
          'kuriers': [('kurie', True)],
          'kurs': [('kurs', True), ('kur', True)],
          "kurs'": [('kurs', False)],
          'kursen': [('kurs', False)],
          'kursens': [('kurs', False)],
          'kurser': [('kursus', True), ('kurs', True)],
          'kurserne': [('kursus', True), ('kurs', True)],
          'kursernes': [('kursus', True), ('kurs', True)],
          'kursers': [('kursus', True), ('kurs', True)],
          'kurterne': [('kurt', False)],
          'kurve': [('kurve', True), ('kurv', True)],
          'kurven': [('kurve', True), ('kurv', True)],
          'kurvens': [('kurve', True), ('kurv', True)],
          'kurves': [('kurve', True), ('kurv', True)],
          'kus': [('ku', False)],
          'kuske': [('kusk', False)],
          'kusken': [('kusk', False)],
          'kussen': [('kusse', True)],
          'kussens': [('kusse', True)],
          'kusser': [('kusse', True)],
          'kusserne': [('kusse', True)],
          'kussernes': [('kusse', True)],
          'kussers': [('kusse', True)],
          'kutter': [('kutter', True), ('kutte', True)],
          'kutterne': [('kutte', True), ('kutter', True)],
          'kutternes': [('kutte', True), ('kutter', True)],
          'kutters': [('kutter', True), ('kutte', True)],
          'kvader': [('kvader', True)],
          'kvaderne': [('kvader', True)],
          'kvadernes': [('kvader', True)],
          'kvaders': [('kvader', True)],
          'kvalen': [('kval', False)],
          'kvalens': [('kval', False)],
          'kvaler': [('kval', False)],
          'kvalerne': [('kval', False)],
          'kvalernes': [('kval', False)],
          'kvalers': [('kval', True)],
          'kvalme': [('kvalme', True)],
          'kvalmen': [('kvalme', True)],
          'kvalmens': [('kvalme', True)],
          'kvalmes': [('kvalme', True)],
          'kvals': [('kval', True)],
          'kvanders': [('kvand', False)],
          'kvanen': [('kvan', True)],
          'kvanens': [('kvan', True)],
          'kvaner': [('kvan', True)],
          'kvanerne': [('kvan', True)],
          'kvanernes': [('kvan', True)],
          'kvaners': [('kvan', True)],
          'kvannens': [('kvan', True)],
          'kvannerne': [('kvan', True)],
          'kvannernes': [('kvan', True)],
          'kvans': [('kvan', True)],
          'kvanten': [('kvant', True)],
          'kvantens': [('kvant', True)],
          'kvanter': [('kvant', True)],
          'kvanterne': [('kvant', True)],
          'kvanternes': [('kvant', True)],
          'kvanters': [('kvant', True)],
          'kvarers': [('kvare', False)],
          'kvariernes': [('kvarie', False)],
          'kvariet': [('kvarie', False)],
          'kvariets': [('kvarie', False)],
          'kvarter': [('kvart', True), ('kvarter', True)],
          'kvarternes': [('kvart', True)],
          'kvarters': [('kvart', True), ('kvarter', True)],
          'kvarts': [('kvarts', True), ('kvart', True)],
          'kvas': [('kvas', True)],
          'kvejens': [('kvej', False)],
          'kvejes': [('kvej', False)],
          'kvejlen': [('kvejl', True)],
          'kvejlens': [('kvejl', True)],
          'kvellernes': [('kveller', True)],
          'kvellers': [('kveller', True)],
          'kvens': [('kvens', False)],
          'kvers': [('kvers', False)],
          'kvidder': [('kvidder', True)],
          'kvidders': [('kvidder', True)],
          'kviden': [('kvide', True)],
          'kvidens': [('kvide', True)],
          'kvider': [('kvid', False)],
          'kviderne': [('kvid', False)],
          'kvidernes': [('kvid', False)],
          'kviders': [('kvid', False)],
          'kvien': [('kvie', False)],
          'kviens': [('kvie', False)],
          'kvier': [('kvie', True)],
          'kvierne': [('kvie', False)],
          'kviernes': [('kvie', False)],
          'kviers': [('kvie', False)],
          'kviet': [('kvie', False)],
          'kviets': [('kvie', False)],
          'kvikken': [('kvik', True)],
          'kvikkens': [('kvik', True)],
          'kvikker': [('kvik', True)],
          'kvikkerne': [('kvik', True)],
          'kvikkernes': [('kvik', True)],
          'kvikkers': [('kvik', True)],
          'kvillens': [('kvil', False)],
          'kviller': [('kvil', False)],
          'kvillernes': [('kvil', False)],
          'kvillers': [('kvil', False)],
          'kvinde': [('kvinde', False)],
          'kvinden': [('kvinde', False)],
          'kvindens': [('kvinde', False)],
          'kvinder': [('kvinde', False)],
          'kvinderne': [('kvinde', False)],
          'kvindernes': [('kvinde', False)],
          'kvinders': [('kvinde', False)],
          'kvindes': [('kvinde', False)],
          'kvinens': [('kvin', False)],
          'kvines': [('kvin', False)],
          'kvingen': [('kvinge', False)],
          'kvinger': [('kvinge', False)],
          'kvingerne': [('kvinge', False)],
          'kvingernes': [('kvinge', False)],
          'kvins': [('kvin', False)],
          'kvinter': [('kvint', True)],
          'kvinters': [('kvint', True)],
          'kvintet': [('kvintet', True), ('kvint', True)],
          'kvintets': [('kvintet', True), ('kvint', True)],
          'kvis': [('kvis', False)],
          'kvisen': [('kvis', False)],
          'kvisens': [('kvis', False)],
          'kviser': [('kvis', False)],
          'kviserne': [('kvis', False)],
          'kvisernes': [('kvis', False)],
          'kvisers': [('kvis', False)],
          'kvisten': [('kvist', True)],
          'kvits': [('kvit', False)],
          'kvæder': [('kvæde', True)],
          'kvæderne': [('kvæde', True)],
          'kvædet': [('kvæde', True)],
          'kvædets': [('kvæde', True)],
          'kvækkerne': [('kvækkerne', False)],
          'kvælden': [('kvæld', True)],
          'kvældens': [('kvæld', True)],
          'kyder': [('kyder', False)],
          'kyderne': [('kyder', False)],
          'kydernes': [('kyd', False)],
          'kyders': [('kyd', False)],
          'kyen': [('ky', False)],
          'kyens': [('ky', False)],
          'kyer': [('ky', False)],
          'kyerne': [('ky', False)],
          'kyernes': [('ky', False)],
          'kyers': [('ky', False)],
          'kyggers': [('kygge', False)],
          'kylden': [('kyld', False)],
          'kyldens': [('kyld', False)],
          'kyle': [('kyle', False)],
          'kyles': [('kyle', False)],
          'kylet': [('kyle', False)],
          'kylets': [('kyle', False)],
          'kyllens': [('kylle', False)],
          'kyllerne': [('kylle', False)],
          'kyllernes': [('kylle', False)],
          'kynder': [('kynder', False)],
          'kynderne': [('kynder', False)],
          'kyndernes': [('kynder', False)],
          'kynders': [('kynder', False)],
          'kypernes': [('kyper', False)],
          'kypers': [('kyper', True)],
          'kys': [('kys', True)],
          'kysen': [('kyse', True)],
          'kysens': [('kyse', True)],
          'kyser': [('kyse', True)],
          'kyserne': [('kyse', True)],
          'kysernes': [('kyse', True)],
          'kysten': [('kyst', False)],
          'kystens': [('kyst', True)],
          'kyster': [('kyst', True)],
          'kysterne': [('kyst', True)],
          'kysternes': [('kyst', True)],
          'kysters': [('kyst', True)],
          'kyterne': [('kyter', False)],
          'kytlen': [('kyttel', False)],
          'kytlens': [('kyttel', False)],
          'kytlers': [('kyttel', False)],
          'kyts': [('kyts', False)],
          'kåbers': [('kåbe', False)],
          'kågens': [('kåg', True)],
          'kåges': [('kåg', True)],
          'kåler': [('kål', False)],
          'kålerne': [('kål', False)],
          'kålers': [('kål', False)],
          'kånernes': [('kåner', False)],
          'kåners': [('kåner', False)],
          'kårens': [('kåre', False)],
          'kårernes': [('kåre', False)],
          'kæbens': [('kæbe', True)],
          'kæberne': [('kæbe', False)],
          'kæbers': [('kæbe', False)],
          'kæden': [('kæde', False)],
          'kædens': [('kæde', False)],
          'kæder': [('kæde', False)],
          'kæderne': [('kæde', False)],
          'kædernes': [('kæde', False)],
          'kæders': [('kæde', True)],
          'kæer': [('kæ', False)],
          'kæerne': [('kæ', False)],
          'kæernes': [('kæ', False)],
          'kæers': [('kæ', False)],
          'kæfte': [('kæft', True)],
          'kæfter': [('kæft', True)],
          'kæfterne': [('kæft', True)],
          'kæfternes': [('kæft', True)],
          'kæfters': [('kæft', True)],
          'kæftes': [('kæft', True)],
          'kæggens': [('kæg', False)],
          'kælder': [('kælder', False)],
          'kælders': [('kælder', True)],
          'kældrene': [('kælder', True)],
          'kældrenes': [('kælder', False)],
          'kældres': [('kælder', False)],
          'kælke': [('kælk', False)],
          'kælken': [('kælk', False)],
          'kælkens': [('kælk', True)],
          'kælkes': [('kælk', False)],
          'kælme': [('kælm', False)],
          'kælmen': [('kælm', False)],
          'kælmens': [('kælm', False)],
          'kælmerne': [('kælm', False)],
          'kælmernes': [('kælm', False)],
          'kælmers': [('kælm', False)],
          'kælmes': [('kælm', False)],
          'kæmien': [('kæmi', False)],
          'kæmiens': [('kæmi', False)],
          'kæmper': [('kæmpe', True)],
          'kæmperne': [('kæmpe', True)],
          'kæmpernes': [('kæmpe', True)],
          'kæmpers': [('kæmpe', True)],
          'kænd': [('kænd', False)],
          'kændene': [('kænd', False)],
          'kændenes': [('kænd', False)],
          'kænders': [('kand', False)],
          'kænds': [('kænd', False)],
          'kænen': [('kæne', False)],
          'kænens': [('kæne', False)],
          'kæner': [('kæne', False)],
          'kænerne': [('kæne', False)],
          'kænernes': [('kæne', False)],
          'kænke': [('kænk', False)],
          'kænken': [('kænk', False)],
          'kænkes': [('kænk', False)],
          'kæppe': [('kæp', True)],
          'kæppen': [('kæp', False)],
          'kæppens': [('kæp', True)],
          'kæppes': [('kæp', True)],
          'kære': [('kære', True)],
          'kæren': [('kær', False)],
          'kærens': [('kær', False)],
          'kærer': [('kærer', False)],
          'kærerne': [('kærer', False)],
          'kærernes': [('kærer', False)],
          'kærers': [('kærer', False)],
          'kærme': [('kærm', False)],
          'kærmen': [('kærm', False)],
          'kærmens': [('kærm', False)],
          'kærmes': [('kærm', False)],
          'kærnerne': [('kærne', True)],
          'kærners': [('kærne', True)],
          'kærren': [('kærre', True)],
          'kærten': [('kærte', True)],
          'kærtens': [('kærte', True)],
          'kærter': [('kærte', False)],
          'kærterne': [('kærte', True)],
          'kærternes': [('kærte', True)],
          'kærters': [('kærte', False)],
          'kærve': [('kærv', False)],
          'kærven': [('kærv', True)],
          'kærvens': [('kærv', True)],
          'kærvernes': [('kærve', False)],
          'kærvers': [('kærve', False)],
          'kærves': [('kærv', False)],
          'kæs': [('kæ', False)],
          'kæsen': [('kæs', False)],
          'kæsens': [('kæs', False)],
          'kætter': [('kætter', True)],
          'kætterne': [('kætter', True)],
          'kætternes': [('kætter', True)],
          'kætters': [('kætter', True)],
          'kævle': [('kævle', True)],
          'kævlens': [('kævle', True)],
          'kævler': [('kævle', True)],
          'kævlerne': [('kævle', True)],
          'kævlernes': [('kævle', True)],
          'kævles': [('kævle', True)],
          'køber': [('køber', False)],
          'købernes': [('køber', False)],
          'købet': [('køb', True)],
          'kød': [('kød', True)],
          'kødet': [('kød', False)],
          'kødets': [('kød', False)],
          'køds': [('kød', True)],
          'køer': [('kø', True), ('ko', True)],
          'køerne': [('ko', True), ('kø', True)],
          'køernes': [('kø', True), ('ko', True)],
          'køers': [('kø', True), ('ko', True)],
          'køge': [('køge', False)],
          'køgen': [('køge', False)],
          'køgens': [('køge', False)],
          'køger': [('køge', False)],
          'køgerne': [('køge', False)],
          'køgernes': [('køge', False)],
          'køgers': [('køge', False)],
          'køges': [('køge', False)],
          'køje': [('køje', False)],
          'køjen': [('køje', False)],
          'køjens': [('køje', True)],
          'køjer': [('køje', True)],
          'køjerne': [('køje', True)],
          'køjernes': [('køje', False)],
          'køjers': [('køje', False)],
          'køjes': [('køje', False)],
          'køllen': [('kølle', False)],
          'køllens': [('kølle', False)],
          'køller': [('kølle', False)],
          'køllerne': [('kølle', False)],
          'køllernes': [('kølle', True)],
          'køllers': [('kølle', False)],
          'køre': [('køre', False)],
          'køren': [('køre', False)],
          'kørens': [('kør', False)],
          'kører': [('kører', True)],
          'kørerne': [('kører', True)],
          'kørernes': [('kører', False)],
          'kørers': [('kører', True)],
          'køres': [('køre', True)],
          'kørner': [('kørner', True)],
          'kørnernes': [('kørner', True)],
          'køs': [('kø', False)],
          'l': [('l', True)],
          "l'erne": [('l', True)],
          'l.': [('liter', True)],
          'la': [('la', False)],
          'labas': [('laba', False)],
          'labbens': [('lab', True)],
          'labber': [('lab', False)],
          'labbernes': [('lab', True)],
          'labbers': [('lab', False)],
          'labe': [('lab', False)],
          'laben': [('lab', False)],
          'labens': [('lab', False)],
          'laber': [('laber', False)],
          'labers': [('laber', False)],
          'labes': [('lab', False)],
          'labs': [('lab', False)],
          'labys': [('laby', False)],
          'ladder': [('ladder', False)],
          'ladders': [('ladder', False)],
          'lade': [('lade', False)],
          'laden': [('lade', False)],
          'ladens': [('lade', False)],
          'lader': [('lade', True), ('lader', True)],
          'laderne': [('lader', True), ('lade', True)],
          'ladernes': [('lade', True), ('lader', True)],
          'laders': [('lader', True), ('lade', True)],
          'lades': [('lade', False)],
          'lados': [('lado', False)],
          'lads': [('lad', True)],
          "lads'": [('lads', False)],
          'ladser': [('lads', False)],
          'ladserne': [('lads', False)],
          'ladsernes': [('lads', False)],
          'ladsers': [('lads', False)],
          'ladset': [('lads', False)],
          'ladsets': [('lads', False)],
          'laen': [('la', False)],
          'laens': [('la', False)],
          'laer': [('la', False)],
          'laerne': [('la', False)],
          'laernes': [('la', False)],
          'laers': [('la', False)],
          'laffen': [('laf', False)],
          'laffenes': [('laf', False)],
          'laffer': [('laf', True)],
          'lafferne': [('laf', True)],
          'laffernes': [('laf', True)],
          'laffers': [('laf', True)],
          'lage': [('lage', False)],
          'lagen': [('lage', True), ('lagen', True)],
          'lagens': [('lage', True), ('lagen', True)],
          'lager': [('lage', True), ('lager', True)],
          'lageret': [('lager', True)],
          'lagerets': [('lager', True)],
          'lagerne': [('lage', True), ('lager', True)],
          'lagernes': [('lage', True), ('lager', True)],
          'lagers': [('lage', True), ('lager', True)],
          'lages': [('lage', False)],
          'laggen': [('lag', False)],
          'laggens': [('lag', False)],
          'laggerne': [('lagge', False)],
          'laggernes': [('lagge', False)],
          'laggers': [('lagge', False)],
          'lagner': [('lagen', False)],
          'lagnernes': [('lagen', False)],
          'lagners': [('lagen', True)],
          'lagnummers': [('lagnummer', False)],
          'lags': [('lag', True)],
          "lags'": [('lags', False)],
          'lagsene': [('lags', False)],
          'lagsenes': [('lags', False)],
          'lagters': [('lagter', False)],
          'laiden': [('laid', False)],
          'laider': [('laid', False)],
          'laiderne': [('laid', False)],
          'laidernes': [('laid', False)],
          'laiders': [('laid', False)],
          'laids': [('laid', False)],
          'laisen': [('lais', False)],
          'laisens': [('lais', False)],
          'laiser': [('lais', False)],
          'laiserne': [('lais', False)],
          'laisernes': [('lais', False)],
          'laisers': [('lais', False)],
          'laiterne': [('lait', False)],
          'lakaternes': [('lakat', False)],
          'laketter': [('lakette', False)],
          'lakken': [('lak', False)],
          'lakkens': [('lak', True)],
          'lakkerne': [('lak', False)],
          'laks': [('laks', True), ('lak', True)],
          "laks'": [('laks', False)],
          'laksen': [('laks', False)],
          'laksens': [('laks', False)],
          'lalders': [('lalder', False)],
          'lamager': [('lamage', False)],
          'lamagerne': [('lamage', False)],
          'lamagernes': [('lamage', False)],
          'lamagers': [('lamage', False)],
          'lamen': [('lame', False)],
          'lamenter': [('lament', False)],
          'lamenterne': [('lament', False)],
          'lamentet': [('lament', False)],
          'lamentets': [('lament', False)],
          'lamer': [('lame', False)],
          'lamerne': [('lame', False)],
          'lamernes': [('lame', False)],
          'lamier': [('lami', False)],
          'lamierne': [('lami', False)],
          'lamiernes': [('lami', False)],
          'lamiers': [('lami', False)],
          'lammen': [('lamme', False)],
          'lammens': [('lam', False)],
          'lammerne': [('lamme', False)],
          'lammers': [('lamme', False)],
          'lampernes': [('lampe', False)],
          'lampers': [('lampe', False)],
          'lancer': [('lancer', False)],
          'lancerne': [('lancer', False)],
          'lancernes': [('lancer', False)],
          'lancers': [('lancer', False)],
          'lanchen': [('lanche', False)],
          'lanchens': [('lanche', False)],
          'lande': [('land', False)],
          'landen': [('land', False)],
          'landens': [('land', False)],
          'lander': [('lander', False)],
          'landerne': [('lande', False)],
          'landernes': [('lande', False)],
          'landers': [('lande', False)],
          'landes': [('land', False)],
          'landet': [('land', False)],
          'landets': [('land', False)],
          'landler': [('landel', False)],
          'landlers': [('landel', False)],
          'lane': [('lane', False)],
          'lanen': [('lan', False)],
          'lanens': [('lane', False)],
          'laner': [('lane', False)],
          'lanerne': [('lan', False)],
          'lanernes': [('lan', False)],
          'laners': [('laner', False)],
          'lanes': [('lane', False)],
          'lange': [('lange', True)],
          'langen': [('lange', True)],
          'langens': [('lange', True)],
          'langer': [('lange', False)],
          'langerne': [('lange', True)],
          'langernes': [('lange', False)],
          'langers': [('lange', False)],
          'langes': [('lange', True)],
          'lanier': [('lani', False)],
          'laniernes': [('lani', False)],
          'laniet': [('lani', False)],
          'laniets': [('lani', False)],
          'lanis': [('lani', False)],
          'lankens': [('lanke', False)],
          'lanker': [('lanke', False)],
          'lankerne': [('lanke', False)],
          'lankernes': [('lanke', False)],
          'lankers': [('lanke', False)],
          'lanket': [('lanket', False)],
          'lankets': [('lanket', False)],
          'lannerne': [('lanner', False)],
          'lannernes': [('lanner', False)],
          'lanners': [('lanner', False)],
          "lans'": [('lans', False)],
          'lansen': [('lanse', True)],
          'lansens': [('lanse', True)],
          'lanser': [('lanse', True)],
          'lanserne': [('lanse', True)],
          'lansernes': [('lanse', True)],
          'lansers': [('lanse', True)],
          'lantaterne': [('lantat', False)],
          'lantaters': [('lantat', False)],
          'lanten': [('lant', False)],
          'lantens': [('lant', False)],
          'lanterne': [('lanterne', True)],
          'lanternen': [('lanterne', True)],
          'lanternens': [('lanterne', False)],
          'lanterner': [('lanterne', True)],
          'lanternerne': [('lanterne', True)],
          'lanternernes': [('lanterne', True)],
          'lanterners': [('lanterne', True)],
          'lanternes': [('lanterne', True)],
          'lantinerne': [('lantine', False)],
          'lantiners': [('lantine', False)],
          'lants': [('lant', False)],
          'lapis': [('lapis', True)],
          'lappen': [('lap', False)],
          'lappens': [('lap', False)],
          'lapper': [('lap', True)],
          'lapperne': [('lap', False)],
          'lappernes': [('lap', True)],
          'lappers': [('lap', False)],
          'laps': [('lap', True), ('laps', True)],
          "laps'": [('laps', False)],
          'lapse': [('laps', True)],
          'lapsen': [('laps', False)],
          'lapsens': [('laps', False)],
          'lapser': [('laps', False)],
          'lapserne': [('laps', False)],
          'lapsernes': [('laps', False)],
          'lapses': [('laps', True)],
          'larbejder': [('larbejder', False)],
          'larbejderne': [('larbejder', False)],
          'larbejdernes': [('larbejder', False)],
          'larbejders': [('larbejder', False)],
          'larderne': [('lard', False)],
          'lardernes': [('lard', False)],
          'larer': [('larer', False)],
          'larerne': [('lar', False)],
          'larernes': [('larer', False)],
          'larers': [('lar', False)],
          'laret': [('laret', False)],
          'larets': [('laret', False)],
          'larier': [('larie', False)],
          'larierne': [('larie', False)],
          'lariernes': [('larie', False)],
          'lariers': [('larie', False)],
          'lariet': [('larium', False)],
          'lariets': [('larium', False)],
          'larinet': [('larinet', False)],
          'larinets': [('larinet', False)],
          'larium': [('larie', False)],
          'lariums': [('larie', False)],
          'larkets': [('lark', False)],
          'larmens': [('larm', False)],
          'larmerne': [('larm', False)],
          'larmernes': [('larm', False)],
          'larmers': [('larm', False)],
          'lars': [('lars', False)],
          "lars'": [('lars', False)],
          'larsen': [('lars', False)],
          'larsens': [('lars', False)],
          'larser': [('lars', False)],
          'larserne': [('lars', False)],
          'larsernes': [('lars', False)],
          'larsers': [('lars', False)],
          'larten': [('lart', False)],
          'larterne': [('lart', False)],
          'lartoner': [('lartone', False)],
          'lartonerne': [('lartone', False)],
          'lartoners': [('lartone', False)],
          'larven': [('larve', True)],
          'larvens': [('larve', False)],
          'las': [('las', True), ('la', True)],
          'lase': [('lase', False)],
          'lasen': [('las', True)],
          'lasens': [('las', True)],
          'laser': [('laser', True), ('las', True)],
          'laserne': [('laser', True), ('las', True)],
          'lasernes': [('laser', True), ('las', True)],
          'lasers': [('laser', True), ('las', True)],
          'lases': [('lase', False)],
          'laske': [('lask', True), ('laske', True)],
          'lasken': [('lask', True), ('laske', True)],
          'laskens': [('lask', True), ('laske', True)],
          'lasker': [('lask', True), ('laske', True)],
          'laskerne': [('lask', True), ('laske', True)],
          'laskernes': [('lask', True), ('laske', True)],
          'laskers': [('lask', True), ('laske', True)],
          'laskes': [('lask', True), ('laske', True)],
          'lasket': [('lask', False)],
          'laskets': [('lask', False)],
          'lassen': [('las', False)],
          'lassens': [('las', False)],
          'lasser': [('lasse', False)],
          'lasserne': [('las', False)],
          'lassernes': [('lasse', False)],
          'lassers': [('lasse', False)],
          'lasten': [('last', False)],
          'lastens': [('last', False)],
          'laster': [('last', True)],
          'lasterne': [('last', False)],
          'lasternes': [('last', False)],
          'lasters': [('last', False)],
          'lastiks': [('lastik', False)],
          'lata': [('lata', False)],
          'latens': [('latens', True)],
          'laternes': [('lat', False)],
          'latinen': [('latine', False)],
          'latinens': [('latine', False)],
          'latiner': [('latiner', True)],
          'latinerne': [('latiner', False)],
          'latinernes': [('latiner', True)],
          'latiners': [('latiner', True)],
          'latorier': [('latorie', False)],
          'latoriernes': [('latorie', False)],
          'latorium': [('latorie', False)],
          'latoriums': [('latorie', False)],
          "lats'": [('lats', False)],
          'latten': [('latte', True)],
          'lattens': [('latte', True)],
          'latter': [('latter', True), ('latte', True)],
          'latterne': [('latte', False)],
          'latternes': [('latte', True)],
          'latters': [('latter', True), ('latte', True)],
          'lauder': [('laud', True)],
          'lauderne': [('laud', True)],
          'laudernes': [('laud', True)],
          'lauders': [('laud', True)],
          'laus': [('laus', False)],
          'lausen': [('laus', False)],
          'lausens': [('laus', False)],
          'lauser': [('laus', False)],
          'lauserne': [('laus', False)],
          'lausernes': [('laus', False)],
          'lausers': [('laus', False)],
          'lave': [('lave', False)],
          'laven': [('lav', True)],
          'lavene': [('lav', True)],
          'lavenes': [('lav', False)],
          'lavens': [('lav', True)],
          'laver': [('lav', False)],
          'laverne': [('lav', True)],
          'lavernes': [('lav', False)],
          'lavers': [('lav', False)],
          'laves': [('lave', False)],
          'lavet': [('lavet', True), ('lav', True)],
          'lavets': [('lav', True), ('lavet', True)],
          'lavnen': [('lavn', False)],
          'lavnens': [('lavn', False)],
          'lavvandet': [('lavvande', True)],
          'lavvandets': [('lavvande', True)],
          'lazer': [('lazer', False)],
          'lazers': [('lazer', False)],
          'lbaner': [('lbaner', False)],
          'lbanerne': [('lbaner', False)],
          'lbanernes': [('lbaner', False)],
          'lbaners': [('lbaner', False)],
          'lbanken': [('lbank', False)],
          'lbankens': [('lbank', False)],
          'lbanker': [('lbank', False)],
          'lbankerne': [('lbank', False)],
          'lbankernes': [('lbank', False)],
          'lbankers': [('lbank', False)],
          'lbars': [('lbar', False)],
          'lbas': [('lbas', False)],
          'lbassen': [('lbas', False)],
          'lbassens': [('lbas', False)],
          'lbasser': [('lbas', False)],
          'lbasserne': [('lbas', False)],
          'lbassernes': [('lbas', False)],
          'lbassers': [('lbas', False)],
          'lbeder': [('lbeder', False)],
          'lbederne': [('lbeder', False)],
          'lbedernes': [('lbeder', False)],
          'lbeders': [('lbeder', False)],
          'lben': [('lbe', False)],
          'lbenet': [('lben', False)],
          'lbenets': [('lben', False)],
          'lbens': [('lbe', False)],
          'lber': [('lbe', False)],
          'lberne': [('lbe', False)],
          'lbernes': [('lbe', False)],
          'lbidder': [('lbidder', False)],
          'lbidderne': [('lbidder', False)],
          'lbiddernes': [('lbidder', False)],
          'lbidders': [('lbidder', False)],
          'lbilens': [('lbil', False)],
          'lbilernes': [('lbil', False)],
          'lbilers': [('lbil', False)],
          'lbirkes': [('lbirk', False)],
          'lblænders': [('lblænde', False)],
          'lbo': [('lboer', False)],
          'lboen': [('lboer', False)],
          'lboens': [('lboer', False)],
          'lboer': [('lboer', False)],
          'lboerne': [('lboer', False)],
          'lboernes': [('lbo', False)],
          'lboers': [('lbo', False)],
          'lbogen': [('lbog', False)],
          'lbomber': [('lbombe', False)],
          'lbomberne': [('lbombe', False)],
          'lbombernes': [('lbombe', False)],
          'lbombers': [('lbombe', False)],
          'lborets': [('lbor', False)],
          'lbos': [('lboer', False)],
          'lbriks': [('lbrik', False)],
          'lbrinten': [('lbrinte', False)],
          'lbrintens': [('lbrinte', False)],
          'lbuds': [('lbud', False)],
          'lbuen': [('lbue', False)],
          'lbuernes': [('lbue', False)],
          'lbuers': [('lbue', False)],
          'lbukser': [('lbukser', False)],
          'lbukserne': [('lbukser', False)],
          'lbuksernes': [('lbukser', False)],
          'lbuksers': [('lbukser', False)],
          'lbums': [('lbum', False)],
          'lbønnen': [('lbønne', False)],
          'lbønnens': [('lbønne', False)],
          'lbønner': [('lbønne', False)],
          'lbønnerne': [('lbønne', False)],
          'lbønnernes': [('lbønne', False)],
          'lbønners': [('lbønne', False)],
          'lceller': [('lcelle', False)],
          'lcenter': [('lcenter', False)],
          'lcentre': [('lcenter', False)],
          'lcentrene': [('lcenter', False)],
          'lcentrenes': [('lcenter', False)],
          'lcentres': [('lcenter', False)],
          'lcentret': [('lcenter', False)],
          'lcentrets': [('lcenter', False)],
          'lcium': [('lcium', False)],
          'lciums': [('lcium', False)],
          'lcyklen': [('lcykel', False)],
          'lcyklens': [('lcykel', False)],
          'lcykler': [('lcykel', False)],
          'lcyklerne': [('lcykel', False)],
          'lcyklernes': [('lcykel', False)],
          'lcyklers': [('lcykel', False)],
          'ld': [('ld', False)],
          'ldage': [('ldag', False)],
          'ldagen': [('ldag', False)],
          'ldagene': [('ldag', False)],
          'ldages': [('ldag', False)],
          'ldarbejder': [('ldarbejde', False)],
          'ldarbejderne': [('ldarbejde', False)],
          'ldaten': [('ldat', False)],
          'ldatens': [('ldat', False)],
          'ldater': [('ldat', False)],
          'ldaterne': [('ldat', False)],
          'ldaters': [('ldat', False)],
          'ldats': [('ldat', False)],
          'lde': [('ld', False)],
          'ldebroderen': [('ldebror', False)],
          'ldehals': [('ldehal', False)],
          'ldekoder': [('ldekode', False)],
          'ldekoderne': [('ldekode', False)],
          'ldekodernes': [('ldekode', False)],
          'ldekoders': [('ldekode', False)],
          'ldemens': [('ldemens', False)],
          'ldemoders': [('ldemor', False)],
          'ldenes': [('ld', False)],
          'ldenser': [('ldenser', False)],
          'ldensernes': [('ldenser', False)],
          'ldensers': [('ldenser', False)],
          'ldere': [('lder', False)],
          'lderen': [('lder', False)],
          'lderens': [('lder', False)],
          'lderes': [('lder', False)],
          'lderet': [('lder', False)],
          'lderets': [('lder', False)],
          'lders': [('lder', False)],
          'ldes': [('ld', False)],
          'ldesten': [('ldesten', False)],
          'ldestens': [('ldest', False)],
          'ldet': [('ld', False)],
          'ldets': [('ld', False)],
          'ldhuen': [('ldhu', False)],
          'ldhus': [('ldhu', False)],
          'ldi': [('ldo', False)],
          'ldiene': [('ldo', False)],
          'ldienes': [('ldo', False)],
          'ldiker': [('ldiker', False)],
          'ldikerne': [('ldiker', False)],
          'ldikernes': [('ldiker', False)],
          'ldikers': [('ldiker', False)],
          'ldiks': [('ldik', False)],
          'ldis': [('ldo', False)],
          'ldiverne': [('ldiver', False)],
          'ldivers': [('ldiver', False)],
          'ldkoppernes': [('ldkopper', False)],
          'ldkurs': [('ldkur', False)],
          'ldmarker': [('ldmark', False)],
          'ldmarkerne': [('ldmark', False)],
          'ldner': [('ldner', False)],
          'ldnerne': [('ldner', False)],
          'ldners': [('ldner', False)],
          'ldrager': [('ldrager', False)],
          'ldragerne': [('ldrager', False)],
          'ldragernes': [('ldrager', False)],
          'ldragers': [('ldrager', False)],
          'ldranker': [('ldranke', False)],
          'ldrankerne': [('ldranke', False)],
          'ldrankernes': [('ldranke', False)],
          'ldrankers': [('ldranke', False)],
          'ldrede': [('ldrede', False)],
          'ldrene': [('lder', False)],
          'ldrenes': [('lder', False)],
          'ldrens': [('ldre', False)],
          'ldrer': [('ldre', False)],
          'ldrerne': [('ldre', False)],
          'ldrernes': [('ldre', False)],
          'ldrers': [('ldrer', False)],
          'ldres': [('lder', False)],
          'ldrets': [('lder', False)],
          'lds': [('ld', False)],
          "lds'": [('ld', False)],
          'ldsager': [('ldsag', False)],
          'ldsagerne': [('ldsag', False)],
          'ldsagernes': [('ldsag', False)],
          'ldsdage': [('ldsdag', False)],
          'ldsdagene': [('ldsdag', False)],
          'ldsdagenes': [('ldsdag', False)],
          'ldsdages': [('ldsdag', False)],
          'ldsskiftet': [('ldsskift', False)],
          'ldsteder': [('ldsted', False)],
          'ldstederne': [('ldsted', False)],
          'ldstedernes': [('ldsted', False)],
          'ldsteders': [('ldsted', False)],
          'ldtangen': [('ldtang', False)],
          'ldtangens': [('ldtang', False)],
          'ldtimers': [('ldtimer', False)],
          'lduens': [('ldue', False)],
          'lduernes': [('ldue', False)],
          'ldure': [('ldur', False)],
          'ldures': [('ldur', False)],
          'ldækket': [('ldæk', False)],
          'ldækkets': [('ldæk', False)],
          'le': [('le', False)],
          'leaderne': [('leader', False)],
          'leaders': [('leader', False)],
          'leaks': [('leaks', False)],
          'learbejder': [('learbejde', False)],
          'learbejderne': [('learbejde', False)],
          'leaser': [('leaser', False)],
          'leaserne': [('leaser', False)],
          'leasernes': [('leaser', False)],
          'leasers': [('leaser', False)],
          'leballer': [('lebal', False)],
          'leballers': [('lebal', False)],
          'lebens': [('leben', False)],
          'lebis': [('lebi', False)],
          'leboer': [('lebo', False)],
          'leboerne': [('lebo', False)],
          'leboernes': [('leboer', False)],
          'leboers': [('lebo', False)],
          'lebroderens': [('lebror', False)],
          'lebrødre': [('lebror', False)],
          'lebrødrene': [('lebror', False)],
          'lebrødrenes': [('lebror', False)],
          'lebrødres': [('lebror', False)],
          'lebs': [('lebs', False)],
          'lebus': [('lebus', False)],
          'ledagens': [('ledag', False)],
          'ledden': [('led', True)],
          'leddens': [('led', True)],
          'ledder': [('led', False)],
          'ledderne': [('led', True)],
          'leddernes': [('led', True)],
          'ledders': [('led', True)],
          'lede': [('lede', False)],
          'leden': [('lede', False)],
          'ledens': [('lede', False)],
          'leder': [('leder', True)],
          'lederne': [('leder', False)],
          'ledernes': [('leder', True)],
          'leders': [('leder', False)],
          'ledes': [('lede', False)],
          'ledet': [('lede', False)],
          'ledets': [('lede', False)],
          'ledsager': [('ledsager', True)],
          'ledsagerne': [('ledsager', True)],
          'ledsagernes': [('ledsager', False)],
          'ledømmernes': [('ledømme', False)],
          'ledømmers': [('ledømme', False)],
          'leen': [('le', True)],
          'leens': [('le', False)],
          'leer': [('le', True)],
          'leerne': [('le', True)],
          'leernes': [('le', True)],
          'leers': [('le', True)],
          'lefinger': [('lefinger', False)],
          'lefingers': [('lefinger', False)],
          'leforældre': [('leforældre', False)],
          'legas': [('lega', False)],
          'legaver': [('legave', False)],
          'legaverne': [('legave', False)],
          'legavernes': [('legave', False)],
          'legavers': [('legave', False)],
          'lege': [('leg', True)],
          'legen': [('leg', False)],
          'legene': [('leg', True)],
          'legenes': [('leg', True)],
          'legens': [('leg', False)],
          'leges': [('leg', True)],
          'leget': [('lege', False)],
          'legets': [('lege', False)],
          'legier': [('legi', False)],
          'legierne': [('legi', False)],
          'legiernes': [('legi', False)],
          'legiers': [('legi', False)],
          'lehandlerne': [('lehandler', False)],
          'lehandlernes': [('lehandler', False)],
          'lei': [('leu', True)],
          'leis': [('leu', True)],
          'lejders': [('lejder', True)],
          'leje': [('leje', False)],
          'lejen': [('leje', False)],
          'lejens': [('leje', False)],
          'lejer': [('leje', True), ('lejer', True)],
          'lejerne': [('lejer', True), ('leje', True)],
          'lejernes': [('lejer', True), ('leje', True)],
          'lejers': [('lejer', True), ('leje', True)],
          'lejes': [('leje', False)],
          'lejet': [('leje', False)],
          'lejets': [('leje', False)],
          'lejle': [('lejl', False)],
          'lejlen': [('lejl', False)],
          'lejlens': [('lejl', False)],
          'lejles': [('lejl', False)],
          'lejre': [('lejr', False)],
          'lejren': [('lejr', False)],
          'lejrens': [('lejr', False)],
          'lejres': [('lejr', False)],
          'lejs': [('lejs', False)],
          'lejse': [('lejs', False)],
          'lejsen': [('lejs', False)],
          'lejsens': [('lejs', False)],
          'lejser': [('lejs', False)],
          'lejserne': [('lejs', False)],
          'lejsernes': [('lejs', False)],
          'lejsers': [('lejs', False)],
          'lejses': [('lejs', False)],
          'lekerne': [('lekerne', False)],
          'lekernes': [('lekerne', False)],
          'lekonger': [('lekonge', False)],
          'lekongers': [('lekonge', False)],
          'leks': [('leks', False)],
          'lekserne': [('leks', False)],
          'leksernes': [('leks', False)],
          'leksers': [('leks', False)],
          'lekter': [('lekt', False)],
          'lekterne': [('lekt', False)],
          'lekternes': [('lekt', False)],
          'lekters': [('lekt', False)],
          'lekunsterne': [('lekunst', False)],
          'lekunsters': [('lekunst', False)],
          'lekyler': [('lekyle', False)],
          'lekylerne': [('lekyle', False)],
          'lekylernes': [('lekyle', False)],
          'lekylers': [('lekyle', False)],
          'lele': [('lele', False)],
          'lelen': [('lele', False)],
          'lelens': [('lele', False)],
          'leler': [('lele', False)],
          'lelernes': [('lele', False)],
          'lelers': [('lele', False)],
          'leles': [('lele', False)],
          'leleverne': [('lelev', False)],
          'lelevernes': [('lelev', False)],
          'lelisternes': [('leliste', False)],
          'lelisters': [('leliste', False)],
          'lellen': [('lel', False)],
          'leller': [('lel', False)],
          'lellers': [('lel', False)],
          'lelsers': [('lelse', False)],
          'lelærerne': [('lelærer', False)],
          'lelærernes': [('lelærer', False)],
          'lemagerne': [('lemager', False)],
          'lemagernes': [('lemager', False)],
          'lemagers': [('lemager', False)],
          'lemanden': [('lemand', False)],
          'lemandens': [('lemand', False)],
          'lemen': [('leman', False)],
          'lemens': [('leman', False)],
          'lemlejer': [('lemleje', False)],
          'lemlejerne': [('lemleje', False)],
          'lemlejers': [('lemleje', False)],
          'lemme': [('lem', False)],
          'lemmelser': [('lemmelse', False)],
          'lemmelserne': [('lemmelse', False)],
          'lemmelsernes': [('lemmelse', False)],
          'lemmen': [('lem', False)],
          'lemmens': [('lem', False)],
          'lemmer': [('lem', True)],
          'lemmerne': [('lem', True)],
          'lemmernes': [('lem', False)],
          'lemmers': [('lem', True)],
          'lemmes': [('lem', False)],
          'lemos': [('lemos', False)],
          'lemosen': [('lemos', False)],
          'lemosens': [('lemos', False)],
          'lemunde': [('lemund', False)],
          'lemærker': [('lemærke', False)],
          'lemærkerne': [('lemærker', False)],
          'lemærkernes': [('lemærker', False)],
          'lemærkers': [('lemærker', False)],
          'len': [('len', True)],
          'lender': [('lender', False)],
          'lenderne': [('lender', False)],
          'lendernes': [('lender', False)],
          'lenders': [('lender', False)],
          'lener': [('lener', False)],
          'lenerne': [('lener', False)],
          'lenernes': [('lener', False)],
          'leners': [('lener', False)],
          'lenet': [('len', True)],
          'lenets': [('len', True)],
          'lens': [('len', True)],
          "lens'": [('lens', False)],
          'lensen': [('lens', False)],
          'lensens': [('lens', False)],
          'lenser': [('lens', False)],
          'lenserne': [('lenser', False)],
          'lensernes': [('lens', False)],
          'lensers': [('lens', False)],
          'lenten': [('lent', False)],
          'lentens': [('lent', False)],
          'lenter': [('lent', False)],
          'lenterne': [('lent', False)],
          'lenternes': [('lent', False)],
          'lenters': [('lent', False)],
          'lentet': [('lent', False)],
          'lentets': [('lent', False)],
          'leoner': [('leon', False)],
          'leonerne': [('leon', False)],
          'leonernes': [('leon', False)],
          'leoners': [('leon', False)],
          'leposen': [('lepose', False)],
          'leposens': [('lepose', False)],
          'leposer': [('lepose', False)],
          'leposerne': [('lepose', False)],
          'leposernes': [('lepose', False)],
          'lepottens': [('lepotte', False)],
          'lepotter': [('lepotte', False)],
          'lepotterne': [('lepotte', False)],
          'leppen': [('lep', False)],
          'leppens': [('lep', False)],
          'ler': [('ler', True)],
          'lera': [('lera', False)],
          'lerader': [('lerad', False)],
          'leradernes': [('lerad', False)],
          'lerarbejdernes': [('lerarbejde', False)],
          'lerarbejders': [('lerarbejde', False)],
          'leras': [('lera', False)],
          'leredernes': [('lerede', False)],
          'leredes': [('lerede', False)],
          'lerejser': [('lerejser', False)],
          'lerenser': [('lerenser', False)],
          'lerenserne': [('lerenser', False)],
          'lerer': [('lerer', False)],
          'lererne': [('lerer', False)],
          'lerernes': [('lerer', False)],
          'lerers': [('lerer', False)],
          'leret': [('ler', True)],
          'lerets': [('ler', True)],
          'leretten': [('leret', False)],
          'lerettens': [('leret', False)],
          'lergens': [('lergen', False)],
          'lerheden': [('lerhed', False)],
          'lerien': [('leri', False)],
          'leriens': [('leri', False)],
          'lerier': [('leri', False)],
          'lerierne': [('leri', False)],
          'leriernes': [('leri', False)],
          'leriers': [('leri', False)],
          'leriet': [('leri', False)],
          'leriets': [('leri', False)],
          'leris': [('leri', False)],
          'leritterne': [('lerit', False)],
          'lerken': [('lerk', False)],
          'lerkens': [('lerk', False)],
          'lermænd': [('lermand', False)],
          'lermændene': [('lermand', False)],
          'lermændenes': [('lermand', False)],
          'lermænds': [('lermand', False)],
          'lerne': [('ler', False)],
          'lernes': [('ler', False)],
          'leroen': [('lero', False)],
          'leroens': [('lero', False)],
          'leros': [('lero', False)],
          'lers': [('ler', True)],
          'lerten': [('lert', False)],
          'lertens': [('lert', False)],
          'lerter': [('lert', False)],
          'lerterne': [('lert', False)],
          'lerters': [('lert', False)],
          'lerts': [('lert', False)],
          'lerusen': [('leruse', False)],
          'lerusens': [('leruse', False)],
          'leruser': [('leruse', False)],
          'leruserne': [('leruse', False)],
          'lerusernes': [('leruse', False)],
          'lerusers': [('leruse', False)],
          'leruses': [('leruse', False)],
          'les': [('le', False)],
          "les'": [('le', False)],
          'lesager': [('lesag', False)],
          'lesans': [('lesans', False)],
          'lesene': [('le', False)],
          'lesenes': [('le', False)],
          'lesers': [('leser', False)],
          'lesken': [('lesken', False)],
          'leskens': [('leske', False)],
          'leskernes': [('leske', False)],
          'leskøderne': [('leskøde', False)],
          'leskødet': [('leskøde', False)],
          'leskødets': [('leskøde', False)],
          'leskøjten': [('leskøjte', False)],
          'leskøjtens': [('leskøjte', False)],
          'leskøjters': [('leskøjte', False)],
          'lespiller': [('lespiller', False)],
          'lespillerne': [('lespiller', False)],
          'lespillernes': [('lespiller', False)],
          'lespillers': [('lespiller', False)],
          'lessenes': [('lessene', False)],
          'lessens': [('lesse', False)],
          'lestarterne': [('lestart', False)],
          'lestarters': [('lestart', False)],
          'lesten': [('leste', False)],
          'lestens': [('lesten', False)],
          'lester': [('leste', False)],
          'lesterne': [('leste', False)],
          'lesternes': [('leste', False)],
          'lesters': [('leste', False)],
          'lestøvler': [('lestøvler', False)],
          'lestøvlerne': [('lestøvler', False)],
          'lestøvlernes': [('lestøvler', False)],
          'letage': [('letage', False)],
          'leter': [('let', False)],
          'leters': [('let', False)],
          'letes': [('lete', False)],
          'letiden': [('letid', False)],
          'letiner': [('letin', False)],
          'letinernes': [('letin', False)],
          'letogets': [('letog', False)],
          'letonen': [('letone', False)],
          'letonens': [('letone', False)],
          'letoner': [('letone', False)],
          'letonerne': [('letone', False)],
          'letonernes': [('letone', False)],
          'letoners': [('letone', False)],
          'letten': [('lette', True)],
          'lettens': [('lette', True)],
          'letter': [('lette', False)],
          'letterne': [('lette', True)],
          'letternes': [('lette', True)],
          'letters': [('lette', True)],
          'lettet': [('let', False)],
          'lettets': [('let', False)],
          'letæer': [('letå', False)],
          'letæerne': [('letå', False)],
          'letæernes': [('letå', False)],
          'letæers': [('letå', False)],
          'leuret': [('leuret', False)],
          'leve': [('leve', True)],
          'leven': [('lev', True)],
          'levens': [('lev', True)],
          'lever': [('lever', True)],
          'leverne': [('lever', True)],
          'levernes': [('lever', True)],
          'levers': [('lever', False)],
          'leves': [('leve', True)],
          'levetiden': [('levetid', True)],
          'levitten': [('levit', True)],
          'levner': [('levner', False)],
          'levnerne': [('levner', False)],
          'levnernes': [('levner', False)],
          'levners': [('levner', False)],
          'lfanger': [('lfanger', False)],
          'lfangerne': [('lfanger', False)],
          'lfangernes': [('lfanger', False)],
          'lfangers': [('lfanger', False)],
          'lfarternes': [('lfart', False)],
          'lfas': [('lfa', False)],
          'lfase': [('lfase', False)],
          'lfasen': [('lfase', False)],
          'lfasens': [('lfase', False)],
          'lfases': [('lfase', False)],
          'lfe': [('lfe', False)],
          'lfen': [('lf', False)],
          'lfens': [('lf', False)],
          'lfere': [('lfer', False)],
          'lferes': [('lfer', False)],
          'lferiens': [('lferie', False)],
          'lferierne': [('lferie', False)],
          'lfers': [('lf', False)],
          'lfes': [('lfe', False)],
          'lfider': [('lfid', False)],
          'lfiderne': [('lfid', False)],
          'lfidernes': [('lfid', False)],
          'lfiders': [('lfid', False)],
          'lfien': [('lfie', False)],
          'lfiens': [('lfie', False)],
          'lfier': [('lfie', False)],
          'lfierne': [('lfie', False)],
          'lfiernes': [('lfie', False)],
          'lfiers': [('lfie', False)],
          'lfilter': [('lfilter', False)],
          'lfilters': [('lfilt', False)],
          'lfiner': [('lfin', False)],
          'lfiners': [('lfin', False)],
          'lfis': [('lfis', False)],
          'lflikker': [('lflikker', False)],
          'lflikkerne': [('lflikker', False)],
          'lflikkernes': [('lflikker', False)],
          'lflikkers': [('lflikker', False)],
          'lflisen': [('lflise', False)],
          'lflisens': [('lflise', False)],
          'lfliser': [('lflise', False)],
          'lfliserne': [('lflise', False)],
          'lflisernes': [('lflise', False)],
          'lflisers': [('lflise', False)],
          'lflugter': [('lflugt', False)],
          'lflugternes': [('lflugt', False)],
          'lflugters': [('lflugt', False)],
          'lflys': [('lfly', False)],
          'lfonds': [('lfond', False)],
          'lfons': [('lfons', False)],
          'lfos': [('lfo', False)],
          'lfærden': [('lfærd', False)],
          'lfærdens': [('lfærd', False)],
          'lg': [('lg', False)],
          'lgader': [('lgade', False)],
          'lgamet': [('lgam', False)],
          'lgamets': [('lgam', False)],
          'lgarerne': [('lgarer', False)],
          'lgarers': [('lgarer', False)],
          'lge': [('lg', False)],
          'lgene': [('lg', False)],
          'lgenen': [('lgen', False)],
          'lgenens': [('lgen', False)],
          'lgener': [('lgen', False)],
          'lgenerne': [('lgen', False)],
          'lgenernes': [('lgen', False)],
          'lgeners': [('lgen', False)],
          'lgenes': [('lg', False)],
          'lgenier': [('lgeni', False)],
          'lgenierne': [('lgeni', False)],
          'lgeniernes': [('lgeni', False)],
          'lgeniers': [('lgeni', False)],
          'lgens': [('lge', False)],
          'lger': [('lger', False)],
          'lgere': [('lger', False)],
          'lgeren': [('lger', False)],
          'lgerens': [('lger', False)],
          'lgeres': [('lger', False)],
          'lgerier': [('lgerier', False)],
          'lgerierne': [('lgerier', False)],
          'lgeriernes': [('lgerier', False)],
          'lgeriers': [('lgerier', False)],
          'lgerne': [('lge', False)],
          'lgernes': [('lge', False)],
          'lgers': [('lge', False)],
          'lges': [('lg', False)],
          'lget': [('lg', False)],
          'lgets': [('lg', False)],
          'lgien': [('lgi', False)],
          'lgiens': [('lgi', False)],
          'lgier': [('lgier', False)],
          'lgierne': [('lgier', False)],
          'lgiernes': [('lgier', False)],
          'lgiers': [('lgier', False)],
          'lgis': [('lgi', False)],
          'lgret': [('lgret', False)],
          'lgrets': [('lgret', False)],
          'lgretten': [('lgret', False)],
          'lgrettens': [('lgret', False)],
          'lgrus': [('lgrus', False)],
          'lgs': [('lg', False)],
          'lgsteder': [('lgsted', False)],
          'lgstederne': [('lgsted', False)],
          'lgstedernes': [('lgsted', False)],
          'lgsteders': [('lgsted', False)],
          'lgørerne': [('lgører', False)],
          'lhals': [('lhals', False)],
          'lhandler': [('lhandler', False)],
          'lhandlerne': [('lhandler', False)],
          'lhandlers': [('lhandler', False)],
          'lhans': [('lhans', False)],
          'lhaver': [('lhaver', False)],
          'lhaverne': [('lhaver', False)],
          'lhavernes': [('lhaver', False)],
          'lhavers': [('lhaver', False)],
          'lheden': [('lhed', False)],
          'lhedens': [('lhede', False)],
          'lheder': [('lhed', False)],
          'lhederne': [('lhed', False)],
          'lhedernes': [('lhed', False)],
          'lheders': [('lhed', False)],
          'lhuen': [('lhue', False)],
          'lhuens': [('lhue', False)],
          'lhus': [('lhus', False)],
          'lhøjder': [('lhøjde', False)],
          'lhøjderne': [('lhøjde', False)],
          'lhøjdernes': [('lhøjde', False)],
          'lhøjders': [('lhøjde', False)],
          'lhørerne': [('lhører', False)],
          'lhørernes': [('lhører', False)],
          'li': [('li', False)],
          'lialer': [('lial', False)],
          'lialerne': [('lial', False)],
          'lialernes': [('lial', False)],
          'lialers': [('lial', False)],
          'lianer': [('lian', True)],
          'lianerne': [('lian', True)],
          'lianernes': [('lian', True)],
          'lianers': [('lian', True)],
          'lians': [('lian', True)],
          'liben': [('lib', False)],
          'libens': [('lib', False)],
          'liber': [('liber', False)],
          'liberier': [('liberier', True), ('liberi', True)],
          'liberierne': [('liberier', True), ('liberi', True)],
          'liberiernes': [('liberier', True), ('liberi', True)],
          'liberiers': [('liberier', True), ('liberi', True)],
          'liberis': [('liberi', True)],
          'liberne': [('liber', False)],
          'libernes': [('liber', False)],
          'libier': [('libi', False)],
          'libierne': [('libi', False)],
          'libiernes': [('libi', False)],
          'libiers': [('libi', False)],
          'libiet': [('libi', False)],
          'libis': [('libi', False)],
          'libris': [('libris', False)],
          'licen': [('lice', False)],
          'licens': [('licens', True)],
          'licer': [('lice', False)],
          'licerne': [('lice', False)],
          'licernes': [('lice', False)],
          'licers': [('lice', False)],
          'lices': [('lice', False)],
          "lices'": [('lice', False)],
          'licet': [('lice', False)],
          'licets': [('lice', False)],
          'lide': [('lide', False)],
          'liden': [('lide', False)],
          'lidenden': [('lidend', False)],
          'lidendens': [('lidend', False)],
          'lidene': [('lide', False)],
          'lidenes': [('lide', False)],
          'lidens': [('lid', False)],
          'lider': [('lider', False)],
          'liderne': [('lider', False)],
          'lidernes': [('lider', False)],
          'liders': [('lider', False)],
          'lides': [('lide', False)],
          'lids': [('lid', True)],
          "lids'": [('lids', False)],
          'lidsen': [('lidse', True)],
          'lidsens': [('lidse', True)],
          'lidser': [('lidse', True)],
          'lidserne': [('lidse', True)],
          'lidsernes': [('lidse', True)],
          'lidsers': [('lidse', True)],
          'lien': [('li', True)],
          'liene': [('lus', False)],
          'lienes': [('li', False)],
          'liens': [('li', False)],
          "liens'": [('lien', False)],
          'lier': [('li', True)],
          'liere': [('lier', False)],
          'lieren': [('lier', False)],
          'lierens': [('lier', False)],
          'lierer': [('lier', False)],
          'liererne': [('lier', False)],
          'lierernes': [('lier', False)],
          'lierers': [('lier', False)],
          'lieres': [('lier', False)],
          'lieret': [('lier', False)],
          'lierets': [('lier', False)],
          'lierne': [('li', True)],
          'liernes': [('li', True)],
          'liers': [('li', False)],
          'lies': [('lies', False)],
          'liet': [('li', False)],
          'liets': [('li', False)],
          'lif': [('lif', False)],
          'liffer': [('lif', False)],
          'liffernes': [('lif', False)],
          'liffers': [('lif', False)],
          'lifte': [('lift', True)],
          'liften': [('lift', True)],
          'liftens': [('lift', False)],
          'lifterne': [('lift', False)],
          'lifternes': [('lift', False)],
          'lifters': [('lift', True)],
          'liftes': [('lift', False)],
          'liftet': [('lift', True)],
          'liftets': [('lift', True)],
          'lige': [('lige', True)],
          'ligejer': [('ligejer', False)],
          'ligejerne': [('ligejer', False)],
          'ligens': [('ligens', False)],
          'liger': [('lig', False)],
          'ligeret': [('ligeret', True)],
          'ligerets': [('ligeret', True)],
          'ligerne': [('lig', False)],
          'ligernes': [('lig', False)],
          'ligers': [('lig', False)],
          'liges': [('lige', True)],
          'ligger': [('ligger', False)],
          'liggers': [('ligger', False)],
          'lighter': [('lighter', True)],
          'lighterne': [('lighter', False)],
          'lighternes': [('lighter', True)],
          'lighters': [('lighter', True)],
          'lignernes': [('ligner', False)],
          'ligten': [('ligt', False)],
          'ligtens': [('ligt', False)],
          'ligter': [('ligt', False)],
          'ligterne': [('ligt', False)],
          'ligternes': [('ligt', False)],
          'likanens': [('likan', False)],
          'likaner': [('likaner', False)],
          'likanerne': [('likan', False)],
          'likanernes': [('likan', False)],
          'likaners': [('likaner', False)],
          'liken': [('like', False)],
          'likens': [('like', False)],
          'liker': [('like', False)],
          'likerne': [('like', False)],
          'likernes': [('like', False)],
          'likers': [('lika', False)],
          'likke': [('lik', False)],
          'likken': [('lik', False)],
          'likker': [('likker', False)],
          'likkere': [('likker', False)],
          'likkeren': [('likker', False)],
          'likkerens': [('likker', False)],
          'likkeres': [('likker', False)],
          'likkerne': [('lik', False)],
          'likkernes': [('likker', False)],
          'likkers': [('likker', False)],
          'likkes': [('lik', False)],
          'liklen': [('likel', False)],
          'liklerne': [('likel', False)],
          'liklernes': [('likel', False)],
          'liklers': [('likel', False)],
          'likonen': [('likone', False)],
          'likonens': [('likone', False)],
          'likoner': [('likone', False)],
          'likonerne': [('likone', False)],
          'likonernes': [('likone', False)],
          'likoners': [('likone', False)],
          'likosen': [('likose', False)],
          'likosens': [('likose', False)],
          'likten': [('likt', False)],
          'liktens': [('likt', False)],
          'likter': [('likt', False)],
          'likterne': [('likt', False)],
          'likternes': [('likt', False)],
          'likters': [('likt', False)],
          'likum': [('likum', False)],
          'likummernes': [('likum', False)],
          'likums': [('likum', False)],
          'lil': [('lille', False)],
          'lillens': [('lille', False)],
          'liller': [('lille', False)],
          'lillerne': [('lille', False)],
          'lillernes': [('lille', False)],
          'lillers': [('lille', False)],
          'lils': [('lille', False)],
          'lilten': [('lilte', False)],
          'liltens': [('lilte', False)],
          'lilæers': [('lilæer', False)],
          'lima': [('lima', False)],
          'limas': [('lima', False)],
          'lime': [('lim', True), ('lime', True)],
          'limen': [('lime', True), ('lim', True)],
          'limene': [('lime', True), ('lim', True)],
          'limenes': [('lime', True), ('lim', True)],
          'limens': [('lime', True), ('lim', True)],
          'limenterne': [('liment', False)],
          'limentet': [('liment', False)],
          'limentets': [('liment', False)],
          'limers': [('lim', False)],
          'limes': [('lime', True), ('lim', True)],
          'limmer': [('limmer', False)],
          'limmernes': [('lim', False)],
          'limmers': [('lim', False)],
          'linde': [('lind', True)],
          'linden': [('lind', True)],
          'lindens': [('lind', True)],
          'linder': [('linde', False)],
          'linderne': [('linde', False)],
          'lindernes': [('linde', False)],
          'linders': [('linde', False)],
          'lindes': [('lind', True)],
          'lindre': [('linder', False)],
          'lindres': [('linder', False)],
          'line': [('line', False)],
          'linen': [('line', False)],
          'linene': [('lin', True)],
          'linenes': [('lin', True)],
          'linens': [('line', False)],
          'liner': [('liner', True), ('line', True)],
          'linerne': [('line', True), ('liner', True)],
          'linernes': [('liner', True), ('line', True)],
          'liners': [('line', True), ('liner', True)],
          'lines': [('line', False)],
          'linet': [('lin', True)],
          'linets': [('lin', True)],
          'linge': [('ling', False)],
          'lingen': [('ling', False)],
          'lingens': [('ling', False)],
          'linger': [('ling', False)],
          'lingerne': [('ling', False)],
          'lingernes': [('ling', False)],
          'linges': [('ling', False)],
          'lings': [('ling', False)],
          "lings'": [('ling', False)],
          'lini': [('lini', False)],
          'linien': [('linie', True)],
          'liniens': [('lini', False)],
          'linier': [('lini', False)],
          'linierne': [('lini', False)],
          'linis': [('lini', False)],
          'linister': [('linist', False)],
          'linisters': [('linist', False)],
          'linken': [('link', False)],
          'linkens': [('linke', False)],
          'linkernes': [('linke', False)],
          'linkers': [('linke', False)],
          'links': [('link', True)],
          "links'": [('link', False)],
          'linten': [('lint', False)],
          'lintens': [('lint', False)],
          'linter': [('lint', False)],
          'linterne': [('lint', False)],
          'linternes': [('lint', False)],
          'linters': [('lint', False)],
          'lioner': [('lion', False)],
          'lionerne': [('lion', False)],
          'lionernes': [('lion', False)],
          'lioners': [('lion', False)],
          'lions': [('lion', False)],
          'lipens': [('lipens', False)],
          'lipenser': [('lipens', False)],
          'lipensernes': [('lipens', False)],
          'lipensers': [('lipens', False)],
          'lippen': [('lip', False)],
          'lippens': [('lip', False)],
          'lippes': [('lippe', False)],
          'lips': [('lips', False)],
          "lips'": [('lips', False)],
          'lipsen': [('lips', False)],
          'lipsene': [('lips', False)],
          'lipsenes': [('lips', False)],
          'lipsens': [('lips', False)],
          'lipserne': [('lipse', False)],
          'liren': [('lir', True), ('lire', True)],
          'lirene': [('lire', True)],
          'lirenes': [('lire', True)],
          'lirens': [('lire', True), ('lir', True)],
          'lirer': [('lire', False)],
          'lirerne': [('lire', False)],
          'lirernes': [('lire', False)],
          'lirers': [('lire', True)],
          'lirren': [('lirren', False)],
          'lirrens': [('lirren', False)],
          'lirts': [('lirt', False)],
          'lis': [('li', False)],
          'lisander': [('lisander', False)],
          'lise': [('lise', False)],
          'lisen': [('lise', False)],
          'lisens': [('lise', False)],
          'liser': [('lise', False)],
          'liserne': [('lise', False)],
          'lisernes': [('lise', False)],
          'lises': [('lise', False)],
          'lisken': [('lisk', False)],
          'liskes': [('liske', False)],
          'lismen': [('isme', False)],
          'lismens': [('lisme', False)],
          'lissen': [('lis', False)],
          'lissens': [('lis', False)],
          'lisser': [('lis', False)],
          'lisserne': [('lis', False)],
          'lissernes': [('lis', False)],
          'lissers': [('lis', False)],
          'listen': [('liste', True), ('list', True)],
          'listens': [('liste', True), ('list', True)],
          'lister': [('liste', True)],
          'listerne': [('liste', True)],
          'listernes': [('liste', True)],
          'listers': [('liste', True)],
          'litaner': [('litaner', False)],
          'litaners': [('litaner', False)],
          'liten': [('lite', False)],
          'litens': [('lite', False)],
          'liter': [('liter', True)],
          'literne': [('liter', False)],
          'liternes': [('liter', True)],
          'liters': [('liter', True)],
          'liti': [('liti', False)],
          'litis': [('liti', False)],
          'litotes': [('litote', True), ('litotes', True)],
          'lits': [('lits', False)],
          "lits'": [('lits', False)],
          'litsen': [('lits', False)],
          'litsens': [('lits', False)],
          'litser': [('lits', False)],
          'litserne': [('lits', False)],
          'litsernes': [('lits', False)],
          'litsers': [('lits', False)],
          'litten': [('lit', False)],
          'littens': [('lit', False)],
          'litter': [('litter', False)],
          'litteret': [('litter', False)],
          'litterets': [('litter', False)],
          'litternes': [('lit', False)],
          'litters': [('lit', False)],
          'lium': [('lie', False)],
          'liums': [('lie', False)],
          'liven': [('liven', False)],
          'livens': [('liven', False)],
          'liver': [('liver', False)],
          'livernes': [('liver', False)],
          'lizer': [('lizer', False)],
          'lizers': [('lizer', False)],
          'ljakken': [('ljakke', False)],
          'ljens': [('lje', False)],
          'ljer': [('lje', False)],
          'ljorden': [('ljord', False)],
          'ljordens': [('ljord', False)],
          'lk': [('lk', False)],
          'lka': [('lka', False)],
          'lkaffer': [('lkaffe', False)],
          'lkafferne': [('lkaffe', False)],
          'lkaffernes': [('lkaffe', False)],
          'lkaffers': [('lkaffe', False)],
          'lkalier': [('lkali', False)],
          'lkalierne': [('lkali', False)],
          'lkaliernes': [('lkali', False)],
          'lkaliers': [('lkali', False)],
          'lkalken': [('lkalk', False)],
          'lkalkens': [('lkalk', False)],
          'lkandernes': [('lkande', False)],
          'lkanen': [('lkan', False)],
          'lkanens': [('lkan', False)],
          'lkaner': [('lkan', False)],
          'lkanerne': [('lkan', False)],
          'lkanernes': [('lkan', False)],
          'lkaners': [('lkan', False)],
          'lkans': [('lkan', False)],
          'lkas': [('lka', False)],
          'lke': [('lk', False)],
          'lken': [('lk', False)],
          'lkene': [('lk', False)],
          'lkenes': [('lk', False)],
          'lkenet': [('lken', False)],
          'lkenets': [('lken', False)],
          'lkens': [('lk', False)],
          'lker': [('lker', False)],
          'lkere': [('lker', False)],
          'lkeren': [('lker', False)],
          'lkerens': [('lker', False)],
          'lkeres': [('lker', False)],
          'lkerne': [('lker', False)],
          'lkernes': [('lke', False)],
          'lkers': [('lke', False)],
          'lkes': [('lk', False)],
          'lkestyret': [('lkestyre', False)],
          'lkestyrets': [('lkestyre', False)],
          'lket': [('lk', False)],
          'lkets': [('lk', False)],
          'lkien': [('lkie', False)],
          'lkiens': [('lkie', False)],
          'lkier': [('lkie', False)],
          'lkierne': [('lkie', False)],
          'lkiernes': [('lkie', False)],
          'lkiers': [('lkie', False)],
          'lkilder': [('lkilde', False)],
          'lkilderne': [('lkilde', False)],
          'lkildernes': [('lkilde', False)],
          'lkilders': [('lkilde', False)],
          'lkloren': [('lklore', False)],
          'lklorens': [('lklore', False)],
          'lkometer': [('lkometer', False)],
          'lkometers': [('lkometer', False)],
          'lkon': [('lkon', False)],
          'lkonen': [('lkon', False)],
          'lkonens': [('lkon', False)],
          'lkonerne': [('lkon', False)],
          'lkonernes': [('lkon', False)],
          'lkons': [('lkon', False)],
          'lkontroller': [('lkontrol', False)],
          'lkontrollerne': [('lkontrol', False)],
          'lkontrollernes': [('lkontrol', False)],
          'lkontrollers': [('lkontrol', False)],
          'lkrans': [('lkran', False)],
          'lkronen': [('lkrone', False)],
          'lkroner': [('lkrone', False)],
          'lkronernes': [('lkrone', False)],
          'lks': [('lk', False)],
          "lks'": [('lk', False)],
          'lkummet': [('lkum', False)],
          'lkummets': [('lkum', False)],
          'lkunen': [('lkun', False)],
          'lkunens': [('lkun', False)],
          'lkuner': [('lkun', False)],
          'lkunernes': [('lkun', False)],
          'lkuren': [('lkur', False)],
          'lkurens': [('lkur', False)],
          'lkures': [('lkur', False)],
          'lkurser': [('lkurs', False)],
          'lkurserne': [('lkurs', False)],
          'lkursernes': [('lkurs', False)],
          'lkursers': [('lkurs', False)],
          'lkurve': [('lkurve', False)],
          'lkurven': [('lkurv', False)],
          'lkurvens': [('lkurve', False)],
          'lkurves': [('lkurv', False)],
          'lkyder': [('lkyd', False)],
          'lkyderne': [('lkyd', False)],
          'lkys': [('lky', False)],
          'lkøbet': [('lkøb', False)],
          'll': [('ll', False)],
          'll.': [('llion', False)],
          'llader': [('llade', False)],
          'lladerne': [('llade', False)],
          'lladernes': [('llade', False)],
          'lladers': [('llade', False)],
          'llads': [('llads', False)],
          'llager': [('llage', False)],
          'llagerne': [('llage', False)],
          'llagernes': [('llage', False)],
          'llagers': [('llage', False)],
          'llaks': [('llak', False)],
          'llaksen': [('llakse', False)],
          'llaksens': [('llakse', False)],
          'llanens': [('llan', False)],
          'llaner': [('llan', False)],
          'llaners': [('llan', False)],
          'llans': [('llan', False)],
          'llansen': [('llans', False)],
          'llansens': [('llans', False)],
          'llanter': [('llant', False)],
          'llanterne': [('llant', False)],
          'llanternes': [('llant', False)],
          'llanters': [('llant', False)],
          'llappernes': [('llap', False)],
          'llaps': [('llap', False)],
          'llarerne': [('llarer', False)],
          'llarers': [('llarer', False)],
          'llars': [('llar', False)],
          "llars'": [('llar', False)],
          'llas': [('lla', False)],
          'llatens': [('llat', False)],
          'llats': [('llat', False)],
          'lleden': [('lled', False)],
          'lledens': [('lled', False)],
          'lleder': [('llede', False)],
          'llederne': [('llede', False)],
          'lledernes': [('lleder', False)],
          'lleders': [('llede', False)],
          'llege': [('llege', False)],
          'lleges': [('llege', False)],
          'llegier': [('llegie', False)],
          'llegierne': [('llegie', False)],
          'llegiernes': [('llegie', False)],
          'llegiers': [('llegie', False)],
          'llejer': [('lleje', False)],
          'llejerne': [('lleje', False)],
          'llejernes': [('lleje', False)],
          'llejers': [('lleje', False)],
          'llemanden': [('llemande', False)],
          'llemandens': [('llemande', False)],
          'llemærkerne': [('llemærke', False)],
          'llemærkernes': [('llemærke', False)],
          'llemærkers': [('llemærke', False)],
          'llene': [('ll', False)],
          'llenes': [('ll', False)],
          'llenets': [('llen', False)],
          'llenserne': [('llens', False)],
          'llere': [('ller', False)],
          'lleren': [('ller', False)],
          'llerens': [('ller', False)],
          'lleres': [('ller', False)],
          'llerets': [('ller', False)],
          'llerken': [('llerken', False)],
          'llerkens': [('llerken', False)],
          'llesten': [('llesten', False)],
          'lletten': [('llet', False)],
          'llettens': [('llette', False)],
          'lletter': [('llet', False)],
          'lletterne': [('llet', False)],
          'lletternes': [('llet', False)],
          'lletters': [('llette', False)],
          'lleverne': [('llever', False)],
          'lliden': [('llid', False)],
          'llidsen': [('llids', False)],
          'llidsens': [('llids', False)],
          'llidser': [('llids', False)],
          'llidserne': [('llids', False)],
          'llidsernes': [('llids', False)],
          'llidsers': [('llids', False)],
          'llien': [('llie', False)],
          'lliene': [('lli', False)],
          'lliens': [('llie', False)],
          'llierne': [('lli', False)],
          'lliernes': [('llie', False)],
          'llies': [('llie', False)],
          'lliker': [('lliker', False)],
          'llikerne': [('lliker', False)],
          'llikernes': [('lliker', False)],
          'llikers': [('llike', False)],
          'llikker': [('llik', False)],
          'llikkernes': [('llik', False)],
          'llikkers': [('llik', False)],
          'llinen': [('llin', False)],
          'llinens': [('llin', False)],
          'lliner': [('llin', False)],
          'llinerne': [('llin', False)],
          'llinernes': [('llin', False)],
          'lliners': [('llin', False)],
          'llinets': [('llin', False)],
          'llingers': [('lling', False)],
          'llinien': [('llini', False)],
          'llipsen': [('llipse', False)],
          'llipsens': [('llipse', False)],
          'llis': [('llis', False)],
          'llismen': [('llisme', False)],
          'llisten': [('lliste', False)],
          'llistens': [('lliste', False)],
          'llister': [('llist', False)],
          'llisterne': [('lliste', False)],
          'llisternes': [('llist', False)],
          'llisters': [('llist', False)],
          'llits': [('llit', False)],
          'llitter': [('llit', False)],
          'llium': [('llium', False)],
          'lliums': [('llium', False)],
          'llongernes': [('llonge', False)],
          'llonierne': [('lloni', False)],
          'lloniernes': [('lloni', False)],
          'lloniers': [('lloni', False)],
          'llos': [('llos', False)],
          "llos'": [('llo', False)],
          'llosserne': [('llos', False)],
          'llotten': [('llot', False)],
          'llottens': [('llot', False)],
          'llotter': [('llot', False)],
          'llotterne': [('llot', False)],
          'llotternes': [('llot', False)],
          'llotters': [('llot', False)],
          'llove': [('llov', False)],
          'llovernes': [('llover', False)],
          'llovers': [('llover', False)],
          'lls': [('ll', False)],
          "lls'": [('ll', False)],
          'llsene': [('ll', False)],
          'llsenes': [('ll', False)],
          'llummer': [('llum', False)],
          'llummerne': [('llum', False)],
          'lluner': [('llun', False)],
          'llunerne': [('llun', False)],
          'llunernes': [('llun', False)],
          'lluners': [('llun', False)],
          'llunet': [('llun', False)],
          'llunets': [('llun', False)],
          'lluns': [('llun', False)],
          'llurens': [('llur', False)],
          'llusker': [('llusk', False)],
          'lluskerne': [('llusk', False)],
          'lluskernes': [('llusk', False)],
          'lluskers': [('llusk', False)],
          'llyde': [('llyd', False)],
          'llyden': [('llyd', False)],
          'llydens': [('llyd', False)],
          'llydes': [('llyd', False)],
          'llys': [('llys', False)],
          'llyster': [('llyst', False)],
          'llysters': [('llyst', False)],
          'llås': [('llås', False)],
          'llæber': [('llæbe', False)],
          'llæbernes': [('llæbe', False)],
          'llæder': [('llæder', False)],
          'llægerne': [('llæge', False)],
          'llægernes': [('llæge', False)],
          'llænder': [('llænder', False)],
          'llænderne': [('llænder', False)],
          'llændernes': [('llænder', False)],
          'llænders': [('llænder', False)],
          'llærer': [('llære', False)],
          'llærerne': [('llære', False)],
          'llærernes': [('llære', False)],
          'llærers': [('llærer', False)],
          'llører': [('llør', False)],
          'llørernes': [('llør', False)],
          'lm': [('lm', False)],
          'lmager': [('lmager', False)],
          'lmagerne': [('lmager', False)],
          'lmagernes': [('lmager', False)],
          'lmagers': [('lmager', False)],
          'lman': [('lman', False)],
          'lmanens': [('lman', False)],
          'lmaner': [('lman', False)],
          'lmaners': [('lman', False)],
          'lmans': [('lman', False)],
          'lmarcher': [('lmarch', False)],
          'lmarcherne': [('lmarch', False)],
          'lmarchers': [('lmarch', False)],
          'lmas': [('lma', False)],
          'lmassens': [('lmasse', False)],
          'lmaster': [('lmast', False)],
          'lmasterne': [('lmast', False)],
          'lmasternes': [('lmast', False)],
          'lmasters': [('lmast', False)],
          'lme': [('lm', False)],
          'lmebogen': [('lmebog', False)],
          'lmejer': [('lmeje', False)],
          'lmejerne': [('lmeje', False)],
          'lmejernes': [('lmeje', False)],
          'lmejers': [('lmeje', False)],
          'lmelet': [('lmel', False)],
          'lmen': [('lm', False)],
          'lmene': [('lm', False)],
          'lmenes': [('lm', False)],
          'lmens': [('lm', False)],
          'lmes': [('lm', False)],
          'lmet': [('lm', False)],
          'lmets': [('lm', False)],
          'lmidler': [('lmiddel', False)],
          'lmidlerne': [('lmiddel', False)],
          'lmidlernes': [('lmiddel', False)],
          'lmidlers': [('lmiddel', False)],
          'lminen': [('lmine', False)],
          'lminens': [('lmin', False)],
          'lminers': [('lmine', False)],
          'lministers': [('lminister', False)],
          'lmissen': [('lmisse', False)],
          'lmissens': [('lmisse', False)],
          'lmisser': [('lmisse', False)],
          'lmisserne': [('lmisse', False)],
          'lmissernes': [('lmisse', False)],
          'lmissers': [('lmisse', False)],
          'lmodet': [('lmod', False)],
          'lmodets': [('lmod', False)],
          'lmoralen': [('lmoral', False)],
          'lmoralens': [('lmoral', False)],
          'lmosen': [('lmos', False)],
          'lmosens': [('lmos', False)],
          'lms': [('lm', False)],
          'lmskaber': [('lmskaber', False)],
          'lmskabers': [('lmskaber', False)],
          'lmuen': [('lmue', False)],
          'lmuens': [('lmue', False)],
          'lmuer': [('lmue', False)],
          'lmuerne': [('lmue', False)],
          'lmuernes': [('lmue', False)],
          'lmuers': [('lmue', False)],
          'lmusen': [('lmus', False)],
          'lmusens': [('lmus', False)],
          'lmykkernes': [('lmyk', False)],
          'lmykkers': [('lmyk', False)],
          'lmælken': [('lmælk', False)],
          'lmælkens': [('lmælk', False)],
          'lmænd': [('lmand', False)],
          'lmærkerne': [('lmærke', False)],
          'lmærkernes': [('lmærke', False)],
          'lmærkers': [('lmærke', False)],
          'lner': [('lner', False)],
          'lnerne': [('lner', False)],
          'lnernes': [('lner', False)],
          'lningers': [('lning', False)],
          'lnoten': [('lnote', False)],
          'lnotens': [('lnote', False)],
          'lnoter': [('lnote', False)],
          'lnoterne': [('lnote', False)],
          'lnoternes': [('lnote', False)],
          'lnoters': [('lnote', False)],
          'lnummers': [('lnummer', False)],
          'lo': [('lo', False)],
          'lobe': [('lobe', False)],
          'loben': [('lobe', False)],
          'lobens': [('lobe', False)],
          'loberne': [('lobe', False)],
          'lobers': [('lobe', False)],
          'lobes': [('lobe', False)],
          'lobs': [('lob', True)],
          'locks': [('lock', False)],
          'lodde': [('lodde', True)],
          'lodden': [('lodde', True), ('lod', True)],
          'loddens': [('lodde', True), ('lod', True)],
          'lodder': [('lod', True), ('lodde', True)],
          'lodderne': [('lod', True), ('lodde', True)],
          'loddernes': [('lodde', True), ('lod', True)],
          'lodders': [('lodde', True), ('lod', True)],
          'loddes': [('lodde', True)],
          'loden': [('loden', True)],
          'lodens': [('loden', True)],
          'loder': [('lod', False)],
          'loderne': [('lod', False)],
          'lodernes': [('lod', False)],
          'loders': [('lod', False)],
          'lodi': [('lodi', False)],
          'lodier': [('lodi', False)],
          'lodierne': [('lodi', False)],
          'lodiers': [('lodi', False)],
          'lods': [('lods', True), ('lod', True)],
          'loen': [('lo', True)],
          'loens': [('lo', False)],
          'loer': [('lo', True)],
          'loerne': [('lo', False)],
          'loernes': [('lo', False)],
          'loers': [('lo', False)],
          'loet': [('lo', False)],
          'loets': [('lo', False)],
          'loffer': [('lof', False)],
          'loffers': [('lof', False)],
          'lofonierne': [('lofonium', False)],
          'lofoniernes': [('lofonium', False)],
          'lofoniers': [('lofonium', False)],
          'lofterne': [('loft', False)],
          'lofternes': [('loft', False)],
          'lofters': [('loft', False)],
          'loge': [('loge', False)],
          'logen': [('loge', False)],
          'logens': [('loge', False)],
          'loger': [('loge', True)],
          'logerne': [('loge', True)],
          'logernes': [('loge', False)],
          'logers': [('loge', False)],
          'loges': [('loge', False)],
          'loget': [('loget', False)],
          'logets': [('log', False)],
          'logge': [('log', True)],
          'loggen': [('log', True)],
          'loggens': [('log', True)],
          'logger': [('log', True), ('logger', True)],
          'loggerne': [('log', True), ('logger', True)],
          'loggernes': [('log', True), ('logger', True)],
          'loggers': [('log', True), ('logger', True)],
          'logges': [('log', True)],
          'logien': [('logi', False)],
          'logier': [('logi', False)],
          'logierne': [('logi', False)],
          'logiernes': [('logi', False)],
          'logiers': [('logi', True)],
          'loiden': [('loid', False)],
          'loidens': [('loid', False)],
          'loider': [('loid', False)],
          'loiderne': [('loid', False)],
          'loidernes': [('loid', False)],
          'loiders': [('loid', False)],
          'lokaler': [('lokale', True)],
          'lokalerne': [('lokale', False)],
          'lokalernes': [('lokale', False)],
          'lokalers': [('lokale', False)],
          'lokke': [('lok', False)],
          'lokken': [('lok', False)],
          'lokkens': [('lok', True)],
          'lokker': [('lokker', True), ('lok', True)],
          'lokkerne': [('lok', True), ('lokker', True)],
          'lokkernes': [('lokker', True), ('lok', True)],
          'lokkers': [('lok', True), ('lokker', True)],
          'lokkes': [('lok', False)],
          'loks': [('lok', True)],
          "loks'": [('loks', False)],
          'loksen': [('loks', False)],
          'loksens': [('loks', False)],
          'lokser': [('lokse', False)],
          'lolierne': [('lolie', False)],
          'loliers': [('lolie', False)],
          'lomaner': [('loman', False)],
          'lomanerne': [('loman', False)],
          'lomanernes': [('loman', False)],
          'lomaners': [('loman', False)],
          'lomber': [('lombe', False)],
          'lomberne': [('lombe', False)],
          'lombernes': [('lombe', False)],
          'lometerne': [('lometer', False)],
          'lometernes': [('lometer', False)],
          'lomme': [('lomme', True)],
          'lommen': [('lomme', True), ('lom', True)],
          'lommens': [('lomme', True), ('lom', True)],
          'lommer': [('lom', True), ('lomme', True)],
          'lommerne': [('lom', True), ('lomme', True)],
          'lommernes': [('lomme', True), ('lom', True)],
          'lommers': [('lom', True), ('lomme', True)],
          'lommes': [('lomme', True)],
          'longen': [('longe', True)],
          'longens': [('longe', True)],
          'longer': [('longe', False)],
          'longerne': [('longe', True)],
          'longernes': [('longe', True)],
          'longers': [('longe', True)],
          'lonien': [('loni', False)],
          'loniens': [('loni', False)],
          'lonier': [('loni', False)],
          'lonierne': [('lonier', False)],
          'loniernes': [('lonier', False)],
          'loniers': [('lonier', False)],
          'lonis': [('loni', False)],
          'looner': [('loon', False)],
          'loonerne': [('loon', False)],
          'loonernes': [('loon', False)],
          'looners': [('loon', False)],
          'lopen': [('lope', False)],
          'lopene': [('lope', False)],
          'lopenes': [('lope', False)],
          'lopens': [('lop', False)],
          'loper': [('lope', False)],
          'loperne': [('lope', False)],
          'lopernes': [('lope', False)],
          'lopers': [('loper', False)],
          'loppen': [('loppe', True)],
          'loppens': [('loppe', True)],
          'lopper': [('loppe', True)],
          'lopperne': [('loppe', False)],
          'loppernes': [('loppe', False)],
          'loppers': [('loppe', True)],
          'loppes': [('loppe', True)],
          'lora': [('lora', False)],
          'loras': [('lora', False)],
          'lorden': [('lord', True)],
          'lordens': [('lord', True)],
          'lorderne': [('lord', True)],
          'lordernes': [('lord', True)],
          'lorders': [('lord', True)],
          'lore': [('lore', False)],
          'loren': [('lore', False)],
          'lorens': [('lore', False)],
          'lorer': [('lore', False)],
          'lorerne': [('lore', False)],
          'lorernes': [('lore', False)],
          'lorers': [('lor', False)],
          'loriers': [('lorie', False)],
          'lorte': [('lort', True)],
          'lorten': [('lort', True)],
          'lortens': [('lort', False)],
          'lortes': [('lort', True)],
          'lortet': [('lort', True)],
          'lortets': [('lort', True)],
          'lorts': [('lort', True)],
          'los': [('los', True), ('lo', True)],
          "los'": [('los', True)],
          'losaks': [('losaks', False)],
          'losen': [('lose', False)],
          'losens': [('lose', False)],
          'loser': [('lose', False)],
          'loserne': [('lose', False)],
          'losernes': [('lose', False)],
          'losers': [('lose', False)],
          'losiver': [('losiv', False)],
          'losivers': [('losiv', False)],
          'lossen': [('los', True)],
          'lossens': [('los', True)],
          'losser': [('los', True)],
          'losserne': [('los', True)],
          'lossernes': [('los', True)],
          'lossers': [('los', True)],
          'loste': [('lost', False)],
          'losten': [('lost', False)],
          'lostens': [('lost', False)],
          'lostes': [('lost', False)],
          'lotinen': [('lotine', False)],
          'lotinens': [('lotine', False)],
          'lotiner': [('lotine', False)],
          'lotinerne': [('lotine', False)],
          'lotinernes': [('lotine', False)],
          'lotiners': [('lotine', False)],
          'lotte': [('lotte', True)],
          'lotten': [('lotte', True)],
          'lottens': [('lotte', True)],
          'lotter': [('lotte', False)],
          'lotterne': [('lotte', True)],
          'lotternes': [('lotte', True)],
          'lotters': [('lotte', True)],
          'lottes': [('lotte', True)],
          'love': [('love', True), ('lov', True)],
          'lover': [('lover', False)],
          'loverne': [('lover', False)],
          'lovsens': [('lovse', False)],
          'lovsers': [('lovse', False)],
          'lower': [('lower', False)],
          'lowerne': [('lower', False)],
          'lowernes': [('lower', False)],
          'lowers': [('lower', False)],
          "lp'ers": [('lp', True)],
          'lpalmens': [('lpalme', False)],
          'lparkernes': [('lpark', False)],
          'lparkers': [('lpark', False)],
          'lpasser': [('lpasser', False)],
          'lpasserne': [('lpasser', False)],
          'lpassernes': [('lpasser', False)],
          'lpassers': [('lpasser', False)],
          'lpels': [('lpel', False)],
          'lpen': [('lp', False)],
          'lpene': [('lp', False)],
          'lpenes': [('lp', False)],
          'lpens': [('lp', False)],
          'lper': [('lper', False)],
          'lpere': [('lper', False)],
          'lperens': [('lper', False)],
          'lperes': [('lper', False)],
          'lperne': [('lper', False)],
          'lpernes': [('lpe', False)],
          'lpers': [('lpe', False)],
          'lpet': [('lp', False)],
          'lpeter': [('lpeter', False)],
          'lpeters': [('lpeter', False)],
          'lpets': [('lp', False)],
          'lpiber': [('lpibe', False)],
          'lpiberne': [('lpibe', False)],
          'lpibernes': [('lpibe', False)],
          'lpibers': [('lpibe', False)],
          'lpils': [('lpil', False)],
          'lpressens': [('lpresse', False)],
          'lpresser': [('lpresse', False)],
          'lpresserne': [('lpresse', False)],
          'lpressernes': [('lpresse', False)],
          'lpressers': [('lpresse', False)],
          'lprisen': [('lpris', False)],
          'lprisens': [('lpris', False)],
          'lpriser': [('lpris', False)],
          'lpriserne': [('lpris', False)],
          'lprisernes': [('lpris', False)],
          'lprisers': [('lpris', False)],
          'lprocenter': [('lprocent', False)],
          'lprocenters': [('lprocent', False)],
          'lps': [('lp', False)],
          'lpumpen': [('lpumpe', False)],
          'lpumpens': [('lpumpe', False)],
          'lpumperne': [('lpumpe', False)],
          'lramme': [('lramme', False)],
          'lrammen': [('lramme', False)],
          'lrammens': [('lramme', False)],
          'lrammernes': [('lramme', False)],
          'lrammes': [('lramme', False)],
          'lrendens': [('lrende', False)],
          'lrenterne': [('lrente', False)],
          'lrenternes': [('lrente', False)],
          'lrentes': [('lrente', False)],
          'lret': [('lret', False)],
          'lrets': [('lret', False)],
          'lretter': [('lret', False)],
          'lroden': [('lrod', False)],
          'lrodens': [('lrod', False)],
          'lrods': [('lrod', False)],
          'lroen': [('lroe', False)],
          'lroens': [('lroe', False)],
          'lroer': [('lroe', False)],
          'lroerne': [('lroe', False)],
          'lroernes': [('lroe', False)],
          'lroers': [('lroe', False)],
          'lroller': [('lrolle', False)],
          'lrollerne': [('lrolle', False)],
          'lros': [('lros', False)],
          'lrossernes': [('lros', False)],
          'lrossers': [('lros', False)],
          'lrottens': [('lrotte', False)],
          'lrotter': [('lrotte', False)],
          'lrotternes': [('lrotte', False)],
          'lrotters': [('lrotte', False)],
          'lrummet': [('lrum', False)],
          'lrummets': [('lrum', False)],
          'lrøret': [('lrør', False)],
          'lrørets': [('lrør', False)],
          "ls'": [('ls', False)],
          'lsagen': [('lsag', False)],
          'lsagernes': [('lsag', False)],
          'lsagers': [('lsag', False)],
          'lse': [('ls', False)],
          'lsen': [('ls', False)],
          'lsene': [('ls', False)],
          'lsenen': [('lsen', False)],
          'lsenens': [('lsen', False)],
          'lsener': [('lsen', False)],
          'lsenerne': [('lsen', False)],
          'lsenernes': [('lsen', False)],
          'lseners': [('lsen', False)],
          'lsenes': [('ls', False)],
          'lsens': [('ls', False)],
          'lser': [('ls', False)],
          'lsere': [('lser', False)],
          'lseren': [('lser', False)],
          'lserens': [('lser', False)],
          'lseres': [('lser', False)],
          'lserne': [('ls', False)],
          'lsers': [('lse', False)],
          'lses': [('ls', False)],
          'lset': [('lse', False)],
          'lsets': [('lse', False)],
          'lsetter': [('lset', False)],
          'lsetterne': [('lset', False)],
          'lsetternes': [('lset', False)],
          'lsetters': [('lset', False)],
          'lsikken': [('lsikke', False)],
          'lsikkerne': [('lsikke', False)],
          'lsinen': [('lsin', False)],
          'lsinens': [('lsin', False)],
          'lsinernes': [('lsin', False)],
          'lsjerne': [('lsje', False)],
          'lsjernes': [('lsje', False)],
          'lsjers': [('lsje', False)],
          'lskaber': [('lskab', False)],
          'lskaberne': [('lskab', False)],
          'lskabernes': [('lskab', False)],
          'lskabers': [('lskab', False)],
          'lskernes': [('lsker', False)],
          'lskers': [('lsker', False)],
          'lskifternes': [('lskift', False)],
          'lskiftes': [('lskift', False)],
          'lskiftet': [('lskift', False)],
          'lsknerne': [('lskner', False)],
          'lskos': [('lsko', False)],
          'lskuer': [('lskuer', False)],
          'lskuerne': [('lskuer', False)],
          'lskuernes': [('lskuer', False)],
          'lskuers': [('lskuer', False)],
          'lslags': [('lslag', False)],
          'lsnarre': [('lsnar', False)],
          'lsnarren': [('lsnar', False)],
          'lsnarres': [('lsnar', False)],
          'lsorternes': [('lsort', False)],
          'lstabe': [('lstab', False)],
          'lstabens': [('lstab', False)],
          'lstabler': [('lstabler', False)],
          'lstablerne': [('lstabler', False)],
          'lstablernes': [('lstabler', False)],
          'lstablers': [('lstabler', False)],
          'lstemmer': [('lstemme', False)],
          'lstemmerne': [('lstemme', False)],
          'lstemmernes': [('lstemme', False)],
          'lstemmers': [('lstemme', False)],
          'lsten': [('lsten', False)],
          'lstenes': [('lsten', False)],
          'lstens': [('lsten', False)],
          'lster': [('lster', False)],
          'lsters': [('lster', False)],
          'lstiens': [('lsti', False)],
          'lstierne': [('lsti', False)],
          'lstiers': [('lsti', False)],
          'lstikken': [('lstik', False)],
          'lstikker': [('lstik', False)],
          'lstikkerne': [('lstik', False)],
          'lstikkernes': [('lstik', False)],
          'lstikkers': [('lstik', False)],
          'lstis': [('lsti', False)],
          'lstre': [('lster', False)],
          'lstringens': [('lstring', False)],
          'lstrækker': [('lstrækker', False)],
          'lstrækkerne': [('lstrækker', False)],
          'lstrækkernes': [('lstrækker', False)],
          'lstrækkers': [('lstrækker', False)],
          'lstykkernes': [('lstykke', False)],
          'lstykkers': [('lstykke', False)],
          'lstyrer': [('lstyre', False)],
          'lstyrerne': [('lstyre', False)],
          'lstyrernes': [('lstyre', False)],
          'lstyrers': [('lstyrer', False)],
          'lstyret': [('lstyr', False)],
          'lstyrets': [('lstyre', False)],
          'lstænger': [('lstang', False)],
          'lstængerne': [('lstang', False)],
          'lstængernes': [('lstang', False)],
          'lstængers': [('lstang', False)],
          'lsummer': [('lsum', False)],
          'lsummerne': [('lsum', False)],
          'lsummernes': [('lsum', False)],
          'lsummers': [('lsum', False)],
          'lsure': [('lsur', False)],
          'lsures': [('lsur', False)],
          'lsvier': [('lsvier', False)],
          'lsvierne': [('lsvier', False)],
          'lsviernes': [('lsvier', False)],
          'lsviers': [('lsvier', False)],
          'lsvøben': [('lsvøb', False)],
          'lsvøbens': [('lsvøb', False)],
          'lsyren': [('lsyre', False)],
          'lsyrens': [('lsyre', False)],
          'lsyrer': [('lsyre', False)],
          'lsyrerne': [('lsyre', False)],
          'lsyrernes': [('lsyre', False)],
          'lsyrers': [('lsyre', False)],
          'lsøer': [('lso', False)],
          'lsøerne': [('lso', False)],
          'lsøernes': [('lso', False)],
          'lsøers': [('lso', False)],
          'lsørerne': [('lsøre', False)],
          'lsørers': [('lsøre', False)],
          'lsøret': [('lsøre', False)],
          'lsørets': [('lsøre', False)],
          'ltage': [('ltag', False)],
          'ltagere': [('ltager', False)],
          'ltageren': [('ltager', False)],
          'ltagerens': [('ltager', False)],
          'ltageres': [('ltager', False)],
          'ltages': [('ltag', False)],
          'ltalens': [('ltale', False)],
          'ltaler': [('ltale', False)],
          'ltalerne': [('ltale', False)],
          'ltalernes': [('ltale', False)],
          'ltalers': [('ltale', False)],
          'ltampere': [('ltampere', False)],
          'ltamperes': [('ltampere', False)],
          'ltan': [('ltan', False)],
          'ltanen': [('ltan', False)],
          'ltaner': [('ltan', False)],
          'ltaners': [('ltan', False)],
          'ltangen': [('ltang', False)],
          'ltangens': [('ltang', False)],
          'ltans': [('ltan', False)],
          'ltanten': [('ltant', False)],
          'ltantens': [('ltant', False)],
          'ltanter': [('ltant', False)],
          'ltanterne': [('ltant', False)],
          'ltanternes': [('ltant', False)],
          'ltanters': [('ltant', False)],
          'ltapper': [('ltapper', False)],
          'ltapperne': [('ltapper', False)],
          'ltappernes': [('ltapper', False)],
          'ltappers': [('ltapper', False)],
          'ltarbejdernes': [('ltarbejde', False)],
          'ltarbejders': [('ltarbejde', False)],
          'ltas': [('lta', False)],
          'ltater': [('ltat', False)],
          'ltaterne': [('ltat', False)],
          'ltaternes': [('ltat', False)],
          'ltaters': [('ltat', False)],
          'ltats': [('ltat', False)],
          'lte': [('lt', False)],
          'lteater': [('lteater', False)],
          'ltekster': [('ltekst', False)],
          'lteksterne': [('ltekst', False)],
          'lteksternes': [('ltekst', False)],
          'lteksters': [('ltekst', False)],
          'lteløberne': [('lteløber', False)],
          'lteløbers': [('lteløber', False)],
          'lten': [('lt', False)],
          'ltenes': [('lt', False)],
          'ltens': [('lt', False)],
          'lteret': [('lter', False)],
          'lterets': [('lter', False)],
          'ltes': [('lt', False)],
          'lteser': [('lteser', False)],
          'lteserne': [('lteser', False)],
          'ltesernes': [('lteser', False)],
          'ltesers': [('lteser', False)],
          'ltet': [('lt', False)],
          'lteterne': [('ltet', False)],
          'lteternes': [('ltet', False)],
          'ltets': [('lt', False)],
          'lthuset': [('lthus', False)],
          'ltider': [('ltid', False)],
          'ltiderne': [('ltid', False)],
          'ltidernes': [('ltid', False)],
          'ltiders': [('ltid', False)],
          'ltids': [('ltid', False)],
          'ltiger': [('ltige', False)],
          'ltigerne': [('ltige', False)],
          'ltigernes': [('ltige', False)],
          'ltigers': [('ltige', False)],
          'ltikkens': [('ltik', False)],
          'ltningen': [('ltning', False)],
          'ltninger': [('ltning', False)],
          'ltningerne': [('ltning', False)],
          'ltningernes': [('ltning', False)],
          'ltoer': [('lto', False)],
          'ltoerne': [('lto', False)],
          'ltoernes': [('lto', False)],
          'ltoers': [('lto', False)],
          'ltofter': [('ltofter', False)],
          'ltofterne': [('ltofter', False)],
          'ltofternes': [('ltofter', False)],
          'ltofters': [('ltofter', False)],
          'ltoget': [('ltog', False)],
          'ltoner': [('ltone', False)],
          'ltonerne': [('ltone', False)],
          'ltonernes': [('ltone', False)],
          'ltoners': [('ltone', False)],
          'ltrappernes': [('ltrappe', False)],
          'ltrene': [('lter', False)],
          'ltrenes': [('lter', False)],
          'ltres': [('lter', False)],
          'ltringens': [('ltring', False)],
          'ltros': [('ltro', False)],
          'lts': [('lt', False)],
          "lts'": [('lt', False)],
          'lture': [('ltur', False)],
          'lturen': [('ltur', False)],
          'lturens': [('ltur', False)],
          'lturer': [('ltur', False)],
          'lturerne': [('ltur', False)],
          'lturernes': [('ltur', False)],
          'lturers': [('ltur', False)],
          'ltures': [('ltur', False)],
          'ltus': [('ltus', False)],
          'ltængernes': [('ltang', False)],
          'ltængers': [('ltang', False)],
          'ltørken': [('ltørken', False)],
          'ltørkens': [('ltørken', False)],
          'lubben': [('lubbe', True)],
          'lubbens': [('lubbe', True)],
          'lubber': [('lubbe', True)],
          'lubberne': [('lubbe', True)],
          'lubbernes': [('lubbe', True)],
          'lubbers': [('lubbe', True)],
          'lucerne': [('lucerne', True)],
          'lucernes': [('lucerne', True)],
          'luder': [('luder', False)],
          'luderne': [('luder', False)],
          'ludernes': [('luder', False)],
          'luders': [('luder', True)],
          'ludier': [('ludium', False)],
          'ludiernes': [('ludium', False)],
          'ludiers': [('ludium', False)],
          'ludiet': [('ludium', False)],
          'ludiets': [('ludium', False)],
          'luen': [('lue', True)],
          'luens': [('lue', True)],
          'luenserne': [('luens', False)],
          'luer': [('lue', True)],
          'luerne': [('lue', True)],
          'luernes': [('lue', True)],
          'luers': [('lue', True)],
          'lues': [('lue', True)],
          "lues'": [('lues', False)],
          'luffen': [('luffe', True)],
          'luffens': [('luffe', True)],
          'luffer': [('luffe', True)],
          'lufferne': [('luffe', True)],
          'luffernes': [('luffe', True)],
          'luffers': [('luffe', True)],
          'luge': [('luge', True)],
          'luger': [('luge', True)],
          'lugerne': [('luge', True)],
          'lugernes': [('luge', True)],
          'lugers': [('luge', True)],
          'luggen': [('lug', False)],
          'luggens': [('lug', False)],
          'lugger': [('lugger', True)],
          'luggerne': [('lugger', True)],
          'luggernes': [('lugger', True)],
          'luggers': [('lugger', True)],
          'lugter': [('lugt', False)],
          'lugterne': [('lugt', False)],
          'lugternes': [('lugt', False)],
          'luiden': [('luid', False)],
          'luidens': [('luid', False)],
          'luider': [('luid', False)],
          'luiderne': [('luid', False)],
          'luidernes': [('luid', False)],
          'luiders': [('luid', False)],
          'lukken': [('luk', False)],
          'lukker': [('lukke', True), ('lukker', True)],
          'lukkerne': [('lukker', True), ('lukke', True)],
          'lukkernes': [('lukker', True), ('lukke', True)],
          'lukkers': [('lukke', True), ('lukker', True)],
          'lukket': [('lukke', True)],
          'lukkets': [('lukke', True)],
          'luks': [('luks', False)],
          'lulden': [('luld', False)],
          'lulosen': [('lulose', False)],
          'lulosens': [('lulose', False)],
          'lum': [('lum', False)],
          'luminet': [('lumen', False)],
          'luminets': [('lumen', False)],
          'lummen': [('lum', False)],
          'lummens': [('lum', False)],
          'lummer': [('lummer', False)],
          'lummerne': [('lumme', False)],
          'lummernes': [('lum', False)],
          'lummers': [('lum', False)],
          'lumpen': [('lump', False)],
          'lumpens': [('lump', False)],
          'lumper': [('lump', False)],
          'lumperne': [('lump', False)],
          'lumpernes': [('lump', False)],
          'lumpers': [('lump', False)],
          'lums': [('lum', False)],
          'lunde': [('lund', True), ('lunde', True)],
          'lunden': [('lund', True), ('lunde', True)],
          'lundens': [('lund', True), ('lunde', True)],
          'lunder': [('lunde', True)],
          'lunderne': [('lunde', True)],
          'lundernes': [('lunde', True)],
          'lunders': [('lunde', True)],
          'lundes': [('lund', True), ('lunde', True)],
          'luner': [('lune', True)],
          'lunerne': [('lune', True)],
          'lunernes': [('lune', True)],
          'luners': [('lune', True)],
          'lunet': [('lune', False)],
          'lunets': [('lune', True)],
          'lungers': [('lunge', False)],
          'lunken': [('lunke', True)],
          'lunkens': [('lunke', False)],
          'lunker': [('lunke', True)],
          'lunkerne': [('lunke', True)],
          'lunkernes': [('lunke', False)],
          'lunkers': [('lunke', False)],
          'luns': [('luns', True)],
          "luns'": [('luns', True)],
          'lunser': [('luns', True)],
          'lunserne': [('luns', True)],
          'lunsernes': [('luns', True)],
          'lunsers': [('luns', True)],
          'lunter': [('lunte', True)],
          'lunternes': [('lunte', True)],
          'lupinerne': [('lupin', True)],
          'lupiners': [('lupin', True)],
          'luppen': [('lup', True)],
          'luppens': [('lup', True)],
          'lupperne': [('lup', False)],
          'luppers': [('lup', False)],
          'lure': [('lur', True)],
          'luren': [('lur', True)],
          'lurens': [('lur', True)],
          'lurer': [('lur', True), ('lurer', True)],
          'lurerne': [('lur', True), ('lurer', True)],
          'lurernes': [('lurer', True), ('lur', True)],
          'lurers': [('lurer', True), ('lur', True)],
          'lures': [('lur', True)],
          'luret': [('lur', False)],
          'lurets': [('lur', False)],
          'lurger': [('lurg', False)],
          'lurgernes': [('lurg', False)],
          'lurgers': [('lurg', False)],
          'lurs': [('lur', False)],
          'lurter': [('lurt', False)],
          'lurterne': [('lurt', False)],
          'lus': [('lus', True)],
          'luse': [('luse', False)],
          'lusen': [('lus', True)],
          'lusens': [('lus', True)],
          'luser': [('luse', False)],
          'luserne': [('luse', False)],
          'lusernes': [('luse', False)],
          'lusers': [('luse', False)],
          'luses': [('luse', False)],
          'lusier': [('lusier', False)],
          'lusken': [('lusk', False)],
          'lusker': [('lusker', True)],
          'luskerne': [('lusker', True)],
          'luskernes': [('lusker', True)],
          'luskers': [('lusker', True)],
          'luslen': [('lusel', False)],
          'lussen': [('lussen', False)],
          'lussens': [('lussen', False)],
          'lusser': [('lus', False)],
          'lusserne': [('lus', False)],
          'lusters': [('luster', False)],
          'luten': [('luten', False)],
          'lutene': [('lute', False)],
          'lutenes': [('lute', False)],
          'lutens': [('luten', False)],
          'luter': [('lut', False)],
          'lutet': [('lute', False)],
          'lutets': [('lute', False)],
          'lutiernes': [('luti', False)],
          'lutiers': [('luti', False)],
          'lutten': [('lut', False)],
          'luttens': [('lut', False)],
          'lutter': [('lut', True)],
          'lutterne': [('lut', True)],
          'lutternes': [('lut', False)],
          'lutters': [('lut', False)],
          'luven': [('luv', True)],
          'luvens': [('luv', True)],
          'lvaber': [('lvabe', False)],
          'lvabernes': [('lvabe', False)],
          'lvabers': [('lvabe', False)],
          'lvanders': [('lvand', False)],
          'lvarers': [('lvare', False)],
          'lve': [('lv', False)],
          'lveder': [('lvede', False)],
          'lvederne': [('lvede', False)],
          'lvedernes': [('lvede', False)],
          'lvedet': [('lvede', False)],
          'lvedets': [('lvede', False)],
          'lveje': [('lveje', False)],
          'lvejen': [('lvej', False)],
          'lvejens': [('lvej', False)],
          'lvejes': [('lveje', False)],
          'lven': [('lv', False)],
          'lvene': [('lv', False)],
          'lvenes': [('lv', False)],
          'lvens': [('lv', False)],
          'lver': [('lver', False)],
          'lverens': [('lver', False)],
          'lveret': [('lver', False)],
          'lverets': [('lver', False)],
          'lverne': [('lver', False)],
          'lvernes': [('lver', False)],
          'lvers': [('lver', False)],
          'lves': [('lv', False)],
          'lvet': [('lv', False)],
          'lvets': [('lv', False)],
          'lvien': [('lvie', False)],
          'lviens': [('lvie', False)],
          'lvier': [('lvie', False)],
          'lvierne': [('lvie', False)],
          'lviernes': [('lvie', False)],
          'lviers': [('lvie', False)],
          'lvinde': [('lvind', False)],
          'lvinden': [('lvinde', False)],
          'lvindens': [('lvinde', False)],
          'lvinder': [('lvinder', False)],
          'lvinderne': [('lvinder', False)],
          'lvindernes': [('lvinder', False)],
          'lvinders': [('lvinder', False)],
          'lvindes': [('lvinde', False)],
          'lvinen': [('lvin', False)],
          'lvinens': [('lvin', False)],
          'lvines': [('lvin', False)],
          'lvingen': [('lving', False)],
          'lvingens': [('lving', False)],
          'lvinger': [('lving', False)],
          'lvingerne': [('lving', False)],
          'lvingernes': [('lving', False)],
          'lvingers': [('lving', False)],
          'lvins': [('lvin', False)],
          'lvinter': [('lvinter', False)],
          'lvs': [('lv', False)],
          'lvstarter': [('lvstarter', False)],
          'lvvejen': [('lvvejen', False)],
          'lyde': [('lyde', True), ('lyd', True)],
          'lyden': [('lyd', True), ('lyde', True)],
          'lydens': [('lyd', True), ('lyde', True)],
          'lyder': [('lyde', True)],
          'lyderne': [('lyde', True)],
          'lydernes': [('lyde', False)],
          'lyders': [('lyde', False)],
          'lydes': [('lyd', True), ('lyde', True)],
          'lyen': [('ly', False)],
          'lyens': [('ly', False)],
          'lyer': [('ly', False)],
          'lyere': [('lyer', False)],
          'lyeren': [('lyer', False)],
          'lyerens': [('lyer', False)],
          'lyeres': [('lyer', False)],
          'lyerne': [('ly', False)],
          'lyernes': [('ly', False)],
          'lyers': [('ly', False)],
          'lykkens': [('lykke', False)],
          'lykkernes': [('lykke', False)],
          'lykkers': [('lykke', False)],
          'lynder': [('lynder', False)],
          'lynderne': [('lynder', False)],
          'lyndernes': [('lynder', False)],
          'lynders': [('lynder', False)],
          'lyngen': [('lyng', False)],
          'lyngens': [('lyng', False)],
          'lyngernes': [('lynge', False)],
          'lyngers': [('lynge', False)],
          'lyre': [('lyre', True)],
          'lyren': [('lyre', True)],
          'lyrens': [('lyre', True)],
          'lyrer': [('lyre', True)],
          'lyrerne': [('lyre', True)],
          'lyrernes': [('lyre', True)],
          'lyrers': [('lyre', True)],
          'lys': [('ly', True), ('lys', True)],
          'lysen': [('lyse', False)],
          'lysens': [('lyse', False)],
          'lyser': [('lyse', False)],
          'lyserne': [('lyse', False)],
          'lysernes': [('lyse', False)],
          'lyskernes': [('lyske', True)],
          'lysser': [('lys', False)],
          'lysserne': [('lys', False)],
          'lysten': [('lyst', False)],
          'lystens': [('lyst', False)],
          'lyster': [('lyster', True), ('lyst', True)],
          'lysterne': [('lyst', True)],
          'lysternes': [('lyst', False)],
          'lysters': [('lyster', True), ('lyst', True)],
          'lytten': [('lyt', False)],
          'lyttens': [('lyt', False)],
          'lytter': [('lytter', False)],
          'lytterne': [('lytter', False)],
          'lytternes': [('lytter', True)],
          'lytters': [('lytter', False)],
          'lyvetiden': [('lyvetid', False)],
          'lyveørerne': [('lyveører', False)],
          'låbnerne': [('låbner', False)],
          'låde': [('låde', False)],
          'låden': [('låde', False)],
          'lådens': [('låde', False)],
          'låders': [('låde', False)],
          'lådes': [('låde', False)],
          'låge': [('låge', True)],
          'lågen': [('låge', False)],
          'låger': [('låge', True)],
          'lågers': [('låge', False)],
          'lånernes': [('låner', True)],
          'låners': [('låner', True)],
          'lås': [('lås', True)],
          'læbens': [('læbe', True)],
          'læber': [('læbe', True)],
          'læberne': [('læbe', False)],
          'læbernes': [('læbe', True)],
          'læbers': [('læbe', False)],
          'læbler': [('læble', False)],
          'læden': [('læde', False)],
          'lædens': [('læde', False)],
          'læder': [('læder', True)],
          'læderne': [('læder', False)],
          'lædernes': [('læder', False)],
          'læders': [('læder', True)],
          'læers': [('læer', False)],
          'læet': [('læ', False)],
          'læets': [('læ', False)],
          'læge': [('læge', False)],
          'lægen': [('læge', False)],
          'lægens': [('læge', True)],
          'læger': [('læge', False)],
          'lægerne': [('læge', True)],
          'lægernes': [('læge', True)],
          'lægers': [('læge', True)],
          'lægger': [('lægger', False)],
          'lægges': [('læg', True)],
          'lægten': [('lægte', True)],
          'lægtens': [('lægte', True)],
          'lægter': [('lægte', True), ('lægter', True)],
          'lægterne': [('lægter', True), ('lægte', True)],
          'lægternes': [('lægte', True), ('lægter', True)],
          'lægters': [('lægter', True), ('lægte', True)],
          'lækken': [('læk', True)],
          'lækkens': [('læk', True)],
          'lækker': [('læk', True)],
          'lækkerne': [('læk', True)],
          'lækkernes': [('læk', True)],
          'lækkers': [('læk', True)],
          'lænd': [('lænd', True)],
          'lænden': [('lænd', True)],
          'lændens': [('lænd', True)],
          'lænder': [('lænd', True)],
          'lændere': [('lænder', False)],
          'lænderen': [('lænder', False)],
          'lænderens': [('lænder', False)],
          'lænderes': [('lænder', False)],
          'lænderne': [('lænd', True)],
          'lændernes': [('lænd', True)],
          'lænders': [('lænd', True)],
          'lænds': [('lænd', True)],
          'lænen': [('læne', False)],
          'lænens': [('læne', False)],
          'læner': [('læne', False)],
          'lænerne': [('læne', False)],
          'lænernes': [('læne', False)],
          'læners': [('læn', False)],
          'længer': [('længe', True)],
          'længerne': [('længe', True)],
          'længernes': [('længe', False)],
          'længers': [('længe', False)],
          'længet': [('læng', False)],
          'længets': [('læng', False)],
          'lænkens': [('lænke', False)],
          'lænkerne': [('lænke', True)],
          'lænkernes': [('lænke', True)],
          'lænkers': [('lænke', True)],
          'lænser': [('lænser', False)],
          'lænserne': [('lænser', False)],
          'lænsernes': [('lænser', False)],
          'lænsers': [('lænser', False)],
          'lære': [('lære', False)],
          'læren': [('lære', False)],
          'lærens': [('lære', False)],
          'lærer': [('lærer', True), ('lære', True)],
          'lærerne': [('lære', True), ('lærer', True)],
          'lærernes': [('lære', True), ('lærer', True)],
          'lærers': [('lære', True), ('lærer', True)],
          'læret': [('lære', False)],
          'lærets': [('lære', False)],
          'lærke': [('lærk', True), ('lærke', True)],
          'lærken': [('lærk', True), ('lærke', True)],
          'lærkens': [('lærk', True), ('lærke', True)],
          'lærker': [('lærke', True)],
          'lærkes': [('lærk', True), ('lærke', True)],
          'læs': [('læs', True), ('læ', True)],
          'læsen': [('læse', False)],
          'læsens': [('læse', False)],
          'læser': [('læser', True)],
          'læserne': [('læser', True)],
          'læsernes': [('læser', True)],
          'læsers': [('læser', False)],
          'læses': [('læse', False)],
          'læssene': [('læs', False)],
          'læssenes': [('læs', False)],
          'læssernes': [('læsser', False)],
          'læssers': [('læsser', False)],
          'læste': [('læst', True)],
          'læstens': [('læst', True)],
          'læster': [('læst', True)],
          'læsterne': [('læst', True)],
          'læsternes': [('læst', True)],
          'læsters': [('læst', True)],
          'læstes': [('læst', False)],
          'lætten': [('læt', False)],
          'lættens': [('læt', False)],
          'løben': [('løbe', True)],
          'løbens': [('løbe', True)],
          'løber': [('løber', False)],
          'løberne': [('løber', True)],
          'løbernes': [('løber', False)],
          'løbers': [('løber', True)],
          'løden': [('lød', True)],
          'lødens': [('lød', True)],
          'løder': [('lød', False)],
          'løderne': [('lød', False)],
          'lødernes': [('lød', False)],
          'løders': [('lød', False)],
          'løen': [('løe', False)],
          'løens': [('løe', False)],
          'løerne': [('lø', False)],
          'løernes': [('lo', False)],
          'løers': [('lo', False)],
          'løfter': [('løfte', False)],
          'løfterne': [('løfte', True)],
          'løfternes': [('løfte', True)],
          'løfters': [('løfte', True)],
          'løftet': [('løft', True), ('løfte', True)],
          'løftets': [('løft', True), ('løfte', True)],
          'løjden': [('løjd', False)],
          'løjdens': [('løjd', False)],
          'løje': [('løje', True)],
          'løjen': [('løje', True)],
          'løjens': [('løje', True)],
          'løjer': [('løje', True), ('løjer', True)],
          'løjerne': [('løje', True), ('løjer', True)],
          'løjernes': [('løjer', True), ('løje', True)],
          'løjers': [('løjer', True), ('løje', True)],
          'løjes': [('løje', False)],
          'løjet': [('løj', False)],
          'løjets': [('løj', False)],
          'løjlen': [('løjl', False)],
          'løjlens': [('løjl', False)],
          'løjler': [('løjl', False)],
          'løjlers': [('løjl', False)],
          'løjter': [('løjte', False)],
          'løjterne': [('løjte', False)],
          'løjternes': [('løjte', False)],
          'løkke': [('løkke', True)],
          'løkken': [('løkke', True)],
          'løkkens': [('løkke', True)],
          'løkker': [('løkke', True)],
          'løkkerne': [('løkke', True)],
          'løkkernes': [('løkke', True)],
          'løkkers': [('løkke', True)],
          'løkkes': [('løkke', True)],
          'lønne': [('løn', True)],
          'lønnen': [('løn', False)],
          'lønnens': [('løn', False)],
          'lønner': [('lønner', False)],
          'lønnerne': [('lønner', False)],
          'lønnernes': [('lønner', False)],
          'lønners': [('lønner', False)],
          'lønnes': [('løn', True)],
          'løren': [('lør', False)],
          'lørene': [('lør', False)],
          'lørenes': [('lør', False)],
          'lørens': [('lør', False)],
          'lørerne': [('lør', False)],
          'lørers': [('lør', False)],
          'løres': [('løre', False)],
          'løret': [('lør', False)],
          'lørets': [('løre', False)],
          'lørner': [('lørner', True)],
          'lørnernes': [('lørner', True)],
          'løs': [('lø', False)],
          'løsen': [('løsen', True)],
          'løsens': [('løsen', True)],
          'løsernes': [('løser', False)],
          'løssen': [('løss', True)],
          'løssens': [('løss', True)],
          'løve': [('løve', True)],
          'løven': [('løve', True)],
          'løvens': [('løve', False)],
          'løver': [('løve', False)],
          'løverne': [('løve', False)],
          'løvernes': [('løve', False)],
          'løvers': [('løve', False)],
          'løves': [('løve', False)],
          'm': [('m', True)],
          "m'erne": [('m', True)],
          'm-udgiften': [('adratmeter-udgift', False)],
          'm.': [('adratmeter', False)],
          'ma': [('ma', False)],
          'macets': [('macet', False)],
          'machen': [('machen', False)],
          'machens': [('machen', False)],
          'macien': [('maci', False)],
          'maciens': [('maci', False)],
          'macis': [('maci', False)],
          'madden': [('mad', True)],
          'maddens': [('mad', True)],
          'madder': [('mad', False)],
          'madderne': [('mad', False)],
          'maddernes': [('mad', False)],
          'madders': [('mad', True)],
          'made': [('made', False)],
          'maden': [('mad', True)],
          'madens': [('mad', True)],
          'maderne': [('made', False)],
          'maders': [('made', False)],
          'mades': [('made', False)],
          'mads': [('mad', True)],
          'maen': [('ma', False)],
          'maene': [('ma', False)],
          'maenes': [('ma', False)],
          'maens': [('ma', False)],
          'maer': [('ma', False)],
          'maerne': [('ma', False)],
          'maernes': [('ma', False)],
          'maers': [('ma', False)],
          'mage': [('mage', True)],
          'magen': [('mage', False)],
          'magens': [('mage', True)],
          'mager': [('mage', True), ('mager', True)],
          'magerne': [('mage', True), ('mager', True)],
          'magernes': [('mage', True), ('mager', True)],
          'magers': [('mage', True), ('mager', True)],
          'mages': [('mage', False)],
          'maget': [('mage', False)],
          'magets': [('mage', False)],
          'magister': [('magister', True)],
          'magnet': [('magnet', False)],
          'magnets': [('magnet', False)],
          'magnummer': [('magnum', True)],
          'magter': [('magt', False)],
          'magterne': [('magt', False)],
          'magternes': [('magt', False)],
          'majs': [('maj', True), ('majs', True)],
          'maka': [('makum', False)],
          'makas': [('makum', False)],
          'maken': [('make', False)],
          'makene': [('make', False)],
          'makenes': [('make', False)],
          'makens': [('make', False)],
          'makes': [('make', False)],
          "makes'": [('make', False)],
          'maket': [('make', False)],
          'makets': [('make', False)],
          'makken': [('mak', False)],
          'makkens': [('makke', False)],
          'makker': [('makker', False)],
          'makkerne': [('makker', True)],
          'makkernes': [('makker', True)],
          'makkers': [('makker', True)],
          'makon': [('makum', False)],
          'makons': [('makum', False)],
          'makroer': [('makro', True)],
          'makroerne': [('makro', True)],
          'makroernes': [('makro', True)],
          'maks': [('mak', False)],
          "maks'": [('maks', False)],
          'maksen': [('maks', False)],
          'maksens': [('maks', False)],
          'makser': [('maks', False)],
          'makserne': [('maks', False)],
          'maksernes': [('maks', False)],
          'maksers': [('maks', False)],
          'makterne': [('makt', False)],
          'makternes': [('makt', False)],
          'makters': [('makt', False)],
          'malaners': [('malaner', False)],
          'malders': [('malder', False)],
          'malen': [('mal', False)],
          'malens': [('mal', False)],
          'maler': [('maler', False)],
          'malerne': [('maler', False)],
          'malernes': [('maler', False)],
          'malers': [('maler', False)],
          'malias': [('malia', False)],
          'malien': [('mali', False)],
          'maliens': [('mali', False)],
          'malier': [('malier', True)],
          'malierne': [('malier', True)],
          'maliernes': [('malier', False)],
          'maliers': [('malier', True)],
          'malis': [('mali', False)],
          'malker': [('malker', True)],
          'malkerne': [('malker', True)],
          'malkernes': [('malker', True)],
          'malkers': [('malker', True)],
          'mallens': [('malle', True)],
          'mallerne': [('malle', True)],
          'mallernes': [('malle', True)],
          'mallers': [('malle', True)],
          'malme': [('malm', False)],
          'malmen': [('malm', False)],
          'malmens': [('malm', False)],
          'malmes': [('malm', False)],
          'malten': [('malt', True)],
          'maltens': [('malt', True)],
          'malter': [('malte', False)],
          'malterne': [('malte', False)],
          'malternes': [('malte', False)],
          'malters': [('malte', False)],
          'mamen': [('mam', False)],
          'mamens': [('mam', False)],
          'mamenter': [('mament', False)],
          'mamenterne': [('mament', False)],
          'mamentet': [('mament', False)],
          'mamentets': [('mament', False)],
          'mamers': [('mam', False)],
          'mammen': [('mam', False)],
          'mammens': [('mam', False)],
          'mammer': [('mam', False)],
          'mammerne': [('mam', False)],
          'mammernes': [('mam', False)],
          'mammers': [('mam', False)],
          'man': [('man', True)],
          'managerne': [('manager', True)],
          'managernes': [('manager', False)],
          'managers': [('manager', True)],
          'mandage': [('mandag', False)],
          'mandagen': [('mandag', False)],
          'mandages': [('mandag', False)],
          'mandanten': [('mandant', False)],
          'mandantens': [('mandant', True)],
          'mandanter': [('mandant', False)],
          'mandanterne': [('mandant', True)],
          'mandanternes': [('mandant', False)],
          'mandanters': [('mandant', True)],
          'manden': [('mand', False)],
          'mandens': [('mand', False)],
          'mander': [('mander', False)],
          'manderne': [('mand', False)],
          'mandernes': [('mand', False)],
          'manders': [('mand', False)],
          'mandler': [('mandel', True)],
          'mandlers': [('mandel', True)],
          'manen': [('man', False)],
          'manens': [('man', True)],
          'maner': [('man', True)],
          'manerne': [('man', False)],
          'manernes': [('man', False)],
          'maners': [('man', True)],
          'mangas': [('manga', True)],
          'manglens': [('mangel', False)],
          'mangler': [('mangel', True)],
          'manglerne': [('mangel', True)],
          'manglernes': [('mangel', True)],
          'manglers': [('mangel', True)],
          'manien': [('mani', False)],
          'maniens': [('mani', False)],
          'manier': [('mani', False)],
          'maniernes': [('mani', False)],
          'manis': [('mani', False)],
          'manister': [('manist', False)],
          'manisters': [('manist', False)],
          'mankens': [('manke', True)],
          'manker': [('manke', True)],
          'mankerne': [('manke', True)],
          'mankers': [('manke', True)],
          'mannen': [('man', False)],
          'mannens': [('man', False)],
          'manner': [('man', False)],
          'mannerne': [('manner', False)],
          'mannernes': [('manner', False)],
          'manners': [('manner', False)],
          'mans': [('man', True)],
          'manten': [('mant', False)],
          'mantens': [('mant', False)],
          'manterne': [('mant', False)],
          'manternes': [('mant', False)],
          'manters': [('mant', False)],
          'mantissen': [('mantisse', True)],
          'mantissens': [('mantisse', True)],
          'mantisser': [('mantisse', True)],
          'mantisserne': [('mantisse', True)],
          'mantissernes': [('mantisse', True)],
          'mantissers': [('mantisse', True)],
          'mants': [('mant', False)],
          'mappen': [('mappe', True)],
          'mappens': [('mappe', True)],
          'mapper': [('mappe', False)],
          'mapperne': [('mappe', False)],
          'mappernes': [('mappe', False)],
          'mappers': [('mappe', False)],
          'mappes': [('mappe', False)],
          'marbejder': [('marbejde', False)],
          'marbejderne': [('marbejde', False)],
          'marbejdernes': [('marbejde', False)],
          'marbejders': [('marbejde', False)],
          'marchen': [('march', True)],
          'marchens': [('march', True)],
          'marcher': [('march', True)],
          'marcherne': [('march', True)],
          'marchernes': [('march', False)],
          'marchers': [('march', True)],
          'maren': [('mare', True)],
          'marens': [('mare', True)],
          'marer': [('mare', True)],
          'marerne': [('mare', True)],
          'marernes': [('mare', True)],
          'marers': [('mare', True)],
          'mariens': [('marie', False)],
          'marier': [('marie', False)],
          'marierne': [('marie', False)],
          'mariernes': [('marie', False)],
          'mariers': [('marie', False)],
          'marinen': [('marine', True)],
          'marinens': [('marine', True)],
          'mariner': [('marine', True), ('mariner', True)],
          'marinerne': [('mariner', True), ('marine', True)],
          'marinernes': [('marine', True), ('mariner', True)],
          'mariners': [('mariner', True), ('marine', True)],
          'marker': [('marker', True), ('mark', True)],
          'markerne': [('marker', True), ('mark', True)],
          'markernes': [('marker', True), ('mark', True)],
          'markers': [('marker', True), ('mark', True)],
          'markets': [('mark', False)],
          'markis': [('markis', True)],
          'markisen': [('markis', True), ('markise', True)],
          'markisens': [('markise', True), ('markis', True)],
          'markiser': [('markis', True), ('markise', True)],
          'markiserne': [('markis', True), ('markise', True)],
          'markisernes': [('markis', True), ('markise', True)],
          'markisers': [('markise', True), ('markis', True)],
          'maronen': [('marone', False)],
          'maronens': [('marone', False)],
          'maroner': [('marone', False)],
          'maronerne': [('marone', False)],
          'maronernes': [('marone', False)],
          'maroners': [('marone', False)],
          'marsker': [('marsk', True)],
          'marskerne': [('marsk', True)],
          'marskernes': [('marsk', True)],
          'marskers': [('marsk', True)],
          'marts': [('marts', True)],
          'marven': [('marv', False)],
          'marvens': [('marv', True)],
          'mas': [('mas', True)],
          'maske': [('maske', False)],
          'masken': [('mask', True), ('maske', True)],
          'maskens': [('mask', True), ('maske', True)],
          'masker': [('maske', True)],
          'maskerne': [('maske', True)],
          'maskernes': [('maske', False)],
          'maskers': [('maske', True)],
          'maskes': [('maske', False)],
          'masket': [('mask', False)],
          'maskets': [('mask', False)],
          'massager': [('massage', False)],
          'massen': [('masse', True)],
          'massens': [('masse', True)],
          'masser': [('masse', True)],
          'masserne': [('masse', True)],
          'massernes': [('masse', False)],
          'massers': [('masse', False)],
          'masten': [('mast', False)],
          'mastens': [('mast', False)],
          'master': [('mast', True), ('master', True)],
          'masterne': [('mast', True), ('master', True)],
          'masternes': [('master', True), ('mast', True)],
          'masters': [('master', True), ('mast', True)],
          'mata': [('ma', False)],
          'matas': [('ma', False)],
          'materialhandler': [('materialhandel', True), ('materialhandler', True)],
          'materialhandlerne': [('materialhandel', True), ('materialhandler', True)],
          'materialhandlernes': [('materialhandler', True), ('materialhandel', True)],
          'materialhandlers': [('materialhandel', True), ('materialhandler', True)],
          'maternes': [('mat', False)],
          'matier': [('mati', False)],
          'matierne': [('mati', False)],
          'matiernes': [('mati', False)],
          'matiers': [('mati', False)],
          'matiet': [('mati', False)],
          'matiets': [('mati', False)],
          'matinerne': [('matiner', False)],
          'matiners': [('matiner', False)],
          'matis': [('mati', False)],
          'matorier': [('matorie', False)],
          'matoriernes': [('matorie', False)],
          'matorium': [('matorie', False)],
          'matoriums': [('matorie', False)],
          'matrice': [('matrice', True)],
          'matricen': [('matrix', True), ('matrice', True)],
          'matricens': [('matrix', True), ('matrice', True)],
          'matricer': [('matrice', True), ('matrix', True)],
          'matricerne': [('matrix', True), ('matrice', True)],
          'matricernes': [('matrix', True), ('matrice', True)],
          'matricers': [('matrix', True), ('matrice', True)],
          'matroner': [('matrone', True)],
          'matten': [('mat', False)],
          'mattens': [('mat', False)],
          'matternes': [('mat', True)],
          'matters': [('mat', False)],
          'mave': [('mave', False)],
          'maven': [('mave', True)],
          'mavens': [('mave', True)],
          'maver': [('mave', False)],
          'maverne': [('mave', False)],
          'mavernes': [('mave', False)],
          'mavers': [('mave', False)],
          'maves': [('mave', False)],
          'mavlen': [('mavl', False)],
          'mavlens': [('mavl', False)],
          'mbakken': [('mbak', False)],
          'mbakkens': [('mbak', False)],
          'mbarden': [('mbard', False)],
          'mbardens': [('mbard', False)],
          'mbarder': [('mbard', False)],
          'mbarderne': [('mbard', False)],
          'mbardernes': [('mbard', False)],
          'mbarders': [('mbard', False)],
          'mbarierne': [('mbarium', False)],
          'mbariernes': [('mbarium', False)],
          'mbariets': [('mbarium', False)],
          'mbas': [('mba', False)],
          'mbassen': [('mbasse', False)],
          'mbassens': [('mbasse', False)],
          'mbasser': [('mbasse', False)],
          'mbasserne': [('mbasse', False)],
          'mbassernes': [('mbasse', False)],
          'mbassers': [('mbasse', False)],
          'mbede': [('mbede', False)],
          'mbedes': [('mbede', False)],
          'mbedet': [('mbede', False)],
          'mbedets': [('mbede', False)],
          'mben': [('mbe', False)],
          'mbenets': [('mben', False)],
          'mbens': [('mbe', False)],
          'mber': [('mbe', False)],
          'mberne': [('mbe', False)],
          'mbernes': [('mbe', False)],
          'mbers': [('mber', False)],
          'mbien': [('mbie', False)],
          'mbiens': [('mbie', False)],
          'mbier': [('mbie', False)],
          'mbierne': [('mbie', False)],
          'mbiernes': [('mbier', False)],
          'mbiers': [('mbier', False)],
          'mbies': [('mbie', False)],
          'mbitter': [('mbit', False)],
          'mbitterne': [('mbit', False)],
          'mbitternes': [('mbit', False)],
          'mbitters': [('mbit', False)],
          'mble': [('mble', False)],
          'mblens': [('mbel', False)],
          'mbler': [('mbler', False)],
          'mblerne': [('mbler', False)],
          'mblernes': [('mble', False)],
          'mblers': [('mbler', False)],
          'mbles': [('mble', False)],
          'mblet': [('mbel', False)],
          'mblets': [('mbel', False)],
          'mboer': [('mbo', False)],
          'mboerne': [('mbo', False)],
          'mboernes': [('mbo', False)],
          'mboers': [('mbo', False)],
          'mbogen': [('mbog', False)],
          'mbolet': [('mbol', False)],
          'mbolets': [('mbol', False)],
          'mbomber': [('mbombe', False)],
          'mbomberne': [('mbombe', False)],
          'mbombernes': [('mbombe', False)],
          'mbombers': [('mbombe', False)],
          'mbonen': [('mbone', False)],
          'mbonens': [('mbone', False)],
          'mboner': [('mbone', False)],
          'mbonerne': [('mbone', False)],
          'mbonernes': [('mbone', False)],
          'mboners': [('mbone', False)],
          'mboret': [('mbor', False)],
          'mborets': [('mbor', False)],
          'mbras': [('mbra', False)],
          'mbre': [('mbre', False)],
          'mbrugs': [('mbrug', False)],
          'mbs': [('mb', False)],
          'mbuks': [('mbuk', False)],
          'mburs': [('mburs', False)],
          'mbus': [('mbus', False)],
          'mcellers': [('mcelle', False)],
          'mcyklen': [('mcykel', False)],
          'mcyklens': [('mcykel', False)],
          'mcykler': [('mcykel', False)],
          'mcyklerne': [('mcykel', False)],
          'mcyklernes': [('mcykel', False)],
          'mcyklers': [('mcykel', False)],
          'mdelerne': [('mdeler', False)],
          'mder': [('mde', False)],
          'mderne': [('mde', False)],
          'mdernes': [('mde', False)],
          'mdes': [('mde', False)],
          'mdømmer': [('mdømme', False)],
          'mdømmerne': [('mdømme', False)],
          'me': [('me', False)],
          'mearbejder': [('mearbejde', False)],
          'mearbejderne': [('mearbejde', False)],
          'mearen': [('mear', False)],
          'mearens': [('mear', False)],
          'meballer': [('mebal', False)],
          'meballers': [('mebal', False)],
          'mecker': [('mecker', False)],
          'meckernes': [('mecker', False)],
          'med.': [('med.', False)],
          'medagens': [('medag', False)],
          'medaner': [('medaner', False)],
          'medanerne': [('medaner', False)],
          'medanernes': [('medaner', False)],
          'medaners': [('medaner', False)],
          'medans': [('medans', False)],
          'medarerne': [('medar', False)],
          'medarers': [('medar', False)],
          'mede': [('mede', True)],
          'medeje': [('medeje', True)],
          'medejes': [('medeje', True)],
          'meden': [('mede', True)],
          'medens': [('mede', True)],
          'meder': [('mede', True)],
          'mederne': [('mede', True)],
          'medernes': [('mede', True)],
          'meders': [('mede', True)],
          'medes': [('mede', True)],
          'mediciner': [('mediciner', True), ('medicin', True)],
          'medicinerne': [('medicin', True), ('mediciner', True)],
          'medicinernes': [('medicin', True), ('mediciner', True)],
          'mediciners': [('mediciner', True), ('medicin', True)],
          'megas': [('mega', False)],
          'megne': [('megn', False)],
          'megnen': [('megn', False)],
          'mehave': [('mehav', False)],
          'meister': [('meister', False)],
          'meisterne': [('meister', False)],
          'meisternes': [('meister', False)],
          'meisters': [('meister', False)],
          'meje': [('meje', False)],
          'mejen': [('meje', False)],
          'mejens': [('meje', False)],
          'mejer': [('mejer', True)],
          'mejerne': [('mejer', True)],
          'mejernes': [('mejer', True)],
          'mejers': [('mejer', True)],
          'mejes': [('meje', False)],
          'mejet': [('meje', False)],
          'mejets': [('meje', False)],
          'mejs': [('mejs', True)],
          'mejsen': [('mejs', True), ('mejse', True)],
          'mejsens': [('mejs', True), ('mejse', True)],
          'mejser': [('mejs', True), ('mejse', True)],
          'mejserne': [('mejs', True), ('mejse', True)],
          'mejsernes': [('mejs', True), ('mejse', True)],
          'mejsers': [('mejs', True), ('mejse', True)],
          'melader': [('melade', False)],
          'meladerne': [('melade', False)],
          'meldrøjer': [('meldrøjer', True), ('meldrøje', True)],
          'meldrøjerne': [('meldrøje', True), ('meldrøjer', True)],
          'meldrøjernes': [('meldrøje', True), ('meldrøjer', True)],
          'meldrøjers': [('meldrøje', True), ('meldrøjer', True)],
          'melerne': [('mel', False)],
          'melet': [('mel', True)],
          'melets': [('mel', False)],
          'melfarternes': [('melfart', False)],
          'melflugter': [('melflugt', False)],
          'melflugternes': [('melflugt', False)],
          'melflugters': [('melflugt', False)],
          'meliers': [('melier', False)],
          'melighedsindeks': [('lighedsindeks', False)],
          'meliner': [('melin', False)],
          'melinernes': [('melin', False)],
          'meliners': [('melin', False)],
          'melissen': [('melis', True), ('melisse', True)],
          'melissens': [('melis', True), ('melisse', True)],
          'meliter': [('meliter', False)],
          'meliterne': [('meliter', False)],
          'meliternes': [('meliter', False)],
          'meliters': [('meliter', False)],
          'mellen': [('mel', False)],
          'meller': [('mel', False)],
          'mellers': [('mel', False)],
          'melsers': [('melse', False)],
          'melten': [('melt', False)],
          'meltenes': [('melt', False)],
          'meltens': [('melt', False)],
          'melter': [('melt', False)],
          'melterne': [('melt', False)],
          'melternes': [('melt', False)],
          'melukkerne': [('melukker', False)],
          'melukkers': [('melukker', False)],
          'melures': [('melure', False)],
          'melærerne': [('melærer', False)],
          'melærernes': [('melærer', False)],
          'memasterne': [('memaster', False)],
          'memasternes': [('memaster', False)],
          'men': [('men', True)],
          'menaders': [('menade', False)],
          'menager': [('menage', False)],
          'mene': [('', False)],
          'menen': [('men', False)],
          'menens': [('men', False)],
          'mener': [('mener', False)],
          'menerne': [('mener', False)],
          'menernes': [('men', False)],
          'meners': [('mener', False)],
          'menes': [('', False)],
          'meniens': [('meni', False)],
          'menier': [('menier', False)],
          'menierne': [('menier', False)],
          'meniernes': [('menier', False)],
          'meniers': [('menier', False)],
          'menis': [('meni', False)],
          'menneskehandler': [('menneskehandel', True), ('menneskehandler', True)],
          'menneskehandlerne': [('menneskehandler', True), ('menneskehandel', True)],
          'menneskehandlernes': [('menneskehandler', True), ('menneskehandel', True)],
          'menneskehandlers': [('menneskehandel', True), ('menneskehandler', True)],
          'mens': [('men', True)],
          "mens'": [('mens', False)],
          'mensen': [('mens', False)],
          'mensens': [('mens', False)],
          'menses': [('menses', True)],
          'mentaler': [('mentaler', False)],
          'mentalerne': [('mentaler', False)],
          'mentalernes': [('mentaler', False)],
          'mentalers': [('mentaler', False)],
          'mentarier': [('mentarie', False)],
          'mentarierne': [('mentarium', False)],
          'mentariernes': [('mentarium', False)],
          'mentariers': [('mentarium', False)],
          'mentariet': [('mentarie', False)],
          'mentariets': [('mentarie', False)],
          'mentarium': [('mentarium', False)],
          'mentariums': [('mentarium', False)],
          'menten': [('mente', True)],
          'mentens': [('mente', True)],
          'menter': [('mente', True)],
          'menterne': [('mente', True)],
          'menternes': [('mente', True)],
          'menters': [('mente', True)],
          'mentet': [('ment', False)],
          'mentets': [('ment', False)],
          'mentinen': [('mentin', False)],
          'mentinens': [('mentin', False)],
          'mentiner': [('mentin', False)],
          'mentinernes': [('mentin', False)],
          'mentis': [('menti', False)],
          'menuen': [('menu', False)],
          'menuens': [('menu', False)],
          'menuer': [('menu', False)],
          'menuerne': [('menu', False)],
          'menuernes': [('menu', False)],
          'menuers': [('menu', True)],
          'menuets': [('menuet', True)],
          'menus': [('menu', True)],
          'mer': [('me', False)],
          'mera': [('mera', False)],
          'meraler': [('merale', False)],
          'meralerne': [('merale', False)],
          'meralernes': [('merale', False)],
          'meralers': [('merale', False)],
          'meralet': [('merale', False)],
          'meralets': [('merale', False)],
          'meraliers': [('merale', False)],
          'meraner': [('meraner', False)],
          'meraners': [('meraner', False)],
          'meras': [('mera', False)],
          'merer': [('merer', False)],
          'mererne': [('merer', False)],
          'merernes': [('merer', False)],
          'merers': [('merer', False)],
          'meretten': [('meret', False)],
          'merettens': [('meret', False)],
          'merformer': [('merform', False)],
          'merformers': [('merform', False)],
          'merhandlernes': [('merhandel', False)],
          'merhedens': [('merhede', False)],
          'merianer': [('merian', True)],
          'merianers': [('merian', True)],
          'merier': [('meri', False)],
          'merierne': [('meri', False)],
          'meriernes': [('meri', False)],
          'meriers': [('meri', False)],
          'meriet': [('meri', False)],
          'meriets': [('meri', False)],
          'meris': [('meri', False)],
          'meritis': [('meritus', False)],
          'meritter': [('meritter', True), ('merit', True)],
          'meritterne': [('merit', True), ('meritter', True)],
          'meritternes': [('meritter', True), ('merit', True)],
          'meritters': [('meritter', True), ('merit', True)],
          'merkors': [('merkor', False)],
          'merne': [('me', False)],
          'mernes': [('me', False)],
          'merret': [('merret', False)],
          "mers'": [('mers', False)],
          'mersen': [('mers', False)],
          'mersens': [('mers', False)],
          'merten': [('mert', False)],
          'mertens': [('mert', False)],
          'merters': [('mert', False)],
          'merts': [('mert', False)],
          'mes': [('me', False)],
          "mes'": [('me', False)],
          'mesers': [('meser', False)],
          'mesidens': [('meside', False)],
          'mesis': [('mesi', False)],
          'meskifters': [('meskift', False)],
          'mesmerterne': [('mesmerter', False)],
          'messens': [('messe', False)],
          'messer': [('messe', False)],
          'messerne': [('messe', False)],
          'messernes': [('messe', False)],
          'messers': [('messe', True)],
          'mester': [('mester', False)],
          'mesteret': [('mester', False)],
          'mesterets': [('mester', False)],
          'mestudies': [('mestudie', False)],
          'mestyrers': [('mestyre', False)],
          'meter': [('meter', True)],
          'meterne': [('meter', True)],
          'meternes': [('meter', False)],
          'meters': [('meter', True)],
          'metiden': [('metid', False)],
          'metonen': [('metone', False)],
          'metonens': [('metone', False)],
          'metoner': [('metone', False)],
          'metonerne': [('metone', False)],
          'metonernes': [('metone', False)],
          'metoners': [('metone', False)],
          'metre': [('metrum', True)],
          'metrene': [('metrum', True)],
          'metrenes': [('metrum', True)],
          'metres': [('metrum', True)],
          'metret': [('metrum', True)],
          'metrets': [('metrum', True)],
          'metter': [('mette', False)],
          'metterne': [('mette', False)],
          'metternes': [('mette', False)],
          'metters': [('mette', False)],
          'metylen': [('metylen', True), ('metyl', True)],
          'metylens': [('metylen', True), ('metyl', True)],
          'meure': [('meur', False)],
          'meures': [('meur', False)],
          'meurets': [('meur', False)],
          'mevers': [('mevers', False)],
          'meviser': [('meviser', False)],
          'meviserne': [('meviser', False)],
          'mevisernes': [('meviser', False)],
          'mevisers': [('meviser', False)],
          'mf': [('mf', True)],
          "mf'er": [('mf', True)],
          "mf'ernes": [('mf', True)],
          "mf'ers": [('mf', True)],
          'mfaren': [('mfar', False)],
          'mfarens': [('mfar', False)],
          'mfars': [('mfar', False)],
          'mfase': [('mfase', False)],
          'mfasen': [('mfase', False)],
          'mfasens': [('mfase', False)],
          'mfaser': [('mfase', False)],
          'mfaserne': [('mfase', False)],
          'mfasernes': [('mfase', False)],
          'mfasers': [('mfase', False)],
          'mfases': [('mfase', False)],
          'mfe': [('mfe', False)],
          'mfen': [('mfe', False)],
          'mfens': [('mfe', False)],
          'mfer': [('mfer', False)],
          'mferet': [('mfer', False)],
          'mferets': [('mfer', False)],
          'mferne': [('mf', False)],
          'mfernes': [('mf', False)],
          'mfers': [('mf', False)],
          'mfes': [('mfe', False)],
          'mfladens': [('mflade', False)],
          'mfonierne': [('mfoni', False)],
          'mfoniernes': [('mfoni', False)],
          'mfoniers': [('mfoni', False)],
          'mfora': [('mfora', False)],
          'mforas': [('mfora', False)],
          'mformer': [('mformer', False)],
          'mformerne': [('mformer', False)],
          'mformernes': [('mformer', False)],
          'mformers': [('mformer', False)],
          'mfritten': [('mfrit', False)],
          'mfrittens': [('mfrit', False)],
          'mfritter': [('mfrit', False)],
          'mfritterne': [('mfrit', False)],
          'mfritternes': [('mfrit', False)],
          'mfritters': [('mfrit', False)],
          'mfruen': [('mfru', False)],
          'mfruens': [('mfru', False)],
          'mfruer': [('mfru', False)],
          'mfruerne': [('mfru', False)],
          'mfruernes': [('mfru', False)],
          'mfruers': [('mfru', False)],
          'mfurer': [('mfur', False)],
          'mfurerne': [('mfur', False)],
          'mfurernes': [('mfur', False)],
          'mfurers': [('mfur', False)],
          'mfædre': [('mfar', False)],
          'mfærden': [('mfærd', False)],
          'mfærdens': [('mfærd', False)],
          'mgænger': [('mgænger', False)],
          'mgængerne': [('mgænger', False)],
          'mgængernes': [('mgænger', False)],
          'mgængers': [('mgænger', False)],
          'mhals': [('mhals', False)],
          'mhandler': [('mhandler', False)],
          'mhandlerne': [('mhandler', False)],
          'mhandlernes': [('mhandler', False)],
          'mhandlers': [('mhandler', False)],
          'mheden': [('mhed', False)],
          'mhedens': [('mhed', False)],
          'mheder': [('mhed', False)],
          'mhederne': [('mhed', False)],
          'mhedernes': [('mhed', False)],
          'mheders': [('mhed', False)],
          'mhejs': [('mhej', False)],
          'mhinde': [('mhinde', False)],
          'mhinden': [('mhinde', False)],
          'mhindens': [('mhinde', False)],
          'mhinder': [('mhinde', False)],
          'mhinderne': [('mhinde', False)],
          'mhindernes': [('mhinde', False)],
          'mhinders': [('mhinde', False)],
          'mhindes': [('mhinde', False)],
          'mholterne': [('mholt', False)],
          'mholters': [('mholt', False)],
          'mhuen': [('mhu', False)],
          'mhuens': [('mhu', False)],
          'mhvirvler': [('mhvirvel', False)],
          'mhvirvlerne': [('mhvirvel', False)],
          'mhvirvlernes': [('mhvirvel', False)],
          'mhvirvlers': [('mhvirvel', False)],
          'mi': [('mi', False)],
          'mianer': [('mian', False)],
          'mianers': [('mian', False)],
          'mians': [('mian', False)],
          'mibiernes': [('mibier', False)],
          'mickerne': [('mick', False)],
          'mickers': [('mick', False)],
          'mide': [('mide', False)],
          'miden': [('mide', False)],
          'midens': [('mide', False)],
          'mider': [('mide', True)],
          'miderne': [('mide', True)],
          'midernes': [('mide', False)],
          'miders': [('mide', True)],
          'mides': [('mide', False)],
          'midler': [('middel', True)],
          'midlerne': [('middel', True)],
          'midlernes': [('middel', True)],
          'midlers': [('middel', True)],
          'mien': [('mi', False)],
          'miens': [('mi', False)],
          'mier': [('mi', False)],
          'miere': [('mier', False)],
          'mieren': [('mier', False)],
          'mierens': [('mier', False)],
          'mieres': [('mier', False)],
          'mierne': [('mi', False)],
          'miernes': [('mi', False)],
          'miers': [('mi', False)],
          'miet': [('mi', True)],
          'miets': [('mi', False)],
          'migejernes': [('migej', False)],
          'migejers': [('migej', False)],
          'migers': [('miger', False)],
          'mika': [('mikon', False)],
          'mikalier': [('mikalie', False)],
          'mikalierne': [('mikalie', False)],
          'mikaliers': [('mikalie', False)],
          'mikas': [('mikon', False)],
          'mikken': [('mik', False)],
          'mikkerne': [('mik', False)],
          'miklens': [('mikkel', False)],
          'mikler': [('mikkel', False)],
          'miklernes': [('mikkel', False)],
          'mikroner': [('mikron', False)],
          'mikronernes': [('mikron', False)],
          'miks': [('miks', True)],
          "miks'": [('miks', True)],
          'miksen': [('miks', True)],
          'miksens': [('miks', True)],
          'mikser': [('mikser', True)],
          'miksernes': [('mikser', False)],
          'mile': [('mile', False)],
          'milen': [('mil', True), ('mile', True)],
          'milens': [('mile', True), ('mil', True)],
          'miler': [('mile', False)],
          'milerne': [('mile', True)],
          'milernes': [('mile', True)],
          'milers': [('mile', True)],
          'miles': [('mile', False)],
          'milet': [('mile', False)],
          'milets': [('mile', False)],
          'milias': [('milias', False)],
          'milien': [('mili', False)],
          'miliens': [('mili', False)],
          'milier': [('milie', False)],
          'milierne': [('milie', False)],
          'miliers': [('milie', False)],
          'miliet': [('mili', False)],
          'miliets': [('mili', False)],
          'milis': [('mili', False)],
          'millens': [('mille', False)],
          'miller': [('mille', False)],
          'millerne': [('mille', False)],
          'millernes': [('mille', False)],
          'millers': [('mille', False)],
          'milte': [('milt', True)],
          'milten': [('milt', True)],
          'miltens': [('milt', True)],
          'miltes': [('milt', True)],
          'mime': [('mime', False)],
          'mimen': [('mime', False)],
          'mimens': [('mime', False)],
          'mimer': [('mimer', True), ('mime', True)],
          'mimerne': [('mimer', True), ('mime', True)],
          'mimernes': [('mimer', True), ('mime', True)],
          'mimers': [('mimer', True), ('mime', True)],
          'mimes': [('mime', True)],
          'miministeriet': [('miministerie', False)],
          'mina': [('mina', False)],
          'minalens': [('minal', False)],
          'minanser': [('minans', False)],
          'minansers': [('minans', False)],
          'minaret': [('minaret', True)],
          'minarets': [('minaret', True)],
          'minas': [('mina', False)],
          'minder': [('minde', False)],
          'minderne': [('minde', False)],
          'mindernes': [('minde', False)],
          'minders': [('minde', True)],
          'mine': [('mine', False)],
          'minearbejdernes': [('minearbejder', False)],
          'minearbejders': [('minearbejder', False)],
          'minen': [('mine', True)],
          'minens': [('mine', True)],
          'miner': [('mine', True)],
          'minerne': [('mine', True)],
          'minernes': [('mine', False)],
          'miners': [('mine', True)],
          'mines': [('mine', True)],
          'minet': [('men', False)],
          'minets': [('men', False)],
          'mingen': [('ming', False)],
          'mingens': [('ming', False)],
          'minger': [('ming', False)],
          'mingerne': [('ming', False)],
          'mingernes': [('ming', False)],
          'mings': [('ming', False)],
          'mini': [('mini', True)],
          'minien': [('mini', True)],
          'miniens': [('mini', True)],
          'minier': [('mini', True)],
          'minierne': [('mini', True)],
          'minis': [('mini', True)],
          'minister': [('minister', True)],
          'ministeriet': [('ministerie', False)],
          'ministers': [('minister', True)],
          'minken': [('mink', True)],
          'minkens': [('mink', True)],
          'minkernes': [('minke', False)],
          'minkers': [('minke', False)],
          'minks': [('mink', True)],
          'mirabellen': [('mirabel', True), ('mirabelle', True)],
          'mirabellens': [('mirabelle', True), ('mirabel', True)],
          'mirabeller': [('mirabel', True), ('mirabelle', True)],
          'mirabellerne': [('mirabelle', True), ('mirabel', True)],
          'mirabellernes': [('mirabelle', True), ('mirabel', True)],
          'mirabellers': [('mirabel', True), ('mirabelle', True)],
          'miren': [('mir', False)],
          'mirer': [('mir', False)],
          'mirerne': [('mir', False)],
          'mirernes': [('mir', False)],
          'mirers': [('mir', False)],
          'mis': [('mis', True), ('mi', True)],
          'mise': [('mise', False)],
          'misere': [('misere', True)],
          'miseren': [('misere', True)],
          'miserens': [('misere', True)],
          'miseres': [('misere', True)],
          'misers': [('mis', False)],
          'mises': [('mise', False)],
          'mismen': [('misme', False)],
          'mismens': [('misme', False)],
          'mismers': [('misme', False)],
          'misole': [('misole', False)],
          'misolen': [('misole', False)],
          'misoles': [('misole', False)],
          'missen': [('miss', True), ('mis', True)],
          'missens': [('miss', True), ('mis', True)],
          'misser': [('miss', True), ('misser', True), ('mis', True)],
          'misserne': [('miss', True), ('mis', True), ('misser', True)],
          'missernes': [('miss', True), ('misser', True), ('mis', True)],
          'missers': [('mis', True), ('misser', True), ('miss', True)],
          'missioner': [('mission', True)],
          'missionerne': [('mission', True)],
          'missionernes': [('mission', True)],
          'missioners': [('mission', True)],
          'misten': [('mist', False)],
          'mistens': [('mist', False)],
          'mister': [('mist', False)],
          'misterne': [('mist', False)],
          'misternes': [('mist', False)],
          'misters': [('mist', False)],
          'mitten': [('mitte', True)],
          'mittens': [('mitte', True)],
          'mitter': [('mitte', True)],
          'mitterne': [('mitte', True)],
          'mitternes': [('mitte', True)],
          'mitters': [('mitte', True)],
          'miver': [('miver', False)],
          'mixer': [('mixer', False)],
          'mixerne': [('mixer', True)],
          'mixernes': [('mixer', False)],
          'mixers': [('mixer', False)],
          'mjøden': [('mjød', True)],
          'mjødens': [('mjød', True)],
          'mkagen': [('mkage', False)],
          'mkagens': [('mkage', False)],
          'mkisten': [('mkiste', False)],
          'mkistens': [('mkiste', False)],
          'mkisterne': [('mkiste', False)],
          'mkisternes': [('mkiste', False)],
          'mklipper': [('mklipper', False)],
          'mklipperne': [('mklipper', False)],
          'mklippernes': [('mklipper', False)],
          'mklippers': [('mklipper', False)],
          'mklips': [('mklip', False)],
          'mklokker': [('mklokke', False)],
          'mklokkerne': [('mklokke', False)],
          'mklokkernes': [('mklokke', False)],
          'mklokkers': [('mklokke', False)],
          'mkreds': [('mkreds', False)],
          'mkronen': [('mkrone', False)],
          'mkroner': [('mkrone', False)],
          'mkræfter': [('mkræfter', False)],
          'mkræfterne': [('mkræfter', False)],
          'mkræfternes': [('mkræfter', False)],
          'mkræfters': [('mkræfter', False)],
          'mkundens': [('mkunde', False)],
          'mkuren': [('mkur', False)],
          'mkures': [('mkur', False)],
          'mkurs': [('mkur', False)],
          'mkurve': [('mkurve', False)],
          'mkurven': [('mkurve', False)],
          'mkurvens': [('mkurve', False)],
          'mkurves': [('mkurve', False)],
          'mkvarter': [('mkvarter', False)],
          'mkvarters': [('mkvarter', False)],
          'mkvædet': [('mkvæd', False)],
          'mkvædets': [('mkvæd', False)],
          'mkæmper': [('mkæmper', False)],
          'mkæmperne': [('mkæmper', False)],
          'mkæmpernes': [('mkæmper', False)],
          'mkæmpers': [('mkæmper', False)],
          'mkød': [('mkød', False)],
          'mle': [('mmel', False)],
          'mledernes': [('mleder', False)],
          'mlejer': [('mleje', False)],
          'mlejerne': [('mleje', False)],
          'mlejers': [('mleje', False)],
          'mlen': [('mmel', False)],
          'mlene': [('mmel', False)],
          'mlenes': [('mmel', False)],
          'mlens': [('mmel', False)],
          'mlere': [('mler', False)],
          'mleren': [('mler', False)],
          'mlerens': [('mler', False)],
          'mleres': [('mler', False)],
          'mlerne': [('mmel', False)],
          'mlernes': [('mmel', False)],
          'mlers': [('mmel', False)],
          'mles': [('mmel', False)],
          'mlet': [('mmel', False)],
          'mlets': [('mmel', False)],
          'mleverne': [('mlever', False)],
          'mlevernes': [('mlever', False)],
          'mlingers': [('mling', False)],
          'mlyden': [('mlyd', False)],
          'mlydens': [('mlyd', False)],
          'mlæbernes': [('mlæbe', False)],
          'mlænder': [('mlænder', False)],
          'mlænderne': [('mlænder', False)],
          'mlændernes': [('mlænder', False)],
          'mlænders': [('mlænder', False)],
          'mlærke': [('mlærke', False)],
          'mlærken': [('mlærke', False)],
          'mlærkens': [('mlærke', False)],
          'mlærkes': [('mlærke', False)],
          'mløser': [('mløser', False)],
          'mløserne': [('mløser', False)],
          'mløsers': [('mløser', False)],
          'mm': [('millimeter', True)],
          'mm.': [('millimeter', True)],
          'mmadders': [('mmad', False)],
          'mmads': [('mmad', False)],
          'mmager': [('mmager', False)],
          'mmagerne': [('mmager', False)],
          'mmagernes': [('mmager', False)],
          'mmagers': [('mmager', False)],
          'mmanens': [('mmanens', False)],
          'mmarchen': [('mmarch', False)],
          'mmarchens': [('mmarch', False)],
          'mmarcherne': [('mmarch', False)],
          'mmas': [('mma', False)],
          'mmasserne': [('mmasse', False)],
          'mmaster': [('mmaster', False)],
          'mmasterne': [('mmaster', False)],
          'mmasternes': [('mmaster', False)],
          'mmasters': [('mmaster', False)],
          'mme': [('m', False)],
          'mmebogen': [('mmebog', False)],
          'mmelser': [('mmelse', False)],
          'mmelserne': [('mmelse', False)],
          'mmelsernes': [('mmelse', False)],
          'mmen': [('m', False)],
          'mmener': [('mmen', False)],
          'mmenerne': [('mmen', False)],
          'mmeners': [('mmen', False)],
          'mmens': [('m', False)],
          'mmere': [('mmer', False)],
          'mmeren': [('mmer', False)],
          'mmerens': [('mmer', False)],
          'mmeres': [('mmer', False)],
          'mmeret': [('mmer', False)],
          'mmerets': [('mmer', False)],
          'mmerter': [('mmert', False)],
          'mmerterne': [('mmert', False)],
          'mmerternes': [('mmert', False)],
          'mmes': [('m', False)],
          'mmet': [('mme', False)],
          'mmeter': [('mmeter', False)],
          'mmeters': [('mmeter', False)],
          'mmetre': [('mmeter', False)],
          'mmetrene': [('mmeter', False)],
          'mmetrenes': [('mmeter', False)],
          'mmetres': [('mmeter', False)],
          'mmetret': [('mmeter', False)],
          'mmetrets': [('mmeter', False)],
          'mmets': [('mme', False)],
          'mmiet': [('mmi', False)],
          'mmis': [('mmis', False)],
          'mmisen': [('mmis', False)],
          'mmisens': [('mmis', False)],
          'mmiser': [('mmis', False)],
          'mmiserne': [('mmis', False)],
          'mmisernes': [('mmis', False)],
          'mmissioner': [('mmission', False)],
          'mmissionerne': [('mmission', False)],
          'mmissionernes': [('mmission', False)],
          'mmissioners': [('mmission', False)],
          'mmoder': [('mmode', False)],
          'mmoderne': [('mmode', False)],
          'mmodernes': [('mmode', False)],
          'mmoders': [('mmor', False)],
          'mmus': [('mmus', False)],
          'mmutter': [('mmut', False)],
          'mmutters': [('mmut', False)],
          'mmælken': [('mmælk', False)],
          'mmælkens': [('mmælk', False)],
          'mmænd': [('mmand', False)],
          'mmændene': [('mmand', False)],
          'mmøren': [('mmør', False)],
          'mmører': [('mmør', False)],
          'mmørerne': [('mmør', False)],
          'mmørernes': [('mmør', False)],
          'mmørers': [('mmør', False)],
          'mnearbejdernes': [('mnearbejde', False)],
          'mnearbejders': [('mnearbejde', False)],
          'mner': [('mner', False)],
          'mnerne': [('mne', False)],
          'mnernes': [('mner', False)],
          'mners': [('mne', False)],
          'mnesers': [('mnese', False)],
          'mnet': [('mne', False)],
          'mnets': [('mne', False)],
          'mnier': [('mnium', False)],
          'mnierne': [('mnium', False)],
          'mniernes': [('mnium', False)],
          'mniers': [('mnium', False)],
          'mniet': [('mnium', False)],
          'mniets': [('mnium', False)],
          'mningers': [('mning', False)],
          'mnium': [('mnium', False)],
          'mniums': [('mnium', False)],
          'mnoterne': [('mnote', False)],
          'mobilen': [('mobile', True), ('mobil', True)],
          'mobilens': [('mobile', True), ('mobil', True)],
          'mobiler': [('mobil', True), ('mobile', True)],
          'mobilerne': [('mobile', True), ('mobil', True)],
          'mobilernes': [('mobile', True), ('mobil', True)],
          'mobilers': [('mobile', True), ('mobil', True)],
          'mobilet': [('mobile', True)],
          'mobilets': [('mobile', True)],
          'moden': [('mode', True)],
          'modens': [('mode', True)],
          'moder': [('mode', True), ('moder', True)],
          'modere': [('mor', False)],
          'moderen': [('mor', False)],
          'moderens': [('mor', False)],
          'moderes': [('mor', False)],
          'moderne': [('mode', True)],
          'modernes': [('mode', True)],
          'moders': [('moder', True), ('mode', True)],
          'modet': [('mod', True)],
          'modets': [('mod', True)],
          'modis': [('modus', True)],
          'moen': [('mo', False)],
          'moens': [('mo', False)],
          'moer': [('mo', False)],
          'moerne': [('mo', False)],
          'moernes': [('mo', False)],
          'moers': [('mo', False)],
          'moet': [('mo', False)],
          'moets': [('mo', False)],
          'moggen': [('mog', False)],
          'moggens': [('mog', False)],
          'moirerne': [('moirer', False)],
          'moirers': [('moirer', False)],
          'mokkens': [('mokke', True)],
          'mokker': [('mokke', True)],
          'mokkerne': [('mokke', True)],
          'mokkernes': [('mokke', True)],
          'mokkers': [('mokke', True)],
          'mokser': [('mokse', False)],
          'mole': [('mole', False)],
          'molen': [('mole', False)],
          'molens': [('mole', False)],
          'moler': [('moler', True), ('mol', True), ('mole', True)],
          'molerne': [('mol', True), ('mole', True)],
          'molernes': [('mole', True), ('mol', True)],
          'molers': [('moler', True), ('mol', True), ('mole', True)],
          'moles': [('mole', False)],
          'molos': [('molo', False)],
          'moms': [('moms', True)],
          "moms'": [('moms', True)],
          'mondernes': [('monde', False)],
          'monen': [('mone', False)],
          'monens': [('mone', False)],
          'moner': [('mone', False)],
          'monerne': [('mone', False)],
          'monernes': [('mone', False)],
          'moners': [('mone', False)],
          'monien': [('moni', False)],
          'moniens': [('moni', False)],
          'monier': [('moni', False)],
          'monierne': [('monium', False)],
          'moniernes': [('monium', False)],
          'moniers': [('monium', False)],
          'moniet': [('moni', False)],
          'moniets': [('moni', False)],
          'monis': [('moni', False)],
          'monnet': [('mon', False)],
          'monnets': [('mon', False)],
          'mopper': [('moppe', False)],
          'mopperne': [('moppe', False)],
          'moppernes': [('moppe', True)],
          'moppes': [('moppe', False)],
          'mops': [('mops', False)],
          "mops'": [('mops', False)],
          'mopsen': [('mops', True)],
          'mopsens': [('mops', False)],
          'mopser': [('mops', True)],
          'mopserne': [('mops', True)],
          'mopsernes': [('mops', True)],
          'morakker': [('morakker', True)],
          'morakkerne': [('morakker', True)],
          'morakkernes': [('morakker', True)],
          'moralen': [('morale', True), ('moral', True)],
          'moralens': [('morale', True), ('moral', True)],
          'moraler': [('morale', True), ('moral', True)],
          'moralerne': [('morale', True), ('moral', True)],
          'moralernes': [('morale', True), ('moral', True)],
          'moralers': [('morale', True), ('moral', True)],
          'morder': [('morder', False)],
          'morer': [('mor', True)],
          'morerne': [('mor', True)],
          'morernes': [('mor', True)],
          'morers': [('mor', False)],
          'morgens': [('morgen', False)],
          'morianer': [('morian', True)],
          'morianers': [('morian', True)],
          'moriden': [('moride', False)],
          'morider': [('moride', False)],
          'moriderne': [('moride', False)],
          'moridernes': [('moride', False)],
          'moriders': [('moride', False)],
          'moris': [('mori', False)],
          'morrens': [('mor', True)],
          'mortalens': [('mortale', False)],
          'mortaler': [('mortale', False)],
          'mortalerne': [('mortale', False)],
          'morter': [('morter', True)],
          'morterer': [('morter', True)],
          'morterne': [('morter', True)],
          'morternes': [('morter', True)],
          'morters': [('morter', True)],
          'mos': [('mos', True)],
          'mosa': [('mosa', False)],
          'mosas': [('mosa', False)],
          'mosen': [('mos', True), ('mose', True)],
          'mosens': [('mose', True), ('mos', True)],
          'moser': [('mose', True)],
          'moserne': [('mose', True)],
          'mosernes': [('mose', False)],
          'mosers': [('mose', True)],
          'mosser': [('mos', True)],
          'mosserne': [('mos', False)],
          'moste': [('most', True)],
          'mosten': [('most', False)],
          'moster': [('moster', True), ('most', True)],
          'mosterne': [('most', False)],
          'mosternes': [('most', False)],
          'mosters': [('moster', True), ('most', True)],
          'mostes': [('most', True)],
          'moten': [('mote', False)],
          'motens': [('mote', False)],
          'moter': [('mote', False)],
          'moterne': [('mote', False)],
          'moternes': [('mote', False)],
          'moters': [('mote', False)],
          'motes': [('mote', False)],
          'motet': [('motet', True)],
          'motets': [('motet', True)],
          'moussen': [('mousse', True)],
          'moussens': [('mousse', True)],
          'movs': [('movs', False)],
          'movsen': [('movs', False)],
          'movser': [('movs', False)],
          'movserne': [('movs', False)],
          'movsernes': [('movs', False)],
          'mpaner': [('mpan', False)],
          'mpaners': [('mpan', False)],
          'mpans': [('mpan', False)],
          'mpansen': [('mpanse', False)],
          'mpansens': [('mpanse', False)],
          'mpanser': [('mpanse', False)],
          'mpanserne': [('mpanse', False)],
          'mpansernes': [('mpanse', False)],
          'mpansers': [('mpanse', False)],
          'mpas': [('mpas', False)],
          'mpasser': [('mpas', False)],
          'mpasserne': [('mpas', False)],
          'mpassernes': [('mpas', False)],
          'mpassers': [('mpas', False)],
          'mpatiens': [('mpati', False)],
          'mpels': [('mpel', False)],
          'mpelse': [('mpelse', False)],
          'mpelsen': [('mpelse', False)],
          'mpelsens': [('mpelse', False)],
          'mpelses': [('mpelse', False)],
          'mpen': [('mp', False)],
          'mpendierne': [('mpendie', False)],
          'mpendium': [('mpendie', False)],
          'mpendiums': [('mpendie', False)],
          'mpene': [('mp', False)],
          'mpenes': [('mp', False)],
          'mpens': [('mp', False)],
          'mpere': [('mper', False)],
          'mperens': [('mper', False)],
          'mperes': [('mper', False)],
          'mperne': [('mper', False)],
          'mpernes': [('mpe', False)],
          'mpers': [('mpe', False)],
          "mpers'": [('mper', False)],
          'mpesten': [('mpesten', False)],
          'mpestens': [('mpesten', False)],
          'mpet': [('mp', False)],
          'mpets': [('mp', False)],
          'mpetter': [('mpet', False)],
          'mpi': [('mpo', False)],
          'mpier': [('mpier', False)],
          'mpierne': [('mpier', False)],
          'mpiernes': [('mpier', False)],
          'mpiers': [('mpier', False)],
          'mpils': [('mpil', False)],
          'mpioner': [('mpion', False)],
          'mpioners': [('mpion', False)],
          'mpiren': [('mpire', False)],
          'mpis': [('mpo', False)],
          'mplanter': [('mplante', False)],
          'mplanterne': [('mplante', False)],
          'mplanternes': [('mplante', False)],
          'mplanters': [('mplante', False)],
          'mple': [('mple', False)],
          'mplen': [('mpel', False)],
          'mplene': [('mple', False)],
          'mplens': [('mpel', False)],
          'mpler': [('mpel', False)],
          'mples': [('mple', False)],
          'mplet': [('mpel', False)],
          'mplets': [('mpel', False)],
          'mplotter': [('mplot', False)],
          'mplotterne': [('mplot', False)],
          'mplotternes': [('mplot', False)],
          'mplotters': [('mplot', False)],
          'mpoet': [('mpo', False)],
          'mpoets': [('mpo', False)],
          'mpons': [('mpon', False)],
          'mpora': [('mpus', False)],
          'mporas': [('mpus', False)],
          'mporter': [('mport', False)],
          'mporterne': [('mport', False)],
          'mporternes': [('mport', False)],
          'mporters': [('mport', False)],
          'mposter': [('mposter', False)],
          'mposterne': [('mposter', False)],
          'mposternes': [('mposter', False)],
          'mposters': [('mposter', False)],
          'mpotens': [('mpotens', False)],
          'mpotten': [('mpot', False)],
          'mpottens': [('mpot', False)],
          'mpotter': [('mpot', False)],
          'mpotterne': [('mpot', False)],
          'mpotternes': [('mpot', False)],
          'mpotters': [('mpot', False)],
          'mpressens': [('mpresse', False)],
          'mpretterne': [('mpret', False)],
          'mpretternes': [('mpret', False)],
          'mpretters': [('mpret', False)],
          'mps': [('mp', False)],
          "mps'": [('mp', False)],
          'mptet': [('mpt', False)],
          'mptus': [('mptu', False)],
          'mpublikummer': [('mpublikum', False)],
          'mpublikummerne': [('mpublikum', False)],
          'mpublikummernes': [('mpublikum', False)],
          'mpublikummers': [('mpublikum', False)],
          'mpullen': [('mpul', False)],
          'mpullens': [('mpul', False)],
          'mpuller': [('mpul', False)],
          'mpullerne': [('mpul', False)],
          'mpullernes': [('mpul', False)],
          'mpullers': [('mpul', False)],
          'mpuls': [('mpul', False)],
          'mre': [('mmer', False)],
          'mrejser': [('mrejse', False)],
          'mrene': [('mmer', False)],
          'mrenes': [('mmer', False)],
          'mrens': [('mren', False)],
          'mrer': [('mrer', False)],
          'mrerne': [('mrer', False)],
          'mrernes': [('mrer', False)],
          'mres': [('mmer', False)],
          'mrianerne': [('mrian', False)],
          'mrianernes': [('mrian', False)],
          'mringer': [('mring', False)],
          'mringerne': [('mring', False)],
          'mringernes': [('mring', False)],
          'mringers': [('mring', False)],
          'mrokke': [('mrokke', False)],
          'mrokken': [('mrokke', False)],
          'mrokkens': [('mrokke', False)],
          'mrokker': [('mrokke', False)],
          'mrokkerne': [('mrokke', False)],
          'mrokkernes': [('mrokke', False)],
          'mrokkers': [('mrokke', False)],
          'mrokkes': [('mrokke', False)],
          'mrollerne': [('mrolle', False)],
          'mros': [('mros', False)],
          'mrosen': [('mros', False)],
          'mrosens': [('mros', False)],
          'mrotter': [('mrotte', False)],
          'mrotternes': [('mrotte', False)],
          'mrotters': [('mrotte', False)],
          'mruller': [('mrulle', False)],
          'mrummet': [('mrum', False)],
          'mrummets': [('mrum', False)],
          'mrunde': [('mrunde', False)],
          'mrunden': [('mrunde', False)],
          'mrunders': [('mrunde', False)],
          'mrundes': [('mrunde', False)],
          'mråder': [('mråde', False)],
          'mråderne': [('mråde', False)],
          'mrådernes': [('mråde', False)],
          'mrådet': [('mråd', False)],
          'mrådets': [('mråde', False)],
          'mræer': [('mrå', False)],
          'mræerne': [('mrå', False)],
          'ms': [('ms', False)],
          "ms'": [('ms', False)],
          'msammen': [('msammen', False)],
          'msammens': [('msammen', False)],
          'mse': [('ms', False)],
          'msen': [('ms', False)],
          'msene': [('ms', False)],
          'msenes': [('ms', False)],
          'msens': [('ms', False)],
          'msere': [('mser', False)],
          'mseren': [('mser', False)],
          'mserens': [('mser', False)],
          'mseres': [('mser', False)],
          'mserne': [('ms', False)],
          'msernes': [('ms', False)],
          'mses': [('ms', False)],
          'mset': [('ms', False)],
          'msets': [('ms', False)],
          'mshandlerne': [('mshandler', False)],
          'mshandlernes': [('mshandler', False)],
          'msingers': [('msing', False)],
          'mskaber': [('mskab', False)],
          'mskaberne': [('mskaber', False)],
          'mskabernes': [('mskaber', False)],
          'mskabers': [('mskab', False)],
          'mskeris': [('mskeri', False)],
          'mskifte': [('mskifte', False)],
          'mskifter': [('mskifte', False)],
          'mskifterne': [('mskifter', False)],
          'mskifternes': [('mskifter', False)],
          'mskifters': [('mskifte', False)],
          'mskiftes': [('mskifte', False)],
          'mskiftet': [('mskifte', False)],
          'mskiftets': [('mskifte', False)],
          'mskos': [('msko', False)],
          'mslags': [('mslag', False)],
          'mslens': [('msel', False)],
          'msler': [('msel', False)],
          'mslyngen': [('mslyng', False)],
          'mslyngens': [('mslyng', False)],
          'msmerter': [('msmerter', False)],
          'msmerterne': [('msmerter', False)],
          'msmerternes': [('msmerter', False)],
          'msmerters': [('msmerter', False)],
          'msoller': [('msoller', False)],
          'msollerne': [('msoller', False)],
          'msollernes': [('msoller', False)],
          'msollers': [('msoller', False)],
          'mssagens': [('mssag', False)],
          'mssager': [('mssag', False)],
          'mssagerne': [('mssag', False)],
          'mssagernes': [('mssag', False)],
          'mstave': [('mstav', False)],
          'mstaven': [('mstav', False)],
          'mstavens': [('mstav', False)],
          'mstaves': [('mstav', False)],
          'msten': [('mst', False)],
          'mstens': [('msten', False)],
          'mster': [('mster', False)],
          'msterne': [('mster', False)],
          'msternes': [('mster', False)],
          'msters': [('mster', False)],
          'mstifter': [('mstift', False)],
          'mstifterne': [('mstift', False)],
          'mstifternes': [('mstift', False)],
          'mstifters': [('mstift', False)],
          'mstringens': [('mstring', False)],
          'mstyrer': [('mstyre', False)],
          'mstyrerne': [('mstyre', False)],
          'mstyrernes': [('mstyre', False)],
          'mstyrers': [('mstyre', False)],
          'mstyret': [('mstyre', False)],
          'mstyrets': [('mstyre', False)],
          'mstænger': [('mstang', False)],
          'mstængerne': [('mstang', False)],
          'mstængernes': [('mstang', False)],
          'mstængers': [('mstang', False)],
          'mtalens': [('mtale', False)],
          'mtaler': [('mtale', False)],
          'mtalerne': [('mtale', False)],
          'mtalernes': [('mtale', False)],
          'mtalers': [('mtale', False)],
          'mtallerne': [('mtal', False)],
          'mtallernes': [('mtal', False)],
          'mtammen': [('mtam', False)],
          'mtammens': [('mtam', False)],
          'mtammerne': [('mtam', False)],
          'mtammers': [('mtam', False)],
          'mtanke': [('mtanke', False)],
          'mtanken': [('mtanke', False)],
          'mtankens': [('mtanke', False)],
          'mtankes': [('mtanke', False)],
          'mtapper': [('mtap', False)],
          'mtapperne': [('mtap', False)],
          'mtappernes': [('mtap', False)],
          'mtappers': [('mtap', False)],
          'mtavlen': [('mtavle', False)],
          'mteater': [('mteater', False)],
          'mteaters': [('mteater', False)],
          'mten': [('mt', False)],
          'mtene': [('mt', False)],
          'mtenernes': [('mtener', False)],
          'mtenes': [('mt', False)],
          'mtens': [('mt', False)],
          'mter': [('mt', False)],
          'mterne': [('mt', False)],
          'mternes': [('mt', False)],
          'mters': [('mt', False)],
          'mtet': [('mt', False)],
          'mtets': [('mt', False)],
          'mtider': [('mtid', False)],
          'mtiderne': [('mtid', False)],
          'mtidernes': [('mtid', False)],
          'mtiders': [('mtid', False)],
          'mtids': [('mtid', False)],
          'mtoner': [('mtone', False)],
          'mtonerne': [('mtone', False)],
          'mtonernes': [('mtone', False)],
          'mtoners': [('mtone', False)],
          "mtops'": [('mtop', False)],
          'mts': [('mt', False)],
          'mturene': [('mtur', False)],
          'mturenes': [('mtur', False)],
          'mtykker': [('mtykke', False)],
          'mtykkerne': [('mtykke', False)],
          'mtænder': [('mtænder', False)],
          'mtænderne': [('mtænder', False)],
          'mtændernes': [('mtænder', False)],
          'mtænders': [('mtænder', False)],
          'muds': [('muds', False)],
          'muen': [('mu', False)],
          'muens': [('mu', False)],
          'muer': [('mu', False)],
          'muerne': [('mu', False)],
          'muernes': [('mu', False)],
          'muers': [('mu', False)],
          'muffen': [('muffe', False)],
          'muffens': [('muffe', False)],
          'muggen': [('mug', True)],
          'muggens': [('mug', True)],
          'mugler': [('mugler', False)],
          'muglerne': [('mugler', False)],
          'muglernes': [('mugler', False)],
          'muglers': [('mugler', False)],
          'mukken': [('muk', False)],
          'mukkerne': [('muk', False)],
          'mukkers': [('muk', False)],
          'mula': [('mula', False)],
          'mulans': [('mulans', False)],
          'mulas': [('mula', False)],
          'mulden': [('muld', False)],
          'mule': [('mule', False)],
          'mulen': [('mule', False)],
          'mulens': [('mule', False)],
          'mulers': [('mule', True)],
          'mules': [('mule', False)],
          'mulets': [('mulet', False)],
          'muletten': [('mulet', False)],
          'mulis': [('mulus', False)],
          'mullens': [('mulle', True)],
          'mullerne': [('mulle', True)],
          'mullernes': [('mulle', True)],
          'multen': [('multe', True), ('mult', True)],
          'multens': [('multe', True), ('mult', True)],
          'multer': [('multe', True)],
          'multerne': [('multe', True)],
          'multernes': [('multe', True)],
          'multers': [('multe', True)],
          'multet': [('mult', True)],
          'multets': [('mult', True)],
          'mulus': [('mulus', False)],
          'mum': [('mum', False)],
          'mumier': [('mumie', True)],
          'mumiers': [('mumie', True)],
          'mummen': [('mum', False)],
          'mummens': [('mum', False)],
          'mummernes': [('mum', False)],
          'mummers': [('mum', False)],
          'mums': [('mum', False)],
          'munde': [('mund', False)],
          'munden': [('mund', False)],
          'mundens': [('mund', False)],
          'mundes': [('mund', True)],
          'munen': [('mune', False)],
          'munens': [('mune', False)],
          'muner': [('mune', False)],
          'munernes': [('mune', False)],
          'munke': [('munk', False)],
          'munken': [('munk', True)],
          'munkens': [('munk', True)],
          'munker': [('munke', False)],
          'munkernes': [('munke', False)],
          'munkers': [('munke', False)],
          'munkes': [('munk', True)],
          'murer': [('murer', False)],
          'murerne': [('murer', True)],
          'murernes': [('murer', True)],
          'murers': [('murer', True)],
          'murs': [('mur', False)],
          'mus': [('mus', True)],
          'muse': [('muse', True)],
          'musen': [('muse', True), ('mus', True)],
          'musens': [('muse', True), ('mus', True)],
          'muser': [('muse', True)],
          'muserne': [('muse', True)],
          'musernes': [('muse', True)],
          'musers': [('muse', True)],
          'muses': [('muse', True)],
          'musket': [('musket', True)],
          'muskets': [('musket', True)],
          'mussen': [('mus', False)],
          'mussens': [('mus', False)],
          'musser': [('mus', False)],
          'musserne': [('mus', False)],
          'mutagens': [('mutagen', True)],
          'mutten': [('mut', False)],
          'muttens': [('mut', False)],
          'mutter': [('mutter', True)],
          'mutterne': [('mut', False)],
          'mutternes': [('mut', False)],
          'mutters': [('mutter', True), ('mutters', True)],
          'mvejens': [('mvej', False)],
          'mvi': [('mvie', False)],
          'mvien': [('mvie', False)],
          'mviens': [('mvie', False)],
          'mvier': [('mvie', False)],
          'mvierne': [('mvie', False)],
          'mviernes': [('mvie', False)],
          'mviers': [('mvie', False)],
          'mvinde': [('mvind', False)],
          'mvinden': [('mvind', False)],
          'mvindens': [('mvind', False)],
          'mvindes': [('mvind', False)],
          'mvinter': [('mvinter', False)],
          'mvis': [('mvie', False)],
          'mviser': [('mviser', False)],
          'mviserne': [('mviser', False)],
          'mvisernes': [('mviser', False)],
          'mvisers': [('mviser', False)],
          'mværet': [('mvær', False)],
          'mværets': [('mvær', False)],
          'mværs': [('mvær', False)],
          'mværternes': [('mvært', False)],
          'myds': [('myds', False)],
          'mydser': [('myds', False)],
          'mydserne': [('myds', False)],
          'mydsernes': [('myds', False)],
          'mydsers': [('myds', False)],
          'myen': [('my', False)],
          'myens': [('my', False)],
          'myer': [('my', False)],
          'myerne': [('my', False)],
          'myernes': [('my', False)],
          'myers': [('my', True)],
          'myggen': [('myg', True)],
          'myggens': [('myg', False)],
          'mykken': [('myk', False)],
          'mykker': [('myk', False)],
          'mykkerne': [('myk', False)],
          'mykkernes': [('mykke', False)],
          'mykkers': [('mykke', False)],
          'mykket': [('mykke', False)],
          'mykkets': [('mykke', False)],
          'mylder': [('mylder', True)],
          'mylders': [('mylder', True)],
          'mynder': [('mynde', True)],
          'mynderne': [('mynde', True)],
          'myndernes': [('mynde', True)],
          'mynders': [('mynde', True)],
          'mynter': [('mynte', False)],
          'myre': [('myre', False)],
          'myren': [('myr', True), ('myre', True)],
          'myrens': [('myre', True), ('myr', True)],
          'myrer': [('myr', True), ('myre', True)],
          'myrerne': [('myre', True), ('myr', True)],
          'myrernes': [('myr', True), ('myre', True)],
          'myrers': [('myr', True), ('myre', True)],
          'mys': [('my', True)],
          'mysen': [('myse', False)],
          'mysens': [('myse', False)],
          'myser': [('myse', False)],
          'myserne': [('myse', False)],
          'mysernes': [('myse', False)],
          'mysser': [('mysse', False)],
          'myssernes': [('mysse', False)],
          'myssers': [('mysse', False)],
          'mysteriet': [('mysterie', True)],
          'mysteriets': [('mysterie', True)],
          'myter': [('myte', True)],
          'myternes': [('myte', True)],
          'myters': [('myte', True)],
          'mytternes': [('myt', False)],
          'mytters': [('myt', False)],
          'myttet': [('myt', False)],
          'myttets': [('myt', False)],
          'måde': [('måde', False)],
          'måden': [('måde', False)],
          'mådens': [('måde', False)],
          'måders': [('måde', False)],
          'mådes': [('måde', False)],
          'måen': [('måen', False)],
          'måens': [('måen', False)],
          'måge': [('måge', False)],
          'mågen': [('måge', False)],
          'måger': [('måge', False)],
          'mågers': [('måge', False)],
          'målerne': [('måler', False)],
          'målernes': [('måler', False)],
          'målscorer': [('målscore', True), ('målscorer', True)],
          'målscorerne': [('målscorer', True), ('målscore', True)],
          'målscorernes': [('målscorer', True), ('målscore', True)],
          'målscorers': [('målscorer', True), ('målscore', True)],
          'månen': [('måne', True)],
          'månens': [('måne', False)],
          'måner': [('måne', False)],
          'månerne': [('måne', False)],
          'månernes': [('måne', False)],
          'måners': [('måne', False)],
          'måre': [('mår', False)],
          'måren': [('mår', False)],
          'mårens': [('mår', False)],
          'mårer': [('mår', False)],
          'mårerne': [('mår', True)],
          'mårernes': [('mår', True)],
          'mårers': [('mår', True)],
          'måres': [('mår', False)],
          'mås': [('mås', True)],
          'måtter': [('måtte', False)],
          'måtterne': [('måtte', True)],
          'mæer': [('mæ', False)],
          'mæerne': [('mæ', False)],
          'mæernes': [('mæ', False)],
          'mæers': [('mæer', False)],
          'mække': [('mæk', False)],
          'mækken': [('mæk', False)],
          'mækkes': [('mæk', False)],
          'mældenes': [('mæld', False)],
          'mælder': [('mælde', True)],
          'mælderne': [('mælde', True)],
          'mældernes': [('mælde', True)],
          'mælders': [('mælde', True)],
          'mældet': [('mæld', False)],
          'mældets': [('mæld', False)],
          'mæle': [('mæle', False)],
          'mæler': [('mæle', False)],
          'mælerne': [('mæle', False)],
          'mælernes': [('mæle', False)],
          'mælers': [('mæle', False)],
          'mæles': [('mæle', False)],
          'mælken': [('mælke', True), ('mælk', True)],
          'mælkens': [('mælke', True), ('mælk', True)],
          'mælkevejen': [('mælkevej', True), ('mælkevejen', True)],
          'mælkevejens': [('mælkevej', True), ('mælkevejen', True)],
          'mænd': [('mand', True)],
          'mændene': [('mand', True)],
          'mændenes': [('mand', True)],
          'mænds': [('mand', True)],
          'mæner': [('mæner', False)],
          'mænerne': [('mæne', False)],
          'mænernes': [('mæne', False)],
          'mæners': [('mæner', False)],
          'mænet': [('mæne', False)],
          'mænets': [('mæne', False)],
          'mænget': [('mæng', False)],
          'mængets': [('mæng', False)],
          'mære': [('mær', True)],
          'mæren': [('mær', True)],
          'mærens': [('mær', True)],
          'mærer': [('mære', False)],
          'mærerne': [('mære', False)],
          'mærernes': [('mære', False)],
          'mærers': [('mære', False)],
          'mæres': [('mær', True)],
          'mærkens': [('mærke', True)],
          'mærker': [('mærke', False)],
          'mærkerne': [('mærke', True)],
          'mærkernes': [('mærke', True)],
          'mærkers': [('mærke', True)],
          'mærs': [('mær', True), ('mærs', True)],
          'mæs': [('mæ', False)],
          'mæsken': [('mæsk', True)],
          'mæskens': [('mæsk', True)],
          'mæslinger': [('mæslinger', True)],
          'mæslingerne': [('mæslinger', True)],
          'mæslingernes': [('mæslinger', True)],
          'mæslingers': [('mæslinger', True)],
          'møberne': [('møbe', False)],
          'møbers': [('møbe', False)],
          'møder': [('møde', True)],
          'møderne': [('møde', True)],
          'mødernes': [('møde', True)],
          'møders': [('møde', False)],
          'mødet': [('møde', False)],
          'mødets': [('møde', False)],
          'møen': [('mø', False)],
          'møens': [('mø', True)],
          'møer': [('mø', True)],
          'møerne': [('mø', False)],
          'møers': [('mø', True)],
          'møge': [('møge', False)],
          'møges': [('møge', False)],
          'møje': [('møje', True)],
          'møjen': [('møje', True)],
          'møjens': [('møje', True)],
          'møjes': [('møje', True)],
          'mølet': [('møl', False)],
          'møllen': [('mølle', False)],
          'møllens': [('mølle', False)],
          'møller': [('møller', True), ('mølle', True)],
          'møllerne': [('møller', True), ('mølle', True)],
          'møllernes': [('møller', True), ('mølle', True)],
          'møllers': [('møller', True), ('mølle', True)],
          'møre': [('møre', False)],
          'møren': [('møre', False)],
          'mørens': [('mør', False)],
          'mører': [('møre', False)],
          'mørerne': [('møre', False)],
          'mørers': [('møre', False)],
          'møres': [('møre', False)],
          'møret': [('mør', False)],
          'mørets': [('møre', False)],
          'mørtler': [('mørtel', True)],
          'møs': [('mø', True)],
          'n': [('n', True)],
          "n'erne": [('n', True)],
          'n.': [('n.', False)],
          'na': [('na', False)],
          'nabe': [('nabe', False)],
          'naben': [('nabe', False)],
          'nabens': [('nabe', False)],
          'nabernes': [('nabe', False)],
          'nabers': [('nabe', False)],
          'nabes': [('nabe', False)],
          'nabler': [('nabel', False)],
          'nablerne': [('nabel', False)],
          'nablernes': [('nabel', False)],
          'nablers': [('nabel', False)],
          'nacer': [('nac', False)],
          'nacerne': [('nac', False)],
          'nacernes': [('nac', False)],
          'nacers': [('nac', False)],
          'nachos': [('nachos', True)],
          'nacks': [('nack', False)],
          "nacks'": [('nack', False)],
          'nadder': [('nadder', False)],
          'nadders': [('nadder', False)],
          'nade': [('nade', False)],
          'naden': [('nade', False)],
          'nadens': [('nade', False)],
          'naderer': [('nader', False)],
          'naderers': [('nader', False)],
          'naderne': [('nade', False)],
          'naders': [('nade', False)],
          'nades': [('nade', False)],
          'nadier': [('nadier', False)],
          'nadiers': [('nadier', False)],
          'nados': [('nado', False)],
          'naen': [('na', False)],
          'naens': [('na', False)],
          'naer': [('na', False)],
          'naerne': [('na', False)],
          'naernes': [('na', False)],
          'naers': [('na', False)],
          'naftalen': [('naftalen', True)],
          'naftalens': [('naftalen', True)],
          'nage': [('nage', False)],
          'nagen': [('nage', False)],
          'nagens': [('nage', False)],
          'nager': [('nage', False)],
          'nages': [('nage', False)],
          'naglens': [('nagle', False)],
          'nagler': [('nagle', False)],
          'naglerne': [('nagle', False)],
          'nagogen': [('nagoge', False)],
          'nagogens': [('nagoge', False)],
          'nagoger': [('nagoge', False)],
          'nagogerne': [('nagoge', False)],
          'nagogernes': [('nagoge', False)],
          'nagogers': [('nagoge', False)],
          'naidens': [('naide', False)],
          'naiser': [('naise', False)],
          'naisers': [('naise', False)],
          'nakke': [('nakke', True)],
          'nakken': [('nakke', True)],
          'nakkens': [('nakke', False)],
          'nakker': [('nakke', False)],
          'nakkerne': [('nakke', True)],
          'nakkernes': [('nakke', True)],
          'nakkers': [('nakke', False)],
          'nakkes': [('nakke', True)],
          'naklen': [('nakel', False)],
          'nakler': [('nakel', False)],
          'naklerne': [('nakel', False)],
          'naklernes': [('nakel', False)],
          'naklers': [('nakel', False)],
          'naks': [('nak', False)],
          'nakter': [('nakt', False)],
          'nakterne': [('nakter', False)],
          'nakternes': [('nakter', False)],
          'nakters': [('nakt', False)],
          'nalden': [('nald', False)],
          'naldens': [('nald', False)],
          'nalder': [('nald', False)],
          'nalderne': [('nald', False)],
          'naldernes': [('nald', False)],
          'nalders': [('nald', False)],
          'nale': [('nale', False)],
          'nalens': [('nal', False)],
          'nales': [('nale', False)],
          'nalias': [('nalia', False)],
          'naller': [('naller', True)],
          'nallerne': [('naller', True)],
          'nallernes': [('naller', True)],
          'namaner': [('namaner', False)],
          'namenter': [('nament', False)],
          'namenterne': [('nament', False)],
          'namentet': [('nament', False)],
          'namentets': [('nament', False)],
          'namer': [('namer', False)],
          'namerne': [('namer', False)],
          'namernes': [('namer', False)],
          'namers': [('namer', False)],
          'namier': [('nami', False)],
          'namierne': [('nami', False)],
          'namiernes': [('nami', False)],
          'namiers': [('nami', False)],
          'nanas': [('nanas', False)],
          'nanden': [('nand', False)],
          'nanderne': [('nand', False)],
          'nandernes': [('nand', False)],
          'nanders': [('nand', False)],
          'nanen': [('nan', False)],
          'nanens': [('nan', False)],
          'naner': [('nan', False)],
          'nanerne': [('nan', False)],
          'nanernes': [('nan', False)],
          'naners': [('nan', False)],
          'nanien': [('nani', False)],
          'naniens': [('nani', False)],
          'nanis': [('nani', False)],
          'nanister': [('nanist', False)],
          'nanisters': [('nanist', False)],
          'nans': [('nans', False)],
          "nans'": [('nans', False)],
          'nansen': [('nans', False)],
          'nansens': [('nans', False)],
          'nanser': [('nans', False)],
          'nansers': [('nans', False)],
          'nanten': [('nant', False)],
          'nantens': [('nant', False)],
          'nanter': [('nante', False)],
          'nanterne': [('nant', False)],
          'nanternes': [('nant', False)],
          'nanters': [('nant', False)],
          'nants': [('nant', False)],
          'nappen': [('nap', False)],
          'nappens': [('nap', False)],
          'napper': [('nap', False)],
          'napperne': [('napper', False)],
          'nappernes': [('napper', False)],
          'nappers': [('nap', False)],
          'naps': [('nap', True)],
          "naps'": [('naps', False)],
          'napse': [('naps', False)],
          'napsen': [('naps', False)],
          'napsens': [('naps', False)],
          'napsers': [('napse', False)],
          'napses': [('naps', False)],
          'naradiser': [('naradise', False)],
          'naradiserne': [('naradise', False)],
          'naradisernes': [('naradise', False)],
          'naradisers': [('naradise', False)],
          'narbejder': [('narbejder', False)],
          'narbejders': [('narbejder', False)],
          'naren': [('nare', False)],
          'narens': [('nare', False)],
          'narer': [('nare', False)],
          'narerne': [('nar', False)],
          'narernes': [('nare', False)],
          'narers': [('nar', False)],
          'narier': [('narie', False)],
          'narierne': [('narie', False)],
          'nariernes': [('narie', False)],
          'nariers': [('narie', False)],
          'narinen': [('narine', False)],
          'narinens': [('narine', False)],
          'narinerne': [('narine', False)],
          'narinernes': [('narine', False)],
          'nario': [('narie', False)],
          'narioer': [('narie', False)],
          'narioerne': [('narie', False)],
          'narioernes': [('narie', False)],
          'narioers': [('narie', False)],
          'narios': [('narie', False)],
          'narium': [('narie', False)],
          'nariums': [('narie', False)],
          'narkerne': [('nark', False)],
          'narre': [('nar', False)],
          'narren': [('nar', True)],
          'narrens': [('nar', True)],
          'narrer': [('narr', False)],
          'narrerne': [('narr', False)],
          'narrernes': [('narr', False)],
          'narrers': [('narre', False)],
          'narres': [('nar', True)],
          'narten': [('nart', False)],
          'nartens': [('nart', False)],
          'narven': [('narv', True)],
          'narvens': [('narv', True)],
          'nas': [('nas', True)],
          'nasen': [('nas', False)],
          'nasens': [('nas', False)],
          'naserne': [('nas', False)],
          'nasien': [('nasi', False)],
          'nasiens': [('nasi', False)],
          'nasiet': [('nasie', False)],
          'nasiets': [('nasie', False)],
          'nasis': [('nasi', False)],
          'nasken': [('nask', False)],
          'naskens': [('nask', False)],
          'nasker': [('nask', False)],
          'naskerne': [('nask', False)],
          'naskernes': [('nask', False)],
          'naskers': [('nask', False)],
          'nasket': [('nask', False)],
          'naskets': [('nask', False)],
          'nassen': [('nas', False)],
          'nassens': [('nas', False)],
          'nasser': [('nasser', True)],
          'nasserne': [('nasser', True)],
          'nassernes': [('nasser', True)],
          'nassers': [('nasser', True)],
          'nasten': [('nast', False)],
          'nastens': [('nast', False)],
          'naster': [('nast', False)],
          'nasterne': [('nast', False)],
          'nasternes': [('nast', False)],
          'nasters': [('nast', False)],
          'nastiks': [('nastik', False)],
          'naten': [('nate', False)],
          'natens': [('nate', False)],
          'naternes': [('nat', False)],
          'nates': [('nate', False)],
          'natinen': [('natine', False)],
          'natinens': [('natine', False)],
          'natiner': [('natine', False)],
          'natinernes': [('natine', False)],
          'natiners': [('natine', False)],
          'natorier': [('natorie', False)],
          'natorierne': [('natorium', False)],
          'natoriernes': [('natorie', False)],
          'natoriers': [('natorium', False)],
          'natoriet': [('natorium', False)],
          'natoriets': [('natorium', False)],
          'natorium': [('natorie', False)],
          'natoriums': [('natorie', False)],
          'natronen': [('natron', True)],
          'natronens': [('natron', True)],
          'natten': [('nat', False)],
          'nattens': [('nat', True)],
          'nauterne': [('naut', False)],
          'nauternes': [('naut', False)],
          'navene': [('nav', False)],
          'navenes': [('nav', False)],
          'naver': [('naver', True)],
          'naverne': [('naver', True)],
          'navernes': [('naver', True)],
          'navers': [('naver', True)],
          'navet': [('nav', False)],
          'navlen': [('navle', True)],
          'navlens': [('navle', True)],
          'navler': [('navle', True)],
          'navlerne': [('navle', True)],
          'navlernes': [('navle', True)],
          'navlers': [('navle', True)],
          'navne': [('navn', False)],
          'navnes': [('navn', False)],
          'navre': [('navr', True)],
          'navs': [('nav', True)],
          'nbanken': [('nbank', False)],
          'nbankens': [('nbank', False)],
          'nbanker': [('nbank', False)],
          'nbankerne': [('nbank', False)],
          'nbankernes': [('nbank', False)],
          'nbankers': [('nbank', False)],
          'nbassen': [('nbasse', False)],
          'nbassens': [('nbasse', False)],
          'nbasser': [('nbasse', False)],
          'nbasserne': [('nbasse', False)],
          'nbassernes': [('nbasse', False)],
          'nbassers': [('nbasse', False)],
          'nbede': [('nbed', False)],
          'nbedes': [('nbed', False)],
          'nbedet': [('nbed', False)],
          'nbenets': [('nben', False)],
          'nbilen': [('nbil', False)],
          'nbilens': [('nbil', False)],
          'nbilerne': [('nbil', False)],
          'nbilernes': [('nbil', False)],
          'nbilers': [('nbil', False)],
          'nboer': [('nbo', False)],
          'nboerne': [('nbo', False)],
          'nboernes': [('nbo', False)],
          'nboers': [('nbo', False)],
          'nbomber': [('nbombe', False)],
          'nbomberne': [('nbombe', False)],
          'nbombernes': [('nbombe', False)],
          'nbombers': [('nbombe', False)],
          'nbondens': [('nbonde', False)],
          'nbonen': [('nbon', False)],
          'nbonens': [('nbon', False)],
          'nborgen': [('nborg', False)],
          'nborgens': [('nborg', False)],
          'nbroder': [('nbroder', False)],
          'nbroderen': [('nbroder', False)],
          'nbroderens': [('nbroder', False)],
          'nbroders': [('nbroder', False)],
          'nbroers': [('nbro', False)],
          'nbrugs': [('nbrug', False)],
          'nbrødre': [('nbroder', False)],
          'nbrødrene': [('nbroder', False)],
          'nbrødrenes': [('nbroder', False)],
          'nbrødres': [('nbroder', False)],
          'nbuen': [('nbue', False)],
          'nbuens': [('nbue', False)],
          'nbuerne': [('nbue', False)],
          'nbuks': [('nbuk', False)],
          'nburets': [('nbur', False)],
          'nbyrden': [('nbyrd', False)],
          'nbyrdens': [('nbyrd', False)],
          'nbønnen': [('nbøn', False)],
          'nbønnens': [('nbøn', False)],
          'nbønner': [('nbøn', False)],
          'nbønnerne': [('nbøn', False)],
          'nbønnernes': [('nbøn', False)],
          'nbønners': [('nbøn', False)],
          'ncaner': [('ncan', False)],
          'ncanerne': [('ncan', False)],
          'ncanernes': [('ncan', False)],
          'ncaners': [('ncan', False)],
          'ncellen': [('ncel', False)],
          'ncellens': [('ncel', False)],
          'nceller': [('ncel', False)],
          'ncellerne': [('ncel', False)],
          'ncellernes': [('ncel', False)],
          'ncellers': [('ncel', False)],
          'ncene': [('nce', False)],
          'ncenes': [('nce', False)],
          'ncenter': [('ncenter', False)],
          'ncentre': [('ncenter', False)],
          'ncentrene': [('ncenter', False)],
          'ncentrenes': [('ncenter', False)],
          'ncentres': [('ncenter', False)],
          'ncentret': [('ncenter', False)],
          'ncentrets': [('ncenter', False)],
          'ncepter': [('ncept', False)],
          'ncernerne': [('ncern', False)],
          'ncerners': [('ncern', False)],
          'nces': [('nce', False)],
          "nces'": [('nce', False)],
          'ncet': [('ncet', False)],
          'nche': [('nche', False)],
          'ncher': [('ncher', False)],
          'ncherne': [('ncher', False)],
          'nchernes': [('ncher', False)],
          'nchers': [('ncher', False)],
          'nches': [('nche', False)],
          'nchet': [('nchet', False)],
          'nchets': [('nchet', False)],
          'nchisen': [('nchise', False)],
          'nchisens': [('nchise', False)],
          'nchos': [('ncho', False)],
          'nd': [('nd', False)],
          "nd'er": [('nd', False)],
          'ndaene': [('ndum', False)],
          'ndaenes': [('ndum', False)],
          'ndage': [('ndag', False)],
          'ndagen': [('ndag', False)],
          'ndagene': [('ndag', False)],
          'ndagenes': [('ndag', False)],
          'ndagerne': [('ndage', False)],
          'ndagernes': [('ndage', False)],
          'ndagers': [('ndage', False)],
          'ndages': [('ndag', False)],
          'ndale': [('ndale', False)],
          'ndales': [('ndale', False)],
          'ndancer': [('ndance', False)],
          'ndancerne': [('ndance', False)],
          'ndancernes': [('ndance', False)],
          'ndancers': [('ndance', False)],
          'ndanser': [('ndans', False)],
          'ndanserne': [('ndans', False)],
          'ndansernes': [('ndans', False)],
          'ndansers': [('ndans', False)],
          'ndanter': [('ndant', False)],
          'ndarbejder': [('ndarbejde', False)],
          'ndarbejderne': [('ndarbejde', False)],
          'ndarbejdernes': [('ndarbejder', False)],
          'ndarbejders': [('ndarbejder', False)],
          'ndarer': [('ndar', False)],
          'ndarernes': [('ndar', False)],
          'ndater': [('ndat', False)],
          'ndaterne': [('ndat', False)],
          'ndaters': [('ndat', False)],
          'ndats': [('ndat', False)],
          'ndbo': [('ndbo', False)],
          'ndboers': [('ndboer', False)],
          'ndbos': [('ndbo', False)],
          'ndbørs': [('ndbørs', False)],
          'nddele': [('nddel', False)],
          'nddelenes': [('nddel', False)],
          'nddeles': [('nddel', False)],
          'nddækket': [('nddække', False)],
          'nddækkets': [('nddække', False)],
          'ndedage': [('ndedag', False)],
          'ndedagene': [('ndedag', False)],
          'ndedagenes': [('ndedag', False)],
          'ndedages': [('ndedag', False)],
          'ndellen': [('ndel', False)],
          'ndellens': [('ndel', False)],
          'ndeller': [('ndel', False)],
          'ndellerne': [('ndel', False)],
          'ndellernes': [('ndel', False)],
          'ndellers': [('ndel', False)],
          'ndemens': [('ndem', False)],
          'ndemoder': [('ndemode', False)],
          'ndemoderne': [('ndemode', False)],
          'ndemodernes': [('ndemode', False)],
          'ndene': [('nd', False)],
          'ndenes': [('nd', False)],
          'ndenser': [('ndenser', False)],
          'ndenserne': [('ndens', False)],
          'ndensernes': [('ndenser', False)],
          'ndensers': [('ndenser', False)],
          'ndenten': [('ndent', False)],
          'ndentens': [('ndent', False)],
          'ndenter': [('ndent', False)],
          'ndenterne': [('ndent', False)],
          'ndenternes': [('ndent', False)],
          'ndenters': [('ndent', False)],
          'ndere': [('nder', False)],
          'nderen': [('nder', False)],
          'nderens': [('nder', False)],
          'nderes': [('nder', False)],
          'nderet': [('nder', False)],
          'nderets': [('nder', False)],
          'nderhandlernes': [('nderhandler', False)],
          'nderkurser': [('nderkurs', False)],
          'nderkurserne': [('nderkurs', False)],
          'nderkursernes': [('nderkursus', False)],
          'nderkursers': [('nderkurs', False)],
          'ndertaler': [('ndertaler', False)],
          'ndertalerne': [('ndertale', False)],
          'ndertalernes': [('ndertaler', False)],
          'ndertalers': [('ndertale', False)],
          'ndesten': [('ndesten', False)],
          'ndestens': [('ndest', False)],
          'ndet': [('nd', False)],
          'ndets': [('nd', False)],
          'ndfaren': [('ndfare', False)],
          'ndfarens': [('ndfare', False)],
          'ndgydernes': [('ndgyde', False)],
          'ndgyders': [('ndgyde', False)],
          'ndhandlerne': [('ndhandel', False)],
          'ndhave': [('ndhav', False)],
          'ndhuens': [('ndhue', False)],
          'ndianer': [('ndianer', False)],
          'ndianers': [('ndianer', False)],
          'ndiaternes': [('ndiat', False)],
          'ndies': [('ndie', False)],
          'ndiks': [('ndiks', False)],
          'ndiner': [('ndine', False)],
          'ndinerne': [('ndine', False)],
          'ndiners': [('ndine', False)],
          'ndis': [('ndis', False)],
          'ndisen': [('ndise', False)],
          'ndisens': [('ndise', False)],
          'ndiser': [('ndiser', False)],
          'ndiserne': [('ndiser', False)],
          'ndisernes': [('ndiser', False)],
          'ndiskos': [('ndisko', False)],
          'ndissens': [('ndis', False)],
          'ndissers': [('ndis', False)],
          'nditten': [('ndit', False)],
          'ndium': [('ndium', False)],
          'ndiums': [('ndium', False)],
          'ndiver': [('ndiv', False)],
          'ndivernes': [('ndiv', False)],
          'ndlens': [('ndel', False)],
          'ndler': [('ndel', False)],
          'ndlers': [('ndel', False)],
          'ndlet': [('ndel', False)],
          'ndlets': [('ndel', False)],
          'ndolens': [('ndol', False)],
          'ndoler': [('ndoler', False)],
          'ndolers': [('ndol', False)],
          'ndomme': [('ndom', False)],
          'ndoner': [('ndoner', False)],
          'ndonerne': [('ndoner', False)],
          'ndonernes': [('ndoner', False)],
          'ndoners': [('ndoner', False)],
          'ndoren': [('ndor', False)],
          'ndorens': [('ndor', False)],
          'ndorer': [('ndor', False)],
          'ndorerne': [('ndor', False)],
          'ndorernes': [('ndor', False)],
          'ndorers': [('ndor', False)],
          'ndpakkerne': [('ndpakker', False)],
          'ndrager': [('ndrager', False)],
          'ndragerne': [('ndrager', False)],
          'ndragernes': [('ndrager', False)],
          'ndragers': [('ndrager', False)],
          'ndramme': [('ndramme', False)],
          'ndrammen': [('ndramme', False)],
          'ndrammens': [('ndramme', False)],
          'ndrammer': [('ndramme', False)],
          'ndrammerne': [('ndramme', False)],
          'ndrammernes': [('ndramme', False)],
          'ndrammers': [('ndramme', False)],
          'ndrammes': [('ndramme', False)],
          'ndras': [('ndra', False)],
          'ndredes': [('ndred', False)],
          'ndren': [('ndren', False)],
          'ndrene': [('nder', False)],
          'ndrenes': [('nder', False)],
          'ndrers': [('ndrer', False)],
          'ndres': [('nder', False)],
          'ndret': [('ndret', False)],
          'ndrets': [('ndret', False)],
          'ndrids': [('ndrids', False)],
          'ndriet': [('ndri', False)],
          'ndriets': [('ndri', False)],
          'ndrikkerne': [('ndrik', False)],
          'ndrikkers': [('ndrik', False)],
          'ndrillen': [('ndril', False)],
          'ndriller': [('ndril', False)],
          'ndrillerne': [('ndril', False)],
          'ndrillernes': [('ndril', False)],
          'ndris': [('ndri', False)],
          'ndronen': [('ndron', False)],
          'ndronens': [('ndron', False)],
          'ndroner': [('ndron', False)],
          'ndronerne': [('ndron', False)],
          'ndronernes': [('ndron', False)],
          'ndroners': [('ndron', False)],
          'ndrops': [('ndrop', False)],
          'ndrotten': [('ndrotte', False)],
          'ndrottens': [('ndrotte', False)],
          'ndrotter': [('ndrotte', False)],
          'ndrotterne': [('ndrotte', False)],
          'ndrotternes': [('ndrotte', False)],
          'ndrotters': [('ndrotte', False)],
          'ndråber': [('ndråber', False)],
          'ndråberne': [('ndråber', False)],
          'ndråbernes': [('ndråber', False)],
          'ndråbers': [('ndråber', False)],
          'nds': [('nd', False)],
          "nds'": [('nd', False)],
          'ndsarbejder': [('ndsarbejder', False)],
          'ndsarbejderne': [('ndsarbejder', False)],
          'ndsarbejdernes': [('ndsarbejder', False)],
          'ndsbombernes': [('ndsbombe', False)],
          'ndsbombers': [('ndsbombe', False)],
          'ndsdage': [('ndsdag', False)],
          'ndsdagene': [('ndsdag', False)],
          'ndsdagenes': [('ndsdag', False)],
          'ndsdages': [('ndsdag', False)],
          'ndsens': [('ndsens', False)],
          'ndskreds': [('ndskreds', False)],
          'ndsskiftets': [('ndsskifte', False)],
          'ndsteder': [('ndsted', False)],
          'ndstederne': [('ndsted', False)],
          'ndstedernes': [('ndsted', False)],
          'ndsteders': [('ndsted', False)],
          'ndstikkens': [('ndstik', False)],
          'ndstikkernes': [('ndstik', False)],
          'ndstykker': [('ndstykke', False)],
          'ndstykkerne': [('ndstykke', False)],
          'ndsuger': [('ndsuger', False)],
          'ndsugerne': [('ndsuger', False)],
          'ndsugernes': [('ndsuger', False)],
          'ndsugers': [('ndsuger', False)],
          'ndten': [('ndten', False)],
          'ndtene': [('ndten', False)],
          'ndtenes': [('ndten', False)],
          'ndtens': [('ndten', False)],
          'ndtimer': [('ndtime', False)],
          'ndtimerne': [('ndtime', False)],
          'ndtimernes': [('ndtime', False)],
          'ndtropper': [('ndtropper', False)],
          'ndtropperne': [('ndtropper', False)],
          'ndtroppernes': [('ndtropper', False)],
          'ndtroppers': [('ndtropper', False)],
          'nduen': [('ndu', False)],
          'nduens': [('ndu', False)],
          'nduer': [('ndue', False)],
          'nduerne': [('ndue', False)],
          'nduernes': [('ndue', False)],
          'nduers': [('ndue', False)],
          'nduet': [('ndue', False)],
          'nduets': [('ndue', False)],
          'ndupper': [('ndupper', False)],
          'ndupperne': [('ndupper', False)],
          'nduppernes': [('ndupper', False)],
          'nduppers': [('ndupper', False)],
          'ndure': [('ndur', False)],
          'ndures': [('ndur', False)],
          'ndus': [('ndu', False)],
          'ndvandet': [('ndvand', False)],
          'ndvandets': [('ndvand', False)],
          'ndviser': [('ndviser', False)],
          'ndviserne': [('ndviser', False)],
          'ndvisernes': [('ndviser', False)],
          'ndvisers': [('ndviser', False)],
          'ndværker': [('ndværk', False)],
          'ndværkerne': [('ndværk', False)],
          'ndværkernes': [('ndværk', False)],
          'ndværkers': [('ndværk', False)],
          'ndækket': [('ndæk', False)],
          'ndækkets': [('ndæk', False)],
          'ndømmer': [('ndømme', False)],
          'ndømmerne': [('ndømme', False)],
          'ndører': [('ndør', False)],
          'ndørerne': [('ndører', False)],
          'ndørernes': [('ndører', False)],
          'ndørers': [('ndør', False)],
          'ne': [('ne', False)],
          'nealer': [('neal', False)],
          'nealerne': [('neal', False)],
          'nealernes': [('neal', False)],
          'nealers': [('neal', False)],
          'neanerne': [('neaner', False)],
          'neanernes': [('neaner', False)],
          'nearbejder': [('nearbejde', False)],
          'nearbejderne': [('nearbejde', False)],
          'nearbejdernes': [('nearbejder', False)],
          'nearbejders': [('nearbejder', False)],
          'nebens': [('neben', False)],
          'neboer': [('nebo', False)],
          'neboerne': [('nebo', False)],
          'neboernes': [('neboer', False)],
          'neboers': [('nebo', False)],
          'nebroderens': [('nebror', False)],
          'nebroerne': [('nebro', False)],
          'nebroernes': [('nebro', False)],
          'nebrødre': [('nebror', False)],
          'nebrødrene': [('nebror', False)],
          'nebrødrenes': [('nebror', False)],
          'nebrødres': [('nebror', False)],
          'nebus': [('nebus', False)],
          'nedagens': [('nedag', False)],
          'nedans': [('nedans', False)],
          'nedanserne': [('nedanser', False)],
          'nedder': [('nedder', False)],
          'nedders': [('nedder', False)],
          'neden': [('ned', False)],
          'nedens': [('ned', False)],
          'neder': [('neder', False)],
          'nederne': [('neder', False)],
          'nedernes': [('neder', False)],
          'neders': [('neder', False)],
          'nedes': [('net', False)],
          'neen': [('ne', False)],
          'neens': [('ne', False)],
          'nefader': [('nefar', False)],
          'nefaderen': [('nefar', False)],
          'nefaderens': [('nefar', False)],
          'nefaders': [('nefar', False)],
          'nefaren': [('nefar', False)],
          'nefædrene': [('nefar', False)],
          'nefædres': [('nefar', False)],
          'nege': [('nege', False)],
          'negen': [('nege', False)],
          'negens': [('nege', False)],
          'neger': [('neger', True)],
          'negerne': [('neger', True)],
          'negernes': [('neger', True)],
          'negers': [('neger', True)],
          'neges': [('nege', False)],
          'negle': [('negl', False)],
          'neglen': [('negl', False)],
          'negles': [('negl', False)],
          'nehals': [('nehals', False)],
          'nehandler': [('nehandel', False)],
          'nehandlers': [('nehandel', False)],
          'nehaver': [('nehave', False)],
          'nehaverne': [('nehave', False)],
          'nehavernes': [('nehave', False)],
          'nehavers': [('nehave', False)],
          'nehaves': [('nehave', False)],
          'neje': [('neje', False)],
          'nejer': [('nej', True)],
          'nejerne': [('nej', True)],
          'nejernes': [('nej', True)],
          'nejers': [('nej', True)],
          'nejes': [('neje', False)],
          'nejet': [('nej', True)],
          'nejets': [('nej', True)],
          'nejs': [('nej', True)],
          'nejsen': [('nejs', False)],
          'nejsens': [('nejs', False)],
          'nekker': [('nekke', False)],
          'nekkernes': [('nekke', False)],
          'nekkers': [('nekke', False)],
          'nekserne': [('neks', False)],
          'neksernes': [('neks', False)],
          'neksers': [('neks', False)],
          'nekursers': [('nekurs', False)],
          'neler': [('neler', False)],
          'nelerne': [('nel', False)],
          'nelers': [('neler', False)],
          'nelets': [('nel', False)],
          'nelisten': [('nelist', False)],
          'nelistens': [('nelist', False)],
          'nelister': [('nelist', False)],
          'nelisterne': [('nelist', False)],
          'nelle': [('nelle', False)],
          'nellen': [('nel', False)],
          'nellens': [('nelle', False)],
          'neller': [('nel', False)],
          'nellerne': [('nelle', False)],
          'nellernes': [('nelle', False)],
          'nellers': [('nel', False)],
          'nelles': [('nelle', False)],
          'nelliker': [('nellike', True)],
          'nellikerne': [('nellike', True)],
          'nellikernes': [('nellike', True)],
          'nellikers': [('nellike', False)],
          'nelsers': [('nelse', False)],
          'nelures': [('nelure', False)],
          'nelærerne': [('nelærer', False)],
          'nelærernes': [('nelærer', False)],
          'nemagerne': [('nemager', False)],
          'nemagernes': [('nemager', False)],
          'nemagers': [('nemager', False)],
          'nemaler': [('nemaler', False)],
          'nemalerne': [('nemaler', False)],
          'nemalernes': [('nemaler', False)],
          'nemalers': [('nemaler', False)],
          'nemanden': [('nemand', False)],
          'nemandens': [('nemand', False)],
          'nemarchen': [('nemarch', False)],
          'nemarcher': [('nemarch', False)],
          'nemarchernes': [('nemarch', False)],
          'nemoder': [('nemor', False)],
          'nemos': [('nemos', False)],
          'nemærker': [('nemærke', False)],
          'nen': [('ne', False)],
          'nenderne': [('nende', False)],
          'nene': [('', False)],
          'nenes': [('en', False)],
          'nens': [('ne', False)],
          "nens'": [('nens', False)],
          'nensen': [('nens', False)],
          'nensens': [('nens', False)],
          'nenser': [('nens', False)],
          'nensernes': [('nens', False)],
          'nensers': [('nens', False)],
          'nenten': [('nent', False)],
          'nentens': [('nent', False)],
          'nenter': [('nent', False)],
          'nenterne': [('nent', False)],
          'nenternes': [('nent', False)],
          'nenters': [('nent', False)],
          'nentet': [('nent', False)],
          'nentets': [('nent', False)],
          'neol': [('neol', False)],
          'neolen': [('neol', False)],
          'neolens': [('neol', False)],
          'neoler': [('neol', False)],
          'neolernes': [('neol', False)],
          'neolers': [('neol', False)],
          'neols': [('neol', False)],
          'neoner': [('neon', False)],
          'neonerne': [('neon', False)],
          'neonernes': [('neon', False)],
          'neoners': [('neon', False)],
          'neppen': [('nep', False)],
          'neppens': [('nep', False)],
          'nepper': [('neppe', False)],
          'nepperne': [('nep', False)],
          'neppernes': [('neppe', False)],
          'neppers': [('nepper', False)],
          'neprisens': [('nepris', False)],
          'nepriser': [('nepris', False)],
          'nepriserne': [('nepris', False)],
          'neprisernes': [('nepris', False)],
          'nera': [('nus', False)],
          'neraberne': [('nerabe', False)],
          'neralier': [('neralier', False)],
          'neras': [('nus', False)],
          'nerenter': [('nerente', False)],
          'nerenters': [('nerente', False)],
          'neret': [('neret', False)],
          'nerets': [('neret', False)],
          'neretten': [('neret', False)],
          'nerettens': [('neret', False)],
          'nerier': [('nerie', True)],
          'nerierne': [('nerie', True)],
          'neriernes': [('nerie', True)],
          'neriers': [('nerie', True)],
          'neriet': [('neri', False)],
          'neriets': [('neri', False)],
          'neris': [('neri', False)],
          'nerpernes': [('nerpe', False)],
          'nerpers': [('nerpe', False)],
          'nerpes': [('nerpe', False)],
          'nerren': [('nerre', False)],
          'nerrens': [('nerre', False)],
          'ners': [('ner', False)],
          'nersken': [('nerske', False)],
          'nersker': [('nerske', False)],
          'nerskerne': [('nerske', False)],
          'nerskers': [('nerske', False)],
          'nerten': [('nert', False)],
          'nertens': [('nert', False)],
          'nerter': [('nert', False)],
          'nerterne': [('nert', False)],
          'nerters': [('nert', False)],
          'nerts': [('nert', False)],
          'nerture': [('nertur', False)],
          'nerturen': [('nertur', False)],
          'nertures': [('nertur', False)],
          'nerves': [('nerve', False)],
          'nes': [('ne', False)],
          "nes'": [('ne', False)],
          'nesager': [('nesag', False)],
          'nesagerne': [('nesag', False)],
          'nese': [('nese', False)],
          'nesen': [('nese', False)],
          'nesene': [('ne', False)],
          'nesenes': [('ne', False)],
          'nesens': [('nese', False)],
          'neser': [('nese', False)],
          'neserier': [('neserie', False)],
          'neserierne': [('neserie', False)],
          'neseriernes': [('neserie', False)],
          'neseriers': [('neseri', False)],
          'neserne': [('nese', False)],
          'nesernes': [('nese', False)],
          'nesers': [('neser', False)],
          'neses': [('nese', False)],
          'nesier': [('nesier', False)],
          'nesierne': [('nesi', False)],
          'nesiernes': [('nesi', False)],
          'nesiers': [('nesi', False)],
          'nesis': [('nesi', False)],
          'neskeden': [('neskede', False)],
          'neskedens': [('neskede', False)],
          'neskene': [('neske', False)],
          'neskernes': [('neske', False)],
          'neskifters': [('neskift', False)],
          'nespiller': [('nespiller', False)],
          'nessen': [('ness', False)],
          'nessens': [('ness', False)],
          'nesser': [('nesse', False)],
          'nesserne': [('nesse', False)],
          'nessernes': [('nesse', False)],
          'nessers': [('nesse', False)],
          'nestagen': [('nestage', False)],
          'nestagens': [('nestage', False)],
          'nesten': [('neste', False)],
          'nestene': [('nesten', False)],
          'nestens': [('nesten', False)],
          'nester': [('neste', False)],
          'nesterne': [('neste', False)],
          'nesternes': [('neste', False)],
          'nesters': [('neste', False)],
          'nestier': [('nesti', False)],
          'nestiernes': [('nesti', False)],
          'nestyrers': [('nestyre', False)],
          'net': [('net', False)],
          'netaler': [('netale', False)],
          'netalers': [('netale', False)],
          'netanke': [('netank', False)],
          'neter': [('net', False)],
          'neterne': [('neter', False)],
          'neternes': [('neter', False)],
          'neters': [('net', False)],
          'netiden': [('netid', False)],
          'nets': [('net', True)],
          'netten': [('net', False)],
          'nettens': [('net', False)],
          'netter': [('net', False)],
          'netterne': [('net', False)],
          'netternes': [('net', False)],
          'netters': [('net', False)],
          'nettet': [('net', False)],
          'nettets': [('net', False)],
          'neven': [('neven', False)],
          'nevens': [('neven', False)],
          'never': [('never', False)],
          'nevers': [('never', False)],
          'nevældens': [('nevælde', False)],
          'nevældet': [('nevælde', False)],
          'nevældets': [('nevælde', False)],
          'nfanen': [('nfan', False)],
          'nfanens': [('nfan', False)],
          'nfangen': [('nfang', False)],
          'nfangens': [('nfang', False)],
          'nfaren': [('nfare', False)],
          'nfarens': [('nfare', False)],
          'nfarer': [('nfare', False)],
          'nfarernes': [('nfare', False)],
          'nfekturer': [('nfekture', False)],
          'nfekturerne': [('nfekture', False)],
          'nfekturernes': [('nfekture', False)],
          'nfekturers': [('nfekture', False)],
          'nferens': [('nferens', False)],
          'nfis': [('nfis', False)],
          'nfladen': [('nflade', False)],
          'nfladens': [('nflade', False)],
          'nfluens': [('nfluens', False)],
          'nfløjten': [('nfløjte', False)],
          'nfos': [('nfo', False)],
          'nfrister': [('nfrist', False)],
          'nfristerne': [('nfrist', False)],
          'nfristernes': [('nfrist', False)],
          'nfristers': [('nfrist', False)],
          'nfruers': [('nfrue', False)],
          'nfølger': [('nfølge', False)],
          'nfølgerne': [('nfølger', False)],
          'nfølgernes': [('nfølger', False)],
          'nfølgers': [('nfølger', False)],
          'nførerne': [('nfører', False)],
          'ng': [('ng', False)],
          'ngaler': [('ngaler', False)],
          'ngalerne': [('ngaler', False)],
          'ngalernes': [('ngal', False)],
          'ngalers': [('ngal', False)],
          'nganer': [('nganer', False)],
          'nganerne': [('nganer', False)],
          'nganernes': [('nganer', False)],
          'nganers': [('nganer', False)],
          'ngarbejdernes': [('ngarbejder', False)],
          'ngarer': [('ngar', False)],
          'ngarerne': [('ngarer', False)],
          'ngarernes': [('ngar', False)],
          'ngarers': [('ngarer', False)],
          'ngas': [('nga', False)],
          "ngas'": [('nga', False)],
          'ngbrødre': [('ngbror', False)],
          'ngbrødrene': [('ngbror', False)],
          'ngbrødrenes': [('ngbror', False)],
          'ngbrødres': [('ngbror', False)],
          'ngden': [('ngde', False)],
          'ngdens': [('ngde', False)],
          'ngdernes': [('ngde', False)],
          'ngders': [('ngde', False)],
          'ngelisternes': [('ngelist', False)],
          'ngelisters': [('ngelist', False)],
          'ngels': [('ngel', False)],
          'ngene': [('ng', False)],
          'ngenes': [('ng', False)],
          'nger': [('ng', False)],
          'ngere': [('nger', False)],
          'ngeren': [('nger', False)],
          'ngerens': [('nger', False)],
          'ngeres': [('nger', False)],
          'ngerne': [('ng', False)],
          'ngernes': [('ng', False)],
          'ngers': [('nge', False)],
          "ngers'": [('nger', False)],
          'ngeser': [('ngeser', False)],
          'ngeserne': [('ngeser', False)],
          'ngesernes': [('ngeser', False)],
          'ngespids': [('ngespids', False)],
          'nget': [('ng', False)],
          'ngets': [('ng', False)],
          'nghaner': [('nghane', False)],
          'nghanerne': [('nghane', False)],
          'nghanernes': [('nghane', False)],
          'nghaners': [('nghane', False)],
          'nghedens': [('nghed', False)],
          'ngister': [('ngist', False)],
          'ngklapper': [('ngklap', False)],
          'ngklappers': [('ngklap', False)],
          'ngle': [('ngle', False)],
          'nglen': [('ngle', False)],
          'nglene': [('ngel', False)],
          'nglenes': [('ngel', False)],
          'nglens': [('ngel', False)],
          'ngler': [('ngel', False)],
          'nglernes': [('ngle', False)],
          'nglers': [('ngle', False)],
          'ngles': [('ngel', False)],
          'nglets': [('ngel', False)],
          'ngliet': [('nglie', False)],
          'nglisternes': [('ngliste', False)],
          'nglisters': [('ngliste', False)],
          'nglærer': [('nglære', False)],
          'nglærers': [('nglære', False)],
          'ngne': [('ng', False)],
          'ngnes': [('ng', False)],
          'ngordner': [('ngorden', False)],
          'ngordnerne': [('ngorden', False)],
          'ngordnernes': [('ngordner', False)],
          'ngordners': [('ngorden', False)],
          'ngpiber': [('ngpiber', False)],
          'ngpiberne': [('ngpiber', False)],
          'ngpibernes': [('ngpiber', False)],
          'ngrene': [('nger', False)],
          'ngrenes': [('nger', False)],
          'ngres': [('nger', False)],
          'ngrider': [('ngrider', False)],
          'ngriderne': [('ngrider', False)],
          'ngriders': [('ngrider', False)],
          'ngruens': [('ngruens', False)],
          'ngrøden': [('ngrød', False)],
          'ngrødens': [('ngrød', False)],
          'ngs': [('ng', False)],
          'ngsarbejder': [('ngsarbejder', False)],
          'ngsarbejderne': [('ngsarbejder', False)],
          'ngsarbejdernes': [('ngsarbejder', False)],
          'ngser': [('ngse', False)],
          'ngserne': [('ngse', False)],
          'ngsernes': [('ngse', False)],
          'ngsers': [('ngse', False)],
          'ngshandler': [('ngshandler', False)],
          'ngshandlers': [('ngshandler', False)],
          'ngslisten': [('ngsliste', False)],
          'ngslistens': [('ngsliste', False)],
          'ngsten': [('ngst', False)],
          'ngstens': [('ngst', False)],
          'ngårs': [('ngår', False)],
          'ngænger': [('ngænger', False)],
          'ngængerne': [('ngænger', False)],
          'ngængernes': [('ngænger', False)],
          'ngængers': [('ngænger', False)],
          'ngærens': [('ngær', False)],
          'ngører': [('ngør', False)],
          'ngørernes': [('ngør', False)],
          'ngørers': [('ngør', False)],
          'nhals': [('nhals', False)],
          'nhandler': [('nhandler', False)],
          'nhandlerne': [('nhandler', False)],
          'nhandlers': [('nhandler', False)],
          'nhave': [('nhave', False)],
          'nhaves': [('nhave', False)],
          'nheden': [('nhed', False)],
          'nhedens': [('nhed', False)],
          'nheder': [('nhed', False)],
          'nhederne': [('nhed', False)],
          'nhedernes': [('nhed', False)],
          'nheders': [('nhed', False)],
          'nhinde': [('nhinde', False)],
          'nhinden': [('nhinde', False)],
          'nhindens': [('nhinde', False)],
          'nhinder': [('nhinde', False)],
          'nhinderne': [('nhinde', False)],
          'nhindernes': [('nhinde', False)],
          'nhinders': [('nhinde', False)],
          'nhindes': [('nhinde', False)],
          'nhoben': [('nhob', False)],
          'nhobens': [('nhob', False)],
          'nholter': [('nholter', False)],
          'nholternes': [('nholter', False)],
          'nhus': [('nhus', False)],
          'nhviler': [('nhvile', False)],
          'nhærens': [('nhærens', False)],
          'nhøjder': [('nhøjde', False)],
          'nhøjderne': [('nhøjde', False)],
          'nhøjdernes': [('nhøjde', False)],
          'nhøjders': [('nhøjde', False)],
          'ni': [('ni', False)],
          'nibe': [('nibe', False)],
          'niberier': [('niberi', False)],
          'niberierne': [('niberi', False)],
          'niberiernes': [('niberi', False)],
          'niberis': [('niberi', False)],
          'nibers': [('nibe', False)],
          'nibes': [('nibe', False)],
          'nibs': [('nibs', False)],
          'nicene': [('nic', False)],
          'nicenes': [('nic', False)],
          'nicer': [('nic', False)],
          'nicernes': [('nic', False)],
          'nichernes': [('niche', True)],
          'nickers': [('nickers', False)],
          'nidder': [('nidder', False)],
          'nidders': [('nidder', False)],
          'nide': [('nide', False)],
          'niden': [('nide', False)],
          'nidens': [('nide', False)],
          'nider': [('nide', False)],
          'niderne': [('nide', False)],
          'nidernes': [('nide', False)],
          'niders': [('nide', False)],
          'nides': [('nide', False)],
          'nien': [('ni', False)],
          'niene': [('ni', False)],
          'nienes': [('ni', False)],
          'niens': [('ni', False)],
          'nienser': [('nienser', False)],
          'niensernes': [('nienser', False)],
          'niensers': [('nienser', False)],
          'nier': [('nier', True)],
          'niere': [('nier', False)],
          'nieren': [('nier', True)],
          'nierens': [('nier', False)],
          'nieres': [('nier', False)],
          'nierne': [('nier', True)],
          'niernes': [('nier', True)],
          'niers': [('nier', False)],
          "nies'": [('nie', False)],
          'niet': [('ni', False)],
          'niets': [('ni', False)],
          'nif': [('nif', False)],
          'nifferne': [('niffer', False)],
          'niffet': [('nif', False)],
          'niffets': [('nif', False)],
          'nigerne': [('niger', False)],
          'nigernes': [('niger', False)],
          'nigers': [('niger', False)],
          'nigte': [('nigt', False)],
          'nigten': [('nigt', False)],
          'nigtens': [('nigt', False)],
          'nigter': [('nigt', False)],
          'nigterne': [('nigt', False)],
          'nigternes': [('nigt', False)],
          'nigtes': [('nigt', False)],
          'nika': [('nikum', False)],
          'nikaene': [('nika', False)],
          'nikaenes': [('nikum', False)],
          'nikaner': [('nikaner', False)],
          'nikaners': [('nikaner', False)],
          'nikas': [('nikum', False)],
          'niken': [('nike', False)],
          'nikens': [('nike', False)],
          'niker': [('nike', False)],
          'nikerne': [('nike', False)],
          'nikernes': [('nike', False)],
          'nikers': [('nike', False)],
          'nikken': [('nik', False)],
          'nikkerne': [('nik', False)],
          'niklen': [('nikel', False)],
          'niklens': [('nikkel', False)],
          'niklerne': [('nikel', False)],
          'niklernes': [('nikel', False)],
          'niklers': [('nikel', False)],
          'niks': [('nik', True)],
          "niks'": [('niks', False)],
          'nikser': [('nikser', False)],
          'niksernes': [('nikser', False)],
          'nikum': [('nikum', False)],
          'nikummer': [('nika', False)],
          'nikummerne': [('nika', False)],
          'nikummernes': [('nika', False)],
          'nikummet': [('nika', False)],
          'nikummets': [('nika', False)],
          'nikums': [('nikum', False)],
          'nilden': [('nild', False)],
          'nildens': [('nild', False)],
          'nile': [('nile', False)],
          'nilen': [('nile', False)],
          'nilens': [('nile', False)],
          'niler': [('nile', False)],
          'nilerne': [('nile', False)],
          'nilernes': [('nile', False)],
          'nilers': [('nile', False)],
          'niles': [('nile', False)],
          'nillens': [('nille', False)],
          'niller': [('nille', False)],
          'nillerne': [('nille', False)],
          'nillernes': [('nille', False)],
          'nillers': [('nille', False)],
          'nima': [('nima', False)],
          'nimas': [('nima', False)],
          'nimenterne': [('niment', False)],
          'nimentet': [('niment', False)],
          'nimentets': [('niment', False)],
          'ninder': [('ninde', False)],
          'ninderne': [('ninde', False)],
          'nindernes': [('ninde', False)],
          'ninders': [('ninde', False)],
          'nine': [('nine', False)],
          'niner': [('nin', False)],
          'ninerne': [('nin', False)],
          'ninernes': [('niner', False)],
          'niners': [('nin', False)],
          'nines': [('nine', False)],
          'ninge': [('ning', False)],
          'ningen': [('ning', False)],
          'ningens': [('ning', False)],
          'ningenser': [('ningenser', False)],
          'ningensernes': [('ningenser', False)],
          'ninger': [('ning', False)],
          'ningerne': [('ning', False)],
          'ningernes': [('ning', False)],
          'ninges': [('ning', False)],
          'nings': [('ning', False)],
          "nings'": [('ning', False)],
          'ninister': [('ninist', False)],
          'ninisters': [('ninist', False)],
          'niolet': [('niol', False)],
          'niolets': [('niol', False)],
          'nioner': [('nion', False)],
          'nionerne': [('nion', False)],
          'nionernes': [('nion', False)],
          'nioners': [('nion', False)],
          'nions': [('nion', False)],
          "nions'": [('nion', False)],
          'niper': [('nipe', False)],
          'niplen': [('nippel', False)],
          'niplens': [('nippel', True)],
          'nippernes': [('nippe', False)],
          'nippers': [('nippe', False)],
          'nippes': [('nippe', False)],
          'nippet': [('nip', True)],
          'nippets': [('nip', True)],
          'nips': [('nip', True), ('nips', True)],
          "nips'": [('nips', True)],
          'nipsen': [('nips', False)],
          'nipsene': [('nips', False)],
          'nipsenes': [('nips', False)],
          'nipsens': [('nips', False)],
          'niren': [('nir', False)],
          'nirer': [('nir', False)],
          'nirerne': [('nir', False)],
          'nirernes': [('nir', False)],
          'nirers': [('nir', False)],
          'nirket': [('nirk', False)],
          'nirkets': [('nirk', False)],
          'nis': [('ni', False)],
          "nis'": [('ni', False)],
          'nisken': [('nisk', False)],
          'niskers': [('nisk', False)],
          'nismen': [('nisme', False)],
          'nismens': [('nisme', False)],
          'nismers': [('nisme', False)],
          'nissen': [('nisse', True)],
          'nissens': [('nisse', True)],
          'nisser': [('nisse', True)],
          'nisserne': [('nisse', True)],
          'nissernes': [('nisse', True)],
          'nissers': [('nisse', True)],
          'nisten': [('nist', False)],
          'nistens': [('nist', False)],
          'nister': [('nist', False)],
          'nisterier': [('nisterie', False)],
          'nisterierne': [('nisterie', False)],
          'nisteriernes': [('nisterie', False)],
          'nisteriers': [('nisterie', False)],
          'nisteriets': [('nisterie', False)],
          'nisterne': [('nist', False)],
          'nisternes': [('nist', False)],
          'nisters': [('nist', False)],
          'niterne': [('niter', False)],
          'nitiden': [('nitiden', False)],
          'nitraten': [('nitrat', False)],
          'nitratens': [('nitrat', False)],
          'nitrater': [('nitrat', False)],
          'nitraterne': [('nitrat', False)],
          'nitraternes': [('nitrat', False)],
          'nitraters': [('nitrat', False)],
          'nitten': [('nitte', True)],
          'nittens': [('nitte', True)],
          'nitter': [('nitte', True), ('nitter', True)],
          'nitterne': [('nitter', True), ('nitte', True)],
          'nitternes': [('nitte', True), ('nitter', True)],
          'nitters': [('nitter', True), ('nitte', True)],
          'nituren': [('niture', False)],
          'niturens': [('niture', False)],
          'niturer': [('niture', False)],
          'niturerne': [('niture', False)],
          'niturernes': [('niture', False)],
          'niturers': [('niture', False)],
          'nituret': [('niture', False)],
          'nitørerne': [('nitør', False)],
          'nitørernes': [('nitør', False)],
          'nitørers': [('nitør', False)],
          'nivers': [('nivers', False)],
          'niører': [('niør', False)],
          'njakken': [('njakke', False)],
          'njas': [('nja', False)],
          'njens': [('nje', False)],
          'njer': [('nje', False)],
          'njorden': [('njord', False)],
          'njordens': [('njord', False)],
          'njuicer': [('njuice', False)],
          'njuicerne': [('njuice', False)],
          'njuicernes': [('njuice', False)],
          'njuicers': [('njuice', False)],
          'njuveler': [('njuvel', False)],
          'njuvelers': [('njuvel', False)],
          'nk': [('nk', False)],
          'nka': [('nka', False)],
          'nkagen': [('nkage', False)],
          'nkagens': [('nkage', False)],
          'nkaner': [('nkaner', False)],
          'nkanerne': [('nkaner', False)],
          'nkanernes': [('nkaner', False)],
          'nkaners': [('nkaner', False)],
          'nkanoner': [('nkanon', False)],
          'nkanoners': [('nkanon', False)],
          'nkas': [('nka', False)],
          'nkekutter': [('nkekutte', False)],
          'nkelen': [('nkel', False)],
          'nkelens': [('nkel', False)],
          'nkelever': [('nkelev', False)],
          'nkelevers': [('nkelev', False)],
          'nken': [('nk', False)],
          'nkendernes': [('nkender', False)],
          'nkene': [('nk', False)],
          'nkenes': [('nk', False)],
          'nkens': [('nke', False)],
          'nker': [('nk', False)],
          'nkeraden': [('nkerad', False)],
          'nkeradens': [('nkerad', False)],
          'nkeraderne': [('nkerad', False)],
          'nkeraders': [('nkerad', False)],
          'nkere': [('nker', False)],
          'nkeren': [('nker', False)],
          'nkerens': [('nker', False)],
          'nkeres': [('nker', False)],
          'nkeret': [('nker', False)],
          'nkerets': [('nker', False)],
          'nkerne': [('nk', False)],
          'nkernes': [('nke', False)],
          'nkerotten': [('nkerot', False)],
          'nkerottens': [('nkerot', False)],
          'nkerotterne': [('nkerot', False)],
          'nkers': [('nke', False)],
          'nketter': [('nket', False)],
          'nkien': [('nkie', False)],
          'nkiens': [('nkie', False)],
          'nkier': [('nkie', False)],
          'nkierne': [('nkie', False)],
          'nkiernes': [('nkie', False)],
          'nkiers': [('nkie', False)],
          'nkilernes': [('nkile', False)],
          'nkilers': [('nkile', False)],
          'nkinder': [('nkinder', False)],
          'nkinderne': [('nkinder', False)],
          'nkindernes': [('nkinder', False)],
          'nkinders': [('nkinder', False)],
          'nkinen': [('nkin', False)],
          'nkinens': [('nkin', False)],
          'nkiner': [('nkin', False)],
          'nkinernes': [('nkin', False)],
          'nkis': [('nkis', False)],
          'nklapper': [('nklap', False)],
          'nklapperne': [('nklap', False)],
          'nklappernes': [('nklap', False)],
          'nklappers': [('nklap', False)],
          'nklaps': [('nklap', False)],
          'nklavens': [('nklave', False)],
          'nklaver': [('nklave', False)],
          'nklavers': [('nklave', False)],
          'nklens': [('nkel', False)],
          'nkler': [('nkel', False)],
          'nklingen': [('nkling', False)],
          'nklingens': [('nkling', False)],
          'nklinger': [('nkling', False)],
          'nklingerne': [('nkling', False)],
          'nklingernes': [('nkling', False)],
          'nklingers': [('nkling', False)],
          'nklipper': [('nklipper', False)],
          'nklipperne': [('nklipper', False)],
          'nklippernes': [('nklipper', False)],
          'nklippers': [('nklipper', False)],
          'nklips': [('nklip', False)],
          'nklæderne': [('nklæder', False)],
          'nklædernes': [('nklæder', False)],
          'nkoderne': [('nkode', False)],
          'nkoders': [('nkode', False)],
          'nkoks': [('nkok', False)],
          'nkoliers': [('nkoli', False)],
          'nkontroller': [('nkontrol', False)],
          'nkontrollerne': [('nkontrol', False)],
          'nkontrollernes': [('nkontrol', False)],
          'nkontrollers': [('nkontrol', False)],
          'nkordater': [('nkordat', False)],
          'nkordaterne': [('nkordat', False)],
          'nkordaternes': [('nkordat', False)],
          'nkordaters': [('nkordat', False)],
          'nkornet': [('nkorn', False)],
          'nkornets': [('nkorn', False)],
          'nkrans': [('nkrans', False)],
          'nkrater': [('nkrater', False)],
          'nkre': [('nker', False)],
          'nkreds': [('nkreds', False)],
          'nkrene': [('nker', False)],
          'nkrenes': [('nker', False)],
          'nkres': [('nker', False)],
          'nkret': [('nkret', False)],
          'nkreter': [('nkret', False)],
          'nkreterne': [('nkret', False)],
          'nkreternes': [('nkret', False)],
          'nkreters': [('nkret', False)],
          'nkrets': [('nker', False)],
          'nkronen': [('nkrone', False)],
          'nkronerne': [('nkrone', False)],
          'nkronernes': [('nkrone', False)],
          'nks': [('nk', False)],
          'nksene': [('nk', False)],
          'nksenes': [('nk', False)],
          'nkser': [('nks', False)],
          'nkurs': [('nkurs', False)],
          'nkurser': [('nkurs', False)],
          'nkurserne': [('nkurs', False)],
          'nkursernes': [('nkurs', False)],
          'nkursers': [('nkurs', False)],
          'nkurve': [('nkurv', False)],
          'nkurven': [('nkurv', False)],
          'nkurvens': [('nkurv', False)],
          'nkurves': [('nkurv', False)],
          'nkvisten': [('nkvisten', False)],
          'nkød': [('nkød', False)],
          'nkøds': [('nkød', False)],
          'nkøren': [('nkør', False)],
          'nkører': [('nkør', False)],
          'nkørerne': [('nkør', False)],
          'nkørernes': [('nkør', False)],
          'nkørers': [('nkør', False)],
          'nlads': [('nlad', False)],
          'nlager': [('nlager', False)],
          'nlageret': [('nlager', False)],
          'nlagerets': [('nlager', False)],
          'nlagerne': [('nlager', False)],
          'nlagernes': [('nlager', False)],
          'nlagers': [('nlager', False)],
          'nlaks': [('nlak', False)],
          'nlatter': [('nlatter', False)],
          'nlatters': [('nlatter', False)],
          'nlavet': [('nlavet', False)],
          'nlavets': [('nlavet', False)],
          'nledernes': [('nleder', False)],
          'nliner': [('nliner', False)],
          'nlinerne': [('nliner', False)],
          'nlinernes': [('nliner', False)],
          'nliners': [('nliner', False)],
          'nluks': [('nluk', False)],
          'nlyden': [('nlyd', False)],
          'nlydens': [('nlyd', False)],
          'nlys': [('nlys', False)],
          'nlås': [('nlås', False)],
          'nlæder': [('nlæder', False)],
          'nlægerne': [('nlæge', False)],
          'nlægernes': [('nlæge', False)],
          'nlænder': [('nlænder', False)],
          'nlænderne': [('nlænder', False)],
          'nlændernes': [('nlænder', False)],
          'nlænders': [('nlænder', False)],
          'nmadders': [('nmad', False)],
          'nmaden': [('nmad', False)],
          'nmads': [('nmad', False)],
          'nmager': [('nmager', False)],
          'nmagerne': [('nmager', False)],
          'nmagernes': [('nmager', False)],
          'nmagers': [('nmager', False)],
          'nman': [('nman', False)],
          'nmarchen': [('nmarch', False)],
          'nmarchens': [('nmarch', False)],
          'nmarer': [('nmarer', False)],
          'nmarerne': [('nmarer', False)],
          'nmarernes': [('nmarer', False)],
          'nmarers': [('nmarer', False)],
          'nmarker': [('nmark', False)],
          'nmarkerne': [('nmark', False)],
          'nmarkernes': [('nmark', False)],
          'nmarkers': [('nmark', False)],
          'nmelet': [('nmel', False)],
          'nmelissen': [('nmelisse', False)],
          'nmelissens': [('nmelisse', False)],
          'nmeter': [('nmeter', False)],
          'nmetre': [('nmeter', False)],
          'nmetrene': [('nmeter', False)],
          'nmetrenes': [('nmeter', False)],
          'nmetres': [('nmeter', False)],
          'nmetret': [('nmeter', False)],
          'nmetrets': [('nmeter', False)],
          'nminers': [('nmine', False)],
          'nmodet': [('nmod', False)],
          'nmodets': [('nmod', False)],
          'nmoter': [('nmot', False)],
          'nmoterne': [('nmot', False)],
          'nmoternes': [('nmot', False)],
          'nmoters': [('nmot', False)],
          'nmotet': [('nmot', False)],
          'nmotets': [('nmot', False)],
          'nmænd': [('nmand', False)],
          'nmændene': [('nmand', False)],
          'nmærkerne': [('nmærke', False)],
          'nmærkernes': [('nmærke', False)],
          'nnader': [('nnade', False)],
          'nnagerne': [('nnage', False)],
          'nnagernes': [('nnage', False)],
          'nnagers': [('nnage', False)],
          'nnalen': [('nnal', False)],
          'nnalens': [('nnale', False)],
          'nnaler': [('nnal', False)],
          'nnalerne': [('nnal', False)],
          'nnalernes': [('nnal', False)],
          'nnalers': [('nnal', False)],
          'nnanserne': [('nnans', False)],
          'nnansernes': [('nnans', False)],
          'nnas': [('nna', False)],
          'nneboernes': [('nnebo', False)],
          'nneler': [('nnel', False)],
          'nnelers': [('nnel', False)],
          'nnellens': [('nnel', False)],
          'nnellerne': [('nnel', False)],
          'nnellernes': [('nnel', False)],
          'nnenes': [('n', False)],
          'nnepper': [('nnep', False)],
          'nneppernes': [('nnep', False)],
          'nneppers': [('nnep', False)],
          'nneret': [('nner', False)],
          'nnerets': [('nner', False)],
          "nnes'": [('nnes', False)],
          'nneser': [('nneser', False)],
          'nneserne': [('nneser', False)],
          'nnesernes': [('nneser', False)],
          'nnet': [('n', False)],
          'nnets': [('n', False)],
          'nnier': [('nnium', False)],
          'nniere': [('nniere', False)],
          'nnieren': [('nniere', False)],
          'nnierens': [('nniere', False)],
          'nnieres': [('nniere', False)],
          'nnierne': [('nni', False)],
          'nniernes': [('nnia', False)],
          'nniers': [('nnia', False)],
          'nniet': [('nnium', False)],
          'nniets': [('nnium', False)],
          'nniklens': [('nnikel', False)],
          'nniks': [('nnik', False)],
          'nninen': [('nnin', False)],
          'nninens': [('nnin', False)],
          'nniner': [('nnine', False)],
          'nninerne': [('nnine', False)],
          'nninernes': [('nnine', False)],
          'nniners': [('nnine', False)],
          'nningers': [('nning', False)],
          'nnis': [('nnis', False)],
          "nnis'": [('nnis', False)],
          'nnissen': [('nnis', False)],
          'nnissens': [('nnis', False)],
          'nnitten': [('nnit', False)],
          'nnittens': [('nnit', False)],
          'nnitter': [('nnit', False)],
          'nnitterne': [('nnit', False)],
          'nnitternes': [('nnit', False)],
          'nnitters': [('nnit', False)],
          'nnium': [('nnium', False)],
          'nniums': [('nnium', False)],
          'nnuet': [('nnuum', False)],
          'nnuets': [('nnuum', False)],
          'nnummers': [('nnummer', False)],
          'nnys': [('nny', False)],
          'nnæers': [('nnæ', False)],
          'nnæs': [('nnæ', False)],
          'nnøren': [('nnør', False)],
          'nnører': [('nnør', False)],
          'nnørernes': [('nnør', False)],
          'nnørers': [('nnør', False)],
          'no': [('no', False)],
          'nobber': [('nob', False)],
          'nobberne': [('nob', False)],
          'nobbernes': [('nob', False)],
          'nobbers': [('nob', False)],
          'nober': [('nober', False)],
          'nobs': [('nob', False)],
          'noders': [('node', False)],
          'nodiernes': [('nodie', False)],
          'noen': [('no', False)],
          'noens': [('no', False)],
          'noer': [('no', False)],
          'noerne': [('no', False)],
          'noernes': [('no', False)],
          'noers': [('no', False)],
          'noet': [('no', False)],
          'noets': [('no', False)],
          'noffen': [('noff', False)],
          'noffens': [('noff', False)],
          'nofret': [('noffer', False)],
          'nofrets': [('noffer', False)],
          'nogen': [('nogen', False)],
          'nogens': [('nogen', False)],
          'noirer': [('noir', False)],
          'noirernes': [('noir', False)],
          'nokken': [('nok', False)],
          'nokker': [('nok', True)],
          'nokkerne': [('nok', False)],
          'nokkernes': [('nok', True)],
          'nokkers': [('nok', False)],
          'noklen': [('nokel', False)],
          'noklens': [('nokkel', False)],
          'nokler': [('nokel', False)],
          'noklerne': [('nokel', False)],
          'noklernes': [('nokel', False)],
          'noklers': [('nokel', False)],
          'nokser': [('nokse', False)],
          'nolde': [('nold', False)],
          'nolden': [('nold', False)],
          'noldene': [('nold', False)],
          'noldenes': [('nold', False)],
          'noldens': [('nold', False)],
          'noldes': [('nold', False)],
          'noler': [('nol', False)],
          'nolerne': [('nol', False)],
          'noliers': [('nolie', False)],
          'nolinen': [('noline', False)],
          'nolinens': [('noline', False)],
          'nolinerne': [('noline', False)],
          'nolinernes': [('noline', False)],
          'noliners': [('noline', False)],
          'nolos': [('nolo', True)],
          'nomalierne': [('nomali', False)],
          'nomen': [('nomen', True)],
          'nomens': [('nomen', False)],
          'nomier': [('nomi', False)],
          'nomierne': [('nomi', False)],
          'nomiernes': [('nomi', False)],
          'nomiers': [('nomi', False)],
          'nomiet': [('nomium', False)],
          'nomiets': [('nomi', False)],
          'nommen': [('nom', False)],
          'nommens': [('nom', False)],
          'nommer': [('nom', False)],
          'nommerne': [('nom', False)],
          'nommernes': [('nom', False)],
          'nommers': [('nom', False)],
          'nonen': [('none', True)],
          'nonens': [('none', True)],
          'noner': [('none', True)],
          'nonerne': [('none', True)],
          'nonernes': [('none', True)],
          'noners': [('none', True)],
          'nonet': [('nonet', True)],
          'nonets': [('nonet', True)],
          'nonomen': [('nonom', False)],
          'noppen': [('noppe', True)],
          'noppens': [('noppe', True)],
          'nopper': [('noppe', True)],
          'nopperne': [('noppe', True)],
          'noppernes': [('noppe', True)],
          'noppers': [('noppe', True)],
          'noppes': [('noppe', True)],
          'nopsers': [('nopsis', False)],
          'nopsis': [('nopsis', False)],
          'norakkers': [('norak', False)],
          'noraks': [('norak', False)],
          'norers': [('nor', False)],
          'nores': [('nor', False)],
          'norken': [('norken', False)],
          'norkens': [('norken', False)],
          'normerne': [('norm', True)],
          'normernes': [('norm', True)],
          'normers': [('norm', True)],
          'nos': [('no', False)],
          "nos'": [('no', False)],
          'nosen': [('nose', False)],
          'nosens': [('nose', False)],
          'noser': [('nose', False)],
          'noserne': [('nose', False)],
          'nosernes': [('nose', False)],
          'nosers': [('nose', False)],
          'nosier': [('nosi', False)],
          'nosierne': [('nosi', False)],
          'nosiernes': [('nosi', False)],
          'nosiers': [('nosi', False)],
          'nosis': [('nosi', False)],
          'nossens': [('nosse', True)],
          'nossernes': [('nosse', True)],
          'nossers': [('nosse', True)],
          'noste': [('nost', False)],
          'nostemmer': [('nostemmer', False)],
          'nostemmerne': [('nostemmer', False)],
          'nostemmernes': [('nostemmer', False)],
          'nostemmers': [('nostemmer', False)],
          'nosten': [('nost', False)],
          'nostens': [('nost', False)],
          'nostes': [('nost', False)],
          'nota': [('nota', True)],
          'notas': [('nota', False)],
          'noten': [('note', True), ('not', True)],
          'notens': [('note', True), ('not', True)],
          'noter': [('note', True), ('not', True)],
          'noterne': [('note', True), ('not', True)],
          'noternes': [('not', True), ('note', True)],
          'noters': [('note', True), ('not', True)],
          'notes': [('note', False)],
          'notten': [('not', False)],
          'nottens': [('not', False)],
          'notter': [('not', False)],
          'notterne': [('not', False)],
          'notternes': [('not', False)],
          'notters': [('not', False)],
          'notypen': [('notype', False)],
          'notyper': [('notype', False)],
          'notyperne': [('notype', False)],
          'npasser': [('npasser', False)],
          'npasserne': [('npasser', False)],
          'npassernes': [('npasser', False)],
          'npassers': [('npasser', False)],
          'npersen': [('nperse', False)],
          'nperser': [('nperse', False)],
          'nperserne': [('nperse', False)],
          'npersernes': [('nperse', False)],
          'npersers': [('nperse', False)],
          'npiber': [('npibe', False)],
          'npiberne': [('npibe', False)],
          'npibernes': [('npibe', False)],
          'npibers': [('npibe', False)],
          'npladerne': [('nplade', False)],
          'npressens': [('npresse', False)],
          'npresser': [('npresse', False)],
          'npresserne': [('npresse', False)],
          'npressernes': [('npresse', False)],
          'npressers': [('npresser', False)],
          'nprisen': [('npris', False)],
          'nprisens': [('npris', False)],
          'npriser': [('npris', False)],
          'npriserne': [('npris', False)],
          'nprisernes': [('npris', False)],
          'nprisers': [('npris', False)],
          'nqueten': [('nquete', False)],
          'nquetens': [('nquete', False)],
          'nr.': [('nummer', False)],
          'nrade': [('nrad', False)],
          'nradens': [('nrad', False)],
          'nraderne': [('nrad', False)],
          'nrades': [('nrad', False)],
          'nrammen': [('nramme', False)],
          'nrammens': [('nramme', False)],
          'nrammernes': [('nramme', False)],
          'nrammes': [('nramme', False)],
          'nranken': [('nranke', False)],
          'nrankernes': [('nranke', False)],
          'nregimenter': [('nregiment', False)],
          'nregimenterne': [('nregiment', False)],
          'nregimenternes': [('nregiment', False)],
          'nregimenters': [('nregiment', False)],
          'nregimentet': [('nregiment', False)],
          'nregimentets': [('nregiment', False)],
          'nrejen': [('nrej', False)],
          'nrejens': [('nrej', False)],
          'nrejer': [('nrej', False)],
          'nrejerne': [('nrej', False)],
          'nrejernes': [('nrej', False)],
          'nrejers': [('nrej', False)],
          'nrejser': [('nrejse', False)],
          'nren': [('nre', False)],
          'nrens': [('nrens', False)],
          'nrers': [('nre', False)],
          'nres': [('nre', False)],
          'nret': [('nret', False)],
          'nretter': [('nret', False)],
          'nrikkens': [('nrik', False)],
          'nrikker': [('nrik', False)],
          'nrikkernes': [('nrik', False)],
          'nrikkers': [('nrik', False)],
          'nriks': [('nrik', False)],
          'nris': [('nris', False)],
          'nrisen': [('nris', False)],
          'nroden': [('nrod', False)],
          'nrodens': [('nrod', False)],
          'nrods': [('nrod', False)],
          'nruller': [('nrulle', False)],
          'nrummet': [('nrum', False)],
          'nrummets': [('nrum', False)],
          'nråer': [('nråer', False)],
          'nråerne': [('nråer', False)],
          'nråernes': [('nråer', False)],
          'nråers': [('nråer', False)],
          'nrækker': [('nrække', False)],
          'nrøret': [('nrør', False)],
          'nrørets': [('nrør', False)],
          'nrøver': [('nrøver', False)],
          'nrøvernes': [('nrøver', False)],
          "ns'": [('ns', False)],
          'nsa': [('nsum', False)],
          'nsaene': [('nsum', False)],
          'nsaenes': [('nsum', False)],
          'nsaften': [('nsaften', False)],
          'nsaftens': [('nsaften', False)],
          'nsagen': [('nsagen', False)],
          'nsager': [('nsager', False)],
          'nsagerne': [('nsager', False)],
          'nsagernes': [('nsag', False)],
          'nsagers': [('nsag', False)],
          'nsaks': [('nsaks', False)],
          'nsanger': [('nsanger', False)],
          'nsarbejder': [('nsarbejde', False)],
          'nsarbejderne': [('nsarbejde', False)],
          'nsarbejdernes': [('nsarbejde', False)],
          'nsarbejders': [('nsarbejder', False)],
          'nsarder': [('nsard', False)],
          'nsarderne': [('nsard', False)],
          'nsardernes': [('nsard', False)],
          'nsarders': [('nsard', False)],
          'nsas': [('nsum', False)],
          'nsats': [('nsat', False)],
          'nsbo': [('nsbo', False)],
          'nsboen': [('nsbo', False)],
          'nsboens': [('nsbo', False)],
          'nsboer': [('nsbo', False)],
          'nsboerne': [('nsbo', False)],
          'nsboernes': [('nsboer', False)],
          'nsboers': [('nsboer', False)],
          'nsbos': [('nsbo', False)],
          'nschernes': [('nscher', False)],
          'nscyklens': [('nscykel', False)],
          'nscykler': [('nscykel', False)],
          'nscyklerne': [('nscykel', False)],
          'nse': [('ns', False)],
          'nseer': [('nseer', False)],
          'nseerne': [('nseer', False)],
          'nseernes': [('nseer', False)],
          'nselen': [('nsel', False)],
          'nselens': [('nsel', False)],
          'nsen': [('ns', False)],
          'nsene': [('ne', False)],
          'nsener': [('nsener', False)],
          'nseners': [('nsener', False)],
          'nsenes': [('ns', False)],
          'nsens': [('ns', False)],
          'nsentens': [('nsent', False)],
          'nser': [('ns', False)],
          'nsere': [('nser', False)],
          'nseren': [('nser', False)],
          'nserens': [('nser', False)],
          'nseres': [('nser', False)],
          'nserier': [('nseri', False)],
          'nserierne': [('nseri', False)],
          'nseriernes': [('nseri', False)],
          'nseriers': [('nseri', False)],
          'nsernes': [('ns', False)],
          'nsers': [('ns', False)],
          'nserver': [('nserv', False)],
          'nserverne': [('nserv', False)],
          'nservernes': [('nserv', False)],
          'nservers': [('nserv', False)],
          'nserves': [('nserves', False)],
          'nses': [('ns', False)],
          "nses'": [('nses', False)],
          'nset': [('ns', False)],
          'nsets': [('ns', False)],
          'nsetter': [('nsetter', False)],
          'nsetterne': [('nsetter', False)],
          'nsformer': [('nsformer', False)],
          'nsformerne': [('nsformer', False)],
          'nsformernes': [('nsformer', False)],
          'nsformers': [('nsformer', False)],
          'nshave': [('nshav', False)],
          'nshaves': [('nshav', False)],
          'nsianer': [('nsianer', False)],
          'nsianers': [('nsianer', False)],
          'nsias': [('nsia', False)],
          'nsider': [('nsider', False)],
          'nsiderne': [('nsider', False)],
          'nsidernes': [('nsider', False)],
          'nsiders': [('nsider', False)],
          'nsien': [('nsie', False)],
          'nsiens': [('nsie', False)],
          'nsier': [('nsie', False)],
          'nsierne': [('nsie', False)],
          'nsiernes': [('nsie', False)],
          'nsiers': [('nsier', False)],
          'nsigten': [('nsigt', False)],
          'nsigtens': [('nsigt', False)],
          'nsigter': [('nsigt', False)],
          'nsigterne': [('nsigt', False)],
          'nsigternes': [('nsigt', False)],
          'nsigters': [('nsigt', False)],
          'nsigtet': [('nsigt', False)],
          'nsigtets': [('nsigt', False)],
          'nsilier': [('nsilium', False)],
          'nsilierne': [('nsilium', False)],
          'nsiliernes': [('nsilie', False)],
          'nsiliers': [('nsilium', False)],
          'nsiliet': [('nsilium', False)],
          'nsiliets': [('nsilie', False)],
          'nsillens': [('nsil', False)],
          "nsions'": [('nsions', False)],
          'nsis': [('nsis', False)],
          'nsistens': [('nsistens', False)],
          'nsitet': [('nsitet', False)],
          'nsitets': [('nsitet', False)],
          'nsitter': [('nsit', False)],
          'nsitterne': [('nsit', False)],
          'nskaber': [('nskab', False)],
          'nskaberne': [('nskab', False)],
          'nskabernes': [('nskab', False)],
          'nskabers': [('nskab', False)],
          'nskallen': [('nskal', False)],
          'nskallens': [('nskal', False)],
          'nskaller': [('nskal', False)],
          'nskallerne': [('nskal', False)],
          'nskallernes': [('nskal', False)],
          'nskallers': [('nskal', False)],
          'nske': [('nske', False)],
          'nsken': [('nsken', False)],
          'nskene': [('nsk', False)],
          'nskens': [('nsken', False)],
          'nsker': [('nske', False)],
          'nskerne': [('nske', False)],
          'nskernes': [('nsker', False)],
          'nskers': [('nsker', False)],
          'nsket': [('nsk', False)],
          'nskets': [('nsk', False)],
          'nskifte': [('nskifte', False)],
          'nskifter': [('nskifte', False)],
          'nskifterne': [('nskifte', False)],
          'nskifternes': [('nskifte', False)],
          'nskifters': [('nskifte', False)],
          'nskiftes': [('nskifte', False)],
          'nskiftet': [('nskifte', False)],
          'nskiftets': [('nskifte', False)],
          'nskos': [('nsko', False)],
          'nskralden': [('nskralde', False)],
          'nskreds': [('nskred', False)],
          'nskrige': [('nskrig', False)],
          'nskrigen': [('nskrig', False)],
          'nskrigens': [('nskrig', False)],
          'nskriges': [('nskrig', False)],
          'nslags': [('nslag', False)],
          'nslangen': [('nslange', False)],
          'nslangens': [('nslange', False)],
          'nslaven': [('nslave', False)],
          'nslavens': [('nslave', False)],
          'nslaver': [('nslave', False)],
          'nslaverne': [('nslave', False)],
          'nslavernes': [('nslave', False)],
          'nslavers': [('nslave', False)],
          'nslens': [('nsel', False)],
          'nsler': [('nsel', False)],
          'nslinger': [('nsling', False)],
          'nslingerne': [('nsling', False)],
          'nslingernes': [('nsling', False)],
          'nslingers': [('nsling', False)],
          'nslås': [('nslås', False)],
          'nslæber': [('nslæbe', False)],
          'nslæberne': [('nslæbe', False)],
          'nslæbernes': [('nslæbe', False)],
          'nslæbers': [('nslæbe', False)],
          'nslærer': [('nslære', False)],
          'nsmutter': [('nsmutte', False)],
          'nsmutterne': [('nsmutte', False)],
          'nsmutternes': [('nsmutte', False)],
          'nsmutters': [('nsmutte', False)],
          'nsmælders': [('nsmælder', False)],
          'nsolen': [('nsol', False)],
          'nsolens': [('nsol', False)],
          'nsollens': [('nsol', False)],
          'nsoner': [('nson', False)],
          'nsonerne': [('nson', False)],
          'nsonernes': [('nson', False)],
          'nsoners': [('nson', False)],
          'nsorden': [('nsorden', False)],
          'nsordens': [('nsorden', False)],
          'nsoriers': [('nsorium', False)],
          'nsorium': [('nsorium', False)],
          'nsoriums': [('nsorium', False)],
          'nsorter': [('nsorter', False)],
          'nsorterne': [('nsorter', False)],
          'nsorternes': [('nsorter', False)],
          'nsorters': [('nsorter', False)],
          'nsortier': [('nsortium', False)],
          'nsortierne': [('nsortium', False)],
          'nsortiernes': [('nsortium', False)],
          'nsortiers': [('nsortium', False)],
          'nsparens': [('nsparens', False)],
          'nspressen': [('nspresse', False)],
          'nspresserne': [('nspresse', False)],
          'nspressers': [('nspresse', False)],
          'nspænder': [('nspænder', False)],
          'nspænderne': [('nspænder', False)],
          'nspændernes': [('nspænder', False)],
          'nspænders': [('nspænder', False)],
          'nspændet': [('nspænd', False)],
          'nspændets': [('nspænd', False)],
          'nsretter': [('nsretter', False)],
          'nssagens': [('nssag', False)],
          'nssager': [('nssag', False)],
          'nssagerne': [('nssag', False)],
          'nssagernes': [('nssag', False)],
          'nsskifternes': [('nsskifte', False)],
          'nsskiftes': [('nsskifte', False)],
          'nsskiftet': [('nsskifte', False)],
          'nsstien': [('nssti', False)],
          'nstabler': [('nstabel', False)],
          'nstablerne': [('nstabel', False)],
          'nstablernes': [('nstabel', False)],
          'nstablers': [('nstabel', False)],
          'nstans': [('nstans', False)],
          'nstansen': [('nstans', False)],
          'nstansens': [('nstans', False)],
          'nstanser': [('nstans', False)],
          'nstanserne': [('nstans', False)],
          'nstansernes': [('nstans', False)],
          'nstansers': [('nstans', False)],
          'nstarter': [('nstart', False)],
          'nstarterne': [('nstart', False)],
          'nstarternes': [('nstart', False)],
          'nstarters': [('nstart', False)],
          'nstemmer': [('nstemme', False)],
          'nstemmerne': [('nstemme', False)],
          'nstemmernes': [('nstemme', False)],
          'nstemmers': [('nstemme', False)],
          'nsten': [('nsten', False)],
          'nstenes': [('nsten', False)],
          'nstens': [('nsten', False)],
          'nster': [('nster', False)],
          'nsters': [('nster', False)],
          'nstifter': [('nstifter', False)],
          'nstifterne': [('nstifter', False)],
          'nstifternes': [('nstifter', False)],
          'nstifters': [('nstifter', False)],
          'nstillen': [('nstillen', False)],
          'nstillens': [('nstillen', False)],
          'nstningers': [('nstning', False)],
          'nstre': [('nster', False)],
          'nstres': [('nstre', False)],
          'nstringens': [('nstring', False)],
          'nstrømperne': [('nstrømpe', False)],
          'nstudiet': [('nstudium', False)],
          'nstyrer': [('nstyrer', False)],
          'nstyrerne': [('nstyrer', False)],
          'nstyrernes': [('nstyrer', False)],
          'nstyrers': [('nstyrer', False)],
          'nstænger': [('nstang', False)],
          'nstængerne': [('nstang', False)],
          'nstængernes': [('nstang', False)],
          'nstængers': [('nstang', False)],
          'nsulen': [('nsul', False)],
          'nsulens': [('nsul', False)],
          'nsuler': [('nsul', False)],
          'nsulerne': [('nsul', False)],
          'nsulernes': [('nsul', False)],
          'nsulers': [('nsul', False)],
          'nsummer': [('nsum', False)],
          'nsummerne': [('nsum', False)],
          'nsummernes': [('nsum', False)],
          'nsummers': [('nsum', False)],
          'nsuren': [('nsur', False)],
          'nsurens': [('nsur', False)],
          'nsurer': [('nsur', False)],
          'nsurerne': [('nsur', False)],
          'nsurernes': [('nsur', False)],
          'nsurers': [('nsur', False)],
          'nsus': [('nsus', False)],
          'nsyren': [('nsyre', False)],
          'nsyrens': [('nsyre', False)],
          'nsyrer': [('nsyre', False)],
          'nsyrerne': [('nsyre', False)],
          'nsyrernes': [('nsyre', False)],
          'nsyrers': [('nsyre', False)],
          'nsæder': [('nsæde', False)],
          'nsæderne': [('nsæde', False)],
          'nsædernes': [('nsæde', False)],
          'nsæders': [('nsæde', False)],
          'nta': [('ntum', False)],
          'ntabus': [('ntabus', False)],
          'ntaene': [('ntum', False)],
          'ntaenes': [('ntum', False)],
          'ntage': [('ntag', False)],
          'ntagen': [('ntagen', False)],
          'ntagens': [('ntage', False)],
          'ntager': [('ntage', False)],
          'ntagere': [('ntager', False)],
          'ntageren': [('ntager', False)],
          'ntagerens': [('ntager', False)],
          'ntageres': [('ntager', False)],
          'ntagerne': [('ntage', False)],
          'ntagernes': [('ntage', False)],
          'ntagers': [('ntage', False)],
          'ntages': [('ntag', False)],
          'ntaklens': [('ntakel', False)],
          'ntakler': [('ntakel', False)],
          'ntaks': [('ntaks', False)],
          'ntalens': [('ntale', False)],
          'ntaler': [('ntale', False)],
          'ntallerne': [('ntal', False)],
          'ntallernes': [('ntal', False)],
          'ntamen': [('ntamen', False)],
          'ntamens': [('ntamen', False)],
          'ntanke': [('ntank', False)],
          'ntanken': [('ntank', False)],
          'ntankens': [('ntank', False)],
          'ntankes': [('ntank', False)],
          'ntanten': [('ntant', False)],
          'ntantens': [('ntant', False)],
          'ntanter': [('ntant', False)],
          'ntanterne': [('ntanter', False)],
          'ntanternes': [('ntanter', False)],
          'ntanters': [('ntanter', False)],
          'ntapper': [('ntapper', False)],
          'ntapperne': [('ntapper', False)],
          'ntappernes': [('ntapper', False)],
          'ntappers': [('ntapper', False)],
          'ntarbejder': [('ntarbejder', False)],
          'ntarbejderne': [('ntarbejder', False)],
          'ntarer': [('ntar', False)],
          'ntarernes': [('ntar', False)],
          'ntaret': [('ntar', False)],
          'ntarets': [('ntar', False)],
          'ntas': [('nta', False)],
          'ntaten': [('ntat', False)],
          'ntatens': [('ntat', False)],
          'ntaterne': [('ntat', False)],
          'ntaters': [('ntat', False)],
          'ntats': [('ntat', False)],
          'ntefødder': [('ntefod', False)],
          'ntekster': [('ntekst', False)],
          'nteksterne': [('ntekst', False)],
          'nteksternes': [('ntekst', False)],
          'nteksters': [('ntekst', False)],
          'ntelisten': [('nteliste', False)],
          'ntelistens': [('nteliste', False)],
          'ntelister': [('nteliste', False)],
          'ntelisterne': [('nteliste', False)],
          'ntellens': [('ntel', False)],
          'ntellerne': [('ntel', False)],
          'ntellernes': [('ntel', False)],
          'nten': [('nt', False)],
          'ntene': [('nt', False)],
          'ntenes': [('nt', False)],
          'ntens': [('nt', False)],
          'ntenserne': [('ntens', False)],
          'ntenten': [('ntente', False)],
          'ntentens': [('ntente', False)],
          'ntenterne': [('ntente', False)],
          'ntenternes': [('ntente', False)],
          'ntenters': [('ntente', False)],
          'nteret': [('nter', False)],
          'nterets': [('nter', False)],
          'nterivarerne': [('nterivare', False)],
          'nterne': [('nt', False)],
          'nternes': [('nt', False)],
          'nternet': [('nternet', False)],
          'nternets': [('nternet', False)],
          'nters': [('nt', False)],
          "ntes'": [('ntes', False)],
          'ntesen': [('ntes', False)],
          'ntesens': [('ntes', False)],
          'nteser': [('ntes', False)],
          'nteserne': [('ntes', False)],
          'ntesernes': [('ntese', False)],
          'ntesers': [('ntese', False)],
          'ntessens': [('ntessens', False)],
          'ntesten': [('ntesten', False)],
          'ntestens': [('ntesten', False)],
          'ntet': [('nt', False)],
          'ntets': [('nt', False)],
          'nthuset': [('nthus', False)],
          'ntias': [('ntia', False)],
          'ntiden': [('ntiden', False)],
          'ntider': [('ntid', False)],
          'ntiderne': [('ntid', False)],
          'ntidernes': [('ntid', False)],
          'ntiders': [('ntid', False)],
          'ntids': [('ntid', False)],
          'ntiene': [('nto', False)],
          'ntienes': [('nto', False)],
          'ntier': [('ntius', False)],
          'ntierne': [('nti', False)],
          'ntiernes': [('ntius', False)],
          'ntigen': [('ntigen', False)],
          'ntigens': [('ntigen', False)],
          'ntikkens': [('ntik', False)],
          'ntikker': [('ntik', False)],
          'ntikkernes': [('ntik', False)],
          'ntikkers': [('ntik', False)],
          'ntiks': [('ntik', False)],
          'ntilens': [('ntil', False)],
          'ntillen': [('ntil', False)],
          'ntillene': [('ntil', False)],
          'ntillenes': [('ntil', False)],
          'ntillens': [('ntil', False)],
          'ntillernes': [('ntil', False)],
          'ntimer': [('ntime', False)],
          'ntimerne': [('ntime', False)],
          'ntimernes': [('ntime', False)],
          'ntimers': [('ntime', False)],
          'ntinet': [('ntin', False)],
          'ntinets': [('ntin', False)],
          'ntingens': [('ntingens', False)],
          'ntium': [('ntium', False)],
          'ntiums': [('ntium', False)],
          'ntiver': [('ntiv', False)],
          'ntivernes': [('ntiv', False)],
          'ntmappens': [('ntmappe', False)],
          'ntmen': [('ntman', False)],
          'ntmens': [('ntman', False)],
          'ntner': [('ntner', False)],
          'ntnernes': [('ntner', False)],
          'ntners': [('ntner', False)],
          'ntningen': [('ntning', False)],
          'ntninger': [('ntning', False)],
          'ntningerne': [('ntning', False)],
          'ntningernes': [('ntning', False)],
          'ntoer': [('nto', False)],
          'ntoerne': [('nto', False)],
          'ntoernes': [('nto', False)],
          'ntoers': [('nto', False)],
          'ntoget': [('ntog', False)],
          'ntomer': [('ntom', False)],
          'ntomers': [('ntom', False)],
          'ntonen': [('nton', False)],
          'ntonens': [('nton', False)],
          'ntoner': [('nton', False)],
          'ntonerne': [('nton', False)],
          'ntonernes': [('nton', False)],
          'ntoners': [('nton', False)],
          'ntoret': [('ntor', False)],
          'ntorets': [('ntor', False)],
          'ntorierne': [('ntori', False)],
          'ntoriers': [('ntori', False)],
          'ntoriet': [('ntori', False)],
          'ntoriets': [('ntori', False)],
          'ntra': [('ntra', False)],
          'ntrapper': [('ntrappe', False)],
          'ntrapperne': [('ntrappe', False)],
          'ntras': [('ntra', False)],
          'ntre': [('ntre', False)],
          'ntrene': [('nter', False)],
          'ntrenes': [('nter', False)],
          'ntrens': [('ntre', False)],
          'ntrer': [('ntre', False)],
          'ntrerne': [('ntre', False)],
          'ntrernes': [('ntre', False)],
          'ntres': [('nter', False)],
          'ntricen': [('ntrice', False)],
          'ntricens': [('ntrice', False)],
          'ntricerne': [('ntrice', False)],
          'ntricernes': [('ntrice', False)],
          'ntricers': [('ntrice', False)],
          'ntriger': [('ntrige', False)],
          'ntrigers': [('ntrige', False)],
          'ntrikken': [('ntrik', False)],
          'ntrikker': [('ntrik', False)],
          'ntrikkerne': [('ntrik', False)],
          'ntrikkernes': [('ntrik', False)],
          'ntrikkers': [('ntrik', False)],
          'ntringens': [('ntring', False)],
          'ntrissernes': [('ntrisse', False)],
          'ntrissers': [('ntrisse', False)],
          'ntropen': [('ntrop', False)],
          'ntropens': [('ntrop', False)],
          'ntroper': [('ntrop', False)],
          'ntroperne': [('ntrop', False)],
          'ntropernes': [('ntrop', False)],
          'ntropers': [('ntrop', False)],
          'ntros': [('ntro', False)],
          'ntrosen': [('ntrose', False)],
          'ntrosens': [('ntrose', False)],
          'ntroser': [('ntrose', False)],
          'ntroserne': [('ntrose', False)],
          'ntrosernes': [('ntrose', False)],
          'ntrosers': [('ntrose', False)],
          'ntræders': [('ntræde', False)],
          'ntrækken': [('ntrække', False)],
          'ntrækkens': [('ntrække', False)],
          'ntrækker': [('ntrække', False)],
          'ntrækkerne': [('ntrække', False)],
          'ntrækkernes': [('ntrække', False)],
          'ntrækkers': [('ntrække', False)],
          'nts': [('nt', False)],
          "nts'": [('nt', False)],
          'ntstifter': [('ntstift', False)],
          'ntuen': [('ntu', False)],
          'ntuens': [('ntu', False)],
          'ntuer': [('ntu', False)],
          'ntuerne': [('ntu', False)],
          'ntuernes': [('ntu', False)],
          'ntuers': [('ntu', False)],
          'ntungen': [('ntung', False)],
          'ntungens': [('ntung', False)],
          'ntunger': [('ntung', False)],
          'ntungerne': [('ntung', False)],
          'ntungernes': [('ntung', False)],
          'ntungers': [('ntung', False)],
          'nturen': [('ntur', False)],
          'nturenes': [('ntur', False)],
          'nturer': [('ntur', False)],
          'nturerne': [('ntur', False)],
          'nturernes': [('ntur', False)],
          'nturers': [('ntur', False)],
          'nturet': [('ntur', False)],
          'ntyden': [('ntyde', False)],
          'ntydens': [('ntyde', False)],
          'ntyder': [('ntyde', False)],
          'ntyderne': [('ntyde', False)],
          'ntypens': [('ntype', False)],
          'ntypernes': [('ntype', False)],
          'ntypers': [('ntype', False)],
          'ntyrer': [('ntyrer', False)],
          'ntyrerne': [('ntyrer', False)],
          'ntyrernes': [('ntyrer', False)],
          'ntyret': [('ntyr', False)],
          'ntyrets': [('ntyr', False)],
          'ntæren': [('ntær', False)],
          'ntærerne': [('ntær', False)],
          'ntærernes': [('ntær', False)],
          'ntømmer': [('ntømmer', False)],
          'ntømmers': [('ntømmer', False)],
          'ntører': [('ntør', False)],
          'nua': [('nuum', False)],
          'nualer': [('nual', False)],
          'nualerne': [('nual', False)],
          'nualernes': [('nual', False)],
          'nualers': [('nual', False)],
          'nualet': [('nual', False)],
          'nualets': [('nual', False)],
          'nuas': [('nuum', False)],
          'nubs': [('nubs', False)],
          "nubs'": [('nubs', False)],
          'nude': [('nude', False)],
          'nuden': [('nude', False)],
          'nudens': [('nude', False)],
          'nuderne': [('nude', False)],
          'nuders': [('nude', False)],
          'nudes': [('nude', False)],
          'nudlen': [('nudel', True)],
          'nudlerne': [('nudel', True)],
          'nudlernes': [('nudel', True)],
          'nuen': [('nu', False)],
          'nuens': [('nu', False)],
          'nuensen': [('nuensis', False)],
          'nuensens': [('nuensis', False)],
          'nuenser': [('nuensis', False)],
          'nuensernes': [('nuensis', False)],
          'nuensers': [('nuensis', False)],
          'nuer': [('nu', False)],
          'nuerne': [('nu', False)],
          'nuernes': [('nu', False)],
          'nuers': [('nu', False)],
          'nuet': [('nu', False)],
          'nuets': [('nu', True)],
          'nuetter': [('nuet', False)],
          'nuglers': [('nugle', False)],
          'nukken': [('nuk', False)],
          'nukkerne': [('nuk', False)],
          'nukkers': [('nuk', False)],
          'nuller': [('nul', True)],
          'nullers': [('nul', True)],
          'num': [('num', False)],
          'nummen': [('num', False)],
          'nummens': [('num', False)],
          'nummer': [('nummer', False)],
          'nummernes': [('num', False)],
          'nummers': [('nummer', True)],
          'nums': [('num', False)],
          'nungers': [('nunge', False)],
          'nuppen': [('nup', False)],
          'nuppens': [('nup', False)],
          'nupperne': [('nup', False)],
          'nuppers': [('nup', False)],
          'nuren': [('nure', False)],
          'nurens': [('nure', False)],
          'nurer': [('nure', False)],
          'nurerne': [('nure', False)],
          'nurernes': [('nure', False)],
          'nurers': [('nure', False)],
          'nuret': [('nur', False)],
          'nurets': [('nur', False)],
          'nurs': [('nur', False)],
          'nurter': [('nurt', False)],
          'nurterne': [('nurt', False)],
          'nus': [('nus', True), ('nu', True)],
          'nuse': [('nuse', False)],
          'nusen': [('nuse', False)],
          'nusens': [('nuse', False)],
          'nuser': [('nuse', False)],
          'nuserne': [('nuser', False)],
          'nusernes': [('nuse', False)],
          'nusers': [('nuse', False)],
          'nuses': [('nuse', False)],
          'nussen': [('nus', False)],
          'nussens': [('nus', False)],
          'nusser': [('nus', False)],
          'nusserne': [('nus', False)],
          'nutten': [('nut', False)],
          'nuttens': [('nut', False)],
          'nutterne': [('nut', False)],
          'nutternes': [('nut', False)],
          'nutters': [('nut', False)],
          'nuturene': [('nutur', False)],
          'nuturenes': [('nutur', False)],
          'nutures': [('nutur', False)],
          'nvallen': [('nval', False)],
          'nvallens': [('nval', False)],
          'nvals': [('nval', False)],
          'nvas': [('nvas', False)],
          'nveje': [('nvej', False)],
          'nvejene': [('nveje', False)],
          'nvejenes': [('nveje', False)],
          'nvejens': [('nvej', False)],
          'nvejes': [('nveje', False)],
          'nvendernes': [('nvender', False)],
          'nverterne': [('nverter', False)],
          'nverters': [('nverter', False)],
          'nvinde': [('nvind', False)],
          'nvinden': [('nvinde', False)],
          'nvindens': [('nvinde', False)],
          'nvinder': [('nvinde', False)],
          'nvinderne': [('nvinde', False)],
          'nvindernes': [('nvinde', False)],
          'nvinders': [('nvinde', False)],
          'nvindes': [('nvinde', False)],
          'nvippens': [('nvippe', False)],
          'nvipper': [('nvippe', False)],
          'nvipperne': [('nvippe', False)],
          'nyder': [('nyder', False)],
          'nyderne': [('nyder', False)],
          'nyen': [('ny', False)],
          'nyens': [('ny', False)],
          'nyer': [('ny', False)],
          'nyere': [('nyer', False)],
          'nyeren': [('nyer', False)],
          'nyerens': [('nyer', False)],
          'nyeres': [('nyer', False)],
          'nyerne': [('ny', False)],
          'nyernes': [('ny', False)],
          'nyers': [('ny', False)],
          'nykkens': [('nykke', True)],
          'nykkernes': [('nykke', True)],
          'nykkers': [('nykke', True)],
          'nyks': [('nyk', True)],
          'nyle': [('nyle', False)],
          'nylen': [('nyle', False)],
          'nylens': [('nyle', False)],
          'nyler': [('nyle', False)],
          'nylerne': [('nyle', False)],
          'nylernes': [('nyle', False)],
          'nylers': [('nyle', False)],
          'nyles': [('nyle', False)],
          'nylter': [('nylter', False)],
          'nylterne': [('nylter', False)],
          'nylternes': [('nylter', False)],
          'nylters': [('nylter', False)],
          'nymer': [('nym', False)],
          'nymers': [('nym', False)],
          'nyre': [('nyre', False)],
          'nyren': [('nyre', True)],
          'nyrens': [('nyre', True)],
          'nyrer': [('nyre', False)],
          'nyrerne': [('nyre', False)],
          'nyrernes': [('nyre', False)],
          'nyrers': [('nyre', False)],
          'nys': [('nys', True), ('ny', True)],
          'nysten': [('nyst', False)],
          'nystens': [('nyst', False)],
          'nyster': [('nyst', False)],
          'nysterne': [('nyst', False)],
          'nysternes': [('nyst', False)],
          'nysters': [('nyst', False)],
          'nytter': [('nytter', False)],
          'nytterne': [('nytter', False)],
          'nytters': [('nytter', False)],
          'nzer': [('nze', False)],
          'nzers': [('nze', False)],
          'nzinen': [('nzin', False)],
          'nzinens': [('nzin', False)],
          'nzinernes': [('nzin', False)],
          'nzoen': [('nzoe', False)],
          'nåbner': [('nåbner', False)],
          'nåde': [('nåde', False)],
          'nåden': [('nåde', False)],
          'nådens': [('nåde', True)],
          'nådes': [('nåde', True)],
          'nånden': [('nånd', False)],
          'nåndens': [('nånd', False)],
          'nånders': [('nånd', False)],
          'næben': [('næb', False)],
          'næbler': [('næbel', False)],
          'næblerne': [('næbel', False)],
          'næblernes': [('næbel', False)],
          'næblers': [('næbel', False)],
          'næer': [('næ', False)],
          'næerne': [('næ', False)],
          'næernes': [('næ', False)],
          'næers': [('næer', False)],
          'næet': [('næ', True)],
          'næets': [('næ', True)],
          'nægte': [('nægt', False)],
          'nægten': [('nægt', False)],
          'nægtens': [('nægt', False)],
          'nægters': [('nægter', False)],
          'nægtes': [('nægt', False)],
          'nækker': [('nækker', False)],
          'nækkernes': [('nækker', False)],
          'nækkers': [('nækker', False)],
          'nælderne': [('nælde', False)],
          'nældernes': [('nælde', True)],
          'næler': [('næler', False)],
          'nælerne': [('næler', False)],
          'nælernes': [('næler', False)],
          'nælers': [('næler', False)],
          'næmien': [('næmi', False)],
          'næmiens': [('næmi', False)],
          'næmier': [('næmi', False)],
          'næmierne': [('næmi', False)],
          'næmiernes': [('næmi', False)],
          'næmiers': [('næmi', False)],
          'nænders': [('nand', False)],
          'nære': [('nære', False)],
          'næren': [('nær', False)],
          'nærens': [('nære', False)],
          'nærer': [('nær', False)],
          'nærers': [('nær', False)],
          'nærten': [('nært', False)],
          'næs': [('næs', True), ('næ', True)],
          'næsen': [('næse', False)],
          'næsens': [('næse', False)],
          'næser': [('næse', False)],
          'næserne': [('næse', False)],
          'næsernes': [('næse', False)],
          'næses': [('næse', False)],
          'næssene': [('næs', True)],
          'næssenes': [('næs', True)],
          'næsten': [('næste', True)],
          'nætter': [('nat', True)],
          'nætterne': [('nat', False)],
          'nætternes': [('nat', False)],
          'nætters': [('nat', False)],
          'næve': [('næve', False)],
          'næven': [('næve', False)],
          'nævens': [('næve', False)],
          'næver': [('næve', False)],
          'næverne': [('næve', False)],
          'nævernes': [('næve', True)],
          'nævers': [('næve', False)],
          'næves': [('næve', False)],
          'nævnerne': [('nævner', False)],
          'nævnernes': [('nævner', True)],
          'nævnet': [('nævn', False)],
          'nævnets': [('nævn', False)],
          'nødder': [('nød', False)],
          'nødderne': [('nød', False)],
          'nøddernes': [('nød', False)],
          'nødders': [('nød', False)],
          'nøens': [('nø', False)],
          'nøer': [('nø', False)],
          'nøerne': [('nø', False)],
          'nøers': [('nø', False)],
          'nøftet': [('nøft', False)],
          'nøftets': [('nøft', False)],
          'nøglerne': [('nøgle', False)],
          'nøje': [('nøje', False)],
          'nøjen': [('nøje', False)],
          'nøjens': [('nøje', False)],
          'nøjerne': [('nøje', False)],
          'nøjernes': [('nøje', False)],
          'nøjers': [('nøje', False)],
          'nøjes': [('nøje', False)],
          'nøjet': [('nøje', False)],
          'nøjets': [('nøje', False)],
          'nøjne': [('nøje', False)],
          'nøkken': [('nøkke', True)],
          'nøkkens': [('nøkke', True)],
          'nøkker': [('nøkke', True)],
          'nøkkernes': [('nøkke', True)],
          'nøkkers': [('nøkke', True)],
          'nøre': [('nøre', False)],
          'nøren': [('nøre', False)],
          'nørens': [('nør', False)],
          'nører': [('nøre', False)],
          'nørerne': [('nør', False)],
          'nørernes': [('nøre', False)],
          'nørers': [('nøre', False)],
          'nøres': [('nøre', False)],
          'nøs': [('nø', False)],
          'nøse': [('nøse', False)],
          'nøsen': [('nøs', False)],
          'nøsens': [('nøs', False)],
          'nøser': [('nøse', False)],
          'nøsers': [('nøse', False)],
          'nøses': [('nøs', False)],
          'nøvlet': [('nøvl', False)],
          'nøvlets': [('nøvl', False)],
          'nøvs': [('nøvs', False)],
          'o': [('o', True)],
          "o'erne": [('o', False)],
          'o.': [('o.', False)],
          'oa': [('oa', False)],
          'oachen': [('oach', False)],
          'oachens': [('oach', False)],
          'oaches': [('oach', False)],
          'oader': [('oader', False)],
          'oaderne': [('oader', False)],
          'oadernes': [('oader', False)],
          'oaders': [('oader', False)],
          'oadien': [('oadie', False)],
          'oadiens': [('oadie', False)],
          'oadier': [('oadie', False)],
          'oadierne': [('oadie', False)],
          'oadiernes': [('oadie', False)],
          'oadies': [('oadie', False)],
          'oaen': [('oa', False)],
          'oaens': [('oa', False)],
          'oaer': [('oa', False)],
          'oaerne': [('oa', False)],
          'oaernes': [('oa', False)],
          'oaers': [('oa', False)],
          'oakken': [('oak', False)],
          'oakkerne': [('oak', False)],
          'oaks': [('oak', False)],
          'oakter': [('oakter', False)],
          'oakterne': [('oakter', False)],
          'oakternes': [('oakter', False)],
          'oakters': [('oakter', False)],
          'oalas': [('oala', False)],
          'oaner': [('oaner', False)],
          'oanerne': [('oaner', False)],
          'oanernes': [('oaner', False)],
          'oaners': [('oaner', False)],
          'oas': [('oa', False)],
          'oase': [('oase', True)],
          'oasen': [('oase', True)],
          'oasens': [('oase', True)],
          'oaser': [('oase', True)],
          'oaserne': [('oase', True)],
          'oasernes': [('oase', True)],
          'oasers': [('oase', True)],
          'oases': [('oase', True)],
          'oasten': [('oast', False)],
          'oastens': [('oast', False)],
          'oasterne': [('oaster', False)],
          'oasters': [('oaster', False)],
          'oatene': [('oat', False)],
          'oatenes': [('oat', False)],
          'oaternes': [('oat', False)],
          'obakken': [('obak', False)],
          'obakkens': [('obak', False)],
          'obakker': [('obak', False)],
          'obakkerne': [('obak', False)],
          'obakkernes': [('obak', False)],
          'obakkers': [('obak', False)],
          'obanden': [('oband', False)],
          'obandens': [('oband', False)],
          'obander': [('oband', False)],
          'obanderne': [('oband', False)],
          'obandernes': [('oband', False)],
          'obanders': [('oband', False)],
          'obanken': [('obank', False)],
          'obankens': [('obank', False)],
          'obanker': [('obank', False)],
          'obankerne': [('obank', False)],
          'obankernes': [('obank', False)],
          'obankers': [('obank', False)],
          'obarden': [('obard', False)],
          'obardens': [('obard', False)],
          'obarder': [('obard', False)],
          'obarderne': [('obard', False)],
          'obardernes': [('obard', False)],
          'obarders': [('obard', False)],
          'obars': [('obar', False)],
          'obben': [('ob', False)],
          'obber': [('obber', False)],
          'obberne': [('obber', False)],
          'obbernes': [('obber', False)],
          'obbers': [('obber', False)],
          'obe': [('ob', False)],
          'oben': [('ob', False)],
          'obene': [('ob', False)],
          'obenes': [('ob', False)],
          'obenets': [('oben', False)],
          'obens': [('ob', False)],
          'ober': [('obe', False)],
          'oberet': [('ober', False)],
          'oberets': [('ober', False)],
          'oberne': [('ob', False)],
          'obernes': [('obe', False)],
          'obers': [('ober', False)],
          'obersten': [('oberst', True)],
          'obes': [('ob', False)],
          'obet': [('ob', False)],
          'obets': [('ob', False)],
          'obilen': [('obil', False)],
          'obilens': [('obil', False)],
          'obilerne': [('obil', False)],
          'obilernes': [('obil', False)],
          'obilers': [('obil', False)],
          'obiner': [('obine', False)],
          'obinerne': [('obine', False)],
          'obinernes': [('obiner', False)],
          'obiners': [('obine', False)],
          'obinet': [('obin', False)],
          'obinets': [('obin', False)],
          'obis': [('obis', False)],
          'obisen': [('obis', False)],
          'obisens': [('obis', False)],
          'obiser': [('obis', False)],
          'obiserne': [('obis', False)],
          'obisernes': [('obis', False)],
          'obisers': [('obis', False)],
          'obissen': [('obisse', False)],
          'obisser': [('obisse', False)],
          'obisserne': [('obisse', False)],
          'obissernes': [('obisse', False)],
          'obissers': [('obisse', False)],
          'obitter': [('obit', False)],
          'obitterne': [('obit', False)],
          'obitternes': [('obit', False)],
          'obitters': [('obit', False)],
          'oble': [('oble', False)],
          'oblen': [('oble', False)],
          'oblens': [('obel', False)],
          'obler': [('obbel', False)],
          'oblerne': [('oble', False)],
          'oblernes': [('oble', False)],
          'oblers': [('oble', False)],
          'obles': [('oble', False)],
          'oblet': [('obbel', False)],
          'oblets': [('obbel', False)],
          'oboer': [('obo', True)],
          'oboerne': [('obo', True)],
          'oboernes': [('obo', True)],
          'oboers': [('obo', True)],
          'obras': [('obra', False)],
          'obriks': [('obrik', False)],
          'obringen': [('obring', False)],
          'obringens': [('obring', False)],
          'obringer': [('obring', False)],
          'obringerne': [('obring', False)],
          'obringernes': [('obring', False)],
          'obringers': [('obring', False)],
          'obroer': [('obroer', False)],
          'obroerne': [('obroer', False)],
          'obroernes': [('obroer', False)],
          'obroers': [('obro', False)],
          'obs': [('obs', True)],
          "obs'": [('ob', False)],
          'obspillets': [('obspil', False)],
          'obuens': [('obue', False)],
          'obuer': [('obue', False)],
          'obuerne': [('obue', False)],
          'ocellen': [('ocelle', False)],
          'oceller': [('ocelle', False)],
          'ocellers': [('ocelle', False)],
          'ocen': [('oc', False)],
          'ocene': [('oc', False)],
          'ocenes': [('oc', False)],
          'ocens': [('oc', False)],
          'ocenters': [('ocent', False)],
          'ocentre': [('ocenter', False)],
          'ocentrene': [('ocenter', False)],
          'ocentrenes': [('ocenter', False)],
          'ocentres': [('ocenter', False)],
          'ocentret': [('ocenter', False)],
          'ocentrets': [('ocenter', False)],
          'ocentrum': [('ocenter', False)],
          'ocentrummer': [('ocenter', False)],
          'ocentrummerne': [('ocenter', False)],
          'ocentrummernes': [('ocenter', False)],
          'ocentrummers': [('ocenter', False)],
          'ocentrummet': [('ocenter', False)],
          'ocentrummets': [('ocenter', False)],
          'ocentrums': [('ocenter', False)],
          'ocer': [('oc', False)],
          'ocerne': [('oc', False)],
          'ocernes': [('oc', False)],
          'ocers': [('oc', False)],
          'oces': [('oces', False)],
          "oces'": [('oces', False)],
          'oche': [('oche', False)],
          'ochen': [('oche', False)],
          'ochens': [('oche', False)],
          'ocher': [('oche', False)],
          'ocherne': [('oche', False)],
          'ochers': [('oche', False)],
          'oches': [('oche', False)],
          'ochips': [('ochip', False)],
          "ochips'": [('ochip', False)],
          'ochipsene': [('ochip', False)],
          'ochipsenes': [('ochip', False)],
          'ocider': [('ocid', False)],
          'ociderne': [('ocid', False)],
          'ocidernes': [('ocid', False)],
          'ociders': [('ocid', False)],
          "ocks'": [('ocks', False)],
          'od': [('od', False)],
          'odansers': [('odanser', False)],
          'odas': [('oda', False)],
          'odbroderen': [('odbroder', False)],
          'oddagen': [('oddagen', False)],
          'odde': [('od', True), ('odde', True)],
          'odden': [('od', True), ('odde', True)],
          'oddens': [('od', True), ('odde', True)],
          'odder': [('odder', True), ('odde', True)],
          'odderne': [('odder', True), ('odde', True)],
          'oddernes': [('odder', True), ('odde', True)],
          'odders': [('odder', True), ('odde', True)],
          'oddes': [('od', True), ('odde', True)],
          'odehandler': [('odehandler', False)],
          'odehandlers': [('odehandler', False)],
          'odeje': [('odej', False)],
          'odejes': [('odej', False)],
          'odellen': [('odel', False)],
          'odellens': [('odel', False)],
          'odeller': [('odel', False)],
          'odellerne': [('odel', False)],
          'odellernes': [('odel', False)],
          'odellers': [('odel', False)],
          'oden': [('ode', True)],
          'odenden': [('odende', False)],
          'odendens': [('odende', False)],
          'odene': [('od', False)],
          'odenes': [('od', False)],
          'odens': [('ode', True)],
          'odentalens': [('odental', False)],
          'odentalers': [('odental', False)],
          'oder': [('ode', False)],
          'odere': [('oder', False)],
          'oderen': [('oder', False)],
          'oderens': [('oder', False)],
          'oderes': [('oder', False)],
          'oderet': [('oder', False)],
          'oderets': [('oder', False)],
          'oderne': [('ode', False)],
          'odernes': [('ode', False)],
          'oderpar': [('ødrepar', False)],
          'oderparrene': [('ødrepar', False)],
          'oderparrenes': [('ødrepar', False)],
          'oderparret': [('ødrepar', False)],
          'oderparrets': [('ødrepar', False)],
          'oderpars': [('ødrepar', False)],
          'oders': [('ode', True)],
          'odes': [('ode', False)],
          "odes'": [('ode', False)],
          'odesen': [('odes', False)],
          'odesens': [('odes', False)],
          'odet': [('od', False)],
          'odets': [('od', False)],
          'odgifte': [('odgift', False)],
          'odgiftes': [('odgift', False)],
          'odi': [('odus', False)],
          'odianer': [('odianer', False)],
          'odianers': [('odianer', False)],
          'odier': [('odie', False)],
          'odierne': [('odie', False)],
          'odiernes': [('odi', False)],
          'odiers': [('odie', False)],
          'odies': [('odie', False)],
          'odiet': [('odie', False)],
          'odiets': [('odie', False)],
          'odiker': [('odiker', False)],
          'odikerne': [('odiker', False)],
          'odikernes': [('odiker', False)],
          'odikers': [('odiker', False)],
          'odiks': [('odik', False)],
          'odis': [('odi', False)],
          'oditten': [('odit', False)],
          'odlejer': [('odleje', False)],
          'odlen': [('odlen', False)],
          'odlens': [('odlen', False)],
          'odnet': [('odnet', False)],
          'odriver': [('odriver', False)],
          'odriverne': [('odriver', False)],
          'odrivernes': [('odriver', False)],
          'odrivers': [('odriver', False)],
          'ods': [('od', False)],
          'odskifterne': [('odskifte', False)],
          'odskifternes': [('odskifte', False)],
          'odskifters': [('odskifte', False)],
          'odstykker': [('odstykke', False)],
          'odstykkerne': [('odstykke', False)],
          'odsuger': [('odsuger', False)],
          'odsugerne': [('odsuger', False)],
          'odsugernes': [('odsuger', False)],
          'odsugers': [('odsuger', False)],
          'odsøerne': [('odsø', False)],
          'odsøernes': [('odsø', False)],
          'odsøers': [('odsø', False)],
          'odte': [('odte', False)],
          'odten': [('odte', False)],
          'odtens': [('odte', False)],
          'odter': [('odte', False)],
          'odterne': [('odte', False)],
          'odternes': [('odte', False)],
          'odters': [('odte', False)],
          'odtes': [('odte', False)],
          'odus': [('odus', False)],
          'odværge': [('odværge', False)],
          'odværges': [('odværge', False)],
          'odækker': [('odækker', False)],
          'odækkerne': [('odækker', False)],
          'odækkernes': [('odækker', False)],
          'odækkers': [('odækker', False)],
          'odækket': [('odæk', False)],
          'odækkets': [('odæk', False)],
          'odører': [('odør', True)],
          'odørers': [('odør', True)],
          'oe': [('oe', False)],
          'oelsers': [('oelse', False)],
          'oene': [('o', False)],
          'oenes': [('o', False)],
          'oersken': [('oerske', False)],
          'oersker': [('oerske', False)],
          'oerskerne': [('oerske', False)],
          'oerskers': [('oerske', False)],
          'oes': [('oe', False)],
          'oesierne': [('oesi', False)],
          'oesiernes': [('oesi', False)],
          'oesiers': [('oesi', False)],
          'oesis': [('oesi', False)],
          'oeter': [('oet', False)],
          'oeters': [('oet', False)],
          'of': [('of', False)],
          'ofagen': [('ofag', False)],
          'ofanger': [('ofanger', False)],
          'ofangerne': [('ofanger', False)],
          'ofangernes': [('ofanger', False)],
          'ofangers': [('ofanger', False)],
          'ofas': [('ofa', False)],
          'ofe': [('ofe', False)],
          'ofen': [('ofe', False)],
          'ofens': [('ofe', False)],
          'ofer': [('ofe', False)],
          'oferen': [('ofer', False)],
          'oferens': [('ofer', False)],
          'oferes': [('ofer', False)],
          'oferien': [('oferie', False)],
          'oferier': [('oferie', False)],
          'oferierne': [('oferie', False)],
          'oferiers': [('oferie', False)],
          'oferne': [('ofe', False)],
          'ofernes': [('ofer', False)],
          'ofers': [('ofe', False)],
          'ofes': [('ofe', False)],
          'ofets': [('ofet', False)],
          'offen': [('of', False)],
          'offens': [('of', False)],
          'offer': [('offer', False)],
          'offerne': [('of', False)],
          'offers': [('offer', False)],
          'offet': [('off', False)],
          'offets': [('of', False)],
          'ofilet': [('ofil', False)],
          'ofilets': [('ofil', False)],
          'ofis': [('ofi', False)],
          'ofløjten': [('ofløjte', False)],
          'ofonier': [('ofonium', False)],
          'ofonierne': [('ofoni', False)],
          'ofoniernes': [('ofoni', False)],
          'ofoniers': [('ofoni', False)],
          'ofons': [('ofon', False)],
          'oformer': [('oform', False)],
          'oformerne': [('oform', False)],
          'oformernes': [('oform', False)],
          'oformers': [('oform', False)],
          'oforter': [('oforte', False)],
          'oforterne': [('oforte', False)],
          'oforternes': [('oforte', False)],
          'oforters': [('oforte', False)],
          'ofortet': [('oforte', False)],
          'ofortets': [('oforte', False)],
          'ofos': [('ofos', False)],
          'ofrelser': [('ofrelse', False)],
          'ofrelserne': [('ofrelse', False)],
          'ofrelsernes': [('ofrelse', False)],
          'ofrelsers': [('ofrelse', False)],
          'ofret': [('offer', True)],
          'ofrets': [('offer', True)],
          'ofretter': [('ofret', False)],
          'ofretterne': [('ofret', False)],
          'ofretternes': [('ofret', False)],
          'ofretters': [('ofret', False)],
          'ofte': [('ofte', False)],
          'often': [('ofte', False)],
          'oftens': [('ofte', False)],
          'ofter': [('oft', False)],
          'ofterne': [('ofte', False)],
          'ofternes': [('ofte', False)],
          'ofters': [('ofte', False)],
          'oftes': [('ofte', False)],
          'oførerne': [('ofører', False)],
          'og': [('og', False)],
          'oganer': [('ogan', False)],
          'oganerne': [('ogan', False)],
          'oganernes': [('ogan', False)],
          'oganers': [('ogan', False)],
          'ogas': [('ogas', False)],
          'oge': [('og', False)],
          'ogen': [('og', False)],
          'ogene': [('og', False)],
          'ogener': [('ogen', False)],
          'ogenerne': [('ogen', False)],
          'ogenernes': [('ogen', False)],
          'ogeners': [('ogen', False)],
          'ogenes': [('og', False)],
          'ogenet': [('ogen', False)],
          'ogenets': [('ogen', False)],
          'ogens': [('og', False)],
          'ogenser': [('ogenser', False)],
          'ogensernes': [('ogenser', False)],
          'ogere': [('oger', False)],
          'ogeren': [('oger', False)],
          'ogerens': [('oger', False)],
          'ogeres': [('oger', False)],
          'oges': [('og', False)],
          'oget': [('og', False)],
          'ogge': [('ogge', False)],
          'oggen': [('ogge', False)],
          'oggenes': [('og', False)],
          'oggens': [('ogge', False)],
          'oggernes': [('ogger', False)],
          'oggers': [('og', False)],
          'ogges': [('ogge', False)],
          'oggings': [('ogging', False)],
          'ogien': [('ogie', False)],
          'ogiens': [('ogi', False)],
          'ogier': [('ogie', False)],
          'ogierne': [('ogie', False)],
          'ogiernes': [('ogie', False)],
          'ogiers': [('ogie', False)],
          'ogiet': [('ogi', False)],
          'ogiministeriet': [('ogiministerium', False)],
          'ogis': [('ogi', False)],
          'ogister': [('ogist', False)],
          'oglader': [('oglade', False)],
          'ogladernes': [('oglade', False)],
          'ogle': [('ogle', False)],
          'oglen': [('ogle', False)],
          'oglernes': [('ogle', False)],
          'oglers': [('ogle', False)],
          'ogles': [('ogle', False)],
          'ogliets': [('ogliet', False)],
          'ogne': [('ogne', False)],
          'ognen': [('ogne', False)],
          'ognens': [('ogne', False)],
          'ogner': [('ogne', False)],
          'ognernes': [('ogne', False)],
          'ogners': [('ogne', False)],
          'ognes': [('ogne', False)],
          'ognier': [('ogni', False)],
          'ognierne': [('ogni', False)],
          'ogniernes': [('ogni', False)],
          'ogniers': [('ogni', False)],
          'ognummer': [('ognummer', False)],
          'ograms': [('ogram', False)],
          'ogrene': [('oger', False)],
          'ogrenes': [('oger', False)],
          'ogres': [('oger', False)],
          'ogs': [('og', False)],
          "ogs'": [('og', False)],
          'ogsene': [('og', False)],
          'ogsenes': [('og', False)],
          'ogter': [('ogter', False)],
          'ogterne': [('ogter', False)],
          'ogternes': [('ogter', False)],
          'ogters': [('ogt', False)],
          'ogøret': [('ogøre', False)],
          'ohalerne': [('ohale', False)],
          'ohandler': [('ohandler', False)],
          'ohandlerne': [('ohandler', False)],
          'ohandlernes': [('ohandler', False)],
          'ohandlers': [('ohandler', False)],
          'ohans': [('ohan', False)],
          'ohave': [('ohave', False)],
          'ohaver': [('ohaver', False)],
          'ohaverne': [('ohaver', False)],
          'ohavernes': [('ohaver', False)],
          'ohavers': [('ohaver', False)],
          'ohaves': [('ohave', False)],
          'ohavet': [('ohave', False)],
          'ohavets': [('ohave', False)],
          'ohemen': [('oheme', False)],
          'ohemens': [('oheme', False)],
          'ohikanerne': [('ohikaner', False)],
          'ohikanernes': [('ohikaner', False)],
          'ohikaners': [('ohikaner', False)],
          'ohærens': [('ohærens', False)],
          'oide': [('oide', False)],
          'oiden': [('oide', False)],
          'oidens': [('oide', False)],
          'oider': [('oide', False)],
          'oiderne': [('oide', False)],
          'oidernes': [('oide', False)],
          'oiders': [('oide', False)],
          'oides': [('oide', False)],
          'oiler': [('oil', False)],
          'oilerne': [('oiler', False)],
          'oilernes': [('oiler', False)],
          'oilers': [('oiler', False)],
          'oilet': [('oilet', False)],
          'oiletten': [('oilette', False)],
          'ointen': [('oint', False)],
          'ointens': [('oint', False)],
          'ointet': [('oint', False)],
          'ointets': [('oint', False)],
          'oiren': [('oir', False)],
          'oirer': [('oirer', False)],
          'oirerne': [('oir', False)],
          'oirernes': [('oirer', False)],
          'oirers': [('oir', False)],
          'oires': [('oires', False)],
          'oiret': [('oire', False)],
          'oirets': [('oire', False)],
          'oisers': [('ois', False)],
          'oismen': [('oisme', False)],
          'oismens': [('oisme', False)],
          'oisten': [('oist', False)],
          'oistens': [('oist', False)],
          'oister': [('oist', False)],
          'oisterne': [('oist', False)],
          'oisternes': [('oist', False)],
          'oisters': [('oist', False)],
          'ojaner': [('ojan', False)],
          'ojanerne': [('ojan', False)],
          'ojanernes': [('ojaner', False)],
          'ojaners': [('ojan', False)],
          'ojas': [('oja', False)],
          'ojeder': [('ojede', False)],
          'ojeders': [('ojede', False)],
          'ojen': [('oj', False)],
          'ojens': [('oj', False)],
          'ojer': [('oj', False)],
          'ojerne': [('oj', False)],
          'ojernes': [('oj', False)],
          'ojers': [('oj', False)],
          'ojet': [('ojet', False)],
          'ojets': [('ojet', False)],
          'ojs': [('oj', False)],
          'ok': [('ok', False)],
          'oka': [('oka', False)],
          'okagen': [('okage', False)],
          'okagens': [('okage', False)],
          'okale': [('okale', False)],
          'okaler': [('okal', False)],
          'okalerne': [('okal', False)],
          'okalernes': [('okal', False)],
          'okalers': [('okal', False)],
          'okalken': [('okalk', False)],
          'okalkens': [('okalk', False)],
          'okanden': [('okande', False)],
          'okandernes': [('okande', False)],
          'okarten': [('okart', False)],
          'okartens': [('okart', False)],
          'okarter': [('okart', False)],
          'okarterne': [('okart', False)],
          'okarternes': [('okart', False)],
          'okarters': [('okart', False)],
          'okas': [('oka', False)],
          'okater': [('okat', False)],
          'okaterne': [('okat', False)],
          'okaters': [('okat', False)],
          'oken': [('ok', False)],
          'okene': [('ok', False)],
          'okenes': [('ok', False)],
          'okens': [('oke', False)],
          'oker': [('oker', False)],
          'okere': [('oker', False)],
          'okeren': [('oker', False)],
          'okerens': [('oker', False)],
          'okeres': [('oker', False)],
          'okerne': [('oker', False)],
          'okernes': [('oker', False)],
          'okers': [('oker', False)],
          'oket': [('oket', False)],
          'okets': [('ok', False)],
          'oketten': [('okette', False)],
          'okettens': [('okette', False)],
          'oketter': [('oket', False)],
          'oketterne': [('okette', False)],
          'oketternes': [('okette', False)],
          'oketters': [('okette', False)],
          'okien': [('okie', False)],
          'okiens': [('okie', False)],
          'okier': [('okie', False)],
          'okierne': [('okie', False)],
          'okiernes': [('okie', False)],
          'okiers': [('okie', False)],
          'okillernes': [('okille', False)],
          'okke': [('okke', False)],
          'okken': [('okke', False)],
          'okkens': [('ok', False)],
          'okker': [('okker', True)],
          'okkerne': [('okker', True)],
          'okkernes': [('okker', True)],
          'okkers': [('okker', True)],
          'okkes': [('okke', False)],
          'okket': [('ok', False)],
          'okkets': [('ok', False)],
          'oklapper': [('oklap', False)],
          'oklapperne': [('oklap', False)],
          'oklappernes': [('oklap', False)],
          'oklappers': [('oklap', False)],
          'oklaps': [('oklap', False)],
          'oklen': [('okkel', False)],
          'okler': [('okkel', False)],
          'oklerne': [('okkel', False)],
          'oklernes': [('okkel', False)],
          'oklers': [('okkel', False)],
          'oklet': [('oklet', False)],
          'oklets': [('oklet', False)],
          'oklingen': [('okling', False)],
          'oklingens': [('okling', False)],
          'oklinger': [('okling', False)],
          'oklingerne': [('okling', False)],
          'oklingernes': [('okling', False)],
          'oklingers': [('okling', False)],
          'okokos': [('okoko', False)],
          'okoks': [('okok', False)],
          'okollats': [('okollat', False)],
          'okollerne': [('okol', False)],
          'okollernes': [('okol', False)],
          'okon': [('okon', False)],
          'okonen': [('okon', False)],
          'okonens': [('okon', False)],
          'okoner': [('okon', False)],
          'okonerne': [('okon', False)],
          'okonernes': [('okon', False)],
          'okoners': [('okon', False)],
          'okons': [('okon', False)],
          'okopper': [('okopper', False)],
          'okopperne': [('okopper', False)],
          'okoppernes': [('okopper', False)],
          'okoppers': [('okopper', False)],
          'okoster': [('okost', False)],
          'okosterne': [('okost', False)],
          'okosternes': [('okost', False)],
          'okosters': [('okost', False)],
          'okotten': [('okotte', False)],
          'okottens': [('okotte', False)],
          'okotterne': [('okotte', False)],
          'okotternes': [('okotte', False)],
          'okotters': [('okotte', False)],
          'okrater': [('okrat', False)],
          'okraterne': [('okrat', False)],
          'okraternes': [('okrat', False)],
          'okraters': [('okrat', False)],
          'okronen': [('okrone', False)],
          'okronernes': [('okrone', False)],
          'oks': [('ok', False)],
          "oks'": [('ok', False)],
          'okse': [('okse', False)],
          'oksen': [('okse', False)],
          'oksens': [('okse', False)],
          'okser': [('okse', True)],
          'okserne': [('okse', False)],
          'oksernes': [('okse', False)],
          'oksers': [('okse', False)],
          'okses': [('okse', False)],
          'oksis': [('oksi', False)],
          'okstarterne': [('okstart', False)],
          'okstarternes': [('okstart', False)],
          'okstarters': [('okstart', False)],
          'oktet': [('oktet', True)],
          'oktets': [('oktet', True)],
          'okuerne': [('oku', False)],
          'okuernes': [('oku', False)],
          'okulden': [('okuld', False)],
          'okuldens': [('okuld', False)],
          'okummer': [('okum', False)],
          'okummerne': [('okum', False)],
          'okummernes': [('okum', False)],
          'okummers': [('okum', False)],
          'okummet': [('okum', False)],
          'okummets': [('okum', False)],
          'okuren': [('okur', False)],
          'okurens': [('okur', False)],
          'okures': [('okur', False)],
          'okurs': [('okur', False)],
          'okus': [('okus', False)],
          'okussen': [('okus', False)],
          'okussens': [('okus', False)],
          'okusser': [('okus', False)],
          'okusserne': [('okus', False)],
          'okussernes': [('okus', False)],
          'okussers': [('okus', False)],
          'okvisten': [('okvist', False)],
          'ol': [('ol', True)],
          'ol.': [('ol.', False)],
          'olader': [('olade', False)],
          'oladerne': [('olader', False)],
          'oladernes': [('olade', False)],
          'oladers': [('olade', False)],
          'olagen': [('olage', False)],
          'olagens': [('olage', False)],
          'olager': [('olage', False)],
          'olagerne': [('olage', False)],
          'olagernes': [('olage', False)],
          'olagers': [('olage', False)],
          'olaks': [('olak', False)],
          'olaner': [('olaner', False)],
          'olanerne': [('olaner', False)],
          'olanernes': [('olaner', False)],
          'olanter': [('olant', False)],
          'olanterne': [('olant', False)],
          'olanternes': [('olant', False)],
          'olanters': [('olant', False)],
          'olaps': [('olaps', False)],
          'olarer': [('olar', False)],
          'olarernes': [('olar', False)],
          'olariet': [('olarie', False)],
          'olariets': [('olarie', False)],
          'olars': [('olar', False)],
          'olas': [('ola', False)],
          'olbo': [('olbo', False)],
          'olboen': [('olbo', False)],
          'olboens': [('olbo', False)],
          'olboer': [('olbo', False)],
          'olboerne': [('olbo', False)],
          'olbos': [('olbo', False)],
          'olden': [('olden', True)],
          'oldene': [('olden', True)],
          'oldenes': [('olden', True)],
          'oldens': [('olden', True)],
          'older': [('older', False)],
          'olderne': [('older', False)],
          'oldernes': [('older', False)],
          'olders': [('old', False)],
          'oleer': [('oleum', False)],
          'oleerne': [('oleum', False)],
          'oleernes': [('oleum', False)],
          'oleers': [('oleum', False)],
          'olemærker': [('olemærker', False)],
          'olen': [('ol', False)],
          'olene': [('ol', False)],
          'olenes': [('ol', False)],
          'olens': [('ol', False)],
          'oler': [('ole', False)],
          'olere': [('oler', False)],
          'oleren': [('oler', False)],
          'olerens': [('oler', False)],
          'olerer': [('oler', False)],
          'olererne': [('oler', False)],
          'olerernes': [('oler', False)],
          'olerers': [('oler', False)],
          'oleres': [('oler', False)],
          'oleret': [('oler', False)],
          'olerets': [('oler', False)],
          'olerne': [('ole', False)],
          'olernes': [('ol', False)],
          'olers': [('ol', False)],
          'olet': [('ol', False)],
          'olets': [('ol', False)],
          'oletten': [('olet', False)],
          'olettens': [('olet', False)],
          'oletter': [('olet', False)],
          'oletterne': [('olet', False)],
          'oletternes': [('olet', False)],
          'oletters': [('olet', False)],
          'olevitten': [('olevitten', False)],
          'olfen': [('olfe', False)],
          'olfens': [('olfe', False)],
          'olfilters': [('olfilter', False)],
          'oli': [('olo', False)],
          'olias': [('olia', False)],
          'olibris': [('olibri', False)],
          'olicens': [('olice', False)],
          'oliden': [('olid', False)],
          'olider': [('olid', False)],
          'oliderne': [('olid', False)],
          'olidernes': [('olid', False)],
          'oliders': [('olid', False)],
          'olids': [('olid', False)],
          'olien': [('olie', False)],
          'oliene': [('oli', False)],
          'olienes': [('olo', False)],
          'oliens': [('olie', False)],
          'olier': [('olie', False)],
          'oliere': [('oliere', False)],
          'olieren': [('oliere', False)],
          'olierens': [('oliere', False)],
          'olierer': [('oliere', False)],
          'oliererne': [('oliere', False)],
          'olierernes': [('oliere', False)],
          'olierers': [('oliere', False)],
          'olieres': [('oliere', False)],
          'olierne': [('olie', True)],
          'oliernes': [('olie', False)],
          'oliers': [('olie', True)],
          'olies': [('olie', False)],
          'oliet': [('olie', False)],
          'oliets': [('olie', False)],
          'oligens': [('olig', False)],
          'oliker': [('oliker', False)],
          'olikerne': [('oliker', False)],
          'olikernes': [('oliker', False)],
          'olikers': [('oliker', False)],
          'olikker': [('olik', False)],
          'olikkernes': [('olik', False)],
          'olikkers': [('olik', False)],
          'olinen': [('olin', False)],
          'olinens': [('olin', False)],
          'oliner': [('oline', False)],
          'olinerne': [('olin', False)],
          'olinernes': [('olin', False)],
          'oliners': [('olin', False)],
          'olinet': [('olin', False)],
          'olinets': [('olin', False)],
          'olinger': [('olinger', False)],
          'olingerne': [('olinger', False)],
          'olingernes': [('olinger', False)],
          'olingers': [('oling', False)],
          'olis': [('olis', False)],
          'olismen': [('olisme', False)],
          'olisten': [('olist', False)],
          'olistens': [('olist', False)],
          'olister': [('olist', False)],
          'olisterne': [('olist', False)],
          'olisternes': [('olist', False)],
          'olisters': [('olist', False)],
          'oliter': [('oliter', False)],
          'oliternes': [('oliter', False)],
          'oliters': [('oliter', False)],
          'olits': [('olit', False)],
          'olitter': [('olit', False)],
          'oljen': [('olje', False)],
          'olkens': [('olkens', False)],
          'olkernes': [('olker', False)],
          'olkers': [('olker', False)],
          'olkurven': [('olkurve', False)],
          'olkurves': [('olkurve', False)],
          'ollagen': [('ollage', False)],
          'ollagens': [('ollage', False)],
          'ollaps': [('ollaps', False)],
          'olle': [('olle', False)],
          'olleger': [('ollega', False)],
          'ollegerne': [('ollega', False)],
          'ollegernes': [('ollege', False)],
          'ollegers': [('ollega', False)],
          'ollen': [('olle', False)],
          'ollens': [('ol', False)],
          'oller': [('olle', False)],
          'olles': [('olle', False)],
          'ollet': [('ol', False)],
          'ollets': [('olle', False)],
          'ollierne': [('ollie', False)],
          'ollinger': [('olling', False)],
          'ollingerne': [('olling', False)],
          'ollingernes': [('olling', False)],
          'ollis': [('olli', False)],
          'olme': [('olme', False)],
          'olmen': [('olme', False)],
          'olmens': [('olme', False)],
          'olmer': [('olme', False)],
          'olmere': [('olme', False)],
          'olmeren': [('olme', False)],
          'olmerens': [('olme', False)],
          'olmeres': [('olme', False)],
          'olmerne': [('olmer', False)],
          'olmernes': [('olme', False)],
          'olmers': [('olme', False)],
          'olmes': [('olme', False)],
          'olods': [('olod', False)],
          'ologen': [('olog', False)],
          'ologens': [('olog', False)],
          'ologer': [('olog', False)],
          'ologerne': [('olog', False)],
          'ologernes': [('olog', False)],
          'ologers': [('olog', False)],
          'ologets': [('ologet', False)],
          'olokkens': [('olok', False)],
          'olokker': [('olok', False)],
          'olokkerne': [('olok', False)],
          'olokkernes': [('olok', False)],
          'olokkers': [('olok', False)],
          'olonierne': [('oloni', False)],
          'oloniernes': [('oloni', False)],
          'oloniers': [('oloni', False)],
          'olorers': [('olore', False)],
          'olos': [('olos', False)],
          "olos'": [('olos', False)],
          'olossernes': [('olos', False)],
          'olossers': [('olos', False)],
          'olpe': [('olpe', False)],
          'olpen': [('olpe', False)],
          'olpens': [('olpe', False)],
          'olper': [('olpe', False)],
          'olperne': [('olpe', False)],
          'olpes': [('olpe', False)],
          'ols': [('ol', False)],
          "ols'": [('ol', False)],
          'olsernes': [('ols', False)],
          'olsers': [('ols', False)],
          'olset': [('ols', False)],
          'olsets': [('ols', False)],
          'olte': [('olte', False)],
          'oltene': [('olt', False)],
          'oltes': [('olte', False)],
          'oluen': [('oluen', False)],
          'oluens': [('oluen', False)],
          'olure': [('olur', False)],
          'olus': [('olus', False)],
          'olussen': [('olus', False)],
          'olussens': [('olus', False)],
          'olvens': [('olvens', False)],
          'olvinden': [('olvind', False)],
          'olvindens': [('olvind', False)],
          'olvindes': [('olvind', False)],
          'olys': [('olys', False)],
          'olytter': [('olyt', False)],
          'olytterne': [('olyt', False)],
          'olytternes': [('olytter', False)],
          'olytters': [('olyt', False)],
          'oløjer': [('oløje', False)],
          'oløjerne': [('oløje', False)],
          'oløjernes': [('oløje', False)],
          'oløjers': [('oløje', False)],
          'om': [('om', False)],
          'om.': [('om.', False)],
          'omaden': [('omade', False)],
          'omadens': [('omade', False)],
          'omagens': [('omage', False)],
          'omagernes': [('omager', False)],
          'omalier': [('omali', False)],
          'omalierne': [('omalier', False)],
          'omaliernes': [('omali', False)],
          'omaliers': [('omali', False)],
          'oman': [('oman', False)],
          'omanens': [('oman', False)],
          'omaner': [('omaner', True)],
          'omanerne': [('omaner', True)],
          'omanernes': [('omaner', True)],
          'omaners': [('omaner', True)],
          'omans': [('oman', False)],
          'omas': [('oma', False)],
          'omassens': [('omasse', False)],
          'omaster': [('omaster', False)],
          'omasterne': [('omaster', False)],
          'omasternes': [('omaster', False)],
          'omasters': [('omaster', False)],
          'ombers': [('ombe', False)],
          'ombiernes': [('ombie', False)],
          'ombiers': [('ombie', False)],
          'omediciner': [('omediciner', False)],
          'omedicinerne': [('omediciner', False)],
          'omedicinernes': [('omediciner', False)],
          'omediciners': [('omediciner', False)],
          'omelet': [('omelet', True)],
          'omelets': [('omelet', True)],
          'omen': [('omen', True)],
          'omene': [('om', False)],
          'omener': [('omen', False)],
          'omenerne': [('omen', False)],
          'omeners': [('omen', False)],
          'omenes': [('om', False)],
          'omens': [('omen', True)],
          'omenter': [('oment', False)],
          'omenterne': [('oment', False)],
          'omenternes': [('oment', False)],
          'omenters': [('oment', False)],
          'omer': [('om', False)],
          'omere': [('omer', False)],
          'omeren': [('omer', False)],
          'omerens': [('omer', False)],
          'omerer': [('omer', False)],
          'omererne': [('omer', False)],
          'omerernes': [('omer', False)],
          'omerers': [('omer', False)],
          'omeres': [('omer', False)],
          'omerne': [('om', False)],
          'omernes': [('om', False)],
          'omers': [('om', False)],
          'omet': [('om', False)],
          'ometer': [('ometer', False)],
          'ometerne': [('omet', False)],
          'ometernes': [('omet', False)],
          'ometers': [('ometer', False)],
          'ometre': [('ometer', False)],
          'ometrene': [('ometer', False)],
          'ometrenes': [('ometer', False)],
          'ometres': [('ometer', False)],
          'ometret': [('ometer', False)],
          'ometrets': [('ometer', False)],
          'omets': [('om', False)],
          'omhus': [('omhu', True)],
          'omider': [('omid', False)],
          'omiderne': [('omid', False)],
          'omidernes': [('omid', False)],
          'omiders': [('omid', False)],
          'omiks': [('omik', False)],
          'omilien': [('omilie', False)],
          'omiliens': [('omilie', False)],
          'omimer': [('omime', False)],
          'omimerne': [('omime', False)],
          'omimernes': [('omime', False)],
          'omimers': [('omime', False)],
          'ominer': [('omen', False)],
          'ominerne': [('omen', False)],
          'ominernes': [('omen', False)],
          'ominers': [('omen', False)],
          'omis': [('omi', False)],
          'omiser': [('omis', False)],
          'omiserne': [('omis', False)],
          'omisernes': [('omis', False)],
          'omitten': [('omit', False)],
          'omittens': [('omit', False)],
          'omitter': [('omit', False)],
          'omitterne': [('omit', False)],
          'omitternes': [('omit', False)],
          'omitters': [('omit', False)],
          'omkostninger': [('omkostning', False)],
          'omkostningerne': [('omkostning', True)],
          'omkostningernes': [('omkostning', False)],
          'omkostningers': [('omkostning', True)],
          'omle': [('omle', False)],
          'omlen': [('omle', False)],
          'omlens': [('omle', False)],
          'omler': [('ommel', False)],
          'omlerne': [('omle', False)],
          'omlernes': [('omle', False)],
          'omlers': [('omle', False)],
          'omles': [('omle', False)],
          'omm.': [('omm.', False)],
          'omme': [('omme', False)],
          'ommelsers': [('ommelse', False)],
          'ommen': [('omme', False)],
          'ommens': [('omme', False)],
          'ommer': [('ommer', True)],
          'ommerne': [('ommer', True)],
          'ommernes': [('ommer', True)],
          'ommers': [('ommer', False)],
          'ommes': [('omme', False)],
          'ommoders': [('ommode', False)],
          'omobilen': [('omobil', False)],
          'omobilens': [('omobil', False)],
          'omobiler': [('omobil', False)],
          'omobilerne': [('omobil', False)],
          'omobilernes': [('omobil', False)],
          'omobilers': [('omobil', False)],
          'omobilet': [('omobil', False)],
          'omobilets': [('omobil', False)],
          'omoner': [('omon', False)],
          'omonerne': [('omon', False)],
          'omonernes': [('omon', False)],
          'omoners': [('omon', False)],
          'omorer': [('omorer', False)],
          'omorerne': [('omorer', False)],
          'omorernes': [('omorer', False)],
          'omorers': [('omorer', False)],
          'omos': [('omo', False)],
          'ompet': [('ompet', False)],
          'ompets': [('ompet', False)],
          'omplet': [('omplet', False)],
          'omplets': [('omplet', False)],
          'ompresser': [('ompres', False)],
          'ompresserne': [('ompres', False)],
          'ompressernes': [('ompres', False)],
          'ompressers': [('ompres', False)],
          'området': [('område', False)],
          'oms': [('om', False)],
          "oms'": [('om', False)],
          'omsene': [('om', False)],
          'omsenes': [('om', False)],
          'omskifter': [('omskifter', True)],
          'omskifters': [('omskifter', True)],
          'omskiftet': [('omskift', True)],
          'omskiftets': [('omskift', True)],
          'omstens': [('omst', False)],
          'omster': [('omst', False)],
          'omsterne': [('omst', False)],
          'omsternes': [('omst', False)],
          'omsters': [('omst', False)],
          'omælken': [('omælk', False)],
          'omælkens': [('omælk', False)],
          'omænd': [('omand', False)],
          'omændene': [('omand', False)],
          'omæner': [('omæne', False)],
          'omæners': [('omæne', False)],
          'omærkerne': [('omærke', False)],
          'omærkers': [('omærke', False)],
          'omøderne': [('omøde', False)],
          'on': [('on', False)],
          'onader': [('onade', False)],
          'onagerne': [('onage', False)],
          'onagernes': [('onage', False)],
          'onagers': [('onage', False)],
          'onalen': [('onal', False)],
          'onaler': [('onal', False)],
          'onalerne': [('onal', False)],
          'onalernes': [('onal', False)],
          'onalers': [('onal', False)],
          'onanserne': [('onans', False)],
          'onansernes': [('onans', False)],
          'onanter': [('onant', False)],
          'onarbejder': [('onarbejde', False)],
          'onarbejderne': [('onarbejder', False)],
          'onarbejdernes': [('onarbejder', False)],
          'onarbejders': [('onarbejde', False)],
          'onaren': [('onar', False)],
          'onarens': [('onar', False)],
          'onarer': [('onar', False)],
          'onarernes': [('onar', False)],
          'onas': [('ona', False)],
          'onater': [('onat', False)],
          'onaterne': [('onat', False)],
          'onaternes': [('onate', False)],
          'onaters': [('onat', False)],
          'onavlen': [('onavl', False)],
          'onavlens': [('onavl', False)],
          'oncen': [('once', False)],
          'oncens': [('once', False)],
          'oncer': [('once', False)],
          'oncerne': [('once', False)],
          'oncernes': [('once', False)],
          'oncers': [('once', False)],
          'onda': [('onda', False)],
          'ondage': [('ondage', False)],
          'ondages': [('ondage', False)],
          'ondanten': [('ondant', False)],
          'ondantens': [('ondant', False)],
          'ondanterne': [('ondant', False)],
          'ondanternes': [('ondant', False)],
          'ondanters': [('ondant', False)],
          'ondas': [('onda', False)],
          'onde': [('onde', False)],
          'onden': [('onde', False)],
          'ondens': [('onde', False)],
          'ondenser': [('ondens', False)],
          'ondensernes': [('ondens', False)],
          'ondensers': [('ondens', False)],
          'onder': [('onde', True)],
          'onderne': [('onde', True)],
          'ondernes': [('onde', True)],
          'onders': [('onde', False)],
          'ondes': [('onde', True)],
          'ondet': [('onde', True)],
          'ondets': [('onde', False)],
          'ondis': [('ondi', False)],
          'ondoler': [('ondol', False)],
          'ondriet': [('ondrie', False)],
          'ondriets': [('ondrie', False)],
          "onds'": [('onds', False)],
          'onduen': [('ondue', False)],
          'onduens': [('ondue', False)],
          'ondus': [('ondus', False)],
          'onellens': [('onel', False)],
          'onellerne': [('onel', False)],
          'onellernes': [('onel', False)],
          'onen': [('on', False)],
          'onene': [('one', False)],
          'onenes': [('one', False)],
          'onens': [('on', False)],
          'oner': [('on', False)],
          'onerier': [('oneri', False)],
          'onerierne': [('oneri', False)],
          'oneriernes': [('oneri', False)],
          'oneriers': [('oneri', False)],
          'onerne': [('on', False)],
          'onernes': [('on', False)],
          'oners': [('on', False)],
          'oneser': [('oneser', False)],
          'oneserne': [('oneser', False)],
          'onesernes': [('oneser', False)],
          'onesierne': [('onesier', False)],
          'onesiernes': [('onesier', False)],
          'onesiers': [('onesier', False)],
          'onessen': [('onesse', False)],
          'onessens': [('onesse', False)],
          'onet': [('on', False)],
          'oneter': [('oneter', False)],
          'oneters': [('oneter', False)],
          'onets': [('on', False)],
          'onfølger': [('onfølger', False)],
          'onge': [('onge', False)],
          'ongen': [('onge', False)],
          'ongens': [('onge', False)],
          'ongerne': [('onge', False)],
          'ongernes': [('onge', False)],
          'ongers': [('ong', False)],
          'onges': [('onge', False)],
          'ongres': [('ongres', False)],
          'onien': [('onie', False)],
          'oniens': [('onie', False)],
          'onierne': [('oni', False)],
          'oniernes': [('oni', False)],
          'oniers': [('oni', False)],
          'oniet': [('onium', False)],
          'oniets': [('onium', False)],
          'onika': [('onika', False)],
          'onikaene': [('onikum', False)],
          'onikas': [('onika', False)],
          'oniker': [('oniker', False)],
          'onikerne': [('oniker', False)],
          'onikernes': [('oniker', False)],
          'onikers': [('oniker', False)],
          'oniks': [('onik', False)],
          'onikummet': [('onikum', False)],
          'onikummets': [('onikum', False)],
          'oninen': [('onin', False)],
          'oninens': [('onin', False)],
          'oningers': [('oning', False)],
          'onis': [('onis', False)],
          "onis'": [('onis', False)],
          'onissen': [('onis', False)],
          'onissens': [('onisse', False)],
          'onisser': [('onisse', False)],
          'onisserne': [('onisse', False)],
          'onissernes': [('onisse', False)],
          'onissers': [('onisse', False)],
          'onitten': [('onit', False)],
          'onittens': [('onit', False)],
          'onitter': [('onit', False)],
          'onitterne': [('onit', False)],
          'onitternes': [('onit', False)],
          'onitters': [('onit', False)],
          'onium': [('onium', False)],
          'oniums': [('onium', False)],
          'onkens': [('onk', False)],
          'onkernes': [('onk', False)],
          'onkers': [('onk', False)],
          'onklerne': [('onkel', False)],
          'onklernes': [('onkel', False)],
          'onklers': [('onkel', False)],
          'onkrets': [('onkret', False)],
          'onne': [('onne', False)],
          'onnen': [('onne', False)],
          'onnens': [('onne', False)],
          'onner': [('onne', False)],
          'onnerne': [('onne', False)],
          'onnernes': [('onne', False)],
          'onners': [('onne', False)],
          'onnes': [('onne', False)],
          'onnet': [('onnet', False)],
          'onnets': [('onnet', False)],
          'onninen': [('onnine', False)],
          'onninens': [('onnine', False)],
          'onoklens': [('onokel', False)],
          'onomens': [('onom', False)],
          'onomer': [('onom', False)],
          'onomerne': [('onom', False)],
          'onomernes': [('onom', False)],
          'onomers': [('onom', False)],
          'onpresser': [('onpresser', False)],
          'onpresserne': [('onpresser', False)],
          'onpressernes': [('onpresser', False)],
          'ons': [('on', False)],
          "ons'": [('on', False)],
          'onsaften': [('onsaft', False)],
          'onsaftens': [('onsaft', False)],
          'onsarbejder': [('onsarbejder', False)],
          'onsarbejderne': [('onsarbejder', False)],
          'onsarbejdernes': [('onsarbejder', False)],
          'onsens': [('onsens', False)],
          'onserne': [('ons', False)],
          'onsiliernes': [('onsilium', False)],
          'onsiliets': [('onsilium', False)],
          'onstres': [('onster', False)],
          'ontage': [('ontage', False)],
          'ontagen': [('ontage', False)],
          'ontages': [('ontage', False)],
          'ontalen': [('ontale', False)],
          'ontalerne': [('ontale', False)],
          'ontalernes': [('ontale', False)],
          'ontalers': [('ontale', False)],
          'ontanter': [('ontanter', False)],
          'onte': [('onte', False)],
          'onter': [('ont', False)],
          'ontes': [('onte', False)],
          'onti': [('onti', False)],
          'ontiden': [('ontid', False)],
          'ontinens': [('ontinens', False)],
          'ontis': [('onti', False)],
          'ontres': [('ontre', False)],
          'ontroller': [('ontroller', False)],
          'ontrollerne': [('ontroller', False)],
          'ontrollers': [('ontroller', False)],
          'onummers': [('onummer', False)],
          'onus': [('onus', False)],
          'onussernes': [('onus', False)],
          'onussers': [('onus', False)],
          'onyks': [('onyks', True)],
          'onys': [('ony', False)],
          'onzen': [('onze', False)],
          'onzens': [('onze', False)],
          'onzerne': [('onze', False)],
          'onzernes': [('onze', False)],
          'onærens': [('onær', False)],
          'onøren': [('onør', False)],
          'onører': [('onør', False)],
          'onørernes': [('onør', False)],
          'onørers': [('onør', False)],
          'onøsen': [('onøse', False)],
          'onøsens': [('onøse', False)],
          'onøses': [('onøse', False)],
          'oo': [('oo', False)],
          'ooden': [('ood', False)],
          'oodens': [('ood', False)],
          'ooen': [('oo', False)],
          'ooens': [('oo', False)],
          'ooer': [('oo', False)],
          'ooerne': [('oo', False)],
          'ooernes': [('oo', False)],
          'ooers': [('oo', False)],
          'ooet': [('oo', False)],
          'ooets': [('oo', False)],
          'oofer': [('oofer', False)],
          'ooferne': [('oofer', False)],
          'oofers': [('oofer', False)],
          'oogiens': [('oogie', False)],
          'ookens': [('ook', False)],
          'ooket': [('ook', False)],
          'ooler': [('ool', False)],
          'oolerne': [('ool', False)],
          'ooliers': [('oolie', False)],
          'oomen': [('oom', False)],
          'oomens': [('oom', False)],
          'ooner': [('ooner', False)],
          'oonerne': [('ooner', False)],
          'oonernes': [('ooner', False)],
          'ooners': [('ooner', False)],
          'oos': [('oo', False)],
          'ooter': [('ooter', False)],
          'ooterne': [('ooter', False)],
          'ooternes': [('ooter', False)],
          'ooters': [('ooter', False)],
          'opans': [('opan', False)],
          'opasens': [('opas', False)],
          'opaser': [('opas', False)],
          'opaserne': [('opas', False)],
          'opasernes': [('opas', False)],
          'opasers': [('opas', False)],
          'opater': [('opat', False)],
          'opaterne': [('opat', False)],
          'opaternes': [('opat', False)],
          'opaters': [('opat', False)],
          'opatiens': [('opati', False)],
          'opels': [('opel', False)],
          'open': [('op', False)],
          'opene': [('op', False)],
          'openes': [('op', False)],
          'opens': [('ope', False)],
          'oper': [('op', False)],
          'opere': [('oper', False)],
          'operens': [('oper', False)],
          'operes': [('oper', False)],
          'operne': [('op', False)],
          'opernes': [('op', False)],
          'opers': [('op', False)],
          'opes': [('ope', False)],
          'opet': [('op', False)],
          'opets': [('op', False)],
          'opids': [('opid', False)],
          'opien': [('opi', False)],
          'opiens': [('opi', False)],
          'opier': [('opi', False)],
          'opierne': [('opi', False)],
          'opiernes': [('opi', False)],
          'opiers': [('opi', False)],
          'opigerne': [('opige', False)],
          'opigernes': [('opige', False)],
          'opigers': [('opige', False)],
          'opillen': [('opille', False)],
          'opillernes': [('opille', False)],
          'opinet': [('opin', False)],
          'opinets': [('opin', False)],
          'opis': [('opi', False)],
          'opla': [('opla', False)],
          'oplader': [('oplader', True)],
          'opladerne': [('oplader', True)],
          'opladernes': [('oplader', True)],
          'opladers': [('oplader', True)],
          'oplanet': [('oplan', False)],
          'oplanets': [('oplan', False)],
          'oplanterne': [('oplanterne', False)],
          'oplanternes': [('oplanterne', False)],
          'ople': [('ople', False)],
          'oplen': [('ople', False)],
          'oplens': [('ople', False)],
          'opler': [('ople', False)],
          'oplerne': [('ople', False)],
          'oplernes': [('ople', False)],
          'oplers': [('ople', False)],
          'oples': [('ople', False)],
          'opoden': [('opod', False)],
          'opodens': [('opod', False)],
          'opoder': [('opod', False)],
          'opoderne': [('opod', False)],
          'opodernes': [('opod', False)],
          'opoders': [('opod', False)],
          'opolernes': [('opol', False)],
          'opolers': [('opol', False)],
          'opolet': [('opol', False)],
          'opolets': [('opol', False)],
          'opos': [('opos', False)],
          'oposer': [('opos', False)],
          'oposerne': [('opos', False)],
          'oposernes': [('opos', False)],
          'oposers': [('opos', False)],
          'oposter': [('opost', False)],
          'oposterne': [('opost', False)],
          'oposternes': [('opost', False)],
          'oposters': [('opost', False)],
          'oppe': [('oppe', False)],
          'oppen': [('oppe', False)],
          'oppens': [('oppe', False)],
          'opper': [('op', False)],
          'opperne': [('opper', False)],
          'oppernes': [('op', False)],
          'oppers': [('oppe', False)],
          'oppes': [('op', False)],
          'oppet': [('op', False)],
          'oppets': [('op', False)],
          'opras': [('opra', False)],
          'opretter': [('opretter', True)],
          'oprisen': [('opris', False)],
          'oprisens': [('opris', False)],
          'opriser': [('opris', False)],
          'opriserne': [('opris', False)],
          'oprisernes': [('opris', False)],
          'oprisers': [('opris', False)],
          'ops': [('op', False)],
          "ops'": [('op', False)],
          'opse': [('opsis', False)],
          'opsen': [('opsis', False)],
          'opsens': [('opsis', False)],
          'opser': [('opsis', False)],
          'opserne': [('opsis', False)],
          'opsernes': [('opsis', False)],
          'opsers': [('ops', False)],
          'opses': [('opsis', False)],
          'opsis': [('opsi', False)],
          'opterne': [('opter', False)],
          'opternes': [('opter', False)],
          'opters': [('opter', False)],
          'oputten': [('oput', False)],
          'oputtens': [('oput', False)],
          'oputter': [('oput', False)],
          'oputterne': [('oput', False)],
          'oputternes': [('oput', False)],
          'oputters': [('oput', False)],
          'or': [('or', False)],
          'orads': [('orads', False)],
          'oragter': [('oragter', False)],
          'oragterne': [('oragter', False)],
          'oragternes': [('oragter', False)],
          'orakkens': [('orak', False)],
          'orakker': [('orak', False)],
          'orakkerne': [('orak', False)],
          'orakkernes': [('orak', False)],
          'orakkers': [('orakker', False)],
          'orakler': [('orakel', True)],
          'oraklerne': [('orakel', True)],
          'oraklernes': [('orakel', True)],
          'oraklers': [('orakel', True)],
          'oraks': [('oraks', False)],
          'oralen': [('oral', False)],
          'oralens': [('oral', True)],
          'oraler': [('oral', False)],
          'oralerne': [('oral', False)],
          'oralernes': [('oral', False)],
          'oralers': [('oral', False)],
          'orancen': [('orance', False)],
          'orancens': [('orance', False)],
          'orander': [('orand', False)],
          'oranen': [('oran', False)],
          'oraner': [('oran', False)],
          'oranerne': [('oraner', False)],
          'oranernes': [('oraner', False)],
          'oraners': [('oran', False)],
          'orangen': [('orange', True)],
          'orangens': [('orange', False)],
          'oranger': [('orange', False)],
          'orangerne': [('orange', True)],
          'orangernes': [('orange', True)],
          'orangers': [('orange', False)],
          'orans': [('oran', False)],
          'orarbejder': [('orarbejde', False)],
          'orarbejderne': [('orarbejde', False)],
          'orater': [('orat', False)],
          'oraterne': [('orat', False)],
          'oraternes': [('orat', False)],
          'oraters': [('orat', False)],
          'oratorierne': [('oratorie', True)],
          'oratoriers': [('oratorie', True)],
          'oratoriet': [('oratorie', False)],
          'oratoriets': [('oratorie', False)],
          'orbens': [('orben', False)],
          'orber': [('orber', False)],
          'orberne': [('orber', False)],
          'orbernes': [('orber', False)],
          'orbers': [('orber', False)],
          'orbet': [('orbet', False)],
          'orbets': [('orbet', False)],
          'orbiernes': [('orbier', False)],
          'orbiers': [('orbier', False)],
          'orbrødrene': [('orbror', False)],
          'orbøllens': [('orbølle', False)],
          'orbøller': [('orbølle', False)],
          'orbøllerne': [('orbølle', False)],
          'orbøllernes': [('orbølle', False)],
          'orbøllers': [('orbølle', False)],
          'orcellens': [('orcelle', False)],
          'orceller': [('orcelle', False)],
          'orcellerne': [('orcelle', False)],
          'orcellernes': [('orcelle', False)],
          'ordanser': [('ordanser', False)],
          'ordanserne': [('ordanser', False)],
          'ordansernes': [('ordans', False)],
          'ordansers': [('ordans', False)],
          'orde': [('orde', False)],
          'ordeler': [('ordeler', False)],
          'ordelerne': [('ordel', False)],
          'ordelernes': [('ordeler', False)],
          'ordelers': [('ordeler', False)],
          'orden': [('orden', True)],
          'ordens': [('orden', False)],
          'order': [('ord', False)],
          'orderne': [('order', False)],
          'ordernes': [('order', False)],
          'orders': [('order', False)],
          'ordes': [('orde', False)],
          'ordinerne': [('ordin', False)],
          'ordiners': [('ordin', False)],
          'ordner': [('orden', False)],
          'ordnerne': [('orden', True)],
          'ordnernes': [('orden', True)],
          'ordners': [('orden', False)],
          'ordrer': [('ordre', True)],
          'ordrerne': [('ordre', True)],
          'ordrernes': [('ordre', True)],
          'ordrers': [('ordre', False)],
          'ore': [('or', False)],
          'oreer': [('oree', False)],
          'oreerne': [('oree', False)],
          'oreernes': [('oree', False)],
          'oreers': [('oree', False)],
          'orelærerne': [('orelære', False)],
          'orelærernes': [('orelære', False)],
          'oremer': [('orem', False)],
          'oremerne': [('orem', False)],
          'oremernes': [('orem', False)],
          'oremers': [('orem', False)],
          'oren': [('or', False)],
          'orenden': [('orende', False)],
          'orendens': [('orende', False)],
          'orene': [('or', False)],
          'orenes': [('or', False)],
          'orens': [('or', False)],
          'orer': [('or', False)],
          'orerne': [('or', False)],
          'orernes': [('or', False)],
          'orers': [('ore', False)],
          'ores': [('ore', False)],
          "ores'": [('ores', False)],
          'oresen': [('ores', False)],
          'oresens': [('ores', False)],
          'oret': [('or', False)],
          'oreterne': [('oret', False)],
          'oreternes': [('oret', False)],
          'orets': [('or', False)],
          'oretten': [('orette', False)],
          'orettens': [('orette', False)],
          'oretter': [('orette', False)],
          'oretterne': [('orette', False)],
          'oretternes': [('orette', False)],
          'oretters': [('orette', False)],
          'orfer': [('orf', False)],
          'orferne': [('orf', False)],
          'orfødder': [('orfod', False)],
          'orgen': [('orgen', False)],
          'orgens': [('org', False)],
          'orgenserne': [('orgenser', False)],
          'orgensers': [('orgenser', False)],
          'orges': [('orges', False)],
          'orgier': [('orgie', False)],
          'orgierne': [('orgie', True)],
          'orgiernes': [('orgie', True)],
          'orgiers': [('orgie', True)],
          'orginen': [('orgine', False)],
          'orginens': [('orgine', False)],
          'orginer': [('orgine', False)],
          'orginerne': [('orgine', False)],
          'orginernes': [('orgine', False)],
          'orhals': [('orhals', False)],
          'orhandlernes': [('orhandler', False)],
          'orhedens': [('orhed', False)],
          'oriander': [('oriander', False)],
          'orianer': [('orianer', False)],
          'orianerne': [('orian', False)],
          'orianernes': [('orian', False)],
          'orianers': [('orianer', False)],
          'orias': [('oria', False)],
          'oriden': [('orid', False)],
          'oridens': [('oride', False)],
          'orider': [('orid', False)],
          'oriderne': [('orid', False)],
          'oridernes': [('orid', False)],
          'oriders': [('orid', False)],
          'orids': [('orid', False)],
          'orien': [('orie', False)],
          'oriens': [('orie', False)],
          'orier': [('orie', False)],
          'orierne': [('orie', False)],
          'oriernes': [('orie', False)],
          'oriers': [('ori', False)],
          'ories': [('orie', False)],
          'orikkens': [('orik', False)],
          'orikker': [('orik', False)],
          'orikkernes': [('orik', False)],
          'orikkers': [('orik', False)],
          'oriks': [('orik', False)],
          'orinden': [('orinde', False)],
          'orindens': [('orinde', False)],
          'orinen': [('orin', False)],
          'orinens': [('orin', False)],
          'orinerne': [('orin', False)],
          'orinernes': [('orin', False)],
          'orinet': [('orin', False)],
          'orinets': [('orin', False)],
          'oringer': [('oring', False)],
          'oringerne': [('oring', False)],
          'oringernes': [('oring', False)],
          'oringers': [('oring', False)],
          'orins': [('orin', False)],
          'orinter': [('orinter', False)],
          'orinterne': [('orint', False)],
          'orinternes': [('orinter', False)],
          'orinters': [('orint', False)],
          'oris': [('oris', False)],
          'orissers': [('oris', False)],
          'orister': [('orist', False)],
          'oristerne': [('orist', False)],
          'oristernes': [('orist', False)],
          'oristers': [('orist', False)],
          'oritten': [('orit', False)],
          'orittens': [('orit', False)],
          'oritter': [('orit', False)],
          'oritterne': [('orit', False)],
          'oritternes': [('orit', False)],
          'oritters': [('orit', False)],
          'orium': [('orium', False)],
          'oriums': [('orium', False)],
          'orkaner': [('orkan', True)],
          'orkanernes': [('orkan', True)],
          'orken': [('ork', True)],
          'orkens': [('ork', True)],
          'orker': [('ork', True)],
          'orkerne': [('ork', True)],
          'orkernes': [('ork', True)],
          'orkers': [('ork', True)],
          'orkors': [('orkors', False)],
          'orkøbet': [('orkøbet', False)],
          'orlande': [('orland', False)],
          'orlandes': [('orland', False)],
          'orlover': [('orlov', True)],
          'orloverne': [('orlov', True)],
          'orlovernes': [('orlov', False)],
          'orlovers': [('orlov', False)],
          'ormaster': [('ormast', False)],
          'ormasters': [('ormast', False)],
          'ormer': [('orm', False)],
          'ormerne': [('ormer', False)],
          'ormernes': [('ormer', False)],
          'ormers': [('ormer', False)],
          'ormidler': [('ormidler', False)],
          'ormidlerne': [('ormidler', False)],
          'ormidlernes': [('ormidler', False)],
          'ormidlers': [('ormidler', False)],
          'orne': [('orne', False)],
          'ornen': [('orne', False)],
          'ornens': [('orne', True)],
          'orner': [('orne', False)],
          'ornernes': [('orne', False)],
          'ornes': [('orne', False)],
          'ornierne': [('ornier', False)],
          'orniernes': [('ornier', False)],
          'orniers': [('ornier', False)],
          'oroen': [('oro', False)],
          'oroens': [('oro', False)],
          'oroner': [('oron', False)],
          'oronerne': [('oron', False)],
          'oronernes': [('oron', False)],
          'oroners': [('oron', False)],
          'oros': [('oro', False)],
          'orosen': [('orose', False)],
          'orosens': [('orose', False)],
          'orottens': [('orotte', False)],
          'orotter': [('orotte', False)],
          'orotternes': [('orotte', False)],
          'orpe': [('orpe', False)],
          'orpen': [('orpe', False)],
          'orpens': [('orpe', False)],
          'orperne': [('orpe', False)],
          'orps': [('orps', False)],
          'orre': [('orre', False)],
          'orren': [('or', False)],
          'orrens': [('orre', False)],
          'orrer': [('orre', False)],
          'orrerne': [('orre', False)],
          'orrernes': [('orre', False)],
          'orrets': [('orret', False)],
          'ors': [('or', False)],
          "ors'": [('or', False)],
          'orsagen': [('orsage', False)],
          'orsager': [('orsage', False)],
          'orsagerne': [('orsager', False)],
          'orsagernes': [('orsager', False)],
          'orsagers': [('orsage', False)],
          'orser': [('orse', False)],
          'orserne': [('orse', False)],
          'orsernes': [('orse', False)],
          'orsers': [('orse', False)],
          'orses': [('orse', False)],
          'orsken': [('orsk', False)],
          'orsker': [('orsker', False)],
          'orskerne': [('orsker', False)],
          'orskers': [('orsker', False)],
          'orskifternes': [('orskifte', False)],
          'orskiftes': [('orskifte', False)],
          'orskiftet': [('orskifte', False)],
          'orskiftets': [('orskifte', False)],
          'orsoner': [('orsoner', False)],
          'orsonerne': [('orsoner', False)],
          'orsonernes': [('orsoner', False)],
          'orsoners': [('orsoner', False)],
          'orstads': [('orstad', False)],
          'orste': [('orst', False)],
          'orsten': [('orst', False)],
          'orstene': [('orsten', False)],
          'orstenes': [('orst', False)],
          'orstens': [('orst', False)],
          'orster': [('orst', False)],
          'orsterne': [('orst', False)],
          'orsternes': [('orst', False)],
          'orsters': [('orst', False)],
          'orstes': [('orst', False)],
          'orsætter': [('orsæt', False)],
          'orsætternes': [('orsæt', False)],
          'ortage': [('ortage', False)],
          'ortages': [('ortage', False)],
          'ortalen': [('ortale', False)],
          'ortalens': [('ortal', False)],
          'ortalernes': [('ortale', False)],
          'ortalers': [('ortale', False)],
          'orte': [('orte', False)],
          'orten': [('orte', False)],
          'ortens': [('orte', False)],
          'orterer': [('orterer', False)],
          'ortererne': [('orterer', False)],
          'orterernes': [('orterer', False)],
          'orterers': [('orterer', False)],
          'orterne': [('orte', False)],
          'orternes': [('ort', False)],
          'ortes': [('orte', False)],
          'ortiers': [('ortier', False)],
          'ortlerne': [('ortel', False)],
          'ortlernes': [('ortel', False)],
          'ortlers': [('ortel', False)],
          'ortoget': [('ortog', False)],
          'ortogets': [('ortog', False)],
          'ortropper': [('ortrop', False)],
          'orts': [('orts', False)],
          "orts'": [('orts', False)],
          'orturens': [('ortur', False)],
          'ortænderne': [('ortand', False)],
          'ortænders': [('ortand', False)],
          'oruder': [('orude', False)],
          'oruderne': [('orude', False)],
          'orudernes': [('orude', False)],
          'oruders': [('orude', False)],
          'orunden': [('orund', False)],
          'orundens': [('orund', False)],
          'orvarer': [('orvare', False)],
          'orvarerne': [('orvare', False)],
          'orvarernes': [('orvare', False)],
          'orvarers': [('orvarer', False)],
          'orveje': [('orvej', False)],
          'orvejen': [('orvejen', False)],
          'orvejene': [('orvej', False)],
          'orvejenes': [('orvej', False)],
          'orvejes': [('orveje', False)],
          'orvet': [('orvet', False)],
          'orvets': [('orvet', False)],
          'orværker': [('orværk', False)],
          'orværkerne': [('orværk', False)],
          'orværkernes': [('orværk', False)],
          'orværkers': [('orværk', False)],
          'oræer': [('oræer', False)],
          'oræerne': [('oræer', False)],
          'oræernes': [('oræer', False)],
          'oræers': [('oræer', False)],
          'orænerne': [('oræne', False)],
          'oræners': [('oræne', False)],
          'os': [('os', False)],
          "os'": [('os', False)],
          'osaene': [('osum', False)],
          'osaenes': [('osum', False)],
          'osaks': [('osak', False)],
          'osarbejder': [('osarbejde', False)],
          'osarbejderne': [('osarbejde', False)],
          'osarbejdernes': [('osarbejde', False)],
          'osarier': [('osarium', False)],
          'osarierne': [('osarium', False)],
          'osariernes': [('osarium', False)],
          'osariers': [('osarium', False)],
          'osen': [('os', False)],
          'osens': [('os', False)],
          'oser': [('oser', True)],
          'osere': [('oser', True)],
          'oseren': [('oser', True)],
          'oserens': [('oser', True)],
          'oseres': [('oser', True)],
          'oserier': [('oseri', False)],
          'oserierne': [('oseri', False)],
          'oseriernes': [('oseri', False)],
          'oseriers': [('oseri', False)],
          'oserne': [('oser', True)],
          'osernes': [('oser', True)],
          'osers': [('oser', True)],
          'oset': [('oset', False)],
          'osets': [('oset', False)],
          'osetter': [('oset', False)],
          'osetterne': [('oset', False)],
          'osetternes': [('oset', False)],
          'osetters': [('oset', False)],
          'oshandler': [('oshandel', False)],
          'oshandlers': [('oshandel', False)],
          'osias': [('osia', False)],
          'osiden': [('osid', False)],
          'osidens': [('osid', False)],
          'osider': [('osid', False)],
          'osiderne': [('osid', False)],
          'osidernes': [('osid', False)],
          'osiders': [('osid', False)],
          'osinen': [('osin', False)],
          'osinens': [('osin', False)],
          'osinernes': [('osin', False)],
          'osis': [('osis', False)],
          'ositet': [('ositet', False)],
          'ositets': [('ositet', False)],
          'ositter': [('osit', False)],
          'ositterne': [('osit', False)],
          'osium': [('osium', False)],
          'osiums': [('osium', False)],
          'osiver': [('osiver', False)],
          'osivers': [('osiver', False)],
          'oskaber': [('oskab', False)],
          'oskaberne': [('oskab', False)],
          'oskabernes': [('oskab', False)],
          'oskabers': [('oskab', False)],
          'osken': [('oske', False)],
          'oskens': [('osk', False)],
          'osker': [('osk', False)],
          'oskerne': [('oske', False)],
          'oskernes': [('osk', False)],
          'oskers': [('oske', False)],
          'oskiftet': [('oskift', False)],
          'oskillingerne': [('oskilling', False)],
          'oskillingers': [('oskilling', False)],
          'oskos': [('osko', False)],
          'oslaven': [('oslav', False)],
          'oslavens': [('oslav', False)],
          'oslen': [('ossel', False)],
          'osler': [('ossel', False)],
          'oslerne': [('ossel', False)],
          'oslernes': [('ossel', False)],
          'oslers': [('ossel', False)],
          'oslinger': [('osling', False)],
          'oslingerne': [('osling', False)],
          'oslingernes': [('osling', False)],
          'oslingers': [('osling', False)],
          'osmer': [('osme', False)],
          'osmerne': [('osmer', False)],
          'osmernes': [('osme', False)],
          'osmers': [('osmer', False)],
          'ospekter': [('ospekt', False)],
          'ospekters': [('ospekt', False)],
          'ospits': [('ospits', False)],
          'ospænder': [('ospænder', False)],
          'ospænderne': [('ospænder', False)],
          'ospændernes': [('ospænder', False)],
          'ospænders': [('ospænder', False)],
          'ossagens': [('ossag', False)],
          'ossager': [('ossag', False)],
          'ossagerne': [('ossag', False)],
          'ossagernes': [('ossag', False)],
          'ossarierne': [('ossarium', False)],
          'ossariernes': [('ossarium', False)],
          'ossen': [('osse', False)],
          'ossene': [('os', False)],
          'ossenes': [('os', False)],
          'ossens': [('oss', False)],
          'osser': [('osse', False)],
          'osserne': [('osse', False)],
          'ossernes': [('os', False)],
          'ossers': [('os', False)],
          'osset': [('os', False)],
          'ossets': [('os', False)],
          'osskifternes': [('osskifte', False)],
          'osskiftes': [('osskifte', False)],
          'osskiftet': [('osskifte', False)],
          'ostamenter': [('ostament', False)],
          'ostamentet': [('ostament', False)],
          'ostamentets': [('ostament', False)],
          'oste': [('ost', True)],
          'ostemmer': [('ostemme', False)],
          'ostemmerne': [('ostemme', False)],
          'ostemmernes': [('ostemme', False)],
          'ostemmers': [('ostemme', False)],
          'ostempler': [('ostempel', False)],
          'ostemplerne': [('ostempel', False)],
          'ostemplernes': [('ostempel', False)],
          'ostemplers': [('ostempel', False)],
          'osten': [('ost', True)],
          'ostene': [('ost', False)],
          'ostenes': [('ost', False)],
          'ostens': [('ost', True)],
          'oster': [('oster', False)],
          'osterier': [('osteri', False)],
          'osterierne': [('osteri', True)],
          'osteriernes': [('osteri', False)],
          'osteriers': [('osteri', False)],
          'osteriet': [('osteri', False)],
          'osteriets': [('osteri', True)],
          'osterne': [('oster', False)],
          'osternes': [('oster', False)],
          'osters': [('oster', False)],
          'ostes': [('ost', True)],
          'ostien': [('ostie', False)],
          'ostiens': [('ostie', False)],
          'ostier': [('ostie', False)],
          'ostierne': [('ostie', False)],
          'ostiernes': [('ostie', False)],
          'ostiers': [('ostie', False)],
          'ostifter': [('ostifter', False)],
          'ostifterne': [('ostifter', False)],
          'ostifternes': [('ostifter', False)],
          'ostifters': [('ostifter', False)],
          'ostika': [('ostikon', False)],
          'ostikas': [('ostikon', False)],
          'ostikken': [('ostik', False)],
          'ostiller': [('ostil', False)],
          'ostillerne': [('ostil', False)],
          'ostillernes': [('ostil', False)],
          'ostillers': [('ostil', False)],
          'ostre': [('oster', False)],
          'ostringens': [('ostring', False)],
          'ostyret': [('ostyr', False)],
          'ostyrets': [('ostyr', False)],
          'ostøvler': [('ostøvle', False)],
          'ostøvlerne': [('ostøvle', False)],
          'ostøvlernes': [('ostøvle', False)],
          'osyren': [('osyre', False)],
          'osyrens': [('osyre', False)],
          'osyrer': [('osyre', False)],
          'osyrerne': [('osyre', False)],
          'osyrernes': [('osyre', False)],
          'osyrers': [('osyre', False)],
          'osætter': [('osætter', False)],
          'osætternes': [('osætter', False)],
          'osøren': [('osør', False)],
          'osørens': [('osør', False)],
          'osører': [('osør', False)],
          'osørernes': [('osør', False)],
          'ota': [('otum', False)],
          'otabene': [('otabene', False)],
          'otabenes': [('otabene', False)],
          'otaene': [('otum', False)],
          'otaenes': [('otum', False)],
          'otage': [('otage', False)],
          'otagens': [('otage', False)],
          'otager': [('otage', False)],
          'otagerne': [('otage', False)],
          'otagernes': [('otage', False)],
          'otagers': [('otage', False)],
          'otages': [('otage', False)],
          'otaksen': [('otakse', False)],
          'otaksens': [('otakse', False)],
          'otakter': [('otakter', False)],
          'otakterne': [('otakter', False)],
          'otakternes': [('otakter', False)],
          'otakters': [('otakter', False)],
          'otalen': [('otal', False)],
          'otalens': [('otal', False)],
          'otaler': [('otal', False)],
          'otalerne': [('otal', False)],
          'otalernes': [('otal', False)],
          'otalers': [('otal', False)],
          'otallerne': [('otal', False)],
          'otallernes': [('otal', False)],
          'otangen': [('otang', False)],
          'otangens': [('otangens', False)],
          'otarer': [('otar', False)],
          'otarernes': [('otar', False)],
          'otas': [('otum', False)],
          'otater': [('otat', False)],
          'otaterne': [('otat', False)],
          'otaternes': [('otat', False)],
          'otaters': [('otat', False)],
          'otats': [('otat', False)],
          'oteiner': [('otein', False)],
          'oteinerne': [('otein', False)],
          'oteiners': [('otein', False)],
          'oteker': [('otek', False)],
          'otekerne': [('otek', False)],
          'otekernes': [('otek', False)],
          'otekers': [('otek', False)],
          'oteket': [('otek', False)],
          'otekets': [('otek', False)],
          'otelets': [('otelet', False)],
          'otellerne': [('otel', False)],
          'otellernes': [('otel', False)],
          'otemmer': [('otem', False)],
          'otemmerne': [('otem', False)],
          'otemmernes': [('otem', False)],
          'otemmers': [('otem', False)],
          'oten': [('ot', False)],
          'otene': [('ot', False)],
          'otenes': [('ot', False)],
          'otens': [('ot', False)],
          'otenserne': [('otens', False)],
          'oter': [('ot', False)],
          'oterier': [('oteria', False)],
          'oterierne': [('oteria', False)],
          'oteriernes': [('oteria', False)],
          'oteriers': [('oteria', False)],
          'oteriet': [('oteria', False)],
          'oteriets': [('oteria', False)],
          'otermen': [('oterm', False)],
          'otermens': [('oterm', False)],
          'otermer': [('oterm', False)],
          'otermerne': [('oterm', False)],
          'otermernes': [('oterm', False)],
          'otermers': [('oterm', False)],
          'oterne': [('ot', False)],
          'oternes': [('ot', False)],
          'oters': [('ot', False)],
          "otes'": [('otes', False)],
          'oteser': [('otese', False)],
          'otesernes': [('otese', False)],
          'otesers': [('otese', False)],
          'otester': [('otest', False)],
          'otesterne': [('otest', False)],
          'otesternes': [('otest', False)],
          'otesters': [('otest', False)],
          'otet': [('ot', False)],
          'otets': [('ot', False)],
          'othandler': [('othandel', False)],
          'othandlers': [('othandel', False)],
          'other': [('other', False)],
          'otherne': [('other', False)],
          'othernes': [('other', False)],
          'others': [('other', False)],
          'otiden': [('otiden', False)],
          'otier': [('oti', False)],
          'otierne': [('oti', False)],
          'otiernes': [('oti', False)],
          'otiers': [('oti', False)],
          'otiet': [('otium', True)],
          'otiets': [('otium', True)],
          'otikas': [('otikum', False)],
          'otikkens': [('otik', False)],
          'otikker': [('otik', False)],
          'otikkernes': [('otik', False)],
          'otikkers': [('otik', False)],
          'otikon': [('otikon', False)],
          'otikons': [('otikon', False)],
          'otiks': [('otik', False)],
          'otillen': [('otille', False)],
          'otillens': [('otille', False)],
          'otiller': [('otille', False)],
          'otillerne': [('otille', False)],
          'otillernes': [('otille', False)],
          'otillers': [('otille', False)],
          'otinen': [('otin', False)],
          'otinens': [('otin', False)],
          'otiner': [('otin', False)],
          'otinerne': [('otin', False)],
          'otinernes': [('otin', False)],
          'otiners': [('otin', False)],
          'otinet': [('otin', False)],
          'otinets': [('otin', False)],
          'otis': [('oti', False)],
          'otits': [('otits', False)],
          'otium': [('otium', True)],
          'otiums': [('otium', True)],
          'otiver': [('otiv', False)],
          'otivernes': [('otiv', False)],
          'otningen': [('otning', False)],
          'otninger': [('otning', False)],
          'otningerne': [('otning', False)],
          'otningernes': [('otning', False)],
          'otoer': [('oto', False)],
          'otoerne': [('oto', False)],
          'otoernes': [('oto', False)],
          'otoers': [('oto', False)],
          'otonen': [('oton', False)],
          'otonens': [('oton', False)],
          'otoner': [('oton', False)],
          'otonerne': [('oton', False)],
          'otonernes': [('oton', False)],
          'otoners': [('oton', False)],
          'otonier': [('otoni', False)],
          'otonierne': [('otoni', False)],
          'otoniernes': [('otoni', False)],
          'otoniers': [('otoni', False)],
          'otrenden': [('otrende', False)],
          'otrendens': [('otrende', False)],
          'otrender': [('otrende', False)],
          'otrenderne': [('otrende', False)],
          'otrendernes': [('otrende', False)],
          'otrenders': [('otrende', False)],
          'otronen': [('otron', False)],
          'otronens': [('otron', False)],
          'otroner': [('otron', False)],
          'otronerne': [('otron', False)],
          'otronernes': [('otron', False)],
          'otroners': [('otron', False)],
          'otropen': [('otrop', False)],
          'otropens': [('otrop', False)],
          'otroper': [('otrop', False)],
          'otroperne': [('otrop', False)],
          'otropernes': [('otrop', False)],
          'otropers': [('otrop', False)],
          'ots': [('ot', False)],
          "ots'": [('ot', False)],
          'otsene': [('ot', False)],
          'otsenes': [('ot', False)],
          'otte': [('otte', False)],
          'otten': [('otte', False)],
          'ottens': [('otte', False)],
          'otter': [('otter', True)],
          'otteredes': [('otterede', False)],
          'otterne': [('otter', True)],
          'otternes': [('otter', True)],
          'otters': [('otter', True)],
          'ottes': [('otte', False)],
          'ottings': [('otting', False)],
          'otunden': [('otunde', False)],
          'otundens': [('otunde', False)],
          'otunder': [('otunde', False)],
          'otunders': [('otunde', False)],
          'oturen': [('otur', False)],
          'otures': [('otur', False)],
          'otus': [('otus', False)],
          'otylen': [('otyl', False)],
          'otylens': [('otyl', False)],
          'otypen': [('otyp', False)],
          'otypens': [('otype', False)],
          'otyper': [('otyp', False)],
          'otyperne': [('otyp', False)],
          'otypernes': [('otype', False)],
          'otypers': [('otype', False)],
          'otøjet': [('otøj', False)],
          'otører': [('otør', False)],
          'oublens': [('ouble', False)],
          'oubler': [('ouble', False)],
          'oublernes': [('ouble', False)],
          'ouchen': [('ouche', False)],
          'oucher': [('oucher', False)],
          'oucherne': [('oucher', False)],
          'ouchernes': [('ouche', False)],
          'ouchers': [('oucher', False)],
          'oudas': [('ouda', False)],
          'ouer': [('ou', False)],
          'ouerne': [('ou', False)],
          'ouernes': [('ou', False)],
          'ouers': [('ou', False)],
          'ouet': [('ou', False)],
          'ouets': [('ou', False)],
          'ouge': [('ouge', False)],
          'ougen': [('ouge', False)],
          'oula': [('oula', False)],
          'oulas': [('oula', False)],
          'oule': [('oule', False)],
          'oules': [('oule', False)],
          'oulets': [('oulet', False)],
          'ouli': [('ouli', False)],
          'ouliers': [('ouli', False)],
          'oulis': [('ouli', False)],
          'ounden': [('ound', False)],
          'oundens': [('ound', False)],
          'ouner': [('ouner', False)],
          'ounerne': [('ouner', False)],
          'ounernes': [('ouner', False)],
          'ouners': [('ouner', False)],
          'oungers': [('ounge', False)],
          'ounten': [('ount', False)],
          'ountens': [('ount', False)],
          'oupien': [('oupie', False)],
          'oupiens': [('oupie', False)],
          'oupiernes': [('oupie', False)],
          'ourer': [('ourer', False)],
          'ourers': [('ourer', False)],
          'ourgerne': [('ourger', False)],
          'ours': [('our', False)],
          "ours'": [('ours', False)],
          'oursen': [('ours', False)],
          'oursens': [('ours', False)],
          'ourser': [('ours', False)],
          'ourserne': [('ours', False)],
          'oursernes': [('ours', False)],
          'oursers': [('ours', False)],
          'ous': [('ou', False)],
          'ouse': [('ouse', False)],
          'ousen': [('ouse', False)],
          'ousens': [('ouse', False)],
          'ouser': [('ous', False)],
          'ousernes': [('ous', False)],
          'ousers': [('ous', False)],
          'ouses': [('ouse', False)],
          'ousierne': [('ousi', False)],
          'ousiernes': [('ousi', False)],
          'ousiers': [('ousi', False)],
          'oussen': [('ous', False)],
          'oussens': [('ous', False)],
          'ousser': [('ousse', False)],
          'oussernes': [('ousse', False)],
          'oussers': [('ousse', False)],
          'outen': [('oute', False)],
          'outens': [('oute', False)],
          'outer': [('out', False)],
          'outerne': [('oute', False)],
          'outernes': [('oute', False)],
          'outers': [('oute', False)],
          'outier': [('outier', False)],
          'outierne': [('outier', False)],
          'outure': [('outure', False)],
          'ovalen': [('oval', True)],
          'ovalens': [('oval', True)],
          'ovaler': [('oval', True)],
          'ovalerne': [('oval', True)],
          'ovalernes': [('oval', True)],
          'ovalers': [('oval', True)],
          'ovals': [('oval', True)],
          'ovarbejdernes': [('ovarbejder', False)],
          'ovaren': [('ovar', False)],
          'ovarens': [('ovar', False)],
          'ovarer': [('ovar', False)],
          'ovarerne': [('ovar', False)],
          'ovarernes': [('ovar', False)],
          'ovarers': [('ovar', False)],
          'ovariernes': [('ovarie', True)],
          'ovariet': [('ovarie', True)],
          'ovariets': [('ovarie', True)],
          'ove': [('ov', False)],
          'oveden': [('oved', False)],
          'ovedens': [('oved', False)],
          'oveder': [('oved', False)],
          'ovederne': [('oved', False)],
          'ovedernes': [('oved', False)],
          'oveders': [('oved', False)],
          'ovedet': [('oved', False)],
          'ovedets': [('oved', False)],
          'oveje': [('ovej', False)],
          'oveksler': [('oveksel', False)],
          'ovekslerne': [('oveksel', False)],
          'ovekslernes': [('oveksel', False)],
          'ovekslers': [('oveksel', False)],
          'ovellen': [('ovelle', False)],
          'oveller': [('ovelle', False)],
          'ovellerne': [('ovelle', False)],
          'ovellers': [('ovelle', False)],
          'oven': [('ov', False)],
          'ovene': [('ov', False)],
          'ovener': [('ovener', False)],
          'ovenerne': [('ovener', False)],
          'ovenernes': [('ovener', False)],
          'oveners': [('ovener', False)],
          'ovenes': [('ov', False)],
          'ovens': [('ov', False)],
          'over': [('over', True)],
          'overens': [('over', False)],
          'overet': [('over', False)],
          'overets': [('over', False)],
          'overne': [('over', True)],
          'overnes': [('over', False)],
          'overs': [('over', False)],
          "overs'": [('over', False)],
          'oves': [('ov', False)],
          'ovet': [('ov', False)],
          'ovets': [('ov', False)],
          'ovianer': [('ovianer', False)],
          'ovianers': [('ovianer', False)],
          'ovien': [('ovie', False)],
          'oviens': [('ovie', False)],
          'ovier': [('ovie', False)],
          'ovierne': [('ovie', False)],
          'oviernes': [('ovie', False)],
          'oviers': [('ovie', False)],
          'oviner': [('oviner', False)],
          'ovinerne': [('oviner', False)],
          'ovinernes': [('oviner', False)],
          'oviners': [('oviner', False)],
          'ovinger': [('ovinger', False)],
          'ovingerne': [('ovinger', False)],
          'ovingernes': [('ovinger', False)],
          'ovingers': [('ovinger', False)],
          'ovins': [('ovins', False)],
          'ovits': [('ovit', False)],
          'ovnerne': [('ovn', False)],
          'ovnernes': [('ovn', False)],
          'ovners': [('ovn', False)],
          'ovoer': [('ovoer', False)],
          'ovoerne': [('ovoer', False)],
          'ovoernes': [('ovoer', False)],
          'ovoers': [('ovoer', False)],
          'ovs': [('ov', False)],
          'ovse': [('ovse', False)],
          'ovsen': [('ovse', False)],
          'ovsens': [('ovs', False)],
          'ovser': [('ovse', False)],
          'ovserne': [('ovse', False)],
          'ovsernes': [('ovse', False)],
          'ovsers': [('ovs', False)],
          'ovses': [('ovse', False)],
          'ovædernes': [('ovæder', False)],
          'ovæders': [('ovæder', False)],
          'oværternes': [('ovært', False)],
          'ower': [('ow', False)],
          'owerne': [('ow', False)],
          'owernes': [('ow', False)],
          'owers': [('ow', False)],
          'owlen': [('owle', False)],
          'owlens': [('owle', False)],
          'oxer': [('ox', False)],
          'oxerne': [('ox', False)],
          'oxernes': [('ox', False)],
          'oxers': [('ox', False)],
          'oyen': [('oy', False)],
          'oyens': [('oyen', False)],
          'oyer': [('oy', False)],
          'oyere': [('oyer', False)],
          'oyeren': [('oyer', False)],
          'oyerens': [('oyer', False)],
          'oyerer': [('oyer', False)],
          'oyererne': [('oyer', False)],
          'oyerernes': [('oyer', False)],
          'oyerers': [('oyer', False)],
          'oyeres': [('oyer', False)],
          'oyerne': [('oy', False)],
          'oyernes': [('oy', False)],
          'oyers': [('oy', False)],
          'oys': [('oy', False)],
          "oys'": [('oy', False)],
          'oysene': [('oy', False)],
          'oysenes': [('oy', False)],
          'ozerne': [('ozer', False)],
          'ozernes': [('ozer', False)],
          'ozoens': [('ozo', False)],
          'ozonen': [('ozon', True)],
          'ozonens': [('ozon', True)],
          'oøje': [('oøje', False)],
          'oøjerne': [('oøje', False)],
          'oøjernes': [('oøje', False)],
          'oøjers': [('oøje', False)],
          'oøjes': [('oøje', False)],
          'oøjet': [('oøje', False)],
          'oøjets': [('oøje', False)],
          "p'er": [('p', True)],
          "p'erne": [('p', False)],
          "p'ernes": [('p', True)],
          "p'ers": [('p', True)],
          'pa': [('pa', False)],
          'pacen': [('pace', False)],
          'pacens': [('pace', False)],
          'packer': [('packer', False)],
          'packernes': [('packer', False)],
          'packs': [('pack', False)],
          "packs'": [('pack', False)],
          'padammen': [('padam', False)],
          'padammens': [('padam', False)],
          'padders': [('padde', True)],
          'pade': [('pade', False)],
          'paden': [('pade', False)],
          'padens': [('pade', False)],
          'paderne': [('pade', False)],
          'paders': [('pade', False)],
          'pades': [('pade', False)],
          'padlen': [('paddel', True)],
          'padlens': [('paddel', True)],
          'padler': [('paddel', True), ('padle', True), ('padler', True)],
          'padlerne': [('padler', True), ('padle', True), ('paddel', True)],
          'padlernes': [('padle', True), ('padler', True), ('paddel', True)],
          'padlers': [('paddel', True), ('padler', True), ('padle', True)],
          'paen': [('pa', False)],
          'paens': [('pa', False)],
          'paer': [('pa', False)],
          'paerne': [('pa', False)],
          'paernes': [('pa', False)],
          'paers': [('pa', False)],
          'page': [('page', False)],
          'pagen': [('page', False)],
          'pagens': [('page', True)],
          'pager': [('page', False)],
          'pagers': [('page', True)],
          'pages': [('page', False)],
          'pagnen': [('pagne', False)],
          'pagnens': [('pagne', False)],
          'pagnerne': [('pagne', False)],
          'pagter': [('pagt', False)],
          'pagterne': [('pagt', False)],
          'pagternes': [('pagt', False)],
          'pagters': [('pagt', True)],
          'pairernes': [('pair', False)],
          'paketten': [('paket', True)],
          'pakettens': [('paket', True)],
          'paketterne': [('paket', True)],
          'paketternes': [('paket', True)],
          'paketters': [('paket', True)],
          'pakis': [('pakis', True)],
          'pakkens': [('pakke', False)],
          'pakker': [('pakke', True), ('pakker', True)],
          'pakkerne': [('pakke', True), ('pakker', True)],
          'pakkernes': [('pakker', True), ('pakke', True)],
          'pakkers': [('pakker', True), ('pakke', True)],
          'paks': [('pak', False)],
          'palas': [('pala', False)],
          'palen': [('pal', True)],
          'palens': [('pal', False)],
          'palet': [('palet', True)],
          'palets': [('palet', True)],
          'pallens': [('palle', False)],
          'pallerne': [('palle', False)],
          'pallernes': [('palle', True)],
          'pallers': [('palle', False)],
          'palmen': [('palme', True)],
          'palmens': [('palme', True)],
          'palpen': [('palpe', True)],
          'palpens': [('palpe', True)],
          'palper': [('palpe', True)],
          'palperne': [('palpe', True)],
          'palpernes': [('palpe', True)],
          'palpers': [('palpe', True)],
          'palter': [('palte', False)],
          'palterne': [('palte', False)],
          'palternes': [('palte', False)],
          'palters': [('palte', False)],
          'pampas': [('pampas', True), ('pampa', True)],
          'pamper': [('pamper', True)],
          'pampere': [('pamper', True)],
          'pamperes': [('pamper', True)],
          'pamperne': [('pamper', True)],
          'panager': [('panage', False)],
          'pande': [('pande', True)],
          'panden': [('pande', True)],
          'pandens': [('pande', True)],
          'pander': [('pande', False)],
          'panderne': [('pande', False)],
          'pandernes': [('pande', False)],
          'panders': [('pande', False)],
          'pandes': [('pande', True)],
          'pandet': [('pand', False)],
          'pandets': [('pand', False)],
          'panen': [('pan', False)],
          'panens': [('pan', False)],
          'paner': [('paner', False)],
          'panerne': [('pan', False)],
          'panernes': [('pan', False)],
          'paners': [('paner', False)],
          'panger': [('pange', False)],
          'pangernes': [('pange', False)],
          'pangers': [('pange', False)],
          'panierne': [('panier', False)],
          'paniers': [('panier', False)],
          'panker': [('panker', False)],
          'pankers': [('panker', False)],
          'panoners': [('panon', False)],
          'pans': [('pans', False)],
          "pans'": [('pans', False)],
          'pansen': [('pans', False)],
          'pansens': [('pans', False)],
          'panser': [('panser', True)],
          'panserne': [('panser', True)],
          'pansernes': [('panser', True)],
          'pansers': [('panser', True)],
          'panten': [('pant', False)],
          'pantens': [('pant', True)],
          'panter': [('panter', True), ('pant', True)],
          'panterne': [('panter', True), ('pant', True)],
          'panternes': [('panter', True), ('pant', True)],
          'panters': [('pant', True), ('panter', True)],
          'pantet': [('pant', False)],
          'pantets': [('pant', True)],
          'pants': [('pant', False)],
          'papas': [('papa', True)],
          'pappen': [('pap', False)],
          'pappens': [('pap', False)],
          'papper': [('pap', False)],
          'papperne': [('pap', True)],
          'pappernes': [('pap', True)],
          'pappers': [('pap', False)],
          'paravanen': [('paravane', True)],
          'paravanens': [('paravane', True)],
          'paravaner': [('paravane', True)],
          'paravanernes': [('paravane', True)],
          'paravaners': [('paravane', True)],
          'parden': [('pard', False)],
          'pardens': [('pard', False)],
          'parderne': [('pard', False)],
          'pardernes': [('pard', False)],
          'parenterne': [('parent', False)],
          'parenternes': [('parent', False)],
          'paris': [('pari', True)],
          'parken': [('park', False)],
          'parker': [('park', False)],
          'parkerne': [('park', False)],
          'parkernes': [('park', True)],
          'parkers': [('park', True)],
          'parket': [('parket', True)],
          'parkets': [('parket', True)],
          'parten': [('part', False)],
          'parter': [('part', False)],
          'parterne': [('part', False)],
          'parters': [('part', False)],
          'parts': [('part', False)],
          'pas': [('pas', True)],
          'pase': [('pase', False)],
          'pasen': [('pas', False)],
          'pasens': [('pase', False)],
          'paser': [('pase', False)],
          'paserne': [('pase', False)],
          'pasernes': [('pase', False)],
          'pasers': [('pase', False)],
          'pases': [('pase', False)],
          'passager': [('passager', True), ('passage', True)],
          'passagers': [('passager', True), ('passage', True)],
          'passen': [('pas', False)],
          'passens': [('pas', False)],
          'passer': [('passer', True), ('pas', True)],
          'passerne': [('passer', True), ('pas', True)],
          'passernes': [('pas', True), ('passer', True)],
          'passers': [('passer', True), ('pas', True)],
          'pasti': [('pasto', False)],
          'pastis': [('pastis', True)],
          'pater': [('pater', True)],
          'paterne': [('pater', True)],
          'paternes': [('pater', True)],
          'paters': [('pater', True)],
          'patien': [('pati', False)],
          'patiens': [('patiens', True)],
          'patier': [('pati', False)],
          'patierne': [('pati', False)],
          'patiernes': [('pati', False)],
          'patiers': [('pati', False)],
          'patis': [('pati', False)],
          'patrice': [('patrice', True)],
          'patricer': [('patrice', True)],
          'patronen': [('patron', True)],
          'patronens': [('patron', True)],
          'patronerne': [('patron', False)],
          'patronernes': [('patron', False)],
          'patroners': [('patron', True)],
          'patten': [('patte', True), ('pat', True)],
          'pattens': [('pat', True), ('patte', True)],
          'patter': [('patte', True), ('pat', True)],
          'patterne': [('patte', True), ('pat', True)],
          'patternes': [('pat', True), ('patte', True)],
          'patters': [('patte', True), ('pat', True)],
          'pave': [('pave', False)],
          'paven': [('pave', False)],
          'pavens': [('pave', True)],
          'paver': [('pave', True)],
          'paverne': [('pave', True)],
          'pavernes': [('pave', False)],
          'pavers': [('pave', False)],
          'paves': [('pave', True)],
          'pbakken': [('pbakke', False)],
          'pbakkens': [('pbakke', False)],
          'pbroderen': [('pbror', False)],
          'pbroderens': [('pbror', False)],
          'pbroers': [('pbro', False)],
          'pc-viraene': [('PC-virus', True), ('pc-virus', True)],
          'pc-viraenes': [('PC-virus', True), ('pc-virus', True)],
          'pdager': [('pdager', False)],
          'pdansernes': [('pdanser', False)],
          'pdrager': [('pdrager', False)],
          'pdragerne': [('pdrager', False)],
          'pdragernes': [('pdrager', False)],
          'pdragers': [('pdrager', False)],
          'pdrætterne': [('pdrætter', False)],
          'pduens': [('pdue', False)],
          'pduernes': [('pdue', False)],
          'pduers': [('pdue', False)],
          'pdukken': [('pdukken', False)],
          'pdukkens': [('pdukken', False)],
          'pe': [('pe', False)],
          'peakers': [('peaker', False)],
          'pearbejder': [('pearbejde', False)],
          'pearbejderne': [('pearbejde', False)],
          'pebanker': [('pebanker', False)],
          'pebankers': [('pebanker', False)],
          'peber': [('peber', True)],
          'pebernes': [('peber', True)],
          'pedans': [('pedans', False)],
          'pedanser': [('pedans', False)],
          'pedansernes': [('pedans', False)],
          'pedansers': [('pedans', False)],
          'pede': [('pede', False)],
          'peden': [('pede', False)],
          'pedens': [('pede', False)],
          'peder': [('pede', False)],
          'pederne': [('pede', False)],
          'pedernes': [('pede', False)],
          'peders': [('pede', False)],
          'pedes': [('pede', False)],
          'pedos': [('pedo', False)],
          'pedømmernes': [('pedømme', False)],
          'pedømmers': [('pedømme', False)],
          'pejders': [('pejder', False)],
          'pejle': [('pejl', False)],
          'pejler': [('pejler', True)],
          'pejlers': [('pejler', True)],
          'pejles': [('pejl', False)],
          'pejs': [('pejs', True)],
          'pejse': [('pejs', True)],
          'pejsen': [('pejs', True)],
          'pejsens': [('pejs', True)],
          'pejses': [('pejs', True)],
          'pek': [('pek', False)],
          'peks': [('pek', False)],
          'pekterne': [('pekt', False)],
          'pekternes': [('pekt', False)],
          'pelager': [('pelag', False)],
          'pelagernes': [('pelag', False)],
          'pelagers': [('pelag', False)],
          'pelever': [('pelever', False)],
          'peleverne': [('pelever', False)],
          'pelevernes': [('pelever', False)],
          'pelevers': [('pelever', False)],
          'pelinen': [('peline', False)],
          'pelinens': [('peline', False)],
          'peliner': [('peliner', False)],
          'pelinerne': [('peliner', False)],
          'pelinernes': [('peliner', False)],
          'pellen': [('pel', False)],
          'peller': [('pel', False)],
          'pellers': [('pel', False)],
          'pellet': [('pellet', True)],
          'pellets': [('pellet', True)],
          'pels': [('pels', False)],
          "pels'": [('pels', False)],
          'pelse': [('pels', True)],
          'pelsen': [('pels', False)],
          'pelsens': [('pels', False)],
          'pelsers': [('pelse', False)],
          'pelses': [('pels', False)],
          'pelten': [('pelt', False)],
          'peltens': [('pelt', False)],
          'pelærerne': [('pelærer', False)],
          'pelærernes': [('pelærer', False)],
          'pemus': [('pemus', False)],
          'pen': [('pen', True)],
          'penaders': [('penade', False)],
          'pencer': [('pencer', False)],
          'pencerne': [('pencer', False)],
          'pencernes': [('pencer', False)],
          'pencers': [('pencer', False)],
          'pendens': [('pendens', False)],
          'pender': [('pender', False)],
          'penders': [('pender', False)],
          'pendier': [('pendie', False)],
          'pendierne': [('pendium', False)],
          'pendiernes': [('pendie', False)],
          'pendiers': [('pendie', False)],
          'pendiet': [('pendie', False)],
          'pendiets': [('pendie', False)],
          'pendium': [('pendium', False)],
          'pendiums': [('pendium', False)],
          'pendler': [('pendel', True), ('pendler', True)],
          'pendlerne': [('pendler', True), ('pendel', True)],
          'pendlernes': [('pendler', True), ('pendel', True)],
          'pendlers': [('pendel', True), ('pendler', True)],
          'pene': [('', False)],
          'penes': [('', False)],
          'penge': [('penge', False)],
          'pengen': [('penge', False)],
          'pengene': [('penge', False)],
          'pengenes': [('penge', False)],
          'pengens': [('penge', False)],
          'penges': [('penge', False)],
          'penissen': [('penis', True)],
          'penissens': [('penis', True)],
          'penisser': [('penis', True)],
          'penisserne': [('penis', True)],
          'penissernes': [('penis', True)],
          'penissers': [('penis', True)],
          'penne': [('pen', False)],
          'pennen': [('pen', False)],
          'pennens': [('pen', False)],
          'pennes': [('pen', True)],
          'pens': [('pen', True)],
          "pens'": [('pens', False)],
          'pensen': [('pense', False)],
          'pensens': [('pense', False)],
          'penserne': [('penser', False)],
          'pentinerne': [('pentine', False)],
          'pentiners': [('pentine', False)],
          'per': [('pe', False)],
          'pera': [('pera', False)],
          'peras': [('pera', False)],
          'peretter': [('perette', False)],
          'peretters': [('perette', False)],
          'performerne': [('performer', True)],
          'performernes': [('performer', True)],
          'perheden': [('perhed', False)],
          'perier': [('peri', False)],
          'perierne': [('peri', False)],
          'periernes': [('peri', False)],
          'periers': [('peri', False)],
          'periet': [('peri', False)],
          'periets': [('peri', False)],
          'peris': [('peri', False)],
          'perium': [('perie', False)],
          'periums': [('perie', False)],
          'permen': [('perm', False)],
          'permens': [('perm', True)],
          'permerne': [('perm', True)],
          'permernes': [('perm', True)],
          'permers': [('perm', True)],
          'permissioner': [('permissioner', True), ('permission', True)],
          'permissionerne': [('permission', True), ('permissioner', True)],
          'permissionernes': [('permissioner', True), ('permission', True)],
          'permissioners': [('permissioner', True), ('permission', True)],
          'permænd': [('permand', False)],
          'permændene': [('permand', False)],
          'permændenes': [('permand', False)],
          'permænds': [('permand', False)],
          'perne': [('pe', False)],
          'peroner': [('perone', False)],
          'peronerne': [('perone', False)],
          'peronernes': [('perone', False)],
          'peroners': [('perone', False)],
          'pers': [('per', False)],
          "pers'": [('pers', False)],
          'persen': [('perse', True)],
          'persens': [('perse', True)],
          'perser': [('perser', True), ('perse', True)],
          'perserne': [('perser', True), ('perse', True)],
          'persernes': [('perse', True), ('perser', True)],
          'persers': [('perser', True), ('perse', True)],
          'pertanker': [('pertanker', False)],
          'pertankerne': [('pertanker', False)],
          'pertankernes': [('pertanker', False)],
          'perten': [('pert', False)],
          'pertens': [('pert', False)],
          'perter': [('pert', False)],
          'perterne': [('pert', False)],
          'perters': [('pert', False)],
          'pertinens': [('pertinens', False)],
          'perts': [('pert', False)],
          "pes'": [('pe', False)],
          'pespiller': [('pespiller', False)],
          'pespillerne': [('pespiller', False)],
          'pespillernes': [('pespiller', False)],
          'pespillers': [('pespiller', False)],
          'pesten': [('pest', False)],
          'pestens': [('pest', False)],
          'pestier': [('pesti', False)],
          'pestiernes': [('pesti', False)],
          'pestigerne': [('pestige', False)],
          'pestigernes': [('pestige', False)],
          'pestigers': [('pestige', False)],
          'peter': [('pet', False)],
          'peterne': [('peter', False)],
          'peternes': [('peter', False)],
          'peters': [('pet', False)],
          'petiden': [('petid', False)],
          'petten': [('pet', False)],
          'pettens': [('pet', False)],
          'petter': [('pette', False)],
          'petterne': [('pet', False)],
          'petternes': [('pet', False)],
          'petters': [('pet', False)],
          'pevals': [('pevals', False)],
          'peviser': [('pevise', False)],
          'peviserne': [('pevise', False)],
          'pfaren': [('pfar', False)],
          'pfarens': [('pfar', False)],
          'pfars': [('pfar', False)],
          'pformer': [('pform', False)],
          'pformerne': [('pform', False)],
          'pformernes': [('pform', False)],
          'pformers': [('pform', False)],
          'pfylden': [('pfyld', False)],
          'pfyldens': [('pfyld', False)],
          'pfædre': [('pfar', False)],
          'pfædrene': [('pfar', False)],
          'pfædrenes': [('pfar', False)],
          'pfølger': [('pfølger', False)],
          'pfølgerne': [('pfølger', False)],
          'pfølgernes': [('pfølger', False)],
          'pfølgers': [('pfølger', False)],
          "pgas'": [('pgas', False)],
          'pgassernes': [('pgas', False)],
          'pglossen': [('pgloss', False)],
          'pglossens': [('pgloss', False)],
          'pglosser': [('pgloss', False)],
          'pglosserne': [('pgloss', False)],
          'pglossernes': [('pgloss', False)],
          'pglossers': [('pgloss', False)],
          'pgunen': [('pgun', False)],
          'pgunens': [('pgun', False)],
          'pgænger': [('pgænger', False)],
          'pgængerne': [('pgænger', False)],
          'pgængernes': [('pgænger', False)],
          'pgængers': [('pgænger', False)],
          'pgørets': [('pgør', False)],
          'phalerne': [('phale', False)],
          'phans': [('phans', False)],
          'phas': [('phas', False)],
          "phas'": [('phas', False)],
          'pheden': [('phed', False)],
          'phedens': [('phed', False)],
          'pheder': [('phed', False)],
          'phederne': [('phed', False)],
          'phedernes': [('phed', False)],
          'pheders': [('phed', False)],
          'phoppen': [('phop', False)],
          'phoppens': [('phop', False)],
          'phopper': [('phopper', False)],
          'phopperne': [('phopper', False)],
          'phoppernes': [('phopper', False)],
          'phoppers': [('phopper', False)],
          'phuen': [('phue', False)],
          'phuens': [('phue', False)],
          'pi': [('pi', False)],
          'piater': [('piat', False)],
          'piaterne': [('piat', False)],
          'piaters': [('piat', False)],
          'pibe': [('pibe', False)],
          'piber': [('piber', True), ('pibe', True)],
          'piberier': [('piberi', False)],
          'piberierne': [('piberi', False)],
          'piberiernes': [('piberi', False)],
          'piberis': [('piberi', False)],
          'piberne': [('piber', True), ('pibe', True)],
          'pibernes': [('pibe', True), ('piber', True)],
          'pibers': [('pibe', True), ('piber', True)],
          'pibes': [('pibe', False)],
          'picer': [('pice', False)],
          'picerne': [('pice', False)],
          'picernes': [('pice', False)],
          'picers': [('pice', False)],
          'pices': [('pice', False)],
          'picet': [('pice', False)],
          'picets': [('pice', False)],
          'picier': [('picier', False)],
          'piciers': [('picier', False)],
          'pidens': [('pid', False)],
          "pids'": [('pids', False)],
          'pidsen': [('pids', False)],
          'pidsens': [('pids', False)],
          'pien': [('pie', True)],
          'piens': [('pie', True)],
          'pier': [('pier', True), ('pie', True), ('pi', True)],
          'piere': [('pier', False)],
          'pieren': [('pier', True)],
          'pierens': [('pier', True)],
          'pierer': [('pier', False)],
          'piererne': [('pier', True)],
          'pierernes': [('pier', True)],
          'pierers': [('pier', False)],
          'pieres': [('pier', False)],
          'pierne': [('pie', True), ('pi', True)],
          'piernes': [('pi', True), ('pie', True)],
          'piers': [('pier', True), ('pi', True), ('pie', True)],
          "pies'": [('pie', False)],
          'piet': [('pi', False)],
          'piets': [('pi', False)],
          'pif': [('pif', True)],
          'piffet': [('pif', True)],
          'piffets': [('pif', True)],
          'piftet': [('pift', True)],
          'piftets': [('pift', True)],
          'pige': [('pige', False)],
          'pigen': [('pige', False)],
          'pigens': [('pige', False)],
          'piger': [('pige', False)],
          'pigerne': [('pige', True)],
          'pigernes': [('pige', True)],
          'pigers': [('pige', True)],
          'piges': [('pige', False)],
          'pigre': [('piger', False)],
          'pikke': [('pik', True)],
          'pikken': [('pik', True)],
          'pikker': [('pikker', False)],
          'pikkere': [('pikker', False)],
          'pikkeren': [('pikker', False)],
          'pikkerens': [('pikker', False)],
          'pikkeres': [('pikker', False)],
          'pikkernes': [('pikker', False)],
          'pikkers': [('pikker', False)],
          'pikkes': [('pik', False)],
          'piks': [('pik', True)],
          "piks'": [('piks', False)],
          'piksen': [('piks', False)],
          'piksens': [('piks', False)],
          'pikserne': [('piks', False)],
          'piksernes': [('piks', False)],
          'piksers': [('piks', False)],
          'pilerne': [('piler', False)],
          'pilernes': [('piler', False)],
          'pilers': [('piler', False)],
          'pilke': [('pilk', True)],
          'pilken': [('pilk', True)],
          'pilkens': [('pilk', True)],
          'pilkes': [('pilk', True)],
          'pillen': [('pille', True)],
          'pillens': [('pille', False)],
          'piller': [('pille', False)],
          'pillerne': [('pille', False)],
          'pillernes': [('pille', True)],
          'pillers': [('pille', True)],
          'pils': [('pils', True), ('pil', True)],
          "pils'": [('pils', True)],
          'pilsen': [('pils', True)],
          'pilsens': [('pils', True)],
          'pilsner': [('pilsner', True)],
          'pilsnernes': [('pilsner', True)],
          'pilsners': [('pilsner', True)],
          'pilte': [('pilt', True)],
          'pilten': [('pilt', True)],
          'piltens': [('pilt', True)],
          'piltes': [('pilt', True)],
          'pimentet': [('piment', True)],
          'pimentets': [('piment', True)],
          'pimperier': [('pimperi', True)],
          'pimperierne': [('pimperi', True)],
          'pimperiernes': [('pimperi', True)],
          'pimperiers': [('pimperi', True)],
          'pimperiet': [('pimperi', True)],
          'pimperiets': [('pimperi', True)],
          'pinde': [('pind', False)],
          'pinden': [('pind', False)],
          'pindens': [('pind', False)],
          'pinderne': [('pinder', False)],
          'pindes': [('pind', True)],
          'pindet': [('pind', False)],
          'pindets': [('pind', False)],
          'pindsøer': [('pindso', True)],
          'pindsøerne': [('pindso', True)],
          'pindsøernes': [('pindso', True)],
          'pindsøers': [('pindso', True)],
          'pine': [('pine', False)],
          'pinen': [('pine', True)],
          'pinens': [('pine', True)],
          'piner': [('pine', False)],
          'pinerne': [('pine', True)],
          'pinernes': [('pine', True)],
          'piners': [('pine', True)],
          'pines': [('pine', False)],
          'pinet': [('pinet', False)],
          'pinets': [('pinet', False)],
          'pinetter': [('pinet', False)],
          'pinetterne': [('pinet', False)],
          'pinetternes': [('pinet', False)],
          'pinetters': [('pinet', False)],
          'pingen': [('ping', False)],
          'pingens': [('ping', False)],
          'pinger': [('ping', True)],
          'pingerne': [('ping', False)],
          'pingernes': [('ping', False)],
          'pings': [('ping', False)],
          "pings'": [('ping', False)],
          'pinister': [('pinist', False)],
          'pinisters': [('pinist', False)],
          'pinner': [('pinner', False)],
          'pinnerne': [('pinner', False)],
          'pinnernes': [('pinner', False)],
          'pinners': [('pinner', False)],
          'pinummers': [('pinum', False)],
          'pioner': [('pioner', True)],
          'pionernes': [('pion', False)],
          'pioners': [('pioner', True)],
          'pions': [('pion', False)],
          "pions'": [('pion', False)],
          'piren': [('pir', False)],
          'pirens': [('pire', False)],
          'pirer': [('pire', False)],
          'pirerne': [('pire', False)],
          'pirernes': [('pire', False)],
          'pirers': [('pir', False)],
          'piris': [('piri', False)],
          'pirke': [('pirk', True)],
          'pirken': [('pirk', True)],
          'pirkes': [('pirk', True)],
          'pirket': [('pirk', True)],
          'pirkets': [('pirk', True)],
          'pis': [('pis', True), ('pi', True)],
          'pise': [('pise', False)],
          'pisen': [('pise', False)],
          'pisens': [('pise', False)],
          'pises': [('pise', False)],
          'piske': [('pisk', True)],
          'pisken': [('pisk', False)],
          'pisker': [('pisker', False)],
          'piskeris': [('piskeris', True)],
          'piskerne': [('pisker', False)],
          'piskernes': [('pisker', True)],
          'pismen': [('pisme', False)],
          'pismens': [('pisme', False)],
          'pissen': [('pis', False)],
          'pissens': [('pis', False)],
          'pissers': [('pisse', False)],
          'piste': [('pist', True)],
          'pisten': [('pist', False)],
          'pistens': [('pist', False)],
          'pister': [('pist', False)],
          'pisterne': [('pist', True)],
          'pisternes': [('pist', False)],
          'pisters': [('pist', False)],
          'pistes': [('pist', True)],
          'pitaler': [('pital', False)],
          'pitalerne': [('pital', False)],
          'pitalernes': [('pital', False)],
          'pitalers': [('pital', False)],
          'pitlerne': [('pitel', False)],
          'pitlernes': [('pitel', False)],
          'pitlers': [('pitel', False)],
          'pits': [('pit', True)],
          "pits'": [('pits', False)],
          'pitser': [('pits', False)],
          'pitserne': [('pits', False)],
          'pitsernes': [('pits', False)],
          'pitsers': [('pits', False)],
          'pitten': [('pit', True)],
          'pittens': [('pit', False)],
          'pitternes': [('pit', False)],
          'pitters': [('pit', False)],
          'piturets': [('pitur', False)],
          'pivaren': [('pivare', False)],
          'pivarens': [('pivare', False)],
          'pivarer': [('pivare', False)],
          'pivarerne': [('pivare', False)],
          'pivarernes': [('pivare', False)],
          'pivarers': [('pivare', False)],
          'pjakken': [('pjakke', False)],
          'pjalter': [('pjalt', True)],
          'pjalters': [('pjalt', True)],
          'pklapper': [('pklap', False)],
          'pklapperne': [('pklap', False)],
          'pklappernes': [('pklap', False)],
          'pklappers': [('pklap', False)],
          'pklaps': [('pklap', False)],
          'pkurser': [('pkursus', False)],
          'pkurserne': [('pkursus', False)],
          'pkursernes': [('pkursus', False)],
          'pkursers': [('pkursus', False)],
          'pkvikker': [('pkvikker', False)],
          'pkvikkerne': [('pkvikker', False)],
          'pkvikkernes': [('pkvikker', False)],
          'pkvikkers': [('pkvikker', False)],
          'pla': [('plum', False)],
          'plader': [('plade', False)],
          'pladerne': [('plade', True)],
          'pladernes': [('plade', False)],
          'pladers': [('plade', False)],
          'plads': [('plads', False)],
          'plage': [('plag', True), ('plage', True)],
          'plagen': [('plage', True), ('plag', True)],
          'plagens': [('plage', True), ('plag', True)],
          'plager': [('plage', True), ('plager', True)],
          'plagerne': [('plager', True), ('plage', True)],
          'plagernes': [('plage', True), ('plager', True)],
          'plagers': [('plager', True), ('plage', True)],
          'plages': [('plage', True), ('plag', True)],
          'plaks': [('plak', False)],
          'planens': [('plan', False)],
          'planer': [('plan', False)],
          'planers': [('plan', False)],
          'planet': [('planet', True), ('plan', True)],
          'planets': [('planet', True), ('plan', True)],
          'plans': [('plan', False)],
          'planten': [('plante', False)],
          'plantens': [('plante', False)],
          'planter': [('planter', True), ('plante', True)],
          'planterne': [('planter', True), ('plante', True)],
          'planternes': [('planter', True), ('plante', True)],
          'planters': [('planter', True), ('plante', True)],
          'plarer': [('plar', False)],
          'plarernes': [('plar', False)],
          'plaret': [('plar', False)],
          'plarets': [('plar', False)],
          'plars': [('plar', False)],
          'plas': [('plum', False)],
          'plasker': [('plasker', False)],
          'plaskerne': [('plasker', False)],
          'plaskernes': [('plasker', False)],
          'plaskers': [('plasker', False)],
          'plaster': [('plaster', True)],
          'plasters': [('plaster', False)],
          'platiners': [('platiner', True)],
          'plats': [('plat', True)],
          'platter': [('platte', True)],
          'platterne': [('platte', True)],
          'platternes': [('platte', True)],
          'platters': [('platte', True)],
          'ple': [('pel', False)],
          'pleen': [('pleen', False)],
          'pleens': [('pleen', False)],
          'plejer': [('pleje', True), ('plejer', True)],
          'plejerne': [('plejer', True), ('pleje', True)],
          'plejernes': [('pleje', True), ('plejer', True)],
          'plejers': [('plejer', True), ('pleje', True)],
          'plekter': [('plekter', True)],
          'plekters': [('plekter', True)],
          'plene': [('pel', False)],
          'plenes': [('ple', False)],
          'plere': [('pler', False)],
          'pleren': [('pler', False)],
          'plerens': [('pler', False)],
          'pleres': [('pler', False)],
          'plerne': [('pel', False)],
          'plernes': [('pel', False)],
          'ples': [('pel', False)],
          'pleskens': [('plesken', True)],
          'plet': [('plet', False)],
          'pletonen': [('pleton', False)],
          'pletonens': [('pleton', False)],
          'pletoner': [('pleton', False)],
          'pletonerne': [('pleton', False)],
          'pletonernes': [('pleton', False)],
          'pletoners': [('pleton', False)],
          'plets': [('plet', True)],
          'pletten': [('plet', False)],
          'plettens': [('plet', False)],
          'pletter': [('plet', False)],
          'pletterne': [('plet', False)],
          'pletternes': [('plet', False)],
          'pletters': [('plet', False)],
          'pliden': [('plid', False)],
          'plids': [('plid', False)],
          'plier': [('pli', False)],
          'plierne': [('pli', False)],
          'plikker': [('plik', False)],
          'plikkernes': [('plik', False)],
          'plikkers': [('plik', False)],
          'plinen': [('plin', False)],
          'plinens': [('plin', False)],
          'pliner': [('plin', False)],
          'plinerne': [('plin', False)],
          'plinernes': [('plin', False)],
          'pliners': [('plin', False)],
          'plinets': [('plin', False)],
          'plingers': [('pling', False)],
          'plits': [('plit', False)],
          'plitter': [('plit', False)],
          'plotter': [('plotter', True)],
          'plotterne': [('plotter', True)],
          'plotternes': [('plotter', True)],
          'plotters': [('plotter', True)],
          'plove': [('plov', False)],
          'plukker': [('plukker', True)],
          'plukkerne': [('plukker', True)],
          'plukkernes': [('plukker', True)],
          'plukkers': [('plukker', True)],
          'plukket': [('pluk', False)],
          'plukkets': [('pluk', False)],
          'pluks': [('pluk', False)],
          'plus': [('plus', True)],
          'plyde': [('plyd', False)],
          'plyden': [('plyd', False)],
          'plydens': [('plyd', False)],
          'plydes': [('plyd', False)],
          'plys': [('plys', False)],
          'plænder': [('plænder', False)],
          'plænderne': [('plænder', False)],
          'plændernes': [('plænder', False)],
          'plænders': [('plænder', False)],
          'plæners': [('plæne', True)],
          'plærke': [('plærke', False)],
          'plærken': [('plærke', False)],
          'plærkens': [('plærke', False)],
          'plærkes': [('plærke', False)],
          'plæserne': [('plæser', False)],
          'plæsernes': [('plæser', False)],
          'pløkke': [('pløk', False)],
          'pløkken': [('pløk', True)],
          'pløkkens': [('pløk', False)],
          'pløkker': [('pløk', False)],
          'pløkkerne': [('pløk', False)],
          'pløkkernes': [('pløk', True)],
          'pløkkers': [('pløk', False)],
          'pløkkes': [('pløk', False)],
          'pløret': [('pløre', True)],
          'pløs': [('pløs', True)],
          'pløse': [('pløs', True)],
          'pløsen': [('pløs', True)],
          'pløsens': [('pløs', True)],
          'pløses': [('pløs', True)],
          'pmager': [('pmager', False)],
          'pmagerne': [('pmager', False)],
          'pmagernes': [('pmager', False)],
          'pmagers': [('pmager', False)],
          'pmarchen': [('pmarch', False)],
          'pmarchens': [('pmarch', False)],
          'pmejsen': [('pmejse', False)],
          'pmejsens': [('pmejse', False)],
          'pmejser': [('pmejse', False)],
          'pmejserne': [('pmejse', False)],
          'pmejsernes': [('pmejse', False)],
          'pmejsers': [('pmejse', False)],
          'pmænd': [('pmand', False)],
          'pningers': [('pning', False)],
          'pnummers': [('pnummer', False)],
          'poden': [('pode', True)],
          'podens': [('pode', True)],
          'poder': [('pode', True)],
          'poderne': [('pode', True)],
          'podernes': [('pode', True)],
          'poders': [('pode', False)],
          'podiernes': [('podie', True)],
          'poen': [('po', False)],
          'poens': [('po', False)],
          'poer': [('po', False)],
          'poerne': [('po', False)],
          'poernes': [('po', False)],
          'poers': [('po', False)],
          'poet': [('poet', True)],
          'poets': [('poet', True)],
          'poffets': [('poff', False)],
          'poiler': [('poiler', False)],
          'pointen': [('pointe', True)],
          'pointens': [('pointe', True)],
          'pointer': [('pointer', True), ('pointe', True)],
          'pointerne': [('pointe', True), ('pointer', True)],
          'pointernes': [('pointer', True), ('pointe', True)],
          'pointers': [('pointe', True), ('pointer', True)],
          'poken': [('poke', False)],
          'poker': [('poker', True)],
          'pokerne': [('poker', True)],
          'pokernes': [('poker', True)],
          'pokers': [('poker', True)],
          'pokken': [('pok', False)],
          'pokkers': [('pokker', True)],
          'pole': [('pole', False)],
          'polen': [('pol', True)],
          'polens': [('pol', True)],
          'poler': [('pol', False)],
          'polerer': [('polerer', True)],
          'polererne': [('polerer', False)],
          'polerernes': [('polerer', False)],
          'polerers': [('polerer', False)],
          'polerne': [('pol', False)],
          'polernes': [('pol', True)],
          'polers': [('pol', True)],
          'poles': [('pole', False)],
          'polet': [('polet', True)],
          'polets': [('polet', True)],
          'poliner': [('polin', False)],
          'polinger': [('poling', False)],
          'polingerne': [('poling', False)],
          'polingernes': [('poling', False)],
          'pollen': [('pollen', True)],
          'pollens': [('pollen', True)],
          'polos': [('polo', False)],
          'polte': [('polt', True)],
          'polten': [('polt', True)],
          'poltens': [('polt', True)],
          'poltes': [('polt', True)],
          'pomet': [('pomet', True)],
          'pometer': [('pomet', True)],
          'pometers': [('pomet', True)],
          'pomets': [('pomet', True)],
          'pondens': [('pondens', False)],
          'ponds': [('pond', False)],
          'pongen': [('pong', False)],
          'pongens': [('pong', False)],
          'ponier': [('poni', False)],
          'poniet': [('poni', False)],
          'poniets': [('poni', False)],
          'ponis': [('poni', False)],
          'pons': [('pons', False)],
          "pons'": [('pons', False)],
          'ponsens': [('pons', False)],
          'popen': [('pope', True)],
          'poper': [('pope', True)],
          'poperne': [('pope', True)],
          'popernes': [('pope', True)],
          'popers': [('pope', True)],
          'poplen': [('poppel', True)],
          'poplens': [('poppel', True)],
          'popler': [('poppel', True)],
          'poplerne': [('poppel', True)],
          'poplernes': [('poppel', True)],
          'poplers': [('poppel', True)],
          'popos': [('popo', True)],
          'poppen': [('pop', True)],
          'poppens': [('pop', False)],
          'popperne': [('pop', False)],
          'poppers': [('pop', False)],
          'pora': [('pora', False)],
          'poras': [('pora', False)],
          'pore': [('pore', True)],
          'poren': [('pore', False)],
          'porens': [('pore', False)],
          'porer': [('pore', False)],
          'porerne': [('pore', False)],
          'porernes': [('pore', False)],
          'porers': [('pore', True)],
          'porren': [('porre', True)],
          'pors': [('pors', True)],
          "pors'": [('pors', True)],
          'porsen': [('pors', True), ('porse', True)],
          'porsens': [('pors', True), ('porse', True)],
          'portalen': [('portal', False)],
          'portaler': [('portal', True)],
          'portalerne': [('portal', True)],
          'portalernes': [('portal', True)],
          'portalers': [('portal', True)],
          'porte': [('port', False)],
          'porten': [('port', False)],
          'portens': [('port', False)],
          'porter': [('porter', True)],
          'porterne': [('porter', True)],
          'porternes': [('porter', False)],
          'porters': [('porter', True)],
          'portes': [('port', False)],
          'portier': [('portier', True)],
          'portieren': [('portiere', True), ('portier', True)],
          'portierens': [('portiere', True), ('portier', True)],
          'portierer': [('portiere', True), ('portier', True)],
          'portiererne': [('portiere', True), ('portier', True)],
          'portierernes': [('portiere', True), ('portier', True)],
          'portierers': [('portiere', True), ('portier', True)],
          'ports': [('port', False)],
          "ports'": [('port', False)],
          'porveje': [('porveje', False)],
          'porvejene': [('porveje', False)],
          'porvejenes': [('porveje', False)],
          'pos': [('po', False)],
          'posen': [('pose', False)],
          'posens': [('pose', False)],
          'poser': [('pose', False)],
          'poserne': [('pose', False)],
          'posernes': [('pose', False)],
          'posers': [('pose', True)],
          'poset': [('pos', False)],
          'posets': [('pos', False)],
          'posser': [('pos', False)],
          'posserne': [('pos', False)],
          'poste': [('post', True)],
          'posten': [('post', False)],
          'postens': [('post', False)],
          'poster': [('poster', True), ('post', True)],
          'posterne': [('post', True), ('poster', True)],
          'posternes': [('poster', True), ('post', True)],
          'posters': [('poster', True), ('post', True)],
          'poten': [('pote', False)],
          'potens': [('potens', True), ('pote', True)],
          'potentialer': [('potentiale', True), ('potential', True)],
          'potentialerne': [('potentiale', True), ('potential', True)],
          'potentialernes': [('potentiale', True), ('potential', True)],
          'potentialers': [('potentiale', True), ('potential', True)],
          'potentialet': [('potentiale', True), ('potential', True)],
          'potentialets': [('potentiale', True), ('potential', True)],
          'poter': [('pote', True)],
          'poterne': [('pote', False)],
          'poternes': [('pote', True)],
          'poters': [('pote', True)],
          'potes': [('pote', False)],
          'potiet': [('poti', False)],
          'potiets': [('poti', False)],
          'potten': [('potte', True), ('pot', True)],
          'pottens': [('potte', True), ('pot', True)],
          'potter': [('pot', True), ('potte', True)],
          'potterne': [('potte', True), ('pot', True)],
          'potternes': [('pot', True), ('potte', True)],
          'potters': [('potte', True), ('pot', True)],
          'pouten': [('pout', False)],
          'poutens': [('pout', False)],
          'pouterne': [('pout', False)],
          'pouternes': [('pout', False)],
          'pove': [('pove', False)],
          'poven': [('pove', False)],
          'povens': [('pove', False)],
          'pover': [('pover', False)],
          'poverne': [('pover', False)],
          'povernes': [('pove', False)],
          'povers': [('pove', False)],
          'poves': [('pove', False)],
          'power': [('power', False)],
          'powers': [('power', False)],
          'ppas': [('ppa', False)],
          'ppasser': [('ppasser', False)],
          'ppasserne': [('ppasser', False)],
          'ppassernes': [('ppasser', False)],
          'ppassers': [('ppasser', False)],
          'ppearbejdernes': [('ppearbejde', False)],
          'ppearbejders': [('ppearbejde', False)],
          'ppels': [('ppel', False)],
          'ppelse': [('ppelse', False)],
          'ppelsen': [('ppelse', False)],
          'ppelsens': [('ppelse', False)],
          'ppelses': [('ppelse', False)],
          'ppen': [('p', False)],
          'ppens': [('p', False)],
          'ppere': [('pper', False)],
          'pperens': [('pper', False)],
          'pperes': [('pper', False)],
          'pperne': [('p', False)],
          'ppernes': [('ppe', False)],
          'ppers': [('p', False)],
          'ppersen': [('ppers', False)],
          'ppersens': [('ppers', False)],
          'pperserne': [('ppers', False)],
          'ppersernes': [('ppers', False)],
          'ppes': [('ppe', False)],
          'ppesten': [('ppesten', False)],
          'ppestens': [('ppesten', False)],
          'ppiens': [('ppie', False)],
          'ppier': [('ppie', False)],
          'ppierne': [('ppie', False)],
          'ppiernes': [('ppie', False)],
          'ppiers': [('ppie', False)],
          'ppiner': [('ppiner', False)],
          'ppinerne': [('ppiner', False)],
          'ppinernes': [('ppiner', False)],
          'pplanet': [('pplan', False)],
          'pplanets': [('pplan', False)],
          'pporter': [('pporter', False)],
          'pporterne': [('pport', False)],
          'pporternes': [('pport', False)],
          'pporters': [('pporter', False)],
          'pps': [('pp', False)],
          "pps'": [('pp', False)],
          'ppsene': [('pp', False)],
          'ppsenes': [('pp', False)],
          'pr': [('pr', True)],
          'pralerne': [('praler', True)],
          'pralernes': [('praler', True)],
          'pralers': [('praler', True)],
          'pramme': [('pram', False)],
          'prammen': [('pram', False)],
          'prammens': [('pram', False)],
          'prammes': [('pram', True)],
          'pranen': [('pran', False)],
          'praner': [('pran', False)],
          'praners': [('pran', False)],
          'pranger': [('pranger', True)],
          'prangerne': [('pranger', True)],
          'prangernes': [('pranger', True)],
          'prangers': [('pranger', True)],
          'prans': [('pran', False)],
          'prasen': [('pras', False)],
          'prasens': [('pras', False)],
          'praser': [('pras', False)],
          'praserne': [('pras', False)],
          'prasernes': [('pras', False)],
          'prasers': [('pras', False)],
          'preder': [('preder', False)],
          'prederne': [('preder', False)],
          'predernes': [('preder', False)],
          'preders': [('preder', False)],
          'pren': [('pren', True)],
          'prene': [('pren', True)],
          'prenes': [('pren', True)],
          'prens': [('pren', False)],
          'prensernes': [('prenser', False)],
          'prer': [('prer', False)],
          'prerne': [('prer', False)],
          'prernes': [('prer', False)],
          'pres': [('pres', False)],
          "pres'": [('pres', False)],
          'pressen': [('presse', False)],
          'pressene': [('pres', False)],
          'pressenes': [('pres', False)],
          'pressens': [('presse', True)],
          'presser': [('presse', True), ('presser', True)],
          'presserne': [('presser', True), ('presse', True)],
          'pressernes': [('presse', True), ('presser', True)],
          'pressers': [('presser', True), ('presse', True)],
          'presset': [('pres', True)],
          'pressets': [('pres', False)],
          'pret': [('pret', False)],
          'pretter': [('pret', False)],
          'pretterne': [('pretter', False)],
          'pretternes': [('pretter', False)],
          'pretters': [('pretter', False)],
          'price': [('price', False)],
          'pricer': [('price', False)],
          'prier': [('prium', False)],
          'prierne': [('prium', False)],
          'priernes': [('prium', False)],
          'priet': [('prium', False)],
          'priets': [('prium', False)],
          'prikkens': [('prik', False)],
          'prikker': [('prik', False)],
          'prikkernes': [('prik', False)],
          'prikkers': [('prik', False)],
          'priks': [('prik', False)],
          'primassen': [('primas', True)],
          'primasser': [('primas', True)],
          'primassernes': [('primas', True)],
          'primassers': [('primas', True)],
          'primer': [('prim', True)],
          'primerne': [('prim', True)],
          'primernes': [('prim', True)],
          'pringer': [('pringer', False)],
          'pringerne': [('pringer', False)],
          'pringernes': [('pringer', False)],
          'pringers': [('pring', False)],
          'printer': [('printer', False)],
          'printernes': [('printer', True)],
          'pris': [('pris', False)],
          'prisen': [('prise', True), ('pris', True)],
          'prisens': [('prise', True), ('pris', True)],
          'priser': [('prise', True), ('pris', True)],
          'priserne': [('prise', True), ('pris', True)],
          'prisernes': [('prise', True), ('pris', True)],
          'prisers': [('pris', True), ('prise', True)],
          'priten': [('prit', False)],
          'pritens': [('prit', False)],
          'priter': [('prit', False)],
          'priterne': [('prit', False)],
          'priternes': [('prit', False)],
          'priters': [('prit', False)],
          'pritten': [('prit', False)],
          'prittens': [('prit', False)],
          'pritter': [('pritter', False)],
          'pritterne': [('pritter', False)],
          'pritternes': [('pritter', False)],
          'pritters': [('pritter', False)],
          'prium': [('prium', False)],
          'priums': [('prium', False)],
          'procenter': [('procenter', True), ('procent', True)],
          'procenters': [('procenter', True), ('procent', True)],
          'produkthandler': [('produkthandler', True), ('produkthandel', True)],
          'produkthandlerne': [('produkthandel', True), ('produkthandler', True)],
          'produkthandlernes': [('produkthandel', True), ('produkthandler', True)],
          'produkthandlers': [('produkthandler', True), ('produkthandel', True)],
          'proer': [('proer', False)],
          'proerne': [('proer', False)],
          'proernes': [('proer', False)],
          'proers': [('proer', False)],
          'prompter': [('prompt', True)],
          'prompterne': [('prompt', True)],
          'prompternes': [('prompt', True)],
          'prompters': [('prompt', True)],
          'pronomen': [('pronomen', False)],
          'propper': [('prop', False)],
          'proppernes': [('prop', False)],
          'props': [('prop', False)],
          'propylen': [('propyl', True), ('propylen', True)],
          'propylens': [('propyl', True), ('propylen', True)],
          'prossen': [('prosse', False)],
          'prossens': [('prosse', False)],
          'prosser': [('prosse', False)],
          'prosserne': [('prosse', False)],
          'prs': [('pr', True)],
          'prutten': [('prut', True)],
          'pruttens': [('prut', True)],
          'prutter': [('prut', True)],
          'prutterne': [('prut', True)],
          'prutternes': [('prut', True)],
          'prutters': [('prut', True)],
          'pryden': [('pryd', True)],
          'prydens': [('pryd', True)],
          'pryds': [('pryd', False)],
          'prykkerne': [('prykker', False)],
          'prykkernes': [('prykker', False)],
          'pråbers': [('pråber', False)],
          'prås': [('prås', True)],
          'pråse': [('prås', False)],
          'pråsen': [('prås', True)],
          'pråsens': [('prås', True)],
          'pråses': [('prås', False)],
          'præer': [('præ', True)],
          'præerne': [('præ', True)],
          'præernes': [('præ', True)],
          'præers': [('præ', True)],
          'prækker': [('prække', False)],
          'præmien': [('præmie', False)],
          'præmiens': [('præmie', False)],
          'præmier': [('præmie', False)],
          'præmierne': [('præmie', False)],
          'præmiernes': [('præmie', False)],
          'præmiers': [('præmie', False)],
          'præs': [('præ', True)],
          'prøret': [('prør', False)],
          'prørets': [('prør', False)],
          'prøve': [('prøve', False)],
          'prøven': [('prøve', False)],
          'prøvens': [('prøve', False)],
          'prøver': [('prøve', False)],
          'prøverne': [('prøve', False)],
          'prøvernes': [('prøve', False)],
          'prøvers': [('prøve', False)],
          'prøves': [('prøve', False)],
          'ps': [('postscriptum', True)],
          "ps'": [('ps', False)],
          'psalter': [('psalter', True)],
          'psalterne': [('psalter', True)],
          'psalver': [('psalve', False)],
          'pscorer': [('pscorer', False)],
          'pscorerne': [('pscorer', False)],
          'pscorernes': [('pscorer', False)],
          'pscorers': [('pscorer', False)],
          'pse': [('ps', False)],
          'psen': [('ps', False)],
          'psene': [('ps', False)],
          'psenes': [('ps', False)],
          'psens': [('ps', False)],
          'pser': [('ps', False)],
          'psere': [('pser', False)],
          'psereder': [('pserede', False)],
          'pserederne': [('pserede', False)],
          'psereders': [('pserede', False)],
          'pseren': [('pser', False)],
          'pserens': [('pser', False)],
          'pseres': [('pser', False)],
          'pserier': [('pseri', False)],
          'pserierne': [('pseri', False)],
          'pseriernes': [('pseri', False)],
          'pseriers': [('pseri', False)],
          'pserne': [('ps', False)],
          'psernes': [('ps', False)],
          'pses': [('ps', False)],
          'psestens': [('psest', False)],
          'pset': [('ps', False)],
          'psets': [('ps', False)],
          'psiden': [('psis', False)],
          'psidens': [('psis', False)],
          'psider': [('psis', False)],
          'psiderne': [('psis', False)],
          'psidernes': [('psis', False)],
          'psiders': [('psis', False)],
          'psier': [('psi', False)],
          'psierne': [('psi', True)],
          'psiet': [('psi', True)],
          'psigten': [('psigt', False)],
          'psigtens': [('psigt', False)],
          'psis': [('psi', True)],
          'pskifte': [('pskifte', False)],
          'pskifter': [('pskifte', False)],
          'pskifterne': [('pskifte', False)],
          'pskifternes': [('pskifte', False)],
          'pskifters': [('pskifte', False)],
          'pskiftes': [('pskifte', False)],
          'pskiftet': [('pskifte', False)],
          'pskiftets': [('pskifte', False)],
          'pskos': [('psko', False)],
          'pskytter': [('pskytte', False)],
          'pslags': [('pslag', False)],
          'pslangen': [('pslange', False)],
          'pslangens': [('pslange', False)],
          'pslens': [('psel', False)],
          'psler': [('psel', False)],
          'pslinger': [('psling', False)],
          'pslingerne': [('psling', False)],
          'pslingernes': [('psling', False)],
          'pslingers': [('psling', False)],
          'pslusen': [('pslus', False)],
          'pslusens': [('pslus', False)],
          'psmidler': [('psmidler', False)],
          'psmidlerne': [('psmidler', False)],
          'psmidlernes': [('psmidler', False)],
          'psmidlers': [('psmidler', False)],
          'psoden': [('psode', False)],
          'psodens': [('psode', False)],
          'psparerne': [('psparer', False)],
          'psparernes': [('psparer', False)],
          'psporer': [('psporer', False)],
          'psporerne': [('psporer', False)],
          'psporernes': [('psporer', False)],
          'psporers': [('psporer', False)],
          'psporter': [('psport', False)],
          'pstarter': [('pstart', False)],
          'pstarterne': [('pstart', False)],
          'pstarternes': [('pstart', False)],
          'pstarters': [('pstart', False)],
          'pstave': [('pstav', False)],
          'pstaven': [('pstav', False)],
          'pstavens': [('pstav', False)],
          'pstaves': [('pstav', False)],
          'psten': [('psten', False)],
          'pstens': [('psten', False)],
          'pster': [('pster', False)],
          'psterne': [('pster', False)],
          'psternes': [('pster', False)],
          'psters': [('pster', False)],
          'pstillernes': [('pstiller', False)],
          'pstykkernes': [('pstykke', False)],
          'pstykkers': [('pstykke', False)],
          'pstøvler': [('pstøvle', False)],
          'pstøvlerne': [('pstøvle', False)],
          'psuiten': [('psuit', False)],
          'psuitens': [('psuit', False)],
          'psus': [('psus', False)],
          'psæder': [('psæde', False)],
          'psæderne': [('psæde', False)],
          'psædernes': [('psæde', False)],
          'psæders': [('psæde', False)],
          'psøer': [('psø', False)],
          'psøerne': [('psø', False)],
          'psøernes': [('psø', False)],
          'psøers': [('psø', False)],
          'pta': [('ptum', False)],
          'ptaene': [('ptum', False)],
          'ptaenes': [('ptum', False)],
          'ptage': [('ptag', False)],
          'ptagere': [('ptager', False)],
          'ptageren': [('ptager', False)],
          'ptagerens': [('ptager', False)],
          'ptageres': [('ptager', False)],
          'ptangen': [('ptang', False)],
          'ptangens': [('ptang', False)],
          'ptanten': [('ptant', False)],
          'ptantens': [('ptant', False)],
          'ptanter': [('ptant', False)],
          'ptanterne': [('ptant', False)],
          'ptanternes': [('ptant', False)],
          'ptanters': [('ptant', False)],
          'ptas': [('ptum', False)],
          'pteaser': [('ptease', False)],
          'pteaserne': [('ptease', False)],
          'pteasernes': [('ptease', False)],
          'pteasers': [('ptease', False)],
          'ptekster': [('ptekst', False)],
          'pteksterne': [('ptekst', False)],
          'pteksternes': [('ptekst', False)],
          'pteksters': [('ptekst', False)],
          'pten': [('pt', False)],
          'ptens': [('pt', False)],
          'pter': [('pter', False)],
          'pteret': [('pter', False)],
          'pterets': [('pter', False)],
          'pterne': [('pt', False)],
          'pternes': [('pt', False)],
          'pters': [('pt', False)],
          'ptets': [('pt', False)],
          'ptika': [('ptika', False)],
          'ptikas': [('ptika', False)],
          'ptikkens': [('ptik', False)],
          'ptikker': [('ptik', False)],
          'ptikkernes': [('ptik', False)],
          'ptikkers': [('ptik', False)],
          'ptikon': [('ptikon', False)],
          'ptikons': [('ptikon', False)],
          'ptiks': [('ptik', False)],
          'ptilet': [('ptil', False)],
          'ptimen': [('ptim', False)],
          'ptimens': [('ptim', False)],
          'ptimer': [('ptim', False)],
          'ptimerne': [('ptim', False)],
          'ptimernes': [('ptim', False)],
          'ptimers': [('ptim', False)],
          'ptis': [('pti', False)],
          'ptiver': [('ptiv', False)],
          'ptivernes': [('ptiv', False)],
          'ptoget': [('ptog', False)],
          'ptomer': [('ptom', False)],
          'ptomers': [('ptom', False)],
          'ptonet': [('pton', False)],
          'ptonets': [('pton', False)],
          "ptops'": [('ptop', False)],
          'ptrene': [('pter', False)],
          'ptrenes': [('pter', False)],
          'ptres': [('pter', False)],
          'pts': [('pt', False)],
          'ptuer': [('ptu', False)],
          'ptuerne': [('ptu', False)],
          'ptuernes': [('ptu', False)],
          'ptuers': [('ptu', False)],
          'pture': [('ptur', False)],
          'pturen': [('ptur', False)],
          'pturens': [('ptur', False)],
          'pturer': [('ptur', False)],
          'pturerne': [('ptur', False)],
          'pturernes': [('ptur', False)],
          'pturers': [('ptur', False)],
          'ptures': [('ptur', False)],
          'pturet': [('ptur', False)],
          'ptus': [('ptus', False)],
          'ptyve': [('ptyve', False)],
          'ptyves': [('ptyve', False)],
          'ptængers': [('ptang', False)],
          'ptøjer': [('ptøjer', False)],
          'ptøjerne': [('ptøjer', False)],
          'ptøjernes': [('ptøjer', False)],
          'ptøjers': [('ptøjer', False)],
          'ptører': [('ptør', False)],
          'pubbens': [('pub', False)],
          'pubber': [('pub', False)],
          'pubbernes': [('pub', True)],
          'pubbers': [('pub', True)],
          'publikummer': [('publikummer', True), ('publikum', True)],
          'publikummerne': [('publikum', True), ('publikummer', True)],
          'publikummernes': [('publikummer', True), ('publikum', True)],
          'publikummers': [('publikum', True), ('publikummer', True)],
          'puckerne': [('puck', True)],
          'puckers': [('puck', True)],
          'pude': [('pude', False)],
          'puden': [('pude', False)],
          'pudens': [('pude', False)],
          'puderne': [('pude', False)],
          'puders': [('pude', False)],
          'pudes': [('pude', False)],
          'pudlens': [('puddel', False)],
          'pudler': [('puddel', False)],
          'pudlers': [('puddel', True)],
          'puds': [('puds', False)],
          'pudsen': [('puds', False)],
          'pudsens': [('puds', False)],
          'pudser': [('pudser', False)],
          'pudsers': [('pudser', False)],
          'puffer': [('puffer', True), ('puf', True)],
          'pufferne': [('puf', True), ('puffer', True)],
          'puffernes': [('puf', True), ('puffer', True)],
          'puffers': [('puf', True), ('puffer', True)],
          'puffet': [('puf', True)],
          'puger': [('puger', False)],
          'pugerne': [('puger', True)],
          'pugernes': [('puger', False)],
          'pugers': [('puger', False)],
          'pula': [('pula', False)],
          'pulas': [('pula', False)],
          'pulde': [('puld', False)],
          'puldens': [('puld', False)],
          'puldes': [('puld', True)],
          'pullen': [('pulle', True)],
          'pullens': [('pulle', True)],
          'puller': [('pulle', True)],
          'pullerne': [('pulle', True)],
          'pullernes': [('pulle', True)],
          'pullers': [('pulle', True)],
          'pulpen': [('pulp', True)],
          'pulpens': [('pulp', True)],
          'puls': [('puls', True)],
          'pulte': [('pult', False)],
          'pulten': [('pult', False)],
          'pultens': [('pult', False)],
          'pulter': [('pult', False)],
          'pulterne': [('pult', False)],
          'pulternes': [('pult', False)],
          'pultes': [('pult', False)],
          'puma': [('puma', True)],
          'pumas': [('puma', True)],
          'pumpen': [('pump', True), ('pumpe', True)],
          'pumpens': [('pump', True), ('pumpe', True)],
          'pumper': [('pumpe', True)],
          'pumperne': [('pumpe', True)],
          'pumpernes': [('pumpe', False)],
          'pumpers': [('pumpe', False)],
          'pundkursers': [('pundkurs', True)],
          'punerne': [('pun', False)],
          'puners': [('pun', False)],
          'punge': [('pung', False)],
          'pungen': [('pung', False)],
          'pungens': [('pung', False)],
          'punges': [('pung', False)],
          'punken': [('punk', False)],
          'punkerne': [('punker', True)],
          'punkers': [('punker', False)],
          'puns': [('pun', False)],
          "puns'": [('puns', False)],
          'punser': [('puns', False)],
          'punsernes': [('puns', False)],
          'punsers': [('puns', False)],
          'pupper': [('puppe', True)],
          'puppernes': [('puppe', True)],
          'puppes': [('puppe', True)],
          'puret': [('pur', False)],
          'purets': [('pur', False)],
          'purrets': [('pur', False)],
          'purs': [('pur', False)],
          'purser': [('purser', True)],
          'purserne': [('purser', True)],
          'pursernes': [('purser', True)],
          'pursers': [('purser', True)],
          'purter': [('purt', False)],
          'purterne': [('purt', False)],
          'purve': [('purv', False)],
          'purven': [('purv', False)],
          'purvens': [('purv', False)],
          'purves': [('purv', False)],
          'pussen': [('pus', False)],
          'pussens': [('pus', False)],
          'pusser': [('pus', False)],
          'pusserne': [('pus', False)],
          'pustens': [('pusten', True)],
          'pusters': [('puster', True)],
          'puter': [('puter', False)],
          'puterne': [('puter', False)],
          'puternes': [('puter', False)],
          'puters': [('puter', False)],
          'putten': [('putte', True)],
          'puttens': [('putte', True)],
          'putter': [('putte', True)],
          'putterne': [('putte', True)],
          'putternes': [('putte', True)],
          'putters': [('putte', True)],
          'putti': [('putto', True)],
          'puttis': [('putto', True)],
          'pvarter': [('pvarter', False)],
          'pvarterne': [('pvarter', False)],
          'pvarters': [('pvarter', False)],
          'pvinde': [('pvind', False)],
          'pvinden': [('pvind', False)],
          'pvindens': [('pvind', False)],
          'pvindes': [('pvind', False)],
          'pvinen': [('pvin', False)],
          'pvines': [('pvin', False)],
          'pyen': [('py', False)],
          'pyens': [('py', False)],
          'pyer': [('py', False)],
          'pyerne': [('py', True)],
          'pyernes': [('py', False)],
          'pyers': [('py', False)],
          'pylenet': [('pylen', False)],
          'pynten': [('pynt', True)],
          'pyntens': [('pynt', False)],
          'pynterne': [('pynt', True)],
          'pynternes': [('pynt', True)],
          'pynters': [('pynt', True)],
          'pyrerne': [('pyr', False)],
          'pyrernes': [('pyr', False)],
          'pys': [('py', False)],
          'pytten': [('pyt', False)],
          'pyttens': [('pyt', False)],
          'pytternes': [('pyt', False)],
          'pytters': [('pyt', True)],
          'pyttet': [('pyt', False)],
          'pyttets': [('pyt', False)],
          'påner': [('pån', False)],
          'pånerne': [('pån', False)],
          'pæden': [('pæd', False)],
          'pædens': [('pæd', False)],
          'pæder': [('pæd', False)],
          'pæderne': [('pæd', False)],
          'pædernes': [('pæd', False)],
          'pæders': [('pæd', False)],
          'pæers': [('pæer', False)],
          'pæksten': [('pæksten', False)],
          'pækstens': [('pæksten', False)],
          'pænd': [('pænd', False)],
          'pændene': [('pænd', False)],
          'pændenes': [('pænd', False)],
          'pændere': [('pænder', False)],
          'pænderen': [('pænder', False)],
          'pænderens': [('pænder', False)],
          'pænderes': [('pænder', False)],
          'pænders': [('pand', False)],
          'pænds': [('pænd', False)],
          'pære': [('pære', False)],
          'pæren': [('pære', False)],
          'pærens': [('pære', True)],
          'pærer': [('pære', False)],
          'pærerne': [('pære', False)],
          'pærernes': [('pære', False)],
          'pærers': [('pære', False)],
          'pærren': [('pærre', False)],
          'pærret': [('pærre', False)],
          'pærrets': [('pærre', False)],
          'pæstens': [('pæst', False)],
          'pæster': [('pæst', False)],
          'pæsterne': [('pæst', False)],
          'pæsternes': [('pæst', False)],
          'pæsters': [('pæst', False)],
          'pætten': [('pætte', False)],
          'pættens': [('pætte', False)],
          'pætter': [('pætte', False)],
          'pætterne': [('pætte', False)],
          'pætternes': [('pætte', False)],
          'pætters': [('pætte', False)],
          'pøllen': [('pølle', True)],
          'pøllens': [('pølle', True)],
          'pøller': [('pølle', True)],
          'pøllerne': [('pølle', True)],
          'pøllernes': [('pølle', True)],
          'pøllers': [('pølle', True)],
          'pøren': [('pør', False)],
          'pørens': [('pør', False)],
          'pører': [('pør', False)],
          'pørerne': [('pør', False)],
          'pørernes': [('pør', False)],
          'pørers': [('pør', False)],
          'pørgens': [('pørge', False)],
          'pøs': [('pøs', True)],
          'pøse': [('pøs', True)],
          'pøsen': [('pøs', True)],
          'pøsens': [('pøs', True)],
          'pøses': [('pøs', True)],
          "q'erne": [('q', True)],
          'qabbens': [('qab', False)],
          'qabber': [('qab', False)],
          'qabbernes': [('qab', False)],
          'qabbers': [('qab', False)],
          'qabs': [('qab', False)],
          'qatarer': [('qatarer', True)],
          'qatarernes': [('qatarer', True)],
          'quer': [('quer', False)],
          'querne': [('quer', False)],
          'quernes': [('quer', False)],
          'quers': [('quer', False)],
          'quet': [('quet', False)],
          'queten': [('quet', False)],
          'quetens': [('quet', False)],
          'quets': [('quet', False)],
          'quis': [('quis', False)],
          'quiset': [('quis', False)],
          'quisets': [('quis', False)],
          'r': [('r', True)],
          "r'erne": [('r', True)],
          'r-': [('rsæde', False)],
          'r.': [('r.', False)],
          'ra': [('ra', False)],
          'rabben': [('rabbe', False)],
          'rabberne': [('rabbe', False)],
          'rabe': [('rabe', False)],
          'raben': [('raben', False)],
          'rabenerne': [('raben', False)],
          'rabenernes': [('raben', False)],
          'rabenet': [('raben', False)],
          'rabenets': [('raben', False)],
          'rabens': [('rabe', False)],
          'raber': [('raber', False)],
          'rabernes': [('raber', False)],
          'rabers': [('raber', False)],
          'rabes': [('rabe', False)],
          'rabet': [('rab', False)],
          'rabilier': [('rabilier', False)],
          'rabiner': [('rabin', False)],
          'rabiners': [('rabin', False)],
          'rabis': [('rabi', False)],
          'rabler': [('rabel', False)],
          'rablerne': [('rabel', False)],
          'rablernes': [('rabel', False)],
          'rablers': [('rabel', False)],
          'rabs': [('rab', False)],
          'rabuds': [('rabud', False)],
          'racen': [('race', False)],
          'racens': [('race', False)],
          'racer': [('racer', True), ('race', True)],
          'racerne': [('racer', True), ('race', True)],
          'racernes': [('racer', True), ('race', True)],
          'racers': [('racer', True), ('race', True)],
          'racet': [('race', True)],
          'racket': [('rack', True)],
          'rackets': [('rack', False)],
          'racks': [('rack', False)],
          "racks'": [('rack', False)],
          'racters': [('ract', False)],
          'racts': [('ract', False)],
          "racts'": [('ract', False)],
          'radans': [('radans', False)],
          'rade': [('rad', True)],
          'raden': [('rad', True)],
          'radens': [('rad', True)],
          'rader': [('rad', False)],
          'raderer': [('raderer', True)],
          'radererne': [('raderer', True)],
          'raderernes': [('raderer', True)],
          'raderers': [('raderer', True)],
          'raderne': [('rad', True)],
          'radernes': [('rad', False)],
          'raders': [('rad', True)],
          'rades': [('rad', True)],
          'radierne': [('radius', False)],
          'radiernes': [('radius', True)],
          'radiers': [('radius', False)],
          'radis': [('radis', False)],
          'radiser': [('radise', False)],
          'radiserne': [('radise', True)],
          'radisernes': [('radise', False)],
          'radisers': [('radise', True)],
          'rados': [('rado', False)],
          "rados'": [('rado', False)],
          'rads': [('rad', True)],
          "rads'": [('rads', False)],
          'radser': [('rads', False)],
          'radserne': [('rads', False)],
          'radsernes': [('rads', False)],
          'radsers': [('rads', False)],
          'radset': [('rads', False)],
          'radsets': [('rads', False)],
          'raen': [('ra', False)],
          'raene': [('rus', False)],
          'raenes': [('ra', False)],
          'raens': [('ra', False)],
          'raer': [('ra', False)],
          'raerne': [('ra', False)],
          'raernes': [('ra', False)],
          'raers': [('ra', False)],
          'raffen': [('raf', False)],
          'raffer': [('raf', False)],
          'rafferne': [('raffe', False)],
          'raffernes': [('raf', False)],
          'raffers': [('raffe', False)],
          'rafier': [('rafi', False)],
          'rafierne': [('rafi', False)],
          'rafiernes': [('rafi', False)],
          'rafiers': [('rafi', False)],
          'rafiet': [('rafi', False)],
          'rafiets': [('rafi', False)],
          'raflen': [('raffel', False)],
          'raflens': [('raffel', False)],
          'rafler': [('raffel', False)],
          'raflerne': [('raffel', False)],
          'raflernes': [('raffel', False)],
          'raflers': [('raffel', False)],
          'raftalens': [('raftale', False)],
          'rafte': [('rafte', True)],
          'raften': [('rafte', True)],
          'raftens': [('rafte', True)],
          'rafter': [('rafte', True)],
          'rafterne': [('rafte', True)],
          'rafternes': [('rafte', True)],
          'rafters': [('rafte', True)],
          'raftes': [('rafte', True)],
          'rage': [('rage', False)],
          'ragen': [('rage', False)],
          'ragens': [('rage', False)],
          'rager': [('rager', False)],
          'ragerne': [('rager', False)],
          'ragernes': [('rager', False)],
          'ragers': [('rager', False)],
          'rages': [('rage', False)],
          'raggen': [('rag', True)],
          'raggens': [('rag', True)],
          'raglen': [('ragel', False)],
          'raglernes': [('ragel', False)],
          'raglers': [('ragel', False)],
          'ragter': [('ragt', False)],
          'ragterne': [('ragt', False)],
          'ragternes': [('ragt', False)],
          'ragters': [('ragter', False)],
          'raiden': [('raid', False)],
          'raids': [('raid', True)],
          "raids'": [('raid', True)],
          'railer': [('railer', False)],
          'railerne': [('rail', False)],
          'railernes': [('rail', False)],
          'railers': [('rail', False)],
          'rainer': [('rainer', False)],
          'rainerne': [('raine', False)],
          'rainernes': [('raine', False)],
          'rainers': [('raine', False)],
          'rais': [('rai', False)],
          'raisen': [('rais', False)],
          'raisens': [('rais', False)],
          'raiserne': [('raiser', False)],
          'raisernes': [('raiser', False)],
          'raketten': [('raket', False)],
          'rakettens': [('raket', False)],
          'raketterne': [('raket', False)],
          'raketternes': [('raket', False)],
          'raketters': [('raket', False)],
          'rakken': [('rak', False)],
          'rakkens': [('rakke', False)],
          'rakker': [('rakker', True)],
          'rakkerne': [('rakker', True)],
          'rakkernes': [('rakker', False)],
          'rakkers': [('rakker', True)],
          'raklen': [('rakle', True)],
          'raklens': [('rakle', True)],
          'rakler': [('rakle', True)],
          'raklerne': [('rakle', True)],
          'raklernes': [('rakle', True)],
          'raklers': [('rakle', True)],
          'raks': [('rak', False)],
          "raks'": [('raks', False)],
          'raksen': [('raks', False)],
          'raksens': [('raks', False)],
          'rakshandler': [('rakshandel', False)],
          'rakshandlers': [('rakshandel', False)],
          'raksis': [('raksis', False)],
          'rakter': [('rakt', False)],
          'rakterne': [('rakt', False)],
          'rakternes': [('rakt', False)],
          'rakters': [('rakt', False)],
          'ralbas': [('ralbas', False)],
          'ralder': [('ralde', False)],
          'ralderne': [('ralde', False)],
          'raldernes': [('ralde', False)],
          'ralders': [('ralde', False)],
          'rale': [('rale', False)],
          'ralens': [('ral', False)],
          'raler': [('raler', False)],
          'ralias': [('ralia', False)],
          'ralien': [('ralie', False)],
          'raliens': [('ralie', False)],
          'ralier': [('ralie', False)],
          'ralierne': [('rale', False)],
          'raliernes': [('ralie', False)],
          'rallen': [('ral', False)],
          'rallene': [('rall', False)],
          'rallenes': [('rall', False)],
          'rallens': [('ral', False)],
          'raller': [('ral', False)],
          'rallers': [('ral', False)],
          'ralogens': [('ralog', False)],
          'ramben': [('rambe', False)],
          'rambens': [('rambe', False)],
          'ramen': [('rame', False)],
          'ramenter': [('rament', False)],
          'ramenterne': [('ramente', False)],
          'ramenternes': [('ramenter', False)],
          'ramenters': [('ramente', False)],
          'ramentet': [('rament', False)],
          'ramentets': [('rament', False)],
          'ramer': [('rama', False)],
          'ramerne': [('rama', False)],
          'ramernes': [('rama', False)],
          'ramers': [('rama', False)],
          'ramider': [('ramide', False)],
          'ramiderne': [('ramide', False)],
          'ramidernes': [('ramide', False)],
          'ramiders': [('ramide', False)],
          'ramier': [('rami', False)],
          'ramierne': [('rami', False)],
          'ramiernes': [('rami', False)],
          'ramiers': [('rami', False)],
          'raminer': [('ramin', False)],
          'raminerne': [('ramin', False)],
          'raminernes': [('ramin', False)],
          'raminers': [('ramin', False)],
          'ramme': [('ramme', True)],
          'rammen': [('ram', True), ('ramme', True)],
          'rammens': [('ram', True), ('ramme', True)],
          'rammer': [('ramme', True)],
          'rammerne': [('ramme', False)],
          'rammernes': [('ramme', True)],
          'rammers': [('ramme', False)],
          'rammes': [('ramme', True)],
          'rampernes': [('rampe', True)],
          'rampers': [('rampe', True)],
          'rampet': [('ramp', False)],
          'rampets': [('ramp', False)],
          'rams': [('ram', True)],
          "rams'": [('rams', False)],
          'ramsen': [('rams', False)],
          'ramsens': [('rams', False)],
          'rancen': [('ranc', False)],
          'rancens': [('ranc', False)],
          'ranchen': [('ranch', True)],
          'ranchens': [('ranch', True)],
          'rancher': [('ranch', True)],
          'rancherne': [('ranch', True)],
          'ranchernes': [('ranch', True)],
          'ranchers': [('ranch', True)],
          'randa': [('randum', False)],
          'randas': [('randum', False)],
          'rande': [('rand', False)],
          'randen': [('rand', False)],
          'randens': [('rand', False)],
          'rander': [('rander', False)],
          'randerne': [('rand', False)],
          'randernes': [('rand', False)],
          'randers': [('rand', False)],
          'randes': [('rand', False)],
          'randet': [('rand', False)],
          'randets': [('rand', False)],
          'ranen': [('rane', False)],
          'ranens': [('ran', False)],
          'raner': [('raner', False)],
          'ranerne': [('ran', False)],
          'ranernes': [('ran', False)],
          'raners': [('raner', False)],
          'ranes': [('rane', False)],
          'ranet': [('ran', True)],
          'ranets': [('ran', True)],
          'ranettet': [('ranet', False)],
          'ranettets': [('ranet', False)],
          'rangen': [('range', True), ('rang', True)],
          'rangens': [('range', True), ('rang', True)],
          'ranger': [('rang', True), ('range', True)],
          'rangerne': [('range', True), ('rang', True)],
          'rangernes': [('rang', True), ('range', True)],
          'rangers': [('range', True), ('rang', True)],
          'ranglen': [('rangle', True)],
          'rangler': [('rangle', True)],
          'ranglerne': [('rangle', True)],
          'ranglernes': [('rangle', True)],
          'ranglers': [('rangle', True)],
          'ranglisten': [('rangliste', True)],
          'ranglistens': [('rangliste', True)],
          'ranglister': [('rangliste', True)],
          'ranglisterne': [('rangliste', True)],
          'ranglisternes': [('rangliste', True)],
          'ranglisters': [('rangliste', True)],
          'ranier': [('ranie', False)],
          'ranierne': [('ranie', False)],
          'raniernes': [('ranie', False)],
          'raniers': [('ranie', False)],
          'ranis': [('rani', False)],
          'ranister': [('ranist', False)],
          'ranisters': [('ranist', False)],
          'ranium': [('ranie', False)],
          'raniums': [('ranie', False)],
          'ranke': [('ranke', True)],
          'ranken': [('ranke', True)],
          'rankens': [('ranke', False)],
          'ranker': [('ranke', True)],
          'rankerne': [('ranke', False)],
          'rankernes': [('ranke', True)],
          'rankers': [('ranke', False)],
          'rankes': [('ranke', True)],
          'ranks': [('rank', False)],
          'rannen': [('ran', False)],
          'rannens': [('ran', False)],
          'ranner': [('ran', False)],
          'ranners': [('ran', False)],
          'rans': [('ran', True)],
          "rans'": [('rans', False)],
          'ranse': [('rans', False)],
          'ransen': [('rans', False)],
          'ransenes': [('rans', False)],
          'ransens': [('rans', False)],
          'ranser': [('rans', False)],
          'ransernes': [('rans', False)],
          'ransers': [('rans', False)],
          'ranses': [('rans', False)],
          'ransler': [('ransel', True)],
          'ranten': [('rant', False)],
          'rantens': [('rant', False)],
          'ranterne': [('rant', False)],
          'ranternes': [('rant', False)],
          'ranters': [('rant', False)],
          'rantis': [('rantis', False)],
          'rants': [('rant', False)],
          "rants'": [('rant', False)],
          'rapas': [('rapa', False)],
          'rapiens': [('rapi', False)],
          'rappen': [('rap', False)],
          'rappens': [('rap', False)],
          'rappes': [('rappe', False)],
          'raps': [('raps', True), ('rap', True)],
          "raps'": [('raps', True)],
          'rapsen': [('raps', True)],
          'rapsens': [('raps', False)],
          'rarbejder': [('rarbejder', False)],
          'rarbejderne': [('rarbejder', False)],
          'rarbejdernes': [('rarbejde', False)],
          'rarbejders': [('rarbejde', False)],
          'raren': [('rare', False)],
          'rarens': [('rare', False)],
          'rarenten': [('rarente', False)],
          'rarentens': [('rarente', False)],
          'rarenter': [('rarente', False)],
          'rarenters': [('rarente', False)],
          'rarentes': [('rarente', False)],
          'rarerne': [('rar', False)],
          'rarers': [('rar', False)],
          'rarier': [('rarie', False)],
          'rarierne': [('rarie', False)],
          'rariernes': [('rarie', False)],
          'rariers': [('rarie', False)],
          'rarium': [('rarie', False)],
          'rariums': [('rarie', False)],
          'rarkets': [('rark', False)],
          'rarmens': [('rarm', False)],
          'rarmes': [('rarm', False)],
          'rarven': [('rarv', False)],
          'rarvens': [('rarv', False)],
          'ras': [('ra', False)],
          'rase': [('rase', False)],
          'rasen': [('rase', False)],
          'rasens': [('rase', False)],
          'raser': [('rase', False)],
          'raserne': [('rase', False)],
          'rasernes': [('rase', False)],
          'rasers': [('rase', False)],
          'rases': [('rase', False)],
          'rasien': [('rasi', False)],
          'rasiens': [('rasi', False)],
          'rasier': [('rasier', False)],
          'rasierne': [('rasier', False)],
          'rasiernes': [('rasi', False)],
          'rasiers': [('rasi', False)],
          'rasis': [('rasi', False)],
          'rasken': [('rask', False)],
          'raskens': [('rask', False)],
          'rasker': [('rask', False)],
          'raskerne': [('rask', False)],
          'raskernes': [('rask', False)],
          'raskers': [('rask', False)],
          'raslen': [('raslen', False)],
          'rasler': [('rasler', False)],
          'raslers': [('rasler', False)],
          'raspen': [('rasp', True)],
          'rassen': [('ras', False)],
          'rassens': [('ras', False)],
          'rasser': [('rasse', False)],
          'rasserne': [('ras', False)],
          'rassernes': [('rasse', False)],
          'rassers': [('rasse', False)],
          'rasten': [('rast', False)],
          'rastens': [('rast', True)],
          'raster': [('rast', True), ('raster', True)],
          'rasterne': [('raster', True), ('rast', True)],
          'rasternes': [('raster', True), ('rast', True)],
          'rasters': [('rast', True), ('raster', True)],
          'rata': [('rata', False)],
          'rataenes': [('ratum', False)],
          'ratas': [('ratum', False)],
          'raten': [('rate', False)],
          'ratene': [('rat', False)],
          'ratenes': [('rat', False)],
          'ratens': [('rate', False)],
          'rater': [('rate', True)],
          'raterier': [('rateri', False)],
          'raterierne': [('rateri', False)],
          'rateriernes': [('rateri', False)],
          'rateriers': [('rateri', False)],
          'raterne': [('rate', True)],
          'raternes': [('rate', True)],
          'raters': [('rate', True)],
          'rates': [('rate', False)],
          'ratiden': [('ratid', False)],
          'ratidens': [('ratid', False)],
          'ratier': [('rati', False)],
          'ratierne': [('rati', False)],
          'ratiernes': [('rati', False)],
          'ratiers': [('rati', False)],
          'ratiet': [('rati', False)],
          'ratiets': [('rati', False)],
          'ratiner': [('ratin', False)],
          'ratinerne': [('ratin', False)],
          'ratinernes': [('ratin', False)],
          'ratis': [('rati', False)],
          'ratorier': [('ratorie', False)],
          'ratorierne': [('ratorium', False)],
          'ratoriernes': [('ratorie', False)],
          'ratoriers': [('ratorium', False)],
          'ratoriet': [('ratorium', False)],
          'ratoriets': [('ratorium', False)],
          'ratorium': [('ratorie', False)],
          'ratoriums': [('ratorie', False)],
          'ratos': [('rato', False)],
          'ratter': [('ratte', False)],
          'ratterne': [('ratte', False)],
          'ratternes': [('ratte', False)],
          'ratters': [('ratte', False)],
          'raus': [('raus', False)],
          'rausen': [('raus', False)],
          'rausens': [('raus', False)],
          'rauser': [('raus', False)],
          'rauserne': [('raus', False)],
          'rausernes': [('raus', False)],
          'rausers': [('raus', False)],
          'rave': [('rave', True)],
          'raven': [('rave', False)],
          'ravene': [('rave', True)],
          'ravenes': [('rave', True)],
          'ravens': [('rave', False)],
          'raver': [('raver', True)],
          'raverne': [('raver', True)],
          'ravernes': [('raver', True)],
          'ravers': [('raver', True)],
          'raves': [('rave', False)],
          'ravet': [('rave', True), ('rav', True)],
          'ravets': [('rave', True), ('rav', True)],
          'ravlen': [('ravl', False)],
          'ravlene': [('ravl', False)],
          'ravlenes': [('ravl', False)],
          'ravlens': [('ravl', False)],
          'ravne': [('ravn', False)],
          'ravnen': [('ravn', False)],
          'ravnens': [('ravn', False)],
          'ravnes': [('ravn', True)],
          'rbakken': [('rbakke', False)],
          'rbakkens': [('rbakke', False)],
          'rbakkerne': [('rbakke', False)],
          'rbaler': [('rbal', False)],
          'rbalerne': [('rbal', False)],
          'rbalernes': [('rbal', False)],
          'rbalers': [('rbal', False)],
          'rbanders': [('rbande', False)],
          'rbanen': [('rban', False)],
          'rbanens': [('rban', False)],
          'rbaner': [('rban', False)],
          'rbanerne': [('rban', False)],
          'rbanernes': [('rban', False)],
          'rbaners': [('rban', False)],
          'rbarier': [('rbari', False)],
          'rbarierne': [('rbarium', False)],
          'rbariernes': [('rbarium', False)],
          'rbariers': [('rbari', False)],
          'rbariet': [('rbari', False)],
          'rbariets': [('rbarium', False)],
          'rbars': [('rbar', False)],
          'rbas': [('rbas', False)],
          'rbede': [('rbed', False)],
          'rbedes': [('rbed', False)],
          'rben': [('rben', False)],
          'rbenets': [('rben', False)],
          'rbens': [('rbe', False)],
          'rberer': [('rber', False)],
          'rbererne': [('rber', False)],
          'rberernes': [('rber', False)],
          'rberers': [('rber', False)],
          'rbergerne': [('rberg', False)],
          'rberis': [('rberis', False)],
          'rberos': [('rberos', False)],
          'rbidet': [('rbid', False)],
          'rbidets': [('rbid', False)],
          'rbier': [('rbier', False)],
          'rbierne': [('rbier', False)],
          'rbiet': [('rbium', False)],
          'rbiets': [('rbium', False)],
          'rbilens': [('rbil', False)],
          'rbilerne': [('rbil', False)],
          'rbilers': [('rbil', False)],
          'rbiner': [('rbine', False)],
          'rbinerne': [('rbine', False)],
          'rbiners': [('rbine', False)],
          'rbirkes': [('rbirkes', False)],
          'rblens': [('rbel', False)],
          'rbler': [('rbel', False)],
          'rboer': [('rbo', False)],
          'rboerne': [('rbo', False)],
          'rboernes': [('rbo', False)],
          'rboers': [('rbo', False)],
          'rbolen': [('rbol', False)],
          'rbolens': [('rbol', False)],
          'rbolet': [('rbol', False)],
          'rbolets': [('rbol', False)],
          'rbomber': [('rbombe', False)],
          'rbomberne': [('rbombe', False)],
          'rbombernes': [('rbombe', False)],
          'rbombers': [('rbombe', False)],
          'rbonernes': [('rbon', False)],
          'rboners': [('rbon', False)],
          'rboret': [('rbor', False)],
          'rborets': [('rbor', False)],
          'rborgen': [('rborg', False)],
          'rborgens': [('rborg', False)],
          'rborger': [('rborger', False)],
          'rbredden': [('rbredde', False)],
          'rbreddens': [('rbredde', False)],
          'rbredder': [('rbredde', False)],
          'rbredderne': [('rbredde', False)],
          'rbreddernes': [('rbredde', False)],
          'rbredders': [('rbredde', False)],
          'rbringer': [('rbringer', False)],
          'rbringerne': [('rbringer', False)],
          'rbringernes': [('rbringer', False)],
          'rbringers': [('rbringer', False)],
          'rbrokken': [('rbrok', False)],
          'rbrokkens': [('rbrok', False)],
          'rbrokker': [('rbrok', False)],
          'rbrokkerne': [('rbrok', False)],
          'rbrokkernes': [('rbrok', False)],
          'rbrokkers': [('rbrok', False)],
          'rbrugs': [('rbrug', False)],
          'rbrødrene': [('rbroder', False)],
          'rbuds': [('rbud', False)],
          'rbuers': [('rbue', False)],
          'rbukser': [('rbukser', False)],
          'rbukserne': [('rbukser', False)],
          'rbuksernes': [('rbukser', False)],
          'rbuksers': [('rbukser', False)],
          'rbulens': [('rbulens', False)],
          'rbums': [('rbum', False)],
          'rbunker': [('rbunker', False)],
          'rbyrden': [('rbyrd', False)],
          'rbyrdens': [('rbyrd', False)],
          'rbyrder': [('rbyrd', False)],
          'rbyrderne': [('rbyrd', False)],
          'rbyrdernes': [('rbyrd', False)],
          'rbyrders': [('rbyrd', False)],
          'rbælter': [('rbælte', False)],
          'rbælterne': [('rbælte', False)],
          'rbælternes': [('rbælte', False)],
          'rbælters': [('rbælte', False)],
          'rbæltet': [('rbælte', False)],
          'rbæltets': [('rbælte', False)],
          'rbøder': [('rbøder', False)],
          'rbøderne': [('rbøder', False)],
          'rbødernes': [('rbøder', False)],
          'rbøders': [('rbøder', False)],
          'rbøllen': [('rbølle', False)],
          'rbøllens': [('rbøl', False)],
          'rbøller': [('rbøl', False)],
          'rbøllerne': [('rbøl', False)],
          'rbøllernes': [('rbøl', False)],
          'rbøllers': [('rbøl', False)],
          'rbønnen': [('rbøn', False)],
          'rbønnens': [('rbøn', False)],
          'rbønner': [('rbøn', False)],
          'rbønnerne': [('rbøn', False)],
          'rbønnernes': [('rbøn', False)],
          'rbønners': [('rbøn', False)],
          'rbørs': [('rbørs', False)],
          'rcellen': [('rcelle', False)],
          'rcellens': [('rcel', False)],
          'rceller': [('rcel', False)],
          'rcellerne': [('rcel', False)],
          'rcellernes': [('rcel', False)],
          'rcellers': [('rcelle', False)],
          'rcene': [('rce', False)],
          'rcenes': [('rce', False)],
          'rcenter': [('rcenter', False)],
          'rcentre': [('rcenter', False)],
          'rcentrene': [('rcenter', False)],
          'rcentrenes': [('rcenter', False)],
          'rcentres': [('rcenter', False)],
          'rcentret': [('rcenter', False)],
          'rcentrets': [('rcenter', False)],
          'rcentrum': [('rcenter', False)],
          'rcentrummer': [('rcenter', False)],
          'rcentrummerne': [('rcenter', False)],
          'rcentrummernes': [('rcenter', False)],
          'rcentrummers': [('rcenter', False)],
          'rcentrummet': [('rcenter', False)],
          'rcentrummets': [('rcenter', False)],
          'rcentrums': [('rcenter', False)],
          'rces': [('rce', False)],
          "rces'": [('rce', False)],
          'rche': [('rche', False)],
          'rches': [('rche', False)],
          'rciner': [('rciner', False)],
          'rciners': [('rciner', False)],
          'rcis': [('rcis', False)],
          'rcissers': [('rcis', False)],
          'rcisterne': [('rcist', False)],
          'rcisternes': [('rcist', False)],
          'rcyklen': [('rcykel', False)],
          'rcyklens': [('rcykel', False)],
          'rcykler': [('rcykel', False)],
          'rcyklerne': [('rcykel', False)],
          'rcyklernes': [('rcykel', False)],
          'rcyklers': [('rcykel', False)],
          'rd': [('rd', False)],
          'rdage': [('rdag', False)],
          'rdagen': [('rdag', False)],
          'rdagene': [('rdag', False)],
          'rdagenes': [('rdag', False)],
          'rdages': [('rdag', False)],
          'rdaksen': [('rdakse', False)],
          'rdaksens': [('rdakse', False)],
          'rdarbejder': [('rdarbejde', False)],
          'rdarbejderne': [('rdarbejde', False)],
          'rdats': [('rdat', False)],
          'rdboers': [('rdboer', False)],
          'rdeje': [('rdej', False)],
          'rdejes': [('rdej', False)],
          'rdele': [('rdel', False)],
          'rdellen': [('rdel', False)],
          'rdellens': [('rdel', False)],
          'rdeller': [('rdel', False)],
          'rdellerne': [('rdel', False)],
          'rdellernes': [('rdel', False)],
          'rdellers': [('rdel', False)],
          'rdemoders': [('rdemor', False)],
          'rden': [('rd', False)],
          'rdenden': [('rdende', False)],
          'rdendens': [('rdende', False)],
          'rdene': [('rd', False)],
          'rdenes': [('rd', False)],
          'rdenier': [('rdenia', False)],
          'rdeniers': [('rdenia', False)],
          'rdens': [('rd', False)],
          'rdenser': [('rdenser', False)],
          'rdensernes': [('rdenser', False)],
          'rdensers': [('rdenser', False)],
          'rdentalen': [('rdentale', False)],
          'rdentalens': [('rdentale', False)],
          'rdentaler': [('rdentale', False)],
          'rdentalerne': [('rdentale', False)],
          'rdentalernes': [('rdentale', False)],
          'rdentalers': [('rdentale', False)],
          'rdenten': [('rdent', False)],
          'rdentens': [('rdent', False)],
          'rdenter': [('rdent', False)],
          'rdenterne': [('rdent', False)],
          'rdenternes': [('rdent', False)],
          'rdenters': [('rdent', False)],
          'rder': [('rde', False)],
          'rdere': [('rder', False)],
          'rderen': [('rder', False)],
          'rderens': [('rder', False)],
          'rderes': [('rder', False)],
          'rderne': [('rd', False)],
          'rdernes': [('rde', False)],
          'rders': [('rd', False)],
          'rdesser': [('rdesse', False)],
          'rdesserne': [('rdesse', False)],
          'rdessernes': [('rdesse', False)],
          'rdessers': [('rdesse', False)],
          'rdet': [('rd', False)],
          'rdets': [('rd', False)],
          'rdgyder': [('rdgyder', False)],
          'rdgyderne': [('rdgyder', False)],
          'rdhaves': [('rdhave', False)],
          'rdianerne': [('rdian', False)],
          'rdianernes': [('rdian', False)],
          'rdien': [('rdie', False)],
          'rdiens': [('rdie', False)],
          'rdier': [('rdi', False)],
          'rdierne': [('rdie', False)],
          'rdiernes': [('rdi', False)],
          'rdiers': [('rdie', False)],
          'rdinen': [('rdin', False)],
          'rdinens': [('rdin', False)],
          'rdiner': [('rdin', False)],
          'rdinernes': [('rdin', False)],
          'rdis': [('rdi', False)],
          'rdle': [('rdle', False)],
          'rdlen': [('rdle', False)],
          'rdlens': [('rdle', False)],
          'rdler': [('rdle', False)],
          'rdlerne': [('rdle', False)],
          'rdlernes': [('rdle', False)],
          'rdlers': [('rdle', False)],
          'rdles': [('rdle', False)],
          'rdlærer': [('rdlære', False)],
          'rdlærers': [('rdlære', False)],
          'rdnerne': [('rden', False)],
          'rdnernes': [('rden', False)],
          'rdnet': [('rdnet', False)],
          'rdomme': [('rdom', False)],
          'rdonen': [('rdon', False)],
          'rdonens': [('rdon', False)],
          'rdoner': [('rdon', False)],
          'rdonerne': [('rdon', False)],
          'rdonernes': [('rdon', False)],
          'rdoners': [('rdon', False)],
          'rdrager': [('rdrager', False)],
          'rdragerne': [('rdrager', False)],
          'rdragernes': [('rdrager', False)],
          'rdragers': [('rdrager', False)],
          'rdre': [('rdre', False)],
          'rdrejer': [('rdreje', False)],
          'rdrejerne': [('rdreje', False)],
          'rdrejernes': [('rdreje', False)],
          'rdrejers': [('rdreje', False)],
          'rdrenge': [('rdreng', False)],
          'rdrenges': [('rdreng', False)],
          'rdrens': [('rdre', False)],
          'rdråber': [('rdråber', False)],
          'rdråberne': [('rdråber', False)],
          'rdråbernes': [('rdråber', False)],
          'rdråbers': [('rdråber', False)],
          'rdræs': [('rdræs', False)],
          'rds': [('rd', False)],
          "rds'": [('rd', False)],
          'rdser': [('rdser', False)],
          'rdserne': [('rdser', False)],
          'rdsernes': [('rdser', False)],
          'rdsers': [('rdser', False)],
          'rdskifterne': [('rdskifte', False)],
          'rdskifternes': [('rdskifte', False)],
          'rdskifters': [('rdskifte', False)],
          'rdstykker': [('rdstykke', False)],
          'rdstykkerne': [('rdstykke', False)],
          'rduen': [('rdue', False)],
          'rduens': [('rdue', False)],
          'rduernes': [('rdue', False)],
          'rduers': [('rdue', False)],
          'rdus': [('rdus', False)],
          'rdusen': [('rdus', False)],
          'rdvolde': [('rdvold', False)],
          'rdvoldene': [('rdvold', False)],
          'rdvoldenes': [('rdvold', False)],
          'rdvoldes': [('rdvold', False)],
          'rdværker': [('rdværk', False)],
          'rdværkerne': [('rdværk', False)],
          'rdværkernes': [('rdværk', False)],
          'rdværkers': [('rdværk', False)],
          'rdækker': [('rdækker', False)],
          'rdækkerne': [('rdækker', False)],
          'rdækkernes': [('rdækker', False)],
          'rdækkers': [('rdækker', False)],
          'rdækket': [('rdæk', False)],
          'rdækkets': [('rdæk', False)],
          'rdømmer': [('rdømme', False)],
          'rdømmerne': [('rdømme', False)],
          're': [('re', False)],
          "reaks'": [('reak', False)],
          'realer': [('real', False)],
          'realerne': [('real', False)],
          'realernes': [('real', False)],
          'realers': [('real', False)],
          "reality-tv'et": [('reality-TV', True), ('reality-tv', True)],
          "reality-tv'ets": [('reality-TV', True), ('reality-tv', True)],
          'reanerne': [('reaner', False)],
          'reanernes': [('reaner', False)],
          'reben': [('reb', False)],
          'rebens': [('reben', False)],
          'reberne': [('reb', False)],
          'rebers': [('reb', False)],
          'rebroderens': [('rebror', False)],
          'rebrødre': [('rebror', False)],
          'rebrødrene': [('rebror', False)],
          'rebrødrenes': [('rebror', False)],
          'rebrødres': [('rebror', False)],
          'rebs': [('reb', True)],
          'rebus': [('rebus', True)],
          'reckerne': [('reck', True)],
          'reckers': [('reck', True)],
          'redagens': [('redag', False)],
          'redder': [('redder', False)],
          'redderne': [('redder', True)],
          'reddernes': [('redder', True)],
          'redders': [('redder', True)],
          'rede': [('red', True), ('rede', True)],
          'reden': [('red', True), ('rede', True)],
          'redens': [('rede', True), ('red', True)],
          'reder': [('reder', True), ('rede', True)],
          'rederne': [('rede', True), ('reder', True)],
          'redernes': [('reder', True), ('rede', True)],
          'reders': [('rede', True), ('reder', True)],
          'redes': [('red', True), ('rede', True)],
          'rediens': [('rediens', False)],
          'redos': [('redo', False)],
          'reds': [('red', True)],
          'redsens': [('reds', False)],
          'reen': [('ree', False)],
          'reens': [('ree', False)],
          'reer': [('re', True)],
          'reerne': [('re', True)],
          'reernes': [('re', True)],
          'reers': [('re', True)],
          'reet': [('re', True)],
          'reets': [('re', True)],
          'regaler': [('regale', True), ('regal', True)],
          'regalerne': [('regale', True), ('regal', True)],
          'regalernes': [('regale', True), ('regal', True)],
          'regalers': [('regale', True), ('regal', True)],
          'regalet': [('regale', True), ('regal', True)],
          'regalets': [('regale', True), ('regal', True)],
          'regen': [('reg', False)],
          'regens': [('reg', False)],
          'reger': [('reg', False)],
          'regerne': [('reg', False)],
          'regernes': [('reg', False)],
          'regers': [('reg', False)],
          'regier': [('regi', True)],
          'regierne': [('regi', True)],
          'regiernes': [('regi', True)],
          'regiers': [('regi', True)],
          'regiet': [('regi', True)],
          'regiets': [('regi', True)],
          'regimenter': [('regimente', True), ('regiment', True)],
          'regimenterne': [('regimente', True), ('regiment', True)],
          'regimenternes': [('regimente', True), ('regiment', True)],
          'regimenters': [('regimente', True), ('regiment', True)],
          'regimentet': [('regimente', True), ('regiment', True)],
          'regimentets': [('regimente', True), ('regiment', True)],
          'reglens': [('regel', False)],
          'reglernes': [('regel', False)],
          'reglers': [('regel', False)],
          'regne': [('regne', False)],
          'regnen': [('regn', True)],
          'regnens': [('regn', False)],
          'regner': [('regner', False)],
          'regnerne': [('regne', False)],
          'regnernes': [('regnum', False)],
          'regners': [('regne', False)],
          'regnes': [('regne', False)],
          'regres': [('regres', True)],
          'regrøden': [('regrød', False)],
          'regrødens': [('regrød', False)],
          'rehals': [('rehals', False)],
          'rehaver': [('rehave', False)],
          'rehaverne': [('rehave', False)],
          'rehavernes': [('rehave', False)],
          'rehavers': [('rehave', False)],
          'rehaves': [('rehave', False)],
          'reiden': [('reide', False)],
          'reidens': [('reide', False)],
          'reje': [('reje', False)],
          'rejen': [('reje', False)],
          'rejenes': [('rej', False)],
          'rejens': [('reje', False)],
          'rejer': [('reje', True)],
          'rejerne': [('reje', False)],
          'rejernes': [('reje', False)],
          'rejers': [('reje', False)],
          'rejes': [('reje', False)],
          'rejet': [('reje', False)],
          'rejets': [('reje', False)],
          'rejfer': [('rejf', True)],
          'rejferne': [('rejf', True)],
          'rejfernes': [('rejf', True)],
          'rejfers': [('rejf', True)],
          'rejler': [('rejler', False)],
          'rejlerne': [('rejl', False)],
          'rejlernes': [('rejl', False)],
          'rejlers': [('rejler', False)],
          'rejser': [('rejse', True)],
          'rejsers': [('rejse', False)],
          'rek': [('rek', False)],
          'rekker': [('rekker', False)],
          'rekkere': [('rekker', False)],
          'rekkeren': [('rekker', False)],
          'rekkerens': [('rekker', False)],
          'rekkeres': [('rekker', False)],
          'rekkerne': [('rekker', False)],
          'rekkernes': [('rekker', False)],
          'rekkers': [('rekker', False)],
          'reklips': [('reklips', False)],
          'reklipsen': [('reklips', False)],
          'reklipsens': [('reklips', False)],
          'reklæder': [('reklæder', False)],
          'reks': [('rek', False)],
          'rekturen': [('rektur', False)],
          'rekturens': [('rektur', False)],
          'rekturer': [('rektur', False)],
          'rekturerne': [('rektur', False)],
          'rekturernes': [('rektur', False)],
          'rekturers': [('rektur', False)],
          'rekursers': [('rekurs', True)],
          'relevernes': [('relev', False)],
          'rellen': [('rel', False)],
          'reller': [('rel', False)],
          'rellers': [('rel', False)],
          'relsers': [('relse', False)],
          'relærer': [('relære', False)],
          'relærerne': [('relærer', False)],
          'relærernes': [('relærer', False)],
          'relærers': [('relære', False)],
          'reløven': [('reløve', False)],
          'reløvens': [('reløve', False)],
          'remaler': [('remaler', False)],
          'remalerne': [('remaler', False)],
          'remalernes': [('remaler', False)],
          'remalers': [('remaler', False)],
          'remanden': [('remand', False)],
          'remandens': [('remand', False)],
          'remasterne': [('remaster', False)],
          'remasternes': [('remaster', False)],
          'remen': [('reme', False)],
          'remens': [('remens', False)],
          'remer': [('reme', False)],
          'remerne': [('reme', False)],
          'remernes': [('reme', False)],
          'remers': [('reme', False)],
          'reminister': [('reminister', False)],
          'remis': [('remis', True)],
          'remisen': [('remise', True), ('remis', True)],
          'remisens': [('remise', True), ('remis', True)],
          'remiser': [('remise', True), ('remis', True)],
          'remiserne': [('remise', True), ('remis', True)],
          'remisernes': [('remise', True), ('remis', True)],
          'remisers': [('remis', True), ('remise', True)],
          'remlejernes': [('remlejer', False)],
          'remme': [('rem', False)],
          'remmelser': [('remmelse', False)],
          'remmelserne': [('remmelse', False)],
          'remmelsernes': [('remmelse', False)],
          'remmen': [('rem', False)],
          'remmens': [('rem', False)],
          'remmer': [('remmer', False)],
          'remmerne': [('remmer', False)],
          'remmernes': [('remme', False)],
          'remmers': [('remmer', False)],
          'remmes': [('rem', False)],
          'rempler': [('rempel', False)],
          'remser': [('remse', True)],
          'remserne': [('remse', True)],
          'remsernes': [('remse', True)],
          'remsers': [('remse', True)],
          'remærker': [('remærke', False)],
          'ren': [('ren', True)],
          'renader': [('renader', False)],
          'renaders': [('renade', False)],
          'rencecenteret': [('ncecenter', False)],
          'rencecenterets': [('ncecenter', False)],
          'rencecentret': [('ncecenter', False)],
          'rencecentrets': [('ncecenter', False)],
          'renda': [('rendum', False)],
          'rendas': [('rendum', False)],
          'renden': [('rende', True)],
          'rendens': [('rende', True)],
          'render': [('rende', False)],
          'renderne': [('rende', True)],
          'rendernes': [('rende', False)],
          'renders': [('rende', False)],
          'rendet': [('rend', False)],
          'rendets': [('rend', False)],
          'rene': [('er', False)],
          'renellikerne': [('renellike', False)],
          'renellikers': [('renellike', False)],
          'renen': [('ren', True)],
          'renens': [('ren', False)],
          'rener': [('ren', True)],
          'renerne': [('ren', True)],
          'renernes': [('ren', True)],
          'reners': [('ren', True)],
          'renes': [('er', False)],
          'renesis': [('renesi', False)],
          'renge': [('reng', False)],
          'rengen': [('reng', False)],
          'rengene': [('reng', False)],
          'rengenes': [('reng', False)],
          'rengens': [('reng', False)],
          'renges': [('reng', False)],
          'rengs': [('reng', False)],
          'reniens': [('reni', False)],
          'renier': [('reni', False)],
          'renis': [('reni', False)],
          'rens': [('rens', True), ('ren', True)],
          "rens'": [('rens', False)],
          'rensen': [('rens', False)],
          'rensens': [('rens', False)],
          'renser': [('renser', True)],
          'renserne': [('renser', True)],
          'rensernes': [('renser', True)],
          'rensers': [('renser', True)],
          'renten': [('rente', True)],
          'rentens': [('rente', True)],
          'renter': [('rente', False)],
          'renterne': [('rente', True)],
          'renternes': [('rente', True)],
          'renters': [('rente', False)],
          'rentes': [('rente', True)],
          'rentet': [('rent', False)],
          'rentets': [('rent', False)],
          'rentialer': [('rentiale', False)],
          'rentialerne': [('rentiale', False)],
          'rentialernes': [('rentiale', False)],
          'rentialers': [('rentiale', False)],
          'rentialet': [('rentiale', False)],
          'rentialets': [('rentiale', False)],
          'rentier': [('rentier', True)],
          'rentiers': [('rentier', True)],
          'rentiner': [('rentiner', False)],
          'rentinerne': [('rentiner', False)],
          'rentinernes': [('rentiner', False)],
          'rentiners': [('rentiner', False)],
          'renøren': [('renør', False)],
          'renørens': [('renør', False)],
          'renører': [('renør', False)],
          'renørerne': [('renør', False)],
          'renørernes': [('renør', False)],
          'renørers': [('renør', False)],
          'reol': [('reol', True)],
          'reolen': [('reol', True)],
          'reolens': [('reol', True)],
          'reoler': [('reol', False)],
          'reolerne': [('reol', True)],
          'reolernes': [('reol', False)],
          'reolers': [('reol', False)],
          'reols': [('reol', False)],
          'reoner': [('reon', False)],
          'reonerne': [('reon', False)],
          'reonernes': [('reon', False)],
          'reoners': [('reon', False)],
          'repos': [('repos', True)],
          'reposen': [('repos', True)],
          'reposens': [('repos', True)],
          'reposer': [('repos', True)],
          'reposerne': [('repos', True)],
          'reposernes': [('repos', True)],
          'reposers': [('repos', True)],
          'reprisen': [('reprise', False)],
          'reprisers': [('reprise', False)],
          'reps': [('reps', True)],
          "reps'": [('reps', True)],
          'rer': [('re', False)],
          'rerarbejdernes': [('rerarbejde', False)],
          'rerarbejders': [('rerarbejde', False)],
          'rerbier': [('rerbi', False)],
          'rerbierne': [('rerbi', False)],
          'rerene': [('rer', False)],
          'rerenes': [('rer', False)],
          'rerer': [('rerer', False)],
          'rererne': [('rerer', False)],
          'rerernes': [('rerer', False)],
          'rerers': [('rerer', False)],
          'reret': [('reret', False)],
          'rerets': [('reret', False)],
          'reretten': [('reret', False)],
          'rerettens': [('reret', False)],
          'reretterne': [('reret', False)],
          'reretternes': [('reret', False)],
          'reretters': [('reret', False)],
          'rerier': [('reri', False)],
          'rerierne': [('reri', False)],
          'reriernes': [('reri', False)],
          'reriers': [('reri', False)],
          'reriet': [('reri', False)],
          'reriets': [('reri', False)],
          'reriget': [('rerige', False)],
          'rerigets': [('rerige', False)],
          'reris': [('reri', False)],
          'rerne': [('re', False)],
          'rernes': [('re', False)],
          'reroen': [('rero', False)],
          'reroens': [('rero', False)],
          'reros': [('rero', False)],
          'rerret': [('rerret', False)],
          'rers': [('rer', False)],
          'rersken': [('rerske', False)],
          'rersker': [('rerske', False)],
          'rerskerne': [('rerske', False)],
          'rerskers': [('rerske', False)],
          'res': [('re', True)],
          "res'": [('re', False)],
          'rescenter': [('rescenter', False)],
          'rescenters': [('rescenter', False)],
          'rese': [('rese', False)],
          'resen': [('rese', False)],
          'resens': [('rese', False)],
          'reser': [('rese', False)],
          'reserne': [('rese', False)],
          'resernes': [('rese', False)],
          'resers': [('res', False)],
          'reservers': [('reserve', True)],
          'reses': [('rese', False)],
          'resier': [('resia', False)],
          'resierne': [('resi', False)],
          'resiernes': [('resia', False)],
          'resiers': [('resia', False)],
          'resis': [('resi', False)],
          'reskens': [('reske', False)],
          'reskernes': [('reske', False)],
          'reskøjten': [('reskøjte', False)],
          'resmerter': [('resmerte', False)],
          'ressene': [('ress', False)],
          'ressenes': [('ress', False)],
          'ressens': [('resse', False)],
          'ressernes': [('res', False)],
          'ressers': [('res', False)],
          'resset': [('ress', False)],
          'ressets': [('ress', False)],
          'resten': [('rest', True)],
          'restens': [('rest', True)],
          'rester': [('rest', True)],
          'resterne': [('rest', False)],
          'resternes': [('rest', False)],
          'resters': [('rest', False)],
          'restier': [('resti', False)],
          'restiernes': [('resti', False)],
          'restøvlers': [('restøvle', False)],
          'ret': [('ret', True)],
          'retage': [('retage', False)],
          'retager': [('retager', False)],
          'retagere': [('retager', False)],
          'retageren': [('retager', False)],
          'retagerens': [('retager', False)],
          'retageres': [('retager', False)],
          'retagerne': [('retager', False)],
          'retagernes': [('retager', False)],
          'retagers': [('retager', False)],
          'retages': [('retage', False)],
          'retanerne': [('retan', False)],
          'retanernes': [('retan', False)],
          'reter': [('ret', False)],
          'reters': [('ret', False)],
          'retiden': [('retid', False)],
          'retinerne': [('retiner', False)],
          'retiners': [('retiner', False)],
          'retoget': [('retoget', False)],
          'retoner': [('retoner', False)],
          'retonerne': [('retoner', False)],
          'retonernes': [('retoner', False)],
          'retoners': [('retoner', False)],
          'rets': [('ret', True)],
          'retten': [('ret', False)],
          'rettens': [('ret', False)],
          'retter': [('ret', True)],
          'retterne': [('ret', False)],
          'retternes': [('ret', False)],
          'retters': [('ret', False)],
          'rettet': [('ret', False)],
          'rettets': [('ret', False)],
          'retæer': [('retå', False)],
          'retæerne': [('retå', False)],
          'retæernes': [('retå', False)],
          'retæers': [('retå', False)],
          'retærens': [('retær', False)],
          'retærer': [('retær', False)],
          'retærers': [('retær', False)],
          'reve': [('reve', False)],
          'reven': [('reve', False)],
          'revens': [('reve', False)],
          'reverens': [('reverens', True)],
          'revers': [('revers', True)],
          'reves': [('reve', False)],
          'revidens': [('reviden', False)],
          'revinde': [('revinde', False)],
          'revinder': [('revinde', False)],
          'revinderne': [('revinde', False)],
          'revindernes': [('revinde', False)],
          'reviser': [('reviser', False)],
          'reviserne': [('reviser', False)],
          'revisernes': [('reviser', False)],
          'revisers': [('reviser', False)],
          'revlen': [('revle', True)],
          'revlens': [('revle', True)],
          'revler': [('revle', True)],
          'revlerne': [('revle', True)],
          'revlernes': [('revle', True)],
          'revlers': [('revle', True)],
          'revners': [('revne', True)],
          'rf': [('rf', False)],
          'rfacet': [('rface', False)],
          'rfacets': [('rface', False)],
          'rfaders': [('rfar', False)],
          'rfaren': [('rfar', False)],
          'rfarens': [('rfar', False)],
          'rfars': [('rfar', False)],
          'rfekter': [('rfektum', False)],
          'rfekterne': [('rfektum', False)],
          'rfekternes': [('rfektum', False)],
          'rfekters': [('rfektum', False)],
          'rfen': [('rf', False)],
          'rfene': [('rf', False)],
          'rfenes': [('rf', False)],
          'rfens': [('rf', False)],
          'rfer': [('rfer', False)],
          'rfere': [('rfer', False)],
          'rferes': [('rfer', False)],
          'rferien': [('rferie', False)],
          'rferier': [('rferie', False)],
          'rferierne': [('rferie', False)],
          'rferiers': [('rferie', False)],
          'rferne': [('rfer', False)],
          'rfernes': [('rf', False)],
          'rfers': [('rf', False)],
          'rfet': [('rf', False)],
          'rfets': [('rf', False)],
          'rfiner': [('rfin', False)],
          'rfiners': [('rfin', False)],
          'rfinker': [('rfinke', False)],
          'rfinkerne': [('rfinke', False)],
          'rfinkernes': [('rfinke', False)],
          'rfinkers': [('rfinke', False)],
          'rfis': [('rfi', False)],
          'rfladen': [('rflade', False)],
          'rfladens': [('rflade', False)],
          'rflys': [('rfly', False)],
          'rfløjten': [('rfløjte', False)],
          'rfornemmelserne': [('rfornemmelse', False)],
          'rfornemmelsernes': [('rfornemmelse', False)],
          'rforældre': [('rforældre', False)],
          'rforældrene': [('rforældre', False)],
          'rforældrenes': [('rforældre', False)],
          'rforældres': [('rforældre', False)],
          'rfter': [('rft', False)],
          'rfædre': [('rfar', False)],
          'rfædrenes': [('rfar', False)],
          'rfødder': [('rfødder', False)],
          'rfølger': [('rfølger', False)],
          'rfølgerne': [('rfølger', False)],
          'rfølgernes': [('rfølger', False)],
          'rfølgers': [('rfølger', False)],
          'rførerne': [('rfører', False)],
          'rg': [('rg', False)],
          'rgales': [('rgal', False)],
          'rganer': [('rgan', False)],
          'rganerne': [('rgan', False)],
          'rganernes': [('rgan', False)],
          'rganers': [('rgan', False)],
          'rgarbejder': [('rgarbejde', False)],
          'rgarbejderne': [('rgarbejde', False)],
          'rgarbejders': [('rgarbejde', False)],
          "rgas'": [('rgas', False)],
          'rge': [('rg', False)],
          'rgels': [('rgel', False)],
          'rgen': [('rg', False)],
          'rgene': [('rg', False)],
          'rgenen': [('rgen', False)],
          'rgenens': [('rgen', False)],
          'rgener': [('rgen', False)],
          'rgenerne': [('rgen', False)],
          'rgenernes': [('rgen', False)],
          'rgeners': [('rgen', False)],
          'rgenes': [('rg', False)],
          'rgenet': [('rgen', False)],
          'rgenets': [('rgen', False)],
          'rgenser': [('rgenser', False)],
          'rgensernes': [('rgenser', False)],
          'rgere': [('rger', False)],
          'rgeren': [('rger', False)],
          'rgerens': [('rger', False)],
          'rgeres': [('rger', False)],
          'rgerne': [('rge', False)],
          "rges'": [('rges', False)],
          'rgesen': [('rges', False)],
          'rgesens': [('rges', False)],
          'rgesers': [('rges', False)],
          'rget': [('rg', False)],
          'rgets': [('rg', False)],
          'rgetterne': [('rgette', False)],
          'rgetternes': [('rgette', False)],
          'rgetters': [('rgette', False)],
          'rgien': [('rgi', False)],
          'rgiens': [('rgi', False)],
          'rgiet': [('rgie', False)],
          'rgiets': [('rgie', False)],
          'rginen': [('rgin', False)],
          'rginens': [('rgin', False)],
          'rginer': [('rgin', False)],
          'rginerne': [('rgin', False)],
          'rginernes': [('rgin', False)],
          'rginers': [('rgine', False)],
          'rgis': [('rgi', False)],
          'rgister': [('rgist', False)],
          'rglen': [('rgel', False)],
          'rglene': [('rgel', False)],
          'rglenes': [('rgel', False)],
          'rglens': [('rgel', False)],
          'rgler': [('rgel', False)],
          'rglerne': [('rgel', False)],
          'rglets': [('rgel', False)],
          'rgnerne': [('rgen', False)],
          'rgnernes': [('rgen', False)],
          'rgnet': [('rgnet', False)],
          'rgnets': [('rgnet', False)],
          'rgonien': [('rgonie', False)],
          'rgoniens': [('rgonie', False)],
          'rgoten': [('rgot', False)],
          'rgotens': [('rgot', False)],
          'rgoter': [('rgot', False)],
          'rgoterne': [('rgot', False)],
          'rgoternes': [('rgot', False)],
          'rgoters': [('rgot', False)],
          'rgrøden': [('rgrød', False)],
          'rgrødens': [('rgrød', False)],
          'rgs': [('rg', False)],
          "rgs'": [('rg', False)],
          'rgænger': [('rgænger', False)],
          'rgængerne': [('rgænger', False)],
          'rgængernes': [('rgænger', False)],
          'rgængers': [('rgænger', False)],
          'rgørerne': [('rgører', False)],
          'rhaler': [('rhaler', False)],
          'rhalerne': [('rhale', False)],
          'rhalernes': [('rhaler', False)],
          'rhalers': [('rhaler', False)],
          'rhallen': [('rhal', False)],
          'rhallens': [('rhal', False)],
          'rhaller': [('rhal', False)],
          'rhallerne': [('rhal', False)],
          'rhallernes': [('rhal', False)],
          'rhallers': [('rhal', False)],
          'rhandler': [('rhandler', False)],
          'rhandlerne': [('rhandler', False)],
          'rhandlers': [('rhandler', False)],
          'rhave': [('rhave', False)],
          'rhaves': [('rhave', False)],
          'rheden': [('rhed', False)],
          'rheder': [('rhed', False)],
          'rhederne': [('rhed', False)],
          'rhedernes': [('rhed', False)],
          'rheders': [('rhed', False)],
          'rhinde': [('rhinde', False)],
          'rhinden': [('rhinde', False)],
          'rhindens': [('rhinde', False)],
          'rhinder': [('rhinde', False)],
          'rhinderne': [('rhinde', False)],
          'rhindernes': [('rhinde', False)],
          'rhinders': [('rhinde', False)],
          'rhindes': [('rhinde', False)],
          'rhuen': [('rhue', False)],
          'rhuens': [('rhue', False)],
          'rhus': [('rhus', False)],
          'rhylden': [('rhylde', False)],
          'rhyldens': [('rhylde', False)],
          'rhøjder': [('rhøjde', False)],
          'rhøjderne': [('rhøjde', False)],
          'rhøjdernes': [('rhøjde', False)],
          'rhøjders': [('rhøjde', False)],
          'ri': [('ri', False)],
          'rialer': [('rial', False)],
          'rialerne': [('rial', False)],
          'rialernes': [('rial', False)],
          'rialers': [('rial', False)],
          'riander': [('riand', False)],
          'rianders': [('riander', False)],
          'rianer': [('rian', False)],
          'rianerne': [('rianer', False)],
          'rianernes': [('rianer', False)],
          'rianers': [('rian', False)],
          'rians': [('rian', False)],
          'riater': [('riat', False)],
          'riaterne': [('riat', False)],
          'riaternes': [('riater', False)],
          'riaters': [('riat', False)],
          'ribbe': [('ribbe', True)],
          'ribben': [('ribben', True), ('ribbe', True)],
          'ribbens': [('ribben', True), ('ribbe', True)],
          'ribbes': [('ribbe', True)],
          'ribe': [('ribe', False)],
          'riben': [('riben', False)],
          'ribens': [('riben', False)],
          'riber': [('riber', False)],
          'riberis': [('riberi', False)],
          'riberne': [('riber', False)],
          'ribernes': [('riber', False)],
          'ribers': [('ribe', False)],
          'ribes': [('ribe', False)],
          'ribiernes': [('ribier', False)],
          'ribis': [('ribi', False)],
          'ribs': [('rib', True), ('ribs', True)],
          'ricen': [('rice', False)],
          'ricens': [('rice', False)],
          'ricerne': [('rice', False)],
          'ricernes': [('rice', False)],
          'ricers': [('rice', False)],
          'rices': [('rice', False)],
          'ricier': [('ricier', False)],
          'riciers': [('ricier', False)],
          'rickerne': [('rick', False)],
          'rickers': [('rick', False)],
          'ricket': [('rick', False)],
          'rickets': [('rick', False)],
          'ridder': [('ridder', False)],
          'ridders': [('ridder', False)],
          'ride': [('ride', True)],
          'riden': [('ride', True)],
          'ridens': [('ride', True)],
          'rider': [('ride', True)],
          'riderne': [('ride', True)],
          'ridernes': [('ride', True)],
          'riders': [('ride', True)],
          'rides': [('ride', False)],
          'ridnets': [('ridnet', False)],
          'rids': [('rids', False)],
          "rids'": [('rids', False)],
          'ridsen': [('ridse', True)],
          'ridsens': [('ridse', True)],
          'ridser': [('ridse', True)],
          'ridserne': [('ridse', True)],
          'ridsernes': [('ridse', True)],
          'ridsers': [('ridse', True)],
          'rien': [('ri', False)],
          'riene': [('ri', False)],
          'rienes': [('ri', False)],
          'riens': [('ri', False)],
          'riere': [('rier', False)],
          'rieren': [('rier', False)],
          'rierens': [('rier', False)],
          'rieres': [('rier', False)],
          'riers': [('rium', False)],
          "ries'": [('ries', False)],
          'riet': [('ri', False)],
          'riets': [('ri', False)],
          'rif': [('rif', False)],
          'riferens': [('rifer', False)],
          'riferien': [('riferi', False)],
          'riferiens': [('riferie', False)],
          'riferier': [('riferi', False)],
          'riferierne': [('riferi', False)],
          'riferiernes': [('riferie', False)],
          'riferiers': [('riferie', False)],
          'rifers': [('rifer', False)],
          'riffene': [('riff', False)],
          'riffenes': [('riff', False)],
          'riffer': [('rif', False)],
          'riffernes': [('rif', False)],
          'riffers': [('rif', False)],
          'riften': [('rift', False)],
          'riftens': [('rift', False)],
          'rifterne': [('rift', False)],
          'rifternes': [('rift', False)],
          'rifters': [('rift', False)],
          'riftet': [('rift', False)],
          'riftets': [('rift', False)],
          'rige': [('rige', False)],
          'rigen': [('rige', False)],
          'rigens': [('rige', False)],
          'riger': [('rige', False)],
          'rigerne': [('rige', True)],
          'rigernes': [('rige', True)],
          'rigers': [('rige', True)],
          'riges': [('rige', False)],
          'riget': [('rige', False)],
          'rigets': [('rige', False)],
          'rigger': [('rigger', False)],
          'riggerne': [('rigger', True)],
          'riggernes': [('rigger', True)],
          'riggers': [('rigger', True)],
          'riglen': [('rigel', True)],
          'riglens': [('rigel', True)],
          'rigler': [('rigel', True)],
          'riglerne': [('rigel', True)],
          'riglernes': [('rigel', False)],
          'riglers': [('rigel', True)],
          'rigten': [('rigt', False)],
          'rigtens': [('rigt', False)],
          'rigter': [('rigt', False)],
          'rigterne': [('rigt', False)],
          'rigternes': [('rigt', False)],
          'rikaene': [('rika', False)],
          'rikaenes': [('rika', False)],
          'rikaner': [('rikaner', False)],
          'rikaners': [('rikaner', False)],
          'riket': [('riket', False)],
          'rikets': [('riket', False)],
          'riketten': [('riket', False)],
          'rikettens': [('riket', False)],
          'riketterne': [('riket', False)],
          'riketternes': [('riket', False)],
          'riketters': [('riket', False)],
          'rikken': [('rik', False)],
          'rikkens': [('rikke', False)],
          'rikkere': [('rikker', False)],
          'rikkeren': [('rikker', False)],
          'rikkerens': [('rikker', False)],
          'rikkeres': [('rikker', False)],
          'rikkerne': [('rik', False)],
          'rikkers': [('rikke', False)],
          'rikkes': [('rik', False)],
          'riklen': [('rikel', False)],
          'riklerne': [('rikel', False)],
          'riklernes': [('rikel', False)],
          'riklers': [('rikel', False)],
          "riks'": [('riks', False)],
          'rikse': [('riks', False)],
          'riksen': [('riks', False)],
          'riksens': [('riks', False)],
          'rikser': [('rikse', False)],
          'rikserne': [('rikse', False)],
          'riksers': [('rikse', False)],
          'rikses': [('riks', False)],
          'rikter': [('rikt', False)],
          'rikterne': [('rikt', False)],
          'rikternes': [('rikt', False)],
          'rikters': [('rikt', False)],
          'rikum': [('rikum', False)],
          'rikummernes': [('rikum', False)],
          'rikummers': [('rikum', False)],
          'rikums': [('rikum', False)],
          'rikvarers': [('rikvare', False)],
          'rild': [('rild', False)],
          'rildens': [('rild', False)],
          'rilder': [('rild', False)],
          'rilderne': [('rild', False)],
          'rildernes': [('rild', False)],
          'rilders': [('rild', False)],
          'rilds': [('rild', False)],
          'rilisternes': [('riliste', False)],
          'rilisters': [('riliste', False)],
          'rille': [('rille', True)],
          'rillen': [('rille', True)],
          'rillene': [('rill', False)],
          'rillenes': [('rill', False)],
          'rillens': [('rille', False)],
          'riller': [('rille', True)],
          'rillerne': [('rille', True)],
          'rillernes': [('rille', True)],
          'rillers': [('rille', False)],
          'rilles': [('rille', True)],
          'rillettens': [('rillette', True)],
          'rilletters': [('rillette', True)],
          'rillingers': [('rilling', False)],
          'rilten': [('rilte', False)],
          'riltens': [('rilte', False)],
          'rimas': [('rimas', False)],
          'rimassen': [('rimasse', False)],
          'rimassens': [('rimas', False)],
          'rimasser': [('rimasse', False)],
          'rimasserne': [('rimas', False)],
          'rimassernes': [('rimasse', False)],
          'rimassers': [('rimasse', False)],
          'rime': [('rime', False)],
          'rimen': [('rim', True)],
          'rimens': [('rim', True)],
          'rimenterne': [('riment', False)],
          'rimentet': [('riment', False)],
          'rimentets': [('riment', False)],
          'rimer': [('rime', False)],
          'rimerne': [('rime', False)],
          'rimernes': [('rime', False)],
          'rimers': [('rim', False)],
          'rimes': [('rime', False)],
          'rimmer': [('rimmer', False)],
          'rimmerne': [('rimmer', False)],
          'rina': [('rina', False)],
          'rinas': [('rina', False)],
          'rinden': [('rind', False)],
          'rindens': [('rind', False)],
          'rinder': [('rinde', False)],
          'rinderne': [('rinde', False)],
          'rindernes': [('rinde', False)],
          'rinders': [('rinde', False)],
          'rine': [('rine', False)],
          'rinene': [('rin', False)],
          'riner': [('rin', False)],
          'rinerne': [('riner', False)],
          'rinernes': [('riner', False)],
          'riners': [('rin', False)],
          'rines': [('rine', False)],
          'rinesers': [('rineser', False)],
          'rinetten': [('rinet', False)],
          'rinettens': [('rinet', False)],
          'rinetter': [('rinet', False)],
          'rinetterne': [('rinet', False)],
          'rinetternes': [('rinet', False)],
          'rinetters': [('rinet', False)],
          'ringe': [('ring', False)],
          'ringen': [('ring', False)],
          'ringens': [('ring', False)],
          'ringenser': [('ringenser', False)],
          'ringensernes': [('ringenser', False)],
          'ringer': [('ringer', True)],
          'ringerne': [('ringer', True)],
          'ringernes': [('ringer', True)],
          'ringers': [('ringer', False)],
          'ringes': [('ring', False)],
          'ringlen': [('ringle', False)],
          'ringlernes': [('ringle', False)],
          'ringlers': [('ringle', False)],
          'rings': [('ring', False)],
          'rinken': [('rink', False)],
          'rinker': [('rink', False)],
          'rinkerne': [('rink', False)],
          'rinkernes': [('rink', False)],
          'rinkers': [('rink', False)],
          'rinklerne': [('rinkler', False)],
          'rinklernes': [('rinkler', False)],
          'rinklers': [('rinkler', False)],
          'rinks': [('rink', False)],
          "rinks'": [('rink', False)],
          'rins': [('rins', False)],
          "rins'": [('rins', False)],
          'rinsen': [('rins', False)],
          'rinsens': [('rins', False)],
          'rinser': [('rins', False)],
          'rinserne': [('rins', False)],
          'rinsernes': [('rins', False)],
          'rinsers': [('rins', False)],
          'rinten': [('rint', False)],
          'rintens': [('rint', False)],
          'rinter': [('rint', False)],
          'rinterne': [('rinter', False)],
          'rinternes': [('rint', False)],
          'rinters': [('rinter', False)],
          'rintet': [('rint', False)],
          'rintets': [('rint', False)],
          'rinummer': [('rinummer', False)],
          'rioet': [('rie', False)],
          'rioets': [('rie', False)],
          'riolet': [('riol', False)],
          'riolets': [('riol', False)],
          'rionernes': [('rion', False)],
          'rioners': [('rion', False)],
          'rionet': [('rion', False)],
          'rionets': [('rion', False)],
          'rions': [('rion', False)],
          'riosa': [('riosum', False)],
          'riosas': [('riosum', False)],
          'ripenserne': [('ripenser', True)],
          'rippen': [('rip', False)],
          'rippens': [('rip', False)],
          'ripper': [('ripper', False)],
          'ripperne': [('ripper', False)],
          'rippernes': [('rip', False)],
          'rippers': [('rip', False)],
          'ripterne': [('ript', False)],
          'ripternes': [('ript', False)],
          'ripters': [('ript', False)],
          'ris': [('ris', True)],
          'rise': [('rise', False)],
          'risen': [('ris', True)],
          'risens': [('ris', True)],
          'riser': [('rise', False)],
          'riserne': [('riser', False)],
          'risernes': [('rise', False)],
          'rises': [('rise', False)],
          'risken': [('risk', False)],
          'riskers': [('risk', False)],
          'rislens': [('rissel', False)],
          'rismen': [('risme', False)],
          'rismens': [('risme', False)],
          'rismers': [('risme', False)],
          'rissen': [('ris', False)],
          'rissens': [('ris', False)],
          'risser': [('ris', False)],
          'risserne': [('ris', False)],
          'rissernes': [('ris', False)],
          'riste': [('rist', False)],
          'risten': [('rist', False)],
          'ristens': [('rist', False)],
          'rister': [('rister', True)],
          'risterne': [('rister', True)],
          'risternes': [('rister', True)],
          'risters': [('rister', True)],
          'ristes': [('rist', False)],
          'ristika': [('ristikum', False)],
          'ristikas': [('ristikum', False)],
          'ritan': [('ritaner', False)],
          'ritanen': [('ritaner', False)],
          'ritaner': [('ritaner', False)],
          'ritaners': [('ritaner', False)],
          'riten': [('ritus', True), ('rite', True)],
          'ritens': [('ritus', True), ('rite', True)],
          'riter': [('ritus', True), ('rite', True)],
          'riterne': [('ritus', True), ('rite', True)],
          'riternes': [('rite', True), ('ritus', True)],
          'riters': [('ritus', True), ('rite', True)],
          'ritlens': [('rittel', False)],
          'ritler': [('rittel', False)],
          'ritten': [('ritte', True)],
          'rittens': [('ritte', True)],
          'ritter': [('ritte', True)],
          'ritterne': [('ritte', True)],
          'ritternes': [('ritte', True)],
          'ritters': [('ritte', True)],
          'rituren': [('riture', False)],
          'riturens': [('riture', False)],
          'ritører': [('ritøre', False)],
          'rium': [('rie', False)],
          'riums': [('rie', False)],
          'rivaren': [('rivare', False)],
          'rivarens': [('rivare', False)],
          'rive': [('rive', False)],
          'riven': [('rive', False)],
          'rivene': [('riv', True)],
          'rivenes': [('riv', True)],
          'rivens': [('rive', False)],
          'river': [('rive', True), ('river', True)],
          'riverne': [('river', True), ('rive', True)],
          'rivernes': [('rive', True), ('river', True)],
          'rivers': [('river', True), ('rive', True)],
          'rives': [('rive', True)],
          'rivien': [('rivi', False)],
          'riviens': [('rivi', False)],
          'rivier': [('rivi', False)],
          'rivierne': [('rivi', False)],
          'riviernes': [('rivi', False)],
          'riviers': [('rivi', False)],
          'rivis': [('rivi', False)],
          'riører': [('riør', False)],
          'rjakken': [('rjakke', False)],
          'rjakkerne': [('rjakke', False)],
          'rjorden': [('rjord', False)],
          'rjordens': [('rjord', False)],
          'rjunker': [('rjunker', False)],
          'rjunkerne': [('rjunker', False)],
          'rjunkernes': [('rjunker', False)],
          'rjunkers': [('rjunker', False)],
          'rk': [('rk', False)],
          'rka': [('rka', False)],
          'rkaffer': [('rkaffe', False)],
          'rkafferne': [('rkaffe', False)],
          'rkaffernes': [('rkaffe', False)],
          'rkaffers': [('rkaffe', False)],
          'rkagen': [('rkage', False)],
          'rkagens': [('rkage', False)],
          'rkalke': [('rkalk', False)],
          'rkalken': [('rkalk', False)],
          'rkalkens': [('rkalk', False)],
          'rkalkes': [('rkalk', False)],
          'rkanen': [('rkan', False)],
          'rkanens': [('rkan', False)],
          'rkaner': [('rkaner', False)],
          'rkanerne': [('rkan', False)],
          'rkanernes': [('rkaner', False)],
          'rkaners': [('rkan', False)],
          'rkans': [('rkan', False)],
          'rkas': [('rka', False)],
          'rkater': [('rkat', False)],
          'rkaterne': [('rkat', False)],
          'rkaters': [('rkat', False)],
          'rke': [('rk', False)],
          'rkeder': [('rked', False)],
          'rkederne': [('rked', False)],
          'rkedernes': [('rked', False)],
          'rkeders': [('rked', False)],
          'rkehandler': [('rkehandler', False)],
          'rkehandlers': [('rkehandler', False)],
          'rkelen': [('rkel', False)],
          'rken': [('rk', False)],
          'rkender': [('rkende', False)],
          'rkenderne': [('rkende', False)],
          'rkendernes': [('rkende', False)],
          'rkenders': [('rkende', False)],
          'rkene': [('rk', False)],
          'rkenes': [('rk', False)],
          'rker': [('rk', False)],
          'rkere': [('rker', False)],
          'rkeren': [('rker', False)],
          'rkerens': [('rker', False)],
          'rkeres': [('rker', False)],
          'rkerne': [('rk', False)],
          'rkernes': [('rk', False)],
          'rkerotter': [('rkerotte', False)],
          'rkerotternes': [('rkerotte', False)],
          'rkerotters': [('rkerotte', False)],
          'rkers': [('rker', False)],
          'rkes': [('rk', False)],
          "rkes'": [('rkes', False)],
          'rkesen': [('rkes', False)],
          'rkesene': [('rkes', False)],
          'rkesenes': [('rkes', False)],
          'rkesens': [('rkes', False)],
          'rket': [('rk', False)],
          'rkets': [('rk', False)],
          'rketter': [('rket', False)],
          'rkiner': [('rkiner', False)],
          'rkinerne': [('rkiner', False)],
          'rkinernes': [('rkiner', False)],
          'rkiners': [('rkiner', False)],
          'rkis': [('rkis', False)],
          'rkisen': [('rkis', False)],
          'rkiser': [('rkis', False)],
          'rkiserne': [('rkis', False)],
          'rkisernes': [('rkis', False)],
          'rkisten': [('rkist', False)],
          'rkistens': [('rkist', False)],
          'rkister': [('rkist', False)],
          'rkisterne': [('rkist', False)],
          'rkisternes': [('rkist', False)],
          'rkisters': [('rkist', False)],
          'rkiver': [('rkiv', False)],
          'rkivernes': [('rkiv', False)],
          'rkivers': [('rkiv', False)],
          'rklager': [('rklage', False)],
          'rklagerne': [('rklage', False)],
          'rklagernes': [('rklage', False)],
          'rklagers': [('rklage', False)],
          'rklaps': [('rklap', False)],
          'rklaver': [('rklaver', False)],
          'rklens': [('rkel', False)],
          'rkler': [('rkel', False)],
          'rklingen': [('rkling', False)],
          'rklingens': [('rkling', False)],
          'rklinger': [('rkling', False)],
          'rklingerne': [('rkling', False)],
          'rklingernes': [('rkling', False)],
          'rklingers': [('rkling', False)],
          'rklipper': [('rklipper', False)],
          'rklipperne': [('rklipper', False)],
          'rklippernes': [('rklipper', False)],
          'rklippers': [('rklipper', False)],
          'rklips': [('rklip', False)],
          'rklokker': [('rklokke', False)],
          'rklokkerne': [('rklokke', False)],
          'rklokkernes': [('rklokke', False)],
          'rklokkers': [('rklokke', False)],
          'rklæder': [('rklæde', False)],
          'rklæderne': [('rklæde', False)],
          'rklædernes': [('rklæde', False)],
          'rklæders': [('rklæde', False)],
          'rknerne': [('rken', False)],
          'rkoks': [('rkok', False)],
          'rkomet': [('rkom', False)],
          'rkometer': [('rkometer', False)],
          'rkometers': [('rkometer', False)],
          'rkomets': [('rkom', False)],
          'rkommers': [('rkommer', False)],
          'rkon': [('rkon', False)],
          'rkonen': [('rkon', False)],
          'rkonens': [('rkon', False)],
          'rkoner': [('rkon', False)],
          'rkonerne': [('rkon', False)],
          'rkonernes': [('rkon', False)],
          'rkoners': [('rkon', False)],
          'rkonet': [('rkon', False)],
          'rkonets': [('rkon', False)],
          'rkons': [('rkon', False)],
          'rkopper': [('rkop', False)],
          'rkopperne': [('rkop', False)],
          'rkoppernes': [('rkop', False)],
          'rkoppers': [('rkop', False)],
          'rkorset': [('rkors', False)],
          'rkorsets': [('rkors', False)],
          'rkorter': [('rkorter', False)],
          'rkorternes': [('rkorter', False)],
          'rkorters': [('rkorter', False)],
          'rkoser': [('rkose', False)],
          'rkreds': [('rkreds', False)],
          'rkronen': [('rkrone', False)],
          'rkroner': [('rkrone', False)],
          'rkronernes': [('rkrone', False)],
          'rkræfter': [('rkraft', False)],
          'rkræfterne': [('rkraft', False)],
          'rkræfternes': [('rkraft', False)],
          'rkræs': [('rkræ', False)],
          'rks': [('rk', False)],
          "rks'": [('rk', False)],
          'rkulosen': [('rkulose', False)],
          'rkulosens': [('rkulose', False)],
          'rkulærerne': [('rkulære', False)],
          'rkundens': [('rkunde', False)],
          'rkurs': [('rkurs', False)],
          'rkursernes': [('rkurs', False)],
          'rkurve': [('rkurv', False)],
          'rkurven': [('rkurv', False)],
          'rkurvens': [('rkurv', False)],
          'rkurves': [('rkurv', False)],
          'rkus': [('rkus', False)],
          'rkusser': [('rkus', False)],
          'rkusserne': [('rkus', False)],
          'rkussernes': [('rkus', False)],
          'rkussers': [('rkus', False)],
          'rkutter': [('rkutter', False)],
          'rkutterne': [('rkutter', False)],
          'rkutternes': [('rkutter', False)],
          'rkutters': [('rkutter', False)],
          'rkvarter': [('rkvarter', False)],
          'rkvarters': [('rkvarter', False)],
          'rkæmper': [('rkæmper', False)],
          'rkæmperne': [('rkæmper', False)],
          'rkæmpernes': [('rkæmper', False)],
          'rkæmpers': [('rkæmper', False)],
          'rkøbet': [('rkøb', False)],
          'rkøjer': [('rkøje', False)],
          'rkøren': [('rkør', False)],
          'rkører': [('rkør', False)],
          'rkørerne': [('rkør', False)],
          'rkørernes': [('rkør', False)],
          'rkørers': [('rkør', False)],
          'rl': [('rl', False)],
          'rlader': [('rlader', False)],
          'rladerne': [('rlader', False)],
          'rladernes': [('rlader', False)],
          'rladers': [('rlader', False)],
          'rlagen': [('rlagen', False)],
          'rlagens': [('rlagen', False)],
          'rlager': [('rlage', False)],
          'rlagerne': [('rlage', False)],
          'rlagernes': [('rlage', False)],
          'rlagers': [('rlage', False)],
          'rlaks': [('rlak', False)],
          'rlammen': [('rlam', False)],
          'rlande': [('rlande', False)],
          'rlanden': [('rlande', False)],
          'rlandens': [('rlande', False)],
          'rlander': [('rlande', False)],
          'rlandes': [('rlande', False)],
          'rlaps': [('rlap', False)],
          'rlatter': [('rlatter', False)],
          'rlatters': [('rlatter', False)],
          'rlavet': [('rlav', False)],
          'rlavets': [('rlav', False)],
          'rle': [('rl', False)],
          'rledernes': [('rleder', False)],
          'rlege': [('rlege', False)],
          'rlegene': [('rlege', False)],
          'rlegenes': [('rlege', False)],
          'rleges': [('rlege', False)],
          'rlejen': [('rlej', False)],
          'rlejens': [('rlej', False)],
          'rlejs': [('rlej', False)],
          'rlemmers': [('rlem', False)],
          'rlen': [('rl', False)],
          'rlene': [('rl', False)],
          'rlenes': [('rl', False)],
          'rlens': [('rl', False)],
          'rler': [('rl', False)],
          'rlere': [('rler', False)],
          'rleren': [('rler', False)],
          'rlerens': [('rler', False)],
          'rleres': [('rler', False)],
          'rlerne': [('rle', False)],
          'rlernes': [('rle', False)],
          'rlers': [('rle', False)],
          'rles': [('rl', False)],
          'rlesken': [('rleske', False)],
          'rlet': [('rlet', False)],
          'rlets': [('rlet', False)],
          'rletten': [('rlet', False)],
          'rlettens': [('rlet', False)],
          'rletter': [('rlet', False)],
          'rletterne': [('rlet', False)],
          'rletternes': [('rlet', False)],
          'rletters': [('rlet', False)],
          'rleven': [('rleven', False)],
          'rlevens': [('rleven', False)],
          'rleverne': [('rlever', False)],
          'rlevernes': [('rlever', False)],
          'rlime': [('rlim', False)],
          'rlimen': [('rlim', False)],
          'rlimene': [('rlim', False)],
          'rlimenes': [('rlim', False)],
          'rlimens': [('rlim', False)],
          'rlimes': [('rlim', False)],
          'rliner': [('rliner', False)],
          'rlinerne': [('rliner', False)],
          'rlinernes': [('rliner', False)],
          'rliners': [('rliner', False)],
          'rlingers': [('rling', False)],
          'rlis': [('rlis', False)],
          'rlisten': [('rliste', False)],
          'rlistens': [('rliste', False)],
          'rlister': [('rliste', False)],
          'rlisterne': [('rliste', False)],
          'rlokkens': [('rlok', False)],
          'rlokker': [('rlok', False)],
          'rlokkerne': [('rlok', False)],
          'rlokkernes': [('rlok', False)],
          'rlokkers': [('rlok', False)],
          'rlomme': [('rlomme', False)],
          'rlommen': [('rlomme', False)],
          'rlommens': [('rlomme', False)],
          'rlommer': [('rlomme', False)],
          'rlommerne': [('rlomme', False)],
          'rlommernes': [('rlomme', False)],
          'rlommers': [('rlomme', False)],
          'rlommes': [('rlomme', False)],
          'rlove': [('rlov', False)],
          'rls': [('rl', False)],
          "rls'": [('rl', False)],
          'rlukker': [('rlukker', False)],
          'rlukkerne': [('rlukker', False)],
          'rlukkernes': [('rlukker', False)],
          'rlukkers': [('rlukker', False)],
          'rlus': [('rlus', False)],
          'rlusen': [('rlus', False)],
          'rlyden': [('rlyd', False)],
          'rlydens': [('rlyd', False)],
          'rlys': [('rlys', False)],
          'rlæbernes': [('rlæbe', False)],
          'rlæder': [('rlæder', False)],
          'rlægernes': [('rlæge', False)],
          'rlægers': [('rlæge', False)],
          'rlænder': [('rlænder', False)],
          'rlænderne': [('rlænder', False)],
          'rlændernes': [('rlænder', False)],
          'rlænders': [('rlænder', False)],
          'rlænger': [('rlænger', False)],
          'rlængerne': [('rlænger', False)],
          'rlængernes': [('rlænger', False)],
          'rlængers': [('rlænger', False)],
          'rlærer': [('rlærer', False)],
          'rlærerne': [('rlærer', False)],
          'rlærernes': [('rlærer', False)],
          'rlærers': [('rlærer', False)],
          'rlæs': [('rlæs', False)],
          'rlæsernes': [('rlæser', False)],
          'rløberne': [('rløber', False)],
          'rløbers': [('rløber', False)],
          'rlører': [('rlør', False)],
          'rlørernes': [('rlør', False)],
          'rløser': [('rløser', False)],
          'rløserne': [('rløser', False)],
          'rløsers': [('rløser', False)],
          'rm': [('rm', False)],
          'rm.': [('rm.', False)],
          'rmadders': [('rmad', False)],
          'rmads': [('rmad', False)],
          'rmager': [('rmager', False)],
          'rmagerne': [('rmager', False)],
          'rmagernes': [('rmager', False)],
          'rmagers': [('rmager', False)],
          'rmaks': [('rmaks', False)],
          'rmaler': [('rmal', False)],
          'rmalerne': [('rmal', False)],
          'rmalernes': [('rmal', False)],
          'rmalers': [('rmal', False)],
          'rman': [('rmanner', False)],
          'rmander': [('rmand', False)],
          'rmanens': [('rmanens', False)],
          'rmaner': [('rmaner', False)],
          'rmanerne': [('rmaner', False)],
          'rmanernes': [('rmaner', False)],
          'rmaners': [('rmaner', False)],
          'rmannen': [('rmanner', False)],
          'rmannens': [('rmanner', False)],
          'rmanner': [('rmanner', False)],
          'rmans': [('rmanner', False)],
          'rmarchen': [('rmarch', False)],
          'rmarchens': [('rmarch', False)],
          'rmarcher': [('rmarch', False)],
          'rmarcherne': [('rmarch', False)],
          'rmas': [('rma', False)],
          'rmasken': [('rmaske', False)],
          'rmaskens': [('rmaske', False)],
          'rmasker': [('rmaske', False)],
          'rmaskerne': [('rmaske', False)],
          'rmaskers': [('rmaske', False)],
          'rmassens': [('rmasse', False)],
          'rmasser': [('rmasse', False)],
          'rmasserne': [('rmasse', False)],
          'rmaster': [('rmaster', False)],
          'rmasterne': [('rmast', False)],
          'rmasternes': [('rmast', False)],
          'rmasters': [('rmaster', False)],
          'rme': [('rm', False)],
          'rmediciner': [('rmedicin', False)],
          'rmedicinerne': [('rmedicin', False)],
          'rmedicinernes': [('rmedicin', False)],
          'rmediciners': [('rmedicin', False)],
          'rmelet': [('rmel', False)],
          'rmelissen': [('rmelis', False)],
          'rmelissens': [('rmelis', False)],
          'rmelser': [('rmelse', False)],
          'rmelserne': [('rmelse', False)],
          'rmelsernes': [('rmelse', False)],
          'rmen': [('rm', False)],
          'rmene': [('rm', False)],
          'rmenes': [('rm', False)],
          'rmens': [('rm', False)],
          'rmenter': [('rment', False)],
          'rmenterne': [('rment', False)],
          'rmenternes': [('rment', False)],
          'rmenters': [('rment', False)],
          'rmere': [('rmer', False)],
          'rmeren': [('rmer', False)],
          'rmerens': [('rmer', False)],
          'rmeres': [('rmer', False)],
          'rmes': [('rm', False)],
          'rmet': [('rme', False)],
          'rmeter': [('rmet', False)],
          'rmeterne': [('rmet', False)],
          'rmeternes': [('rmet', False)],
          'rmeters': [('rmet', False)],
          'rmets': [('rmet', False)],
          'rmidler': [('rmiddel', False)],
          'rmidlerne': [('rmiddel', False)],
          'rmidlernes': [('rmiddel', False)],
          'rmidlers': [('rmiddel', False)],
          'rmier': [('rmie', False)],
          'rmierne': [('rmie', False)],
          'rmiernes': [('rmie', False)],
          'rmiers': [('rmie', False)],
          'rmiet': [('rmie', False)],
          'rmiets': [('rmie', False)],
          'rmiks': [('rmik', False)],
          'rminen': [('rmin', False)],
          'rminens': [('rmin', False)],
          'rminers': [('rmine', False)],
          'rmini': [('rminus', False)],
          'rminis': [('rminus', False)],
          'rministers': [('rminister', False)],
          'rmis': [('rmi', False)],
          'rmitten': [('rmit', False)],
          'rmittens': [('rmit', False)],
          'rmitter': [('rmit', False)],
          'rmitterne': [('rmit', False)],
          'rmitternes': [('rmit', False)],
          'rmitters': [('rmit', False)],
          'rmlen': [('rmel', False)],
          'rmlens': [('rmel', False)],
          'rmler': [('rmel', False)],
          'rmlerne': [('rmel', False)],
          'rmlernes': [('rmel', False)],
          'rmlers': [('rmel', False)],
          'rmoden': [('rmod', False)],
          'rmodens': [('rmod', False)],
          'rmoder': [('rmor', False)],
          'rmoders': [('rmor', False)],
          'rmodet': [('rmod', False)],
          'rmodets': [('rmod', False)],
          'rmonen': [('rmon', False)],
          'rmonens': [('rmon', False)],
          'rmoner': [('rmon', False)],
          'rmonerne': [('rmon', False)],
          'rmonernes': [('rmon', False)],
          'rmoners': [('rmon', False)],
          'rmoniet': [('rmonium', False)],
          'rmoniets': [('rmonium', False)],
          'rmoralen': [('rmoral', False)],
          'rmoralens': [('rmoral', False)],
          'rms': [('rm', False)],
          "rms'": [('rm', False)],
          'rmsene': [('rm', False)],
          'rmsenes': [('rm', False)],
          'rmsten': [('rmsten', False)],
          'rmuen': [('rmue', False)],
          'rmuens': [('rmue', False)],
          'rmuer': [('rmue', False)],
          'rmuerne': [('rmue', False)],
          'rmuernes': [('rmue', False)],
          'rmuers': [('rmue', False)],
          'rmunkens': [('rmunk', False)],
          'rmusen': [('rmus', False)],
          'rmusens': [('rmus', False)],
          'rmynder': [('rmynder', False)],
          'rmynderne': [('rmynder', False)],
          'rmyndernes': [('rmynder', False)],
          'rmynders': [('rmynder', False)],
          'rmyren': [('rmyre', False)],
          'rmyrens': [('rmyre', False)],
          'rmyrer': [('rmyre', False)],
          'rmyrerne': [('rmyre', False)],
          'rmyrernes': [('rmyre', False)],
          'rmyrers': [('rmyre', False)],
          'rmælken': [('rmælk', False)],
          'rmælkens': [('rmælk', False)],
          'rmænd': [('rmand', False)],
          'rmændene': [('rmand', False)],
          'rmændenes': [('rmand', False)],
          'rmænds': [('rmand', False)],
          'rmærkerne': [('rmærke', False)],
          'rmærkernes': [('rmærke', False)],
          'rmærkers': [('rmærke', False)],
          'rmøderne': [('rmøde', False)],
          'rmødernes': [('rmøde', False)],
          'rmøller': [('rmølle', False)],
          'rmøllerne': [('rmølle', False)],
          'rmøllernes': [('rmølle', False)],
          'rmøllers': [('rmølle', False)],
          'rmøren': [('rmør', False)],
          'rmører': [('rmør', False)],
          'rmørerne': [('rmør', False)],
          'rmørernes': [('rmør', False)],
          'rmørers': [('rmør', False)],
          'rn': [('rn', False)],
          'rnakker': [('rnakker', False)],
          'rnakkerne': [('rnakker', False)],
          'rnakkernes': [('rnakker', False)],
          'rnakkers': [('rnakker', False)],
          'rnalder': [('rnalder', False)],
          'rnalders': [('rnalder', False)],
          'rnalen': [('rnal', False)],
          'rnaler': [('rnal', False)],
          'rnalerne': [('rnal', False)],
          'rnalernes': [('rnal', False)],
          'rnalers': [('rnal', False)],
          'rnanten': [('rnante', False)],
          'rnantens': [('rnante', False)],
          'rnanterne': [('rnante', False)],
          'rnanternes': [('rnante', False)],
          'rnanters': [('rnante', False)],
          'rnapperne': [('rnap', False)],
          'rnappernes': [('rnap', False)],
          "rnaps'": [('rnap', False)],
          'rnas': [('rna', False)],
          'rnater': [('rnat', False)],
          'rnaterne': [('rnat', False)],
          'rnaters': [('rnat', False)],
          'rnavlen': [('rnavl', False)],
          'rnavlens': [('rnavl', False)],
          'rne': [('rn', False)],
          'rnearbejder': [('rnearbejder', False)],
          'rnearbejderne': [('rnearbejder', False)],
          'rnellens': [('rnel', False)],
          'rnellerne': [('rnel', False)],
          'rnellernes': [('rnel', False)],
          'rnelliker': [('rnellike', False)],
          'rnellikerne': [('rnellike', False)],
          'rnellikernes': [('rnellike', False)],
          'rnene': [('rn', False)],
          'rnenes': [('rn', False)],
          'rnerne': [('rne', False)],
          'rners': [('rne', False)],
          'rnes': [('rn', False)],
          "rnes'": [('rnes', False)],
          'rnesten': [('rnesten', False)],
          'rnet': [('rn', False)],
          'rnets': [('rn', False)],
          'rnhandlernes': [('rnhandler', False)],
          'rnier': [('rnier', False)],
          'rnierne': [('rni', False)],
          'rniernes': [('rni', False)],
          'rniers': [('rni', False)],
          'rniklen': [('rnikkel', False)],
          'rningers': [('rning', False)],
          'rnips': [('rnips', False)],
          'rnis': [('rnis', False)],
          "rnis'": [('rnis', False)],
          'rnitten': [('rnit', False)],
          'rnittens': [('rnit', False)],
          'rnkerne': [('rnkerne', False)],
          'rns': [('rn', False)],
          "rns'": [('rn', False)],
          'rnsorter': [('rnsort', False)],
          'rnsorterne': [('rnsort', False)],
          'rnsorternes': [('rnsort', False)],
          'rnsorters': [('rnsort', False)],
          'rnstudiet': [('rnstudie', False)],
          'rnummers': [('rnummer', False)],
          'rnure': [('rnur', False)],
          'rnures': [('rnur', False)],
          'rnus': [('rnus', False)],
          'rnusser': [('rnusser', False)],
          'rnusserne': [('rnusser', False)],
          'rnussernes': [('rnus', False)],
          'rnussers': [('rnus', False)],
          'rnvinde': [('rnvinde', False)],
          'rnyer': [('rnyer', False)],
          'rnyerne': [('rnyer', False)],
          'rnyernes': [('rnyer', False)],
          'rnyers': [('rnyer', False)],
          'rnyster': [('rnyster', False)],
          'rnysters': [('rnyster', False)],
          'rnøren': [('rnør', False)],
          'rnører': [('rnør', False)],
          'rnørernes': [('rnør', False)],
          'rnørers': [('rnør', False)],
          'ro': [('ro', False)],
          'robe': [('robe', True)],
          'roben': [('robe', False)],
          'robens': [('robe', True)],
          'roberne': [('robe', True)],
          'robers': [('robe', True)],
          'robes': [('robe', False)],
          'rocenters': [('rocenter', False)],
          'rockere': [('rocker', True)],
          'rockeren': [('rocker', True)],
          'rockerens': [('rocker', True)],
          'rockeres': [('rocker', True)],
          'rockerne': [('rocker', True)],
          'rockernes': [('rocker', True)],
          'rockers': [('rocker', True)],
          'rocks': [('rock', False)],
          'rodder': [('rodde', False)],
          'rodderne': [('rodde', False)],
          'roddernes': [('rodde', False)],
          'rodders': [('rodde', False)],
          'roden': [('rode', True), ('rod', True)],
          'rodens': [('rode', True), ('rod', True)],
          'roder': [('rode', True)],
          'roders': [('rode', True)],
          'rodi': [('rodi', False)],
          'rodier': [('rodi', False)],
          'rodierne': [('rodi', False)],
          'rodiers': [('rodi', False)],
          'rods': [('rod', True)],
          'roen': [('roe', True), ('ro', True)],
          'roens': [('roe', True), ('ro', True)],
          'roer': [('roer', True), ('roe', True)],
          'roerne': [('roe', True), ('roer', True)],
          'roernes': [('roe', True), ('roer', True)],
          'roers': [('roe', True), ('roer', True)],
          'roet': [('ro', False)],
          'roets': [('ro', False)],
          'rofernes': [('rofe', False)],
          'roffer': [('rof', False)],
          'roffers': [('rof', False)],
          'rofrets': [('roffer', False)],
          'roge': [('roge', False)],
          'rogens': [('rogen', False)],
          'roger': [('roge', False)],
          'rogerne': [('roge', False)],
          'rogernes': [('roge', False)],
          'rogers': [('roge', False)],
          'roges': [('roge', False)],
          'rogets': [('rog', False)],
          'roggen': [('rog', False)],
          'roggens': [('rog', False)],
          'rogger': [('rog', False)],
          'roggerne': [('rog', False)],
          'roggernes': [('rog', False)],
          'rognen': [('rogn', True)],
          'rognens': [('rogn', True)],
          'rojaner': [('rojaner', False)],
          'rojanerne': [('rojaner', False)],
          'rojaners': [('rojaner', False)],
          'rok': [('rok', True)],
          'rokets': [('roket', False)],
          'roketten': [('roket', False)],
          'rokettens': [('roket', False)],
          'roketterne': [('roket', False)],
          'roketternes': [('roket', False)],
          'roketters': [('roket', False)],
          'rokke': [('rokke', True), ('rok', True)],
          'rokken': [('rokke', True), ('rok', True)],
          'rokkens': [('rok', True), ('rokke', True)],
          'rokker': [('rokker', True), ('rokke', True)],
          'rokkerne': [('rokker', True), ('rokke', True)],
          'rokkernes': [('rokker', True), ('rokke', True)],
          'rokkers': [('rokker', True), ('rokke', True)],
          'rokkes': [('rok', True), ('rokke', True)],
          'roks': [('rok', True)],
          'rokser': [('rokse', False)],
          'rolde': [('rold', False)],
          'rolden': [('rold', False)],
          'roldene': [('rold', False)],
          'roldenes': [('rold', False)],
          'roldens': [('rold', False)],
          'rolder': [('rold', False)],
          'rolderne': [('rold', False)],
          'roldernes': [('rold', False)],
          'roldes': [('rold', False)],
          'role': [('role', False)],
          'rolen': [('role', False)],
          'rolens': [('role', False)],
          'roler': [('roler', False)],
          'rolerne': [('rol', False)],
          'rolernes': [('roler', False)],
          'rolers': [('role', False)],
          'roles': [('role', False)],
          'rolfen': [('rolf', False)],
          'rolfens': [('rolf', False)],
          'rolingers': [('rolinger', False)],
          'rollen': [('rolle', True)],
          'rollens': [('rolle', False)],
          'roller': [('rolle', True)],
          'rollerne': [('rolle', True)],
          'rollernes': [('rolle', True)],
          'rollers': [('rolle', True)],
          'rolos': [('rolo', False)],
          'rolytternes': [('rolyt', False)],
          'romager': [('romager', False)],
          'romagerne': [('romager', False)],
          'romagernes': [('romage', False)],
          'romagers': [('romager', False)],
          'romaner': [('roman', False)],
          'romanerne': [('roman', False)],
          'romanernes': [('roman', False)],
          'romaners': [('roman', False)],
          'romber': [('rombe', True)],
          'romberne': [('rombe', True)],
          'rombernes': [('rombe', True)],
          'romen': [('rom', False)],
          'romens': [('rom', False)],
          'romer': [('romer', True)],
          'romerne': [('romer', True)],
          'romernes': [('romer', True)],
          'romers': [('romer', True)],
          'rometerne': [('rometer', False)],
          'rometernes': [('rometer', False)],
          'romis': [('romis', False)],
          'romler': [('romle', False)],
          'rommen': [('rom', False)],
          'rommens': [('rom', False)],
          'rommer': [('rom', True)],
          'rommerne': [('rom', False)],
          'rommernes': [('rom', False)],
          'rommers': [('rom', True)],
          'ronaternes': [('ronat', False)],
          'ronen': [('rone', False)],
          'ronens': [('rone', False)],
          'rongen': [('rong', False)],
          'rongens': [('rong', False)],
          'ronger': [('rong', False)],
          'rongerne': [('rong', False)],
          'rongernes': [('rong', False)],
          'ronien': [('roni', False)],
          'roniens': [('roni', False)],
          'ronier': [('roni', False)],
          'roniet': [('roni', False)],
          'roniets': [('roni', False)],
          'ronis': [('roni', False)],
          'ronomen': [('ronom', False)],
          'ronomens': [('ronomen', False)],
          'ronten': [('ront', False)],
          'rontens': [('ront', False)],
          'ronter': [('ronte', False)],
          'ronterne': [('ront', False)],
          'ronternes': [('ront', False)],
          'ronters': [('ront', False)],
          'roppe': [('rop', False)],
          'roppen': [('rop', False)],
          'roppens': [('rop', False)],
          'ropper': [('ropper', False)],
          'ropperne': [('rop', False)],
          'roppernes': [('ropper', False)],
          'roppers': [('rop', False)],
          'rordnernes': [('rorden', False)],
          'rore': [('rore', False)],
          'ros': [('ros', True), ('ro', True)],
          'rosa': [('rosa', False)],
          'rosas': [('rosa', False)],
          'roschen': [('rosche', False)],
          'roschens': [('rosche', False)],
          'roscher': [('rosch', False)],
          'roscherne': [('rosche', False)],
          'roschernes': [('rosch', False)],
          'roschers': [('rosch', False)],
          'rosen': [('rosen', True), ('ros', True), ('rose', True)],
          'rosens': [('ros', True), ('rosen', True), ('rose', True)],
          'roser': [('rose', False)],
          'roserne': [('rose', False)],
          'rosernes': [('rose', False)],
          'rosers': [('rose', True)],
          'roskens': [('roske', False)],
          'rosker': [('roske', False)],
          'roskernes': [('roske', False)],
          'rosmerne': [('rosme', False)],
          'rosmers': [('rosme', False)],
          'rossen': [('ros', False)],
          'rossene': [('ross', False)],
          'rossenes': [('ross', False)],
          'rossens': [('ros', False)],
          'rosser': [('ros', False)],
          'rosserne': [('ros', False)],
          'rossernes': [('rosse', False)],
          'rossers': [('rosse', False)],
          'rosset': [('ros', True)],
          'rossets': [('ros', True)],
          'roste': [('rost', False)],
          'rosten': [('rost', False)],
          'rostens': [('rost', False)],
          'rostes': [('rost', False)],
          'rotangens': [('rotang', True)],
          'rotten': [('rotte', True)],
          'rottens': [('rotte', True)],
          'rotter': [('rotte', True)],
          'rotterne': [('rotte', False)],
          'rotternes': [('rotte', True)],
          'rotters': [('rotte', True)],
          'rouletten': [('roulette', True), ('roulet', True)],
          'roulettens': [('roulet', True), ('roulette', True)],
          'rouletter': [('roulet', True), ('roulette', True)],
          'rouletterne': [('roulet', True), ('roulette', True)],
          'rouletternes': [('roulet', True), ('roulette', True)],
          'rouletters': [('roulet', True), ('roulette', True)],
          'roupier': [('roupie', False)],
          'roupiers': [('roupier', False)],
          'router': [('router', True)],
          'routerne': [('router', True)],
          'routernes': [('router', True)],
          'routers': [('router', True)],
          'rove': [('rove', False)],
          'roven': [('rove', False)],
          'rovens': [('rove', False)],
          'rover': [('rove', False)],
          'roverne': [('rove', False)],
          'rovernes': [('rove', False)],
          'rovers': [('rove', False)],
          "rovers'": [('rovers', False)],
          'roves': [('rove', False)],
          'rovoer': [('rovo', False)],
          'rovoerne': [('rovo', False)],
          'rovoernes': [('rovo', False)],
          'rovoers': [('rovo', False)],
          'royer': [('royer', False)],
          'royerne': [('royer', False)],
          'royernes': [('royer', False)],
          'royers': [('royer', False)],
          'rpagter': [('rpagter', False)],
          'rpagterne': [('rpagter', False)],
          'rpagternes': [('rpagter', False)],
          'rpagters': [('rpagter', False)],
          'rpande': [('rpande', False)],
          'rpanden': [('rpande', False)],
          'rpandes': [('rpande', False)],
          'rpas': [('rpas', False)],
          'rpasser': [('rpasser', False)],
          'rpasserne': [('rpasser', False)],
          'rpassernes': [('rpas', False)],
          'rpassers': [('rpas', False)],
          'rpearbejdernes': [('rpearbejde', False)],
          'rpearbejders': [('rpearbejde', False)],
          'rpelse': [('rpelse', False)],
          'rpelsen': [('rpelse', False)],
          'rpelsens': [('rpelse', False)],
          'rpelses': [('rpelse', False)],
          'rpene': [('rp', False)],
          'rpenes': [('rp', False)],
          'rpere': [('rper', False)],
          'rperens': [('rper', False)],
          'rperes': [('rper', False)],
          'rpernes': [('rpe', False)],
          'rpers': [('rpe', False)],
          'rpes': [('rpe', False)],
          "rpes'": [('rpes', False)],
          'rpet': [('rp', False)],
          'rpets': [('rp', False)],
          'rpigerne': [('rpige', False)],
          'rpigernes': [('rpige', False)],
          'rpigers': [('rpige', False)],
          'rpiks': [('rpiks', False)],
          'rpioner': [('rpion', False)],
          'rpioners': [('rpion', False)],
          'rpis': [('rpi', False)],
          'rpladerne': [('rplade', False)],
          'rplager': [('rplager', False)],
          'rplagerne': [('rplager', False)],
          'rplagernes': [('rplager', False)],
          'rplagers': [('rplager', False)],
          'rplanet': [('rplan', False)],
          'rplanets': [('rplan', False)],
          'rplanter': [('rplante', False)],
          'rplanterne': [('rplante', False)],
          'rplanternes': [('rplante', False)],
          'rplanters': [('rplante', False)],
          'rposter': [('rpost', False)],
          'rposterne': [('rpost', False)],
          'rposternes': [('rpost', False)],
          'rposters': [('rpost', False)],
          'rpotens': [('rpote', False)],
          'rpotten': [('rpot', False)],
          'rpottens': [('rpot', False)],
          'rpretter': [('rpretter', False)],
          'rprisen': [('rpris', False)],
          'rprisens': [('rpris', False)],
          'rpriser': [('rpris', False)],
          'rpriserne': [('rpris', False)],
          'rprisernes': [('rpris', False)],
          'rprisers': [('rpris', False)],
          'rps': [('rp', False)],
          'rpter': [('rpt', False)],
          'rptet': [('rpt', False)],
          'rrailerne': [('rrailer', False)],
          'rrailernes': [('rrailer', False)],
          'rrailers': [('rrailer', False)],
          'rrainer': [('rraine', False)],
          'rrakkens': [('rrak', False)],
          'rrakker': [('rrak', False)],
          'rrakkerne': [('rrak', False)],
          'rrakkernes': [('rrak', False)],
          'rrakkers': [('rrak', False)],
          'rranerne': [('rraner', False)],
          'rranernes': [('rraner', False)],
          'rrangen': [('rrang', False)],
          'rrangens': [('rrang', False)],
          'rraps': [('rraps', False)],
          'rrassen': [('rrasse', False)],
          'rrassens': [('rrasse', False)],
          'rrasserne': [('rrasse', False)],
          'rrata': [('rratum', False)],
          'rre': [('r', False)],
          'rrebs': [('rreb', False)],
          'rreden': [('rred', False)],
          'rredens': [('rred', False)],
          'rreder': [('rred', False)],
          'rrederne': [('rred', False)],
          'rredernes': [('rred', False)],
          'rreders': [('rred', False)],
          'rreds': [('rred', False)],
          'rregimenter': [('rregiment', False)],
          'rregimenterne': [('rregiment', False)],
          'rregimenternes': [('rregiment', False)],
          'rregimenters': [('rregiment', False)],
          'rregimentet': [('rregiment', False)],
          'rregimentets': [('rregiment', False)],
          'rregner': [('rregnum', False)],
          'rregnerne': [('rregnum', False)],
          'rregners': [('rregnum', False)],
          'rrejer': [('rreje', False)],
          'rrejser': [('rrejse', False)],
          'rreklips': [('rreklip', False)],
          'rrelser': [('rrelse', False)],
          'rrelserne': [('rrelse', False)],
          'rrelsernes': [('rrelse', False)],
          'rren': [('rre', False)],
          'rrene': [('r', False)],
          'rrenen': [('rren', False)],
          'rrener': [('rren', False)],
          'rrenerne': [('rren', False)],
          'rreners': [('rren', False)],
          'rrenes': [('r', False)],
          'rrens': [('r', False)],
          'rrensernes': [('rrenser', False)],
          'rrenten': [('rrente', False)],
          'rrentens': [('rrente', False)],
          'rrenter': [('rrent', False)],
          'rrenterne': [('rrent', False)],
          'rrenternes': [('rrente', False)],
          'rrenters': [('rrent', False)],
          'rrentes': [('rrente', False)],
          'rrer': [('rrer', False)],
          'rrerne': [('rrer', False)],
          'rrernes': [('rrer', False)],
          'rrers': [('rre', False)],
          'rres': [('rre', False)],
          'rrestens': [('rrest', False)],
          'rret': [('rret', False)],
          'rretter': [('rret', False)],
          'rribs': [('rrib', False)],
          'rrider': [('rrider', False)],
          'rriderne': [('rrider', False)],
          'rridernes': [('rrider', False)],
          'rriders': [('rrider', False)],
          'rridser': [('rrids', False)],
          'rridserne': [('rrids', False)],
          'rridsernes': [('rrids', False)],
          'rridsers': [('rrids', False)],
          'rrier': [('rrier', False)],
          'rriere': [('rriere', False)],
          'rrieres': [('rriere', False)],
          'rrierne': [('rrier', False)],
          'rriernes': [('rrier', False)],
          'rriers': [('rrier', False)],
          'rrigerne': [('rrige', False)],
          'rrigernes': [('rrige', False)],
          'rrigers': [('rrige', False)],
          'rringer': [('rring', False)],
          'rringerne': [('rring', False)],
          'rringernes': [('rring', False)],
          'rringers': [('rring', False)],
          'rrins': [('rrin', False)],
          'rris': [('rris', False)],
          'rritten': [('rrit', False)],
          'rrittens': [('rrit', False)],
          'rritter': [('rrit', False)],
          'rritterne': [('rrit', False)],
          'rritternes': [('rrit', False)],
          'rritters': [('rrit', False)],
          'rrockere': [('rocker', False)],
          'rrockeren': [('rocker', False)],
          'rrockerens': [('rocker', False)],
          'rrockeres': [('rocker', False)],
          'rrockerne': [('rocker', False)],
          'rrockernes': [('rocker', False)],
          'rrockers': [('rocker', False)],
          'rroden': [('rrod', False)],
          'rrodens': [('rrod', False)],
          'rrods': [('rrod', False)],
          'rroen': [('rroe', False)],
          'rroens': [('rroe', False)],
          'rroer': [('rroe', False)],
          'rroerne': [('rroe', False)],
          'rroernes': [('rroe', False)],
          'rroers': [('rroe', False)],
          'rroider': [('rroide', False)],
          'rroiderne': [('rroide', False)],
          'rroidernes': [('rroide', False)],
          'rroiders': [('rroide', False)],
          'rroller': [('rrolle', False)],
          'rrollerne': [('rrolle', False)],
          'rrollers': [('rrolle', False)],
          'rronen': [('rron', False)],
          'rronens': [('rron', False)],
          'rroner': [('rron', False)],
          'rronerne': [('rron', False)],
          'rronernes': [('rron', False)],
          'rroners': [('rron', False)],
          'rrosen': [('rrose', False)],
          'rrosens': [('rrose', False)],
          'rrosers': [('rrose', False)],
          'rrossen': [('rrosse', False)],
          'rrossens': [('rrosse', False)],
          'rrosser': [('rrosse', False)],
          'rrosserne': [('rrosse', False)],
          'rrottens': [('rrotte', False)],
          'rrotter': [('rrotte', False)],
          'rrotternes': [('rrotte', False)],
          'rrotters': [('rrotte', False)],
          'rrs': [('rr', False)],
          'rruder': [('rrude', False)],
          'rruderne': [('rrude', False)],
          'rrudernes': [('rrude', False)],
          'rruders': [('rrude', False)],
          'rruller': [('rrulle', False)],
          'rrullerne': [('rruller', False)],
          'rrullernes': [('rruller', False)],
          'rrullers': [('rruller', False)],
          'rrummet': [('rrum', False)],
          'rrummets': [('rrum', False)],
          'rrådet': [('rråd', False)],
          'rræders': [('rræder', False)],
          'rrækker': [('rrække', False)],
          'rræner': [('rræn', False)],
          'rrænerne': [('rræn', False)],
          'rrænernes': [('rræn', False)],
          'rræners': [('rræn', False)],
          'rrøret': [('rrør', False)],
          'rrørets': [('rrør', False)],
          "rs'": [('rs', False)],
          'rsaften': [('rsaften', False)],
          'rsaftens': [('rsaften', False)],
          'rsagen': [('rsag', False)],
          'rsagens': [('rsage', False)],
          'rsagers': [('rsag', False)],
          'rsaks': [('rsaks', False)],
          'rsalier': [('rsal', False)],
          'rsaliers': [('rsal', False)],
          'rsangernes': [('rsanger', False)],
          'rsarbejder': [('rsarbejde', False)],
          'rsarbejderne': [('rsarbejde', False)],
          'rsarbejdernes': [('rsarbejde', False)],
          'rsbanken': [('rsbanke', False)],
          'rsbanker': [('rsbanke', False)],
          'rsbo': [('rsbo', False)],
          'rsboer': [('rsbo', False)],
          'rsboerne': [('rsbo', False)],
          'rsbos': [('rsbo', False)],
          'rschen': [('rsch', False)],
          'rschens': [('rsch', False)],
          'rscher': [('rsch', False)],
          'rscherne': [('rsch', False)],
          'rschers': [('rsch', False)],
          'rselets': [('rselet', False)],
          'rselærerne': [('rselære', False)],
          'rselærernes': [('rselære', False)],
          'rsen': [('rs', False)],
          'rsene': [('rs', False)],
          'rsenes': [('rs', False)],
          'rsens': [('rs', False)],
          'rser': [('rs', False)],
          'rsere': [('rser', False)],
          'rseren': [('rser', False)],
          'rserens': [('rser', False)],
          'rseres': [('rser', False)],
          'rserne': [('rs', False)],
          'rsernes': [('rs', False)],
          'rsers': [('rs', False)],
          "rses'": [('rsis', False)],
          'rset': [('rs', False)],
          'rsets': [('rsus', False)],
          'rsetter': [('rset', False)],
          'rsetterne': [('rset', False)],
          'rsetternes': [('rset', False)],
          'rsetters': [('rset', False)],
          'rsfornemmelserne': [('rsfornemmelser', False)],
          'rsfornemmelsernes': [('rsfornemmelser', False)],
          'rshandler': [('rshandel', False)],
          'rshandlers': [('rshandel', False)],
          'rshaver': [('rshave', False)],
          'rshaverne': [('rshave', False)],
          'rshavernes': [('rshave', False)],
          'rshavers': [('rshave', False)],
          'rsianer': [('rsianer', False)],
          'rsianers': [('rsianer', False)],
          'rsias': [('rsia', False)],
          'rsiderne': [('rside', False)],
          'rsier': [('rsia', False)],
          'rsierne': [('rsia', False)],
          'rsiernes': [('rsia', False)],
          'rsiers': [('rsia', False)],
          'rsigten': [('rsigt', False)],
          'rsigtens': [('rsigt', False)],
          'rsigter': [('rsigt', False)],
          'rsigterne': [('rsigt', False)],
          'rsigternes': [('rsigt', False)],
          'rsigters': [('rsigt', False)],
          'rsillen': [('rsille', False)],
          'rsingers': [('rsing', False)],
          'rsitet': [('rsitet', False)],
          'rsitets': [('rsitet', False)],
          'rskaber': [('rskab', False)],
          'rskaberne': [('rskab', False)],
          'rskabernes': [('rskab', False)],
          'rskabers': [('rskab', False)],
          'rskallen': [('rskal', False)],
          'rskallens': [('rskal', False)],
          'rskaller': [('rskal', False)],
          'rskallerne': [('rskal', False)],
          'rskallernes': [('rskal', False)],
          'rskallers': [('rskal', False)],
          'rske': [('rske', False)],
          'rskeden': [('rskede', False)],
          'rskeder': [('rskede', False)],
          'rskedernes': [('rskede', False)],
          'rskeders': [('rskede', False)],
          'rskene': [('rsk', False)],
          'rskens': [('rsk', False)],
          'rskernes': [('rsker', False)],
          'rskes': [('rske', False)],
          'rskifte': [('rskifte', False)],
          'rskifter': [('rskifte', False)],
          'rskifterne': [('rskifte', False)],
          'rskifters': [('rskifte', False)],
          'rskiftes': [('rskift', False)],
          'rskiftet': [('rskift', False)],
          'rskiftets': [('rskift', False)],
          'rskner': [('rsken', False)],
          'rsknernes': [('rsken', False)],
          'rskners': [('rsken', False)],
          'rskos': [('rsko', False)],
          'rskure': [('rskur', False)],
          'rskuren': [('rskur', False)],
          'rskurens': [('rskur', False)],
          'rskures': [('rskur', False)],
          'rskurs': [('rskur', False)],
          'rskødet': [('rskød', False)],
          'rskødets': [('rskød', False)],
          'rslags': [('rslag', False)],
          'rslangen': [('rslange', False)],
          'rslangens': [('rslange', False)],
          'rslens': [('rsel', False)],
          'rsler': [('rsel', False)],
          'rslinger': [('rsling', False)],
          'rslingerne': [('rsling', False)],
          'rslingernes': [('rsling', False)],
          'rslingers': [('rsling', False)],
          'rslipper': [('rslipper', False)],
          'rslipperne': [('rslipper', False)],
          'rslippernes': [('rslipper', False)],
          'rslippers': [('rslipper', False)],
          'rslærer': [('rslære', False)],
          'rsnaps': [('rsnaps', False)],
          'rsoner': [('rson', False)],
          'rsonerne': [('rson', False)],
          'rsonernes': [('rson', False)],
          'rsoners': [('rson', False)],
          'rspids': [('rspids', False)],
          'rspidser': [('rspids', False)],
          'rspiger': [('rspige', False)],
          'rspigerne': [('rspige', False)],
          'rspigernes': [('rspige', False)],
          'rspigers': [('rspige', False)],
          'rspild': [('rspild', False)],
          'rspildet': [('rspild', False)],
          'rspiser': [('rspiser', False)],
          'rspiserne': [('rspiser', False)],
          'rspisernes': [('rspiser', False)],
          'rspisers': [('rspiser', False)],
          'rsporer': [('rspore', False)],
          'rsporerne': [('rspore', False)],
          'rsporernes': [('rspore', False)],
          'rspændet': [('rspænde', False)],
          'rspændets': [('rspænde', False)],
          'rsskifternes': [('rsskifte', False)],
          'rsskiftes': [('rsskifte', False)],
          'rsskiftet': [('rsskifte', False)],
          'rstabe': [('rstab', False)],
          'rstabens': [('rstab', False)],
          'rstads': [('rstads', False)],
          'rstalen': [('rstale', False)],
          'rstalens': [('rstale', False)],
          'rstaler': [('rstale', False)],
          'rstalers': [('rstale', False)],
          'rstallerne': [('rstaller', False)],
          'rstallernes': [('rstaller', False)],
          'rstammen': [('rstamme', False)],
          'rstammens': [('rstamme', False)],
          'rstammer': [('rstamme', False)],
          'rstammerne': [('rstamme', False)],
          'rstammernes': [('rstamme', False)],
          'rstammers': [('rstamme', False)],
          'rstarter': [('rstart', False)],
          'rstarterne': [('rstart', False)],
          'rstarternes': [('rstart', False)],
          'rstarters': [('rstart', False)],
          'rstave': [('rstav', False)],
          'rstaven': [('rstav', False)],
          'rstavens': [('rstav', False)],
          'rstaves': [('rstav', False)],
          'rste': [('rste', False)],
          'rstemmer': [('rstemme', False)],
          'rstemmerne': [('rstemme', False)],
          'rstemmernes': [('rstemme', False)],
          'rstemmers': [('rstemme', False)],
          'rsten': [('rsten', False)],
          'rstene': [('rst', False)],
          'rstenes': [('rsten', False)],
          'rstens': [('rste', False)],
          'rster': [('rste', False)],
          'rsteret': [('rsteret', False)],
          'rsterets': [('rsteret', False)],
          'rsterne': [('rste', False)],
          'rsternes': [('rste', False)],
          'rsters': [('rste', False)],
          'rstes': [('rste', False)],
          'rstikker': [('rstikker', False)],
          'rstikkere': [('rstikker', False)],
          'rstikkeres': [('rstikker', False)],
          'rstikkerne': [('rstikker', False)],
          'rstikkernes': [('rstikker', False)],
          'rstikkers': [('rstikker', False)],
          'rstningers': [('rstning', False)],
          'rstraffe': [('rstraf', False)],
          'rstraffene': [('rstraf', False)],
          'rstraffenes': [('rstraf', False)],
          'rstraffes': [('rstraf', False)],
          'rstykkernes': [('rstykke', False)],
          'rstykkers': [('rstykke', False)],
          'rstænger': [('rstang', False)],
          'rstængerne': [('rstang', False)],
          'rstængernes': [('rstang', False)],
          'rstængers': [('rstang', False)],
          'rstævne': [('rstævn', False)],
          'rstævnes': [('rstævn', False)],
          'rstøvler': [('rstøvle', False)],
          'rstøvlerne': [('rstøvle', False)],
          'rstøvlernes': [('rstøvle', False)],
          'rsummer': [('rsum', False)],
          'rsummerne': [('rsum', False)],
          'rsummernes': [('rsum', False)],
          'rsummers': [('rsum', False)],
          'rsus': [('rsus', False)],
          'rsyren': [('rsyre', False)],
          'rsyrens': [('rsyre', False)],
          'rsæder': [('rsæde', False)],
          'rsæderne': [('rsæde', False)],
          'rsædernes': [('rsæde', False)],
          'rsæders': [('rsæde', False)],
          'rsætter': [('rsætter', False)],
          'rsætterne': [('rsæt', False)],
          'rsætternes': [('rsætter', False)],
          'rsætters': [('rsæt', False)],
          'rsøer': [('rsø', False)],
          'rsøerne': [('rsø', False)],
          'rsøernes': [('rsø', False)],
          'rsøers': [('rsø', False)],
          'rtage': [('rtag', False)],
          'rtagens': [('rtage', False)],
          'rtager': [('rtage', False)],
          'rtagere': [('rtager', False)],
          'rtageren': [('rtager', False)],
          'rtagerens': [('rtager', False)],
          'rtageres': [('rtager', False)],
          'rtagerne': [('rtage', False)],
          'rtagernes': [('rtage', False)],
          'rtagers': [('rtage', False)],
          'rtages': [('rtag', False)],
          'rtakter': [('rtakter', False)],
          'rtakterne': [('rtakter', False)],
          'rtakternes': [('rtakter', False)],
          'rtakters': [('rtakter', False)],
          'rtalens': [('rtale', False)],
          'rtalerne': [('rtal', False)],
          'rtalernes': [('rtal', False)],
          'rtallerne': [('rtal', False)],
          'rtallernes': [('rtal', False)],
          'rtan': [('rtan', False)],
          'rtanden': [('rtand', False)],
          'rtandens': [('rtand', False)],
          'rtanen': [('rtan', False)],
          'rtanerne': [('rtaner', False)],
          'rtanernes': [('rtaner', False)],
          'rtanet': [('rtan', False)],
          'rtanets': [('rtan', False)],
          'rtangen': [('rtang', False)],
          'rtangens': [('rtang', False)],
          'rtanke': [('rtanke', False)],
          'rtanken': [('rtanke', False)],
          'rtankens': [('rtanke', False)],
          'rtankes': [('rtanke', False)],
          'rtans': [('rtan', False)],
          'rtas': [('rta', False)],
          'rtater': [('rtat', False)],
          'rtaterne': [('rtat', False)],
          'rtaternes': [('rtat', False)],
          'rtaters': [('rtat', False)],
          'rtats': [('rtat', False)],
          'rtavlen': [('rtavle', False)],
          'rteater': [('rteater', False)],
          'rtegers': [('rtege', False)],
          'rteges': [('rtege', False)],
          'rtekster': [('rtekst', False)],
          'rteksterne': [('rtekst', False)],
          'rteksternes': [('rtekst', False)],
          'rteksters': [('rtekst', False)],
          'rtelen': [('rtel', False)],
          'rtelens': [('rtel', False)],
          'rtelets': [('rtelet', False)],
          'rtellerne': [('rtel', False)],
          'rtellernes': [('rtel', False)],
          'rten': [('rt', False)],
          'rtene': [('rt', False)],
          'rtenernes': [('rtener', False)],
          'rtenes': [('rt', False)],
          'rtens': [('rt', False)],
          'rter': [('rt', False)],
          'rterer': [('rter', False)],
          'rtererne': [('rter', False)],
          'rterernes': [('rter', False)],
          'rterers': [('rter', False)],
          'rteret': [('rter', False)],
          'rterets': [('rter', False)],
          'rterien': [('rterie', False)],
          'rteriens': [('rterie', False)],
          'rterier': [('rterie', False)],
          'rterierne': [('rterie', False)],
          'rteriernes': [('rterie', False)],
          'rteriers': [('rterie', False)],
          'rterne': [('rt', False)],
          'rterret': [('rterre', False)],
          'rters': [('rt', False)],
          "rtes'": [('rtes', False)],
          'rtet': [('rt', False)],
          'rteten': [('rtet', False)],
          'rtetens': [('rtet', False)],
          'rtets': [('rt', False)],
          'rthuset': [('rthus', False)],
          'rtiden': [('rtid', False)],
          'rtider': [('rtid', False)],
          'rtiderne': [('rtid', False)],
          'rtidernes': [('rtid', False)],
          'rtiders': [('rtid', False)],
          'rtids': [('rtid', False)],
          'rtien': [('rtie', False)],
          'rtiens': [('rtie', False)],
          'rtiere': [('rtiere', False)],
          'rtieres': [('rtiere', False)],
          'rtiernes': [('rtie', False)],
          'rties': [('rtie', False)],
          'rtiet': [('rtium', False)],
          'rtiets': [('rtium', False)],
          'rtilens': [('rtil', False)],
          'rtilisten': [('rtiliste', False)],
          'rtilistens': [('rtiliste', False)],
          'rtilister': [('rtiliste', False)],
          'rtilisterne': [('rtiliste', False)],
          'rtimer': [('rtime', False)],
          'rtimerne': [('rtime', False)],
          'rtimernes': [('rtime', False)],
          'rtimers': [('rtime', False)],
          'rtinen': [('rtin', False)],
          'rtiner': [('rtiner', False)],
          'rtinernes': [('rtiner', False)],
          'rtis': [('rti', False)],
          'rtisanen': [('rtisane', False)],
          'rtisanens': [('rtisane', False)],
          'rtisaner': [('rtisane', False)],
          'rtisanerne': [('rtisane', False)],
          'rtisanernes': [('rtisane', False)],
          'rtisaners': [('rtisan', False)],
          'rtits': [('rtit', False)],
          'rtium': [('rtium', False)],
          'rtiums': [('rtium', False)],
          'rtlens': [('rtel', False)],
          'rtler': [('rtel', False)],
          'rtner': [('rtner', False)],
          'rtnernes': [('rtner', False)],
          'rtners': [('rtner', False)],
          'rtningen': [('rtning', False)],
          'rtninger': [('rtning', False)],
          'rtningerne': [('rtning', False)],
          'rtningernes': [('rtning', False)],
          'rtoget': [('rtoget', False)],
          'rtogets': [('rtoget', False)],
          'rtoner': [('rtone', False)],
          'rtonerne': [('rtone', False)],
          'rtoners': [('rtone', False)],
          'rtonet': [('rton', False)],
          'rtonets': [('rton', False)],
          'rtorier': [('rtorium', False)],
          'rtoriernes': [('rtorium', False)],
          'rtorium': [('rtorium', False)],
          'rtoriums': [('rtorium', False)],
          'rtrene': [('rter', False)],
          'rtrenes': [('rter', False)],
          'rtrers': [('rtrer', False)],
          'rtres': [('rter', False)],
          'rtribunen': [('rtribune', False)],
          'rtribunens': [('rtribune', False)],
          'rtribuner': [('rtribune', False)],
          'rtribunerne': [('rtribune', False)],
          'rtribunernes': [('rtribune', False)],
          'rtribuners': [('rtribune', False)],
          'rtringens': [('rtring', False)],
          'rtropper': [('rtropper', False)],
          'rtropperne': [('rtrop', False)],
          'rtroppernes': [('rtrop', False)],
          'rtroppers': [('rtrop', False)],
          'rtros': [('rtro', False)],
          'rtroskopi': [('troskopi', False)],
          'rtræder': [('rtræder', False)],
          'rtræderne': [('rtræder', False)],
          'rtrædernes': [('rtræder', False)],
          'rtrætter': [('rtræt', False)],
          'rtrætterne': [('rtræt', False)],
          'rtrætternes': [('rtræt', False)],
          'rtrætters': [('rtræt', False)],
          'rts': [('rt', False)],
          'rtsdage': [('rtsdag', False)],
          'rtsdagene': [('rtsdag', False)],
          'rtsdagenes': [('rtsdag', False)],
          'rtsdages': [('rtsdag', False)],
          'rtsider': [('rtside', False)],
          'rtsiderne': [('rtside', False)],
          'rtsidernes': [('rtside', False)],
          'rtsiders': [('rtside', False)],
          'rtungens': [('rtunge', False)],
          'rtunger': [('rtunge', False)],
          'rtungerne': [('rtunge', False)],
          'rtungernes': [('rtunge', False)],
          'rture': [('rtur', False)],
          'rturen': [('rtur', False)],
          'rturene': [('rtur', False)],
          'rturer': [('rtur', False)],
          'rturerne': [('rtur', False)],
          'rturernes': [('rtur', False)],
          'rturers': [('rtur', False)],
          'rtures': [('rtur', False)],
          'rtyren': [('rtyr', False)],
          'rtyrens': [('rtyr', False)],
          'rtyrer': [('rtyr', False)],
          'rtyrerne': [('rtyr', False)],
          'rtyrernes': [('rtyr', False)],
          'rtyrers': [('rtyr', False)],
          'rtyve': [('rtyv', False)],
          'rtyves': [('rtyv', False)],
          'rtænder': [('rtand', False)],
          'rtænderne': [('rtænder', False)],
          'rtændernes': [('rtand', False)],
          'rtænders': [('rtænder', False)],
          'rtængernes': [('rtang', False)],
          'rtængers': [('rtang', False)],
          'rtøjers': [('rtøj', False)],
          'rtøjet': [('rtøj', False)],
          'rtører': [('rtør', False)],
          'rubben': [('rubbe', False)],
          'rubber': [('rubber', True)],
          'rubberne': [('rubber', True)],
          'rubbernes': [('rubber', True)],
          'rubbers': [('rubber', False)],
          'ruben': [('rub', False)],
          'rubens': [('rub', False)],
          'ruber': [('rub', False)],
          'ruberne': [('rub', False)],
          'rubernes': [('rub', False)],
          'rubers': [('rube', False)],
          'rubiner': [('rubin', True)],
          'rubiners': [('rubin', True)],
          'rublen': [('rubel', True)],
          'rubler': [('rubel', True)],
          'rublerne': [('rubel', True)],
          'rublernes': [('rubel', True)],
          'rublers': [('rubel', True)],
          'ruchen': [('ruche', True)],
          'ruchernes': [('ruche', True)],
          'rucker': [('rucker', False)],
          'ruckernes': [('rucker', False)],
          'rude': [('rude', False)],
          'ruden': [('rude', False)],
          'rudens': [('rude', False)],
          'ruder': [('rude', True), ('ruder', True)],
          'ruderne': [('ruder', True), ('rude', True)],
          'rudernes': [('ruder', True), ('rude', True)],
          'ruders': [('ruder', True), ('rude', True)],
          'rudes': [('rude', False)],
          'rudlen': [('rudel', True)],
          'rudlerne': [('rudel', True)],
          'rudlernes': [('rudel', True)],
          'ruds': [('ruds', False)],
          'rudse': [('ruds', False)],
          'rudsen': [('ruds', False)],
          'rudsens': [('ruds', False)],
          'rudses': [('ruds', False)],
          'rudstykker': [('rudstykke', False)],
          'rudstykkerne': [('rudstykke', False)],
          'rudstykkernes': [('rudstykke', False)],
          'rudstykkers': [('rudstykke', False)],
          'ruen': [('ru', False)],
          'ruens': [('ru', False)],
          'ruenserne': [('ruens', False)],
          'ruer': [('ru', False)],
          'ruerne': [('ru', False)],
          'ruernes': [('ru', False)],
          'ruet': [('ru', False)],
          'ruets': [('ru', False)],
          'ruetter': [('ruet', False)],
          'ruffer': [('ruffer', True)],
          'rufferne': [('ruffer', True)],
          'ruffernes': [('ruffer', True)],
          'ruffers': [('ruffer', True)],
          'ruffet': [('ruf', True)],
          'ruge': [('ruge', False)],
          'rugen': [('rug', True)],
          'rugens': [('rug', True)],
          'ruger': [('ruge', False)],
          'rugerne': [('ruger', False)],
          'rugernes': [('ruger', False)],
          'rugers': [('ruger', False)],
          'ruges': [('ruge', False)],
          'rugkiks': [('rugkiks', True)],
          'ruglens': [('rugle', False)],
          'ruglerne': [('rugle', False)],
          'rugs': [('rug', True)],
          "rugs'": [('rugs', False)],
          'rugter': [('rugt', False)],
          'rugterne': [('rugt', False)],
          'rugternes': [('rugt', False)],
          'rukkens': [('rukke', False)],
          'rukker': [('rukke', False)],
          'rukkerne': [('rukke', False)],
          'rukkernes': [('rukke', False)],
          'rukkers': [('rukke', False)],
          'ruks': [('ruks', False)],
          'rukserne': [('ruks', False)],
          'ruksernes': [('ruks', False)],
          'ruksers': [('ruks', False)],
          'rulden': [('ruld', False)],
          'ruldens': [('ruld', False)],
          'rullens': [('rulle', True)],
          'ruller': [('rulle', True)],
          'rullerne': [('rulle', False)],
          'rullernes': [('rulle', True)],
          'rullers': [('rulle', True)],
          'rum': [('rum', False)],
          'ruma': [('ruma', False)],
          'rumas': [('ruma', False)],
          'rumlen': [('rummel', True)],
          'rumlens': [('rummel', True)],
          'rumler': [('rummel', False)],
          'rumlerne': [('rummel', False)],
          'rumlernes': [('rummel', False)],
          'rumlers': [('rummel', False)],
          'rumme': [('rum', False)],
          'rummen': [('rum', False)],
          'rummens': [('rum', False)],
          'rummerne': [('rummer', False)],
          'rummernes': [('rum', False)],
          'rummers': [('rum', False)],
          'rummes': [('rum', False)],
          'rummet': [('rum', True)],
          'rummets': [('rum', True)],
          'rumpernes': [('rumpe', False)],
          'rumpers': [('rumpe', True)],
          'rums': [('rum', False)],
          'runde': [('runde', True)],
          'runden': [('runde', True)],
          'rundens': [('runde', True)],
          'runder': [('runde', False)],
          'runderne': [('runde', False)],
          'rundernes': [('runde', False)],
          'runders': [('runde', True)],
          'rundes': [('runde', True)],
          'rundier': [('rundier', False)],
          'rundierne': [('rundium', False)],
          'rundiernes': [('rundium', False)],
          'rundiers': [('rundier', False)],
          'rundkurser': [('rundkursus', False)],
          'rundkurserne': [('rundkursus', False)],
          'rundkursernes': [('rundkursus', False)],
          'runen': [('rune', False)],
          'runens': [('rune', False)],
          'runer': [('rune', False)],
          'runerne': [('rune', True)],
          'runernes': [('rune', False)],
          'runers': [('rune', True)],
          'runken': [('runk', False)],
          'runkerne': [('runker', False)],
          'runkers': [('runker', False)],
          'runnerne': [('runner', True)],
          'runnernes': [('runner', True)],
          'runs': [('run', True)],
          'runter': [('runte', False)],
          'runternes': [('runte', False)],
          'rupier': [('rupi', True)],
          'rupierne': [('rupi', True)],
          'rupiers': [('rupi', True)],
          'rupler': [('rupel', False)],
          'ruplerne': [('rupler', False)],
          'ruplernes': [('rupel', False)],
          'ruplers': [('rupler', False)],
          'ruppe': [('rup', False)],
          'ruppen': [('rup', False)],
          'ruppens': [('rup', False)],
          'rupper': [('ruppe', False)],
          'rupperne': [('rup', False)],
          'ruppernes': [('ruppe', False)],
          'ruppers': [('rup', False)],
          'ruppes': [('ruppe', False)],
          'ruret': [('rur', False)],
          'rurets': [('rur', False)],
          'rurger': [('rurg', False)],
          'rurgernes': [('rurg', False)],
          'rurgers': [('rurg', False)],
          'rurs': [('rur', True)],
          'rus': [('rus', True)],
          'ruse': [('rus', True), ('ruse', True)],
          'rusen': [('rus', True), ('ruse', True)],
          'rusens': [('rus', True), ('ruse', True)],
          'ruser': [('ruse', False)],
          'ruserne': [('ruse', False)],
          'rusernes': [('ruse', True)],
          'rusers': [('ruse', True)],
          'ruses': [('ruse', True), ('rus', True)],
          'rusher': [('rush', False)],
          'rusherne': [('rush', False)],
          'rushernes': [('rush', False)],
          'rushers': [('rush', False)],
          'ruske': [('rusk', False)],
          'rusken': [('rusk', False)],
          'rusker': [('rusker', False)],
          'ruskerne': [('rusker', False)],
          'ruslens': [('russel', False)],
          'russen': [('rus', False)],
          'russens': [('rus', False)],
          'russer': [('russer', True), ('rus', True)],
          'russerne': [('russer', True), ('rus', True)],
          'russernes': [('rus', True), ('russer', True)],
          'russers': [('rus', True), ('russer', True)],
          'rusten': [('rust', True)],
          'rustens': [('rust', False)],
          'ruster': [('rust', False)],
          'rusterne': [('rust', False)],
          'rusternes': [('rust', False)],
          'rusters': [('rust', False)],
          'ruten': [('rute', True)],
          'rutens': [('rute', True)],
          'ruterne': [('rute', False)],
          'ruternes': [('rute', False)],
          'ruters': [('rute', False)],
          'rutten': [('rut', False)],
          'ruttens': [('rut', False)],
          'rutterne': [('rut', False)],
          'rutternes': [('rut', False)],
          'rutters': [('rut', False)],
          'rvalse': [('rvals', False)],
          'rvalsen': [('rvals', False)],
          'rvalsens': [('rvals', False)],
          'rvalses': [('rvals', False)],
          'rvander': [('rvand', False)],
          'rvanders': [('rvand', False)],
          'rvans': [('rvans', False)],
          'rvarers': [('rvare', False)],
          'rvater': [('rvat', False)],
          'rve': [('rv', False)],
          'rvedage': [('rvedag', False)],
          'rvedagene': [('rvedag', False)],
          'rvedagenes': [('rvedag', False)],
          'rvedages': [('rvedag', False)],
          'rvehals': [('rvehal', False)],
          'rvejen': [('rvej', False)],
          'rvejens': [('rvej', False)],
          'rvejes': [('rvej', False)],
          'rven': [('rv', False)],
          'rvene': [('rv', False)],
          'rvenes': [('rv', False)],
          'rvens': [('rv', False)],
          'rverens': [('rver', False)],
          'rves': [('rv', False)],
          "rves'": [('rves', False)],
          'rvesagernes': [('rvesag', False)],
          'rvesagers': [('rvesag', False)],
          'rvet': [('rv', False)],
          'rvets': [('rv', False)],
          'rvetter': [('rvet', False)],
          'rvetterne': [('rvet', False)],
          'rvetters': [('rvet', False)],
          'rviet': [('rviet', False)],
          'rviets': [('rviet', False)],
          'rvikken': [('rvikke', False)],
          'rvikker': [('rvikke', False)],
          'rvine': [('rvin', False)],
          'rvinen': [('rvin', False)],
          'rvines': [('rvin', False)],
          'rvingen': [('rving', False)],
          'rvingens': [('rving', False)],
          'rvinger': [('rving', False)],
          'rvingerne': [('rving', False)],
          'rvingernes': [('rving', False)],
          'rvingers': [('rving', False)],
          'rvins': [('rvin', False)],
          'rvippen': [('rvippe', False)],
          'rvippens': [('rvippe', False)],
          'rvipper': [('rvippe', False)],
          'rvipperne': [('rvippe', False)],
          'rviser': [('rviser', False)],
          'rviserne': [('rviser', False)],
          'rvisernes': [('rviser', False)],
          'rvisers': [('rviser', False)],
          'rvlen': [('rvel', False)],
          'rvlens': [('rvel', False)],
          'rvoksen': [('rvoks', False)],
          'rvoksens': [('rvoks', False)],
          'rvolten': [('rvolt', False)],
          'rvoltens': [('rvolt', False)],
          'rvolter': [('rvolt', False)],
          'rvolterne': [('rvolt', False)],
          'rvolternes': [('rvolt', False)],
          'rvolters': [('rvolt', False)],
          'rvs': [('rv', False)],
          'rvåger': [('rvåger', False)],
          'rvågerne': [('rvåger', False)],
          'rvågernes': [('rvåger', False)],
          'rvågers': [('rvåger', False)],
          'rvældet': [('rvælde', False)],
          'rvældets': [('rvælde', False)],
          'rværker': [('rværker', False)],
          'rværkerne': [('rværker', False)],
          'rværkernes': [('rværker', False)],
          'rværkers': [('rværker', False)],
          'rværs': [('rvær', False)],
          'ryde': [('ryde', False)],
          'ryden': [('ryde', False)],
          'rydens': [('ryde', False)],
          'ryder': [('ryder', False)],
          'ryderne': [('ryder', False)],
          'rydernes': [('ryde', False)],
          'ryders': [('ryde', False)],
          'rydes': [('ryde', False)],
          'ryds': [('ryds', False)],
          'ryen': [('ry', False)],
          'ryens': [('ry', False)],
          'ryer': [('ry', False)],
          'ryerne': [('ry', False)],
          'ryernes': [('ry', False)],
          'ryers': [('ry', False)],
          'ryfen': [('ryf', False)],
          'ryfer': [('ryf', False)],
          'ryferne': [('ryf', False)],
          'rygerne': [('ryger', False)],
          'rygernes': [('ryger', False)],
          'rygers': [('ryger', False)],
          'rygge': [('ryg', False)],
          'ryggen': [('ryg', False)],
          'ryggens': [('ryg', False)],
          'rygges': [('ryg', False)],
          'rygten': [('rygt', False)],
          'rygtens': [('rygt', False)],
          'rykken': [('ryk', False)],
          'rykkens': [('rykke', False)],
          'rykker': [('rykker', False)],
          'rykkerne': [('rykker', True)],
          'rykkernes': [('rykker', True)],
          'rykkers': [('rykker', False)],
          'ryle': [('ryle', True)],
          'rylen': [('ryle', True)],
          'rylene': [('rylene', False)],
          'rylenen': [('rylene', False)],
          'rylenens': [('rylene', False)],
          'rylenets': [('rylene', False)],
          'rylens': [('ryle', True)],
          'ryler': [('ryle', True)],
          'rylere': [('ryl', False)],
          'ryleren': [('ryl', False)],
          'rylerens': [('ryl', False)],
          'ryleres': [('ryl', False)],
          'rylerne': [('ryle', True)],
          'rylernes': [('ryle', True)],
          'rylers': [('ryle', True)],
          'ryles': [('ryle', True)],
          'ryllen': [('ryl', False)],
          'ryller': [('ryl', False)],
          'ryllers': [('ryl', False)],
          'rynen': [('ryne', False)],
          'rynens': [('ryne', False)],
          'ryner': [('ryne', False)],
          'rynerne': [('ryn', False)],
          'rynernes': [('ryne', False)],
          'ryners': [('ryn', False)],
          'ryns': [('ryns', False)],
          'rypen': [('rype', False)],
          'ryper': [('rype', True)],
          'ryperne': [('rype', False)],
          'rypterne': [('rypt', False)],
          'rypternes': [('rypt', False)],
          'rypters': [('rypt', False)],
          'rys': [('ry', False)],
          'rysers': [('ryser', False)],
          'rysler': [('rysler', True)],
          'ryslernes': [('rysler', True)],
          'rystens': [('rysten', False)],
          'ryster': [('ryster', True)],
          'rysterne': [('ryster', True)],
          'rysternes': [('ryster', False)],
          'rysters': [('ryster', True)],
          'rytler': [('rytle', False)],
          'rytlerne': [('rytle', False)],
          'rytlernes': [('rytle', False)],
          'rytter': [('rytter', False)],
          'rytterne': [('rytter', False)],
          'rytters': [('rytter', False)],
          'rziner': [('rzine', False)],
          'rzinerne': [('rzine', False)],
          'rziners': [('rzine', False)],
          'rzoens': [('rzo', False)],
          'rzoner': [('rzoner', False)],
          'rzoners': [('rzoner', False)],
          'råber': [('råber', False)],
          'råberne': [('råber', True)],
          'råbernes': [('råber', False)],
          'råbers': [('råber', True)],
          'råbnerne': [('råbner', False)],
          'råde': [('råde', False)],
          'råden': [('råde', False)],
          'rådens': [('råde', False)],
          'råder': [('råd', False)],
          'råderne': [('råd', False)],
          'rådernes': [('råd', False)],
          'råders': [('råde', False)],
          'rådes': [('råde', False)],
          'rådet': [('råd', True)],
          'rådets': [('råd', False)],
          'råen': [('rå', False)],
          'råens': [('rå', True)],
          'råer': [('rå', False)],
          'råerne': [('rå', False)],
          'råernes': [('rå', False)],
          'råers': [('rå', False)],
          'råge': [('råge', True)],
          'rågen': [('råge', True)],
          'råger': [('råge', True)],
          'rågers': [('råge', True)],
          'råle': [('råle', False)],
          'rålen': [('råle', False)],
          'rålens': [('råle', False)],
          'råler': [('råle', False)],
          'rålerne': [('rål', False)],
          'rålernes': [('råle', False)],
          'rålers': [('råle', False)],
          'råles': [('råle', False)],
          'råplanet': [('råplan', False)],
          'råplanets': [('råplan', False)],
          'rås': [('rå', False)],
          'råse': [('råse', False)],
          'råsen': [('råse', False)],
          'råsens': [('råse', False)],
          'råser': [('råse', False)],
          'råserne': [('råse', False)],
          'råsernes': [('råse', False)],
          'råsers': [('råser', False)],
          'råses': [('råse', False)],
          'ræben': [('ræben', False)],
          'ræbens': [('ræben', False)],
          'ræber': [('ræber', False)],
          'ræbernes': [('ræber', False)],
          'ræbler': [('ræble', False)],
          'rædder': [('rædder', False)],
          'rædderne': [('rædder', False)],
          'ræddernes': [('rædder', False)],
          'rædders': [('rædder', False)],
          'ræden': [('ræden', False)],
          'rædens': [('ræden', False)],
          'ræder': [('ræder', False)],
          'ræderne': [('ræder', False)],
          'rædernes': [('ræder', False)],
          'ræer': [('rå', True)],
          'ræerne': [('rå', True)],
          'ræernes': [('rå', True)],
          'ræers': [('rå', True)],
          'ræet': [('ræ', False)],
          'ræets': [('ræ', False)],
          'ræge': [('ræge', False)],
          'rægen': [('ræge', False)],
          'ræger': [('ræge', False)],
          'rækken': [('række', True)],
          'rækkens': [('række', False)],
          'rækker': [('række', True)],
          'rækkerne': [('række', False)],
          'rækkernes': [('række', False)],
          'rækkers': [('række', False)],
          'rælder': [('rælder', False)],
          'rælders': [('rælder', False)],
          'rælet': [('ræl', False)],
          'rælets': [('ræl', False)],
          'rælle': [('ræl', False)],
          'rællen': [('ræl', False)],
          'rælles': [('ræl', False)],
          'ræmien': [('ræmi', False)],
          'ræmiens': [('ræmi', False)],
          'ræmier': [('ræmi', False)],
          'ræmierne': [('ræmi', False)],
          'ræmiernes': [('ræmi', False)],
          'ræmiers': [('ræmi', False)],
          'ræmis': [('ræmis', False)],
          'ræmmer': [('ræmmer', False)],
          'ræmmerne': [('ræmmer', False)],
          'ræmmernes': [('ræmme', False)],
          'ræmmers': [('ræmme', False)],
          'rænder': [('rænder', False)],
          'rændere': [('rænder', False)],
          'rænderen': [('rænder', False)],
          'rænderens': [('rænder', False)],
          'rænderes': [('rænder', False)],
          'rænderne': [('rænder', False)],
          'rændernes': [('rænder', False)],
          'rænders': [('rænde', False)],
          'rænen': [('ræne', False)],
          'rænens': [('ræne', False)],
          'ræner': [('ræne', False)],
          'rænerne': [('ræner', False)],
          'rænernes': [('ræne', False)],
          'ræners': [('ræner', False)],
          'rængen': [('rængen', False)],
          'rængens': [('rængen', False)],
          'rængernes': [('rænger', False)],
          'rængers': [('rænger', False)],
          'rænkens': [('rænke', True)],
          'rænker': [('rænke', True)],
          'rænkerne': [('rænke', True)],
          'rænkernes': [('rænke', True)],
          'rænkers': [('rænke', True)],
          'ræppes': [('ræppe', False)],
          'rærtens': [('rært', False)],
          'rærterne': [('rært', False)],
          'ræs': [('ræs', True)],
          'ræsens': [('ræsens', False)],
          'ræsers': [('ræser', False)],
          'ræsser': [('ræs', False)],
          'ræsserne': [('ræs', False)],
          'ræstens': [('ræst', False)],
          'ræster': [('ræst', False)],
          'ræsterne': [('ræst', False)],
          'ræsternes': [('ræst', False)],
          'ræsters': [('ræst', False)],
          'ræten': [('ræte', False)],
          'rætens': [('ræte', False)],
          'ræter': [('ræte', False)],
          'ræterne': [('ræte', False)],
          'ræternes': [('ræte', False)],
          'ræters': [('ræte', False)],
          'rætten': [('ræt', False)],
          'rættens': [('ræt', False)],
          'rætter': [('ræt', False)],
          'rætternes': [('ræt', False)],
          'rætters': [('ræt', False)],
          'rætylen': [('rætylen', False)],
          'rætylens': [('rætylen', False)],
          'rævlen': [('rævl', False)],
          'rævlens': [('rævl', False)],
          'rævlers': [('rævl', False)],
          'røbo': [('røbo', False)],
          'røboen': [('røbo', False)],
          'røboens': [('røbo', False)],
          'røboer': [('røbo', False)],
          'røboerne': [('røbo', False)],
          'røboernes': [('røbo', False)],
          'røboers': [('røbo', False)],
          'røbos': [('røbo', False)],
          'røden': [('røde', False)],
          'rødens': [('røde', False)],
          'rødet': [('rød', False)],
          'rødets': [('rød', False)],
          'rødler': [('rødler', True)],
          'rødlers': [('rødler', True)],
          'rødsdage': [('rødsdage', False)],
          'rødsdagene': [('rødsdage', False)],
          'rødsdagenes': [('rødsdage', False)],
          'rødsdages': [('rødsdage', False)],
          'røen': [('rø', False)],
          'røer': [('rø', False)],
          'røerne': [('rø', False)],
          'røernes': [('rø', False)],
          'røers': [('rø', False)],
          'røfterne': [('røft', False)],
          'røfternes': [('røft', False)],
          'røfters': [('røft', False)],
          'røgerne': [('røger', True)],
          'røgernes': [('røger', True)],
          'røgers': [('røger', True)],
          'røje': [('røje', False)],
          'røjen': [('røje', False)],
          'røjens': [('røje', False)],
          'røjerne': [('røje', False)],
          'røjernes': [('røje', False)],
          'røjers': [('røje', False)],
          'røjes': [('røje', False)],
          'røjet': [('røje', False)],
          'røjter': [('røjte', False)],
          'røjterne': [('røjte', False)],
          'røjternes': [('røjte', False)],
          'røken': [('røken', False)],
          'røkens': [('røken', False)],
          'røkerne': [('røk', False)],
          'røkernes': [('røk', False)],
          'røkers': [('røk', False)],
          'rølet': [('røl', False)],
          'røllen': [('røl', False)],
          'røllens': [('rølle', False)],
          'røller': [('røl', False)],
          'røllerne': [('rølle', False)],
          'røllernes': [('rølle', False)],
          'røllers': [('røl', False)],
          'rømme': [('røm', False)],
          'rømmen': [('røm', False)],
          'rømmens': [('røm', False)],
          'rømmer': [('rømmer', False)],
          'rømmerne': [('rømmer', False)],
          'rømmes': [('røm', False)],
          'rønde': [('rønd', False)],
          'rønden': [('rønd', False)],
          'røndens': [('rønd', False)],
          'røndes': [('rønd', False)],
          'rønen': [('røne', False)],
          'rønens': [('røne', False)],
          'røner': [('røne', False)],
          'rønernes': [('røne', False)],
          'røniker': [('rønike', False)],
          'rønikerne': [('rønike', False)],
          'rønikernes': [('rønike', False)],
          'rønikers': [('rønike', False)],
          'rønne': [('rønne', True), ('røn', True)],
          'rønnen': [('rønne', True), ('røn', True)],
          'rønnens': [('røn', True), ('rønne', True)],
          'rønnernes': [('rønne', True)],
          'rønnes': [('rønne', True), ('røn', True)],
          'røre': [('røre', True)],
          'rørene': [('rør', False)],
          'rørenes': [('rør', False)],
          'rører': [('rører', False)],
          'rørerne': [('rører', False)],
          'rørernes': [('rører', False)],
          'rørers': [('rører', False)],
          'røres': [('røre', True)],
          'røret': [('røre', True), ('rør', True)],
          'rørets': [('røre', True), ('rør', True)],
          'rørne': [('rørn', False)],
          'rørnenes': [('rørn', False)],
          'rørnes': [('rørn', False)],
          'røs': [('rø', False)],
          'røse': [('røse', True)],
          'røser': [('røse', True)],
          'røsernes': [('røse', True)],
          'røsers': [('røse', True)],
          'røsken': [('røsken', True)],
          'røskens': [('røsken', True)],
          'røsten': [('røst', False)],
          'røstens': [('røst', False)],
          'røster': [('røst', True)],
          'røsterne': [('røst', False)],
          'røsternes': [('røst', False)],
          'røsters': [('røst', False)],
          'røve': [('røv', True)],
          'røven': [('røv', True)],
          'røvens': [('røv', True)],
          'røver': [('røver', True)],
          'røverne': [('røver', True)],
          'røvernes': [('røver', True)],
          'røvers': [('røver', True)],
          'røves': [('røv', True)],
          'røvlet': [('røvl', False)],
          'røvlets': [('røvl', False)],
          's': [('s', True)],
          's fritene': [(' frite', False)],
          's fritenes': [(' frite', False)],
          's frites': [(' frite', False)],
          "s frites'": [(' frite', False)],
          "s'": [('s', True)],
          "s'erne": [('s', False)],
          'sa': [('sa', False)],
          'sabe': [('sabe', False)],
          'sabens': [('sabe', False)],
          'sabernes': [('sabe', False)],
          'sabes': [('sabe', False)],
          'sabis': [('sabi', False)],
          'sabler': [('sabel', True)],
          'sablerne': [('sabel', True)],
          'sablernes': [('sabel', False)],
          'sablers': [('sabel', False)],
          'sacks': [('sack', False)],
          "sacks'": [('sack', False)],
          'sade': [('sade', False)],
          'saden': [('sade', False)],
          'sadens': [('sade', False)],
          'saderne': [('sade', False)],
          'saders': [('sade', False)],
          'sades': [('sade', False)],
          'sadlen': [('saddel', True), ('sadel', True)],
          'sadlens': [('saddel', True), ('sadel', True)],
          'sadler': [('saddel', True), ('sadel', True)],
          'sadlerne': [('sadel', True), ('saddel', True)],
          'sadlernes': [('sadel', True), ('saddel', True)],
          'sadlers': [('sadel', True), ('saddel', True)],
          'saen': [('sa', False)],
          'saens': [('sa', False)],
          'saer': [('sa', False)],
          'saerne': [('sa', False)],
          'saernes': [('sa', False)],
          'saers': [('sa', False)],
          'saftalens': [('saftale', False)],
          'saften': [('saft', False)],
          'saftens': [('saft', False)],
          'safterne': [('saft', False)],
          'safternes': [('saft', False)],
          'safters': [('saft', False)],
          'sage': [('sage', False)],
          'sagen': [('sag', True)],
          'sagens': [('sag', False)],
          'sager': [('sag', False)],
          'sagerer': [('sager', False)],
          'sagerne': [('sag', False)],
          'sagernes': [('sag', True)],
          'sagers': [('sag', True)],
          'sages': [('sage', False)],
          'sagnen': [('sagne', False)],
          'sagnens': [('sagne', False)],
          'sagnet': [('sagn', False)],
          'sagnets': [('sagn', False)],
          'sagter': [('sagt', False)],
          'sagterne': [('sagt', False)],
          'sagternes': [('sagt', False)],
          'sais': [('sai', False)],
          'sakes': [('sake', True)],
          'sakke': [('sak', False)],
          'sakken': [('sak', False)],
          'sakkerne': [('sak', False)],
          'sakkes': [('sak', False)],
          'saks': [('saks', True)],
          "saks'": [('saks', False)],
          'sakse': [('saks', False)],
          'saksen': [('saks', False)],
          'saksens': [('saks', False)],
          'sakser': [('sakser', True)],
          'sakserne': [('sakser', True)],
          'saksernes': [('sakser', True)],
          'saksers': [('sakser', False)],
          'sakses': [('saks', False)],
          'sakter': [('sakt', False)],
          'sakternes': [('sakt', False)],
          'sakters': [('sakt', False)],
          'salas': [('sala', False)],
          'salders': [('salder', False)],
          'sale': [('sal', False)],
          'salen': [('sal', False)],
          'salene': [('sal', False)],
          'salenes': [('sal', True)],
          'salens': [('sal', False)],
          'sales': [('sal', False)],
          'salien': [('salie', False)],
          'saliens': [('salie', False)],
          'salier': [('salie', False)],
          'salierne': [('sal', False)],
          'saliernes': [('sal', False)],
          'saliers': [('salie', False)],
          'sallen': [('sal', False)],
          'sallens': [('sal', False)],
          'saller': [('sal', False)],
          'sallers': [('sal', False)],
          'salte': [('salt', False)],
          'saltens': [('salt', False)],
          'salter': [('salt', False)],
          'salterne': [('salt', False)],
          'salternes': [('salter', False)],
          'salters': [('salter', False)],
          'saltes': [('salt', True)],
          'salver': [('salve', True)],
          'salverne': [('salve', True)],
          'salvernes': [('salve', True)],
          'salvers': [('salve', True)],
          'samen': [('same', True)],
          'samens': [('same', True)],
          'samer': [('same', True)],
          'samerne': [('same', True)],
          'samernes': [('same', True)],
          'saminer': [('samin', False)],
          'saminerne': [('samin', False)],
          'saminernes': [('samin', False)],
          'saminers': [('samin', False)],
          'sammen': [('sam', False)],
          'sammens': [('sam', False)],
          'sammer': [('sam', False)],
          'sammerne': [('sam', False)],
          'sammernes': [('sam', False)],
          'sammers': [('sam', False)],
          'sampels': [('sampels', False)],
          'sampler': [('sampler', True)],
          'samplerne': [('sampler', True)],
          'samplernes': [('sampler', True)],
          'samplers': [('sampler', True)],
          'sandaler': [('sandal', False)],
          'sandalers': [('sandal', True)],
          'sanden': [('sand', False)],
          'sandens': [('sand', False)],
          'sanderne': [('sande', False)],
          'sandernes': [('sande', False)],
          'sanders': [('sand', False)],
          'sandet': [('sand', True)],
          'sandets': [('sand', False)],
          'sane': [('sane', False)],
          'sanen': [('san', False)],
          'sanens': [('san', False)],
          'saner': [('san', False)],
          'sanerne': [('san', False)],
          'sanernes': [('san', False)],
          'sanes': [('sane', False)],
          'sange': [('sang', False)],
          'sangen': [('sang', False)],
          'sangens': [('sang', True)],
          'sanger': [('sanger', True)],
          'sangerne': [('sanger', False)],
          'sangernes': [('sanger', True)],
          'sangers': [('sanger', False)],
          'sanges': [('sang', False)],
          'sans': [('sans', False)],
          "sans'": [('sans', False)],
          'sansen': [('sans', False)],
          'sansens': [('sans', False)],
          'sanser': [('sans', True)],
          'sansernes': [('sans', True)],
          'sansers': [('sans', True)],
          'santen': [('sant', False)],
          'santens': [('sant', False)],
          'santerne': [('sant', False)],
          'santernes': [('sant', False)],
          'santers': [('sant', False)],
          'sants': [('sant', False)],
          'sappernes': [('sapp', False)],
          'sappers': [('sapp', False)],
          'sarbejder': [('sarbejder', False)],
          'sarbejderne': [('sarbejder', False)],
          'sarbejdernes': [('sarbejder', False)],
          'sarbejders': [('sarbejde', False)],
          'sarden': [('sard', False)],
          'sarder': [('sarder', True)],
          'sarderne': [('sarder', True)],
          'sardernes': [('sarder', True)],
          'sarders': [('sarder', True)],
          'sardinen': [('sardin', True)],
          'sardinens': [('sardin', True)],
          'sardiner': [('sardin', True)],
          'sardinernes': [('sardin', True)],
          'sarerne': [('sar', False)],
          'sarers': [('sar', False)],
          'sarge': [('sarg', True)],
          'sargen': [('sarg', True)],
          'sargens': [('sarg', True)],
          'sarger': [('sarg', True)],
          'sargernes': [('sarg', True)],
          'sargers': [('sarg', True)],
          'sarges': [('sarg', True)],
          'sarien': [('sari', True)],
          'sariens': [('sari', True)],
          'sarier': [('sari', True)],
          'sarierne': [('sari', True)],
          'sariernes': [('sari', True)],
          'sariers': [('sari', True)],
          'sariet': [('sarium', False)],
          'sariets': [('sarium', False)],
          'saris': [('sari', True)],
          'sarten': [('sart', False)],
          'sarter': [('sart', False)],
          'sarterne': [('sart', False)],
          'sarven': [('sarv', False)],
          'sarvens': [('sarv', False)],
          'sas': [('sa', False)],
          'saternes': [('sat', False)],
          'satiner': [('satin', True)],
          'satinerne': [('satin', True)],
          'satinernes': [('satin', True)],
          'satros': [('satro', False)],
          'sats': [('sats', False)],
          "sats'": [('sats', False)],
          'saurer': [('saur', False)],
          'saurerne': [('saur', False)],
          'saurernes': [('saur', False)],
          'saurers': [('saur', False)],
          'sauternes': [('sauterne', True), ('sauternes', True)],
          'save': [('sav', False)],
          'savene': [('sav', True)],
          'savenes': [('sav', False)],
          'savers': [('saver', False)],
          'saves': [('sav', False)],
          'sballer': [('sbal', False)],
          'sballerne': [('sbal', False)],
          'sballernes': [('sbal', False)],
          'sballers': [('sbal', False)],
          'sballet': [('sbal', False)],
          'sballets': [('sbal', False)],
          'sbanke': [('sbanke', False)],
          'sbanken': [('sbank', False)],
          'sbankens': [('sbanke', False)],
          'sbanker': [('sbank', False)],
          'sbankerne': [('sbanke', False)],
          'sbankernes': [('sbanke', False)],
          'sbankers': [('sbanke', False)],
          'sbankes': [('sbanke', False)],
          'sbars': [('sbar', False)],
          'sbas': [('sba', False)],
          'sbenets': [('sben', False)],
          'sberger': [('sberger', False)],
          'sbergernes': [('sberger', False)],
          'sbergers': [('sberger', False)],
          'sbestens': [('sbest', False)],
          'sbilens': [('sbil', False)],
          'sbilernes': [('sbil', False)],
          'sbilers': [('sbil', False)],
          'sblas': [('sblas', False)],
          'sblus': [('sblus', False)],
          'sblænders': [('sblænde', False)],
          'sboernes': [('sbo', False)],
          'sboers': [('sbo', False)],
          'sbogen': [('sbog', False)],
          'sboghandler': [('sboghandler', False)],
          'sboghandlerne': [('sboghandler', False)],
          'sboghandlernes': [('sboghandler', False)],
          'sboghandlers': [('sboghandler', False)],
          'sbonden': [('sbond', False)],
          'sbondens': [('sbond', False)],
          'sboret': [('sbor', False)],
          'sborets': [('sbor', False)],
          'sborger': [('sborger', False)],
          'sborgers': [('sborger', False)],
          'sbredder': [('sbred', False)],
          'sbredderne': [('sbred', False)],
          'sbreddernes': [('sbred', False)],
          'sbredders': [('sbred', False)],
          'sbriks': [('sbrik', False)],
          'sbroder': [('sbroder', False)],
          'sbroderen': [('sbror', False)],
          'sbroderens': [('sbroder', False)],
          'sbroders': [('sbroder', False)],
          'sbroer': [('sbro', False)],
          'sbroers': [('sbro', False)],
          'sbrugs': [('sbrug', False)],
          'sbrødre': [('sbroder', False)],
          'sbrødrene': [('sbroder', False)],
          'sbrødrenes': [('sbroder', False)],
          'sbrødres': [('sbroder', False)],
          'sbuen': [('sbue', False)],
          'sbuens': [('sbue', False)],
          'sbuks': [('sbuk', False)],
          'sbukser': [('sbukser', False)],
          'sbukserne': [('sbukser', False)],
          'sbuksernes': [('sbukser', False)],
          'sbuksers': [('sbukser', False)],
          'sbyrden': [('sbyrde', False)],
          'sbyrdens': [('sbyrde', False)],
          'sbælter': [('sbælte', False)],
          'sbælterne': [('sbælte', False)],
          'sbælternes': [('sbælte', False)],
          'sbælters': [('sbælte', False)],
          'sbæltet': [('sbælte', False)],
          'sbæltets': [('sbælte', False)],
          'sbønnen': [('sbønne', False)],
          'sbønnens': [('sbøn', False)],
          'sbønner': [('sbøn', False)],
          'sbønnerne': [('sbønne', False)],
          'sbønnernes': [('sbøn', False)],
          'sbønners': [('sbønne', False)],
          'sbørs': [('sbørs', False)],
          'scellen': [('scelle', False)],
          'sceller': [('scelle', False)],
          'scellers': [('scelle', False)],
          'scens': [('scens', False)],
          'scenter': [('scenter', False)],
          'scenters': [('scenter', False)],
          'scentre': [('scenter', False)],
          'scentrene': [('scenter', False)],
          'scentrenes': [('scenter', False)],
          'scentres': [('scenter', False)],
          'scentret': [('scenter', False)],
          'scentrets': [('scenter', False)],
          'scepters': [('scepter', True)],
          "sces'": [('sces', False)],
          'sche': [('sche', False)],
          'scher': [('scher', False)],
          'scherne': [('scher', False)],
          'schernes': [('sch', False)],
          'schers': [('scher', False)],
          'sches': [('sche', False)],
          'scissen': [('scisse', False)],
          'scissens': [('scisse', False)],
          'scisser': [('scisse', False)],
          'scisserne': [('scisse', False)],
          'scissernes': [('scisse', False)],
          'scissers': [('scisse', False)],
          'scisterne': [('scist', False)],
          'scisternes': [('scist', False)],
          'scits': [('scit', False)],
          'scitter': [('scit', False)],
          'scitterne': [('scit', False)],
          'scorer': [('score', True)],
          'scorerne': [('score', True)],
          'scorernes': [('score', False)],
          'scorers': [('score', True)],
          'scripter': [('scripter', True), ('script', True)],
          'scripterne': [('script', True), ('scripter', True)],
          'scripternes': [('script', True), ('scripter', True)],
          'scripters': [('script', True), ('scripter', True)],
          'sculotten': [('sculot', False)],
          'sculottens': [('sculot', False)],
          'sculotter': [('sculot', False)],
          'sculotterne': [('sculot', False)],
          'sculotternes': [('sculot', False)],
          'sculotters': [('sculot', False)],
          'scyklen': [('scykel', False)],
          'scyklens': [('scyklus', False)],
          'scykler': [('scyklus', False)],
          'scyklerne': [('scyklus', False)],
          'scyklernes': [('scykel', False)],
          'scyklers': [('scykel', False)],
          'sd': [('sd', False)],
          'sdage': [('sdag', False)],
          'sdagen': [('sdag', False)],
          'sdagene': [('sdag', False)],
          'sdagenes': [('sdag', False)],
          'sdages': [('sdag', False)],
          'sdaler': [('sdaler', False)],
          'sdele': [('sdel', False)],
          'sdelene': [('sdel', False)],
          'sdeles': [('sdel', False)],
          'sdiskrimination': [('sdiskrimination', False)],
          'sdiskriminationen': [('sdiskrimination', False)],
          'sdiskriminationens': [('sdiskrimination', False)],
          'sdiskriminations': [('sdiskrimination', False)],
          'sdomme': [('sdom', False)],
          'sdrenge': [('sdreng', False)],
          'sdrengene': [('sdreng', False)],
          'sdrengenes': [('sdreng', False)],
          'sdrenges': [('sdreng', False)],
          'sdrikke': [('sdrik', False)],
          'sdråbers': [('sdråbe', False)],
          'sduen': [('sdue', False)],
          'sduernes': [('sdue', False)],
          'sdukkens': [('sdukke', False)],
          'sdækker': [('sdække', False)],
          'sdækket': [('sdæk', False)],
          'sdækkets': [('sdæk', False)],
          'se': [('se', False)],
          'seaksen': [('seakse', False)],
          'seaksens': [('seakse', False)],
          'seanerne': [('seaner', False)],
          'seanernes': [('seaner', False)],
          'seaternes': [('seater', False)],
          'sebakker': [('sebakke', False)],
          'sebakkernes': [('sebakke', False)],
          'sebakkers': [('sebakke', False)],
          'sebens': [('seben', False)],
          'seboer': [('sebo', False)],
          'seboerne': [('sebo', False)],
          'seboers': [('sebo', False)],
          'sedagens': [('sedag', False)],
          'sedas': [('seda', False)],
          'sedlens': [('seddel', True)],
          'sedler': [('seddel', False)],
          'sedlers': [('seddel', False)],
          'seer': [('seer', True)],
          'seerne': [('seer', True)],
          'seernes': [('seer', True)],
          'seers': [('seer', True)],
          'sefinger': [('sefinger', False)],
          'sefingers': [('sefinger', False)],
          'seget': [('seget', False)],
          'segets': [('seget', False)],
          'segle': [('segl', True)],
          'seglen': [('segl', True)],
          'segles': [('segl', True)],
          'sehandler': [('sehandel', False)],
          'sehandlers': [('sehandel', False)],
          'sejden': [('sejd', True)],
          'sejdens': [('sejd', True)],
          'seje': [('seje', False)],
          'sejer': [('sej', False)],
          'sejerne': [('sej', True)],
          'sejernes': [('sej', False)],
          'sejers': [('sej', True)],
          'sejes': [('seje', False)],
          'sejet': [('seje', False)],
          'sejets': [('seje', False)],
          'sejler': [('sejler', True)],
          'sejlers': [('sejler', False)],
          'sejre': [('sejr', True)],
          'sejren': [('sejr', False)],
          'sejrens': [('sejr', True)],
          'sejrer': [('sejrer', False)],
          'sejrerne': [('sejrer', False)],
          'sejrernes': [('sejrer', False)],
          'sejres': [('sejr', True)],
          'sekser': [('sekser', True)],
          'sekserne': [('sekser', True)],
          'seksernes': [('sekser', True)],
          'seksers': [('sekser', True)],
          'seksten': [('sekst', True)],
          'sekstens': [('sekst', True)],
          'sekstiden': [('sekstiden', True)],
          'sekter': [('sekt', False)],
          'sekterne': [('sekt', True)],
          'sekternes': [('sekt', False)],
          'sekters': [('sekt', False)],
          'selagens': [('selage', False)],
          'selagerne': [('selage', False)],
          'sele': [('sele', True)],
          'selen': [('sele', True), ('selen', True)],
          'selens': [('selen', True), ('sele', True)],
          'seler': [('sele', False)],
          'selerer': [('selerer', False)],
          'selererne': [('selerer', False)],
          'selerernes': [('selerer', False)],
          'selerers': [('selerer', False)],
          'selernes': [('sele', False)],
          'selers': [('sele', False)],
          'seles': [('sele', False)],
          'selet': [('selet', False)],
          'selets': [('sel', False)],
          'selinen': [('seline', False)],
          'selinens': [('seline', False)],
          'seliner': [('selin', False)],
          'selinerne': [('seline', False)],
          'selinernes': [('selin', False)],
          'seliners': [('seline', False)],
          'selinet': [('seline', False)],
          'selinets': [('seline', False)],
          'selkurs': [('selkurs', False)],
          'seller': [('seller', False)],
          'sellerne': [('seller', False)],
          'sellernes': [('seller', False)],
          'sellers': [('sel', False)],
          'selsers': [('selse', False)],
          'selukkerne': [('selukker', False)],
          'selukkers': [('selukker', False)],
          'selvmordsbomber': [('selvmordsbomber', True), ('selvmordsbombe', True)],
          'selvmordsbomberne': [('selvmordsbomber', True), ('selvmordsbombe', True)],
          'selvmordsbombernes': [('selvmordsbombe', True), ('selvmordsbomber', True)],
          'selvmordsbombers': [('selvmordsbombe', True), ('selvmordsbomber', True)],
          'selærer': [('selære', False)],
          'selærerne': [('selærer', False)],
          'selærernes': [('selærer', False)],
          'selærers': [('selære', False)],
          'selører': [('seløre', False)],
          'selørerne': [('selør', False)],
          'selørernes': [('seløre', False)],
          'selørers': [('selør', False)],
          'semagerne': [('semager', False)],
          'semagernes': [('semager', False)],
          'semagers': [('semager', False)],
          'semanden': [('semand', False)],
          'semandens': [('semand', False)],
          'semens': [('sem', False)],
          'sempler': [('sempel', False)],
          'semus': [('semus', False)],
          'semærker': [('semærke', False)],
          'sender': [('sender', False)],
          'senderne': [('sender', False)],
          'sendernes': [('sender', True)],
          'senders': [('sender', False)],
          'sene': [('sene', True)],
          'senen': [('sene', True)],
          'senens': [('sene', True)],
          'sener': [('sene', True)],
          'senerne': [('sene', True)],
          'senernes': [('sene', True)],
          'seners': [('sene', True)],
          'senes': [('sene', True)],
          'senesers': [('seneser', False)],
          'senge': [('seng', False)],
          'sengen': [('seng', False)],
          'sengene': [('seng', True)],
          'sengenes': [('seng', False)],
          'sengens': [('seng', False)],
          'senges': [('seng', False)],
          'sengs': [('seng', False)],
          'sennes': [('sennes', True)],
          "sens'": [('sens', False)],
          'sensen': [('sens', False)],
          'sensens': [('sens', False)],
          'senser': [('sens', False)],
          'sensernes': [('sens', False)],
          'sensers': [('sens', False)],
          'sensianer': [('sensianer', False)],
          'sensianerne': [('sensianer', False)],
          'sensianernes': [('sensianer', False)],
          'sensianers': [('sensianer', False)],
          'senten': [('sent', False)],
          'sentens': [('sentens', True)],
          'senter': [('sent', False)],
          'senterne': [('sent', False)],
          'senternes': [('sent', False)],
          'senters': [('sent', False)],
          'sepsis': [('sepsis', True)],
          'septet': [('septet', True)],
          'seras': [('serum', False)],
          'sereder': [('sereder', False)],
          'serederne': [('sereder', False)],
          'seredernes': [('serede', False)],
          'sereders': [('sereder', False)],
          'seredes': [('serede', False)],
          'serer': [('serer', False)],
          'sererne': [('serer', False)],
          'serernes': [('serer', False)],
          'serers': [('sere', False)],
          'serier': [('serie', True)],
          'serierne': [('serie', True)],
          'seriernes': [('serie', True)],
          'seriers': [('serie', True)],
          'seriet': [('seri', False)],
          'seriets': [('seri', False)],
          'seris': [('seri', False)],
          'sernerne': [('serne', False)],
          'serners': [('serne', False)],
          'serpentinen': [('serpentine', True), ('serpentin', True)],
          'serpentinens': [('serpentine', True), ('serpentin', True)],
          'sersten': [('sersten', False)],
          'serten': [('sert', False)],
          'sertens': [('sert', False)],
          'serter': [('sert', False)],
          'serterne': [('sert', False)],
          'serters': [('sert', False)],
          'serts': [('sert', False)],
          'servanten': [('servante', True)],
          'servantens': [('servante', True)],
          'servanter': [('servante', True)],
          'servanterne': [('servante', True)],
          'servanternes': [('servante', True)],
          'servanters': [('servante', True)],
          'serven': [('serv', False)],
          'servens': [('serv', False)],
          'server': [('server', True), ('serv', True)],
          'serverne': [('serv', True), ('server', True)],
          'servernes': [('server', True), ('serv', True)],
          'servers': [('server', True), ('serv', True)],
          'serves': [('serve', False)],
          'ses': [('se', False)],
          "ses'": [('se', False)],
          'sescenter': [('sescenter', False)],
          'sescenters': [('sescenter', False)],
          'sese': [('sese', True)],
          'seser': [('ses', False)],
          'seserne': [('ses', False)],
          'sesernes': [('ses', False)],
          'sesers': [('ses', False)],
          'sesparkers': [('sespark', False)],
          'sessens': [('sesse', False)],
          'sesser': [('sesse', False)],
          'sesserne': [('sesse', False)],
          'sessernes': [('sesse', False)],
          'sessers': [('sesse', False)],
          'sestads': [('sestad', False)],
          'sestagen': [('sestage', False)],
          'sestagens': [('sestage', False)],
          'sesten': [('sest', False)],
          'sestene': [('sesten', False)],
          'sestens': [('sesten', False)],
          'sester': [('sest', False)],
          'sesterne': [('sest', False)],
          'sesternes': [('sest', False)],
          'sesters': [('sest', False)],
          'sestier': [('sesti', False)],
          'sestiernes': [('sesti', False)],
          'sestigerne': [('sestige', False)],
          'sestigernes': [('sestige', False)],
          'sestigers': [('sestige', False)],
          'setiden': [('setid', False)],
          'setips': [('setip', False)],
          'setten': [('set', False)],
          'settens': [('set', False)],
          'setter': [('setter', True)],
          'setterne': [('setter', True)],
          'setternes': [('setter', True)],
          'setters': [('setter', True)],
          'settet': [('set', False)],
          'settets': [('set', False)],
          'seve': [('seve', False)],
          'seves': [('seve', False)],
          'sevikkens': [('sevikke', False)],
          'sevikkerne': [('sevikke', False)],
          'sevikkernes': [('sevikke', False)],
          'sevikkers': [('sevikke', False)],
          'sevners': [('sevne', False)],
          'seøjne': [('seøje', False)],
          'seøjnene': [('seøje', False)],
          'seøjnenes': [('seøje', False)],
          'seøjnes': [('seøje', False)],
          'sfader': [('sfader', False)],
          'sfaderen': [('sfader', False)],
          'sfaderens': [('sfader', False)],
          'sfaders': [('sfader', False)],
          'sfanens': [('sfane', False)],
          'sfangen': [('sfange', False)],
          'sfanger': [('sfange', False)],
          'sfangerne': [('sfange', False)],
          'sfangernes': [('sfange', False)],
          'sfangers': [('sfange', False)],
          'sfaren': [('sfare', False)],
          'sfarens': [('sfar', False)],
          'sfarer': [('sfarer', False)],
          'sfarerne': [('sfarer', False)],
          'sfarernes': [('sfarer', False)],
          'sfarers': [('sfarer', False)],
          'sfars': [('sfar', False)],
          'sfejernes': [('sfejer', False)],
          'sfejers': [('sfejer', False)],
          'sfer': [('sfer', False)],
          'sferien': [('sferie', False)],
          'sferiens': [('sferie', False)],
          'sferier': [('sferie', False)],
          'sferierne': [('sferie', False)],
          'sferiers': [('sferie', False)],
          'sfilter': [('sfilt', False)],
          'sfilters': [('sfilt', False)],
          'sfiner': [('sfiner', False)],
          'sfiners': [('sfiner', False)],
          'sfladen': [('sflade', False)],
          'sfladens': [('sflade', False)],
          'sflugter': [('sflugt', False)],
          'sflugterne': [('sflugt', False)],
          'sflugternes': [('sflugt', False)],
          'sflugters': [('sflugt', False)],
          'sflys': [('sfly', False)],
          'sfonds': [('sfond', False)],
          'sformer': [('sform', False)],
          'sformerne': [('sform', False)],
          'sformernes': [('sform', False)],
          'sformers': [('sform', False)],
          'sfornemmelser': [('sfornemmelser', False)],
          'sfornemmelserne': [('sfornemmelse', False)],
          'sfornemmelsernes': [('sfornemmelse', False)],
          'sfornemmelsers': [('sfornemmelser', False)],
          'sforældre': [('sforælder', False)],
          'sfrister': [('sfrist', False)],
          'sfristerne': [('sfrist', False)],
          'sfristernes': [('sfrist', False)],
          'sfristers': [('sfrist', False)],
          'sfylden': [('sfylde', False)],
          'sfyldens': [('sfylde', False)],
          'sfædre': [('sfar', False)],
          'sfædrene': [('sfader', False)],
          'sfædrenes': [('sfar', False)],
          'sfædres': [('sfader', False)],
          'sfærden': [('sfærd', False)],
          'sfærdens': [('sfærd', False)],
          'sførerne': [('sfører', False)],
          "sgas'": [('sgas', False)],
          'sgassernes': [('sgas', False)],
          'sgassers': [('sgas', False)],
          'sgatter': [('sgatter', False)],
          'sgatterne': [('sgatter', False)],
          'sgatternes': [('sgatter', False)],
          'sgatters': [('sgatter', False)],
          'sgenier': [('sgeni', False)],
          'sgenierne': [('sgeni', False)],
          'sgeniernes': [('sgeni', False)],
          'sgeniers': [('sgeni', False)],
          'sgrever': [('sgreve', False)],
          'sgreverne': [('sgreve', False)],
          'sgrevernes': [('sgreve', False)],
          'sgænger': [('sgænger', False)],
          'sgængerne': [('sgænger', False)],
          'sgængernes': [('sgænger', False)],
          'sgængers': [('sgænger', False)],
          'sh': [('sh', False)],
          'shallen': [('shal', False)],
          'shallens': [('shal', False)],
          'shaller': [('shal', False)],
          'shallerne': [('shal', False)],
          'shallernes': [('shal', False)],
          'shallers': [('shal', False)],
          'shals': [('shal', False)],
          'shamaner': [('shaman', True)],
          'shandler': [('shandler', False)],
          'shandlerne': [('shandel', False)],
          'shandlernes': [('shandel', False)],
          'shandlers': [('shandler', False)],
          'shans': [('shans', False)],
          'sharen': [('shar', False)],
          'sharens': [('shar', False)],
          'sharer': [('shar', False)],
          'sharerne': [('shar', False)],
          'sharernes': [('shar', False)],
          'sharers': [('shar', False)],
          'sharmonier': [('sharmoni', False)],
          'sharmonierne': [('sharmoni', False)],
          'sharmoniernes': [('sharmoni', False)],
          'sharmoniers': [('sharmoni', False)],
          'shas': [('sha', False)],
          'shave': [('shave', False)],
          'shaver': [('shaver', False)],
          'shaverne': [('shaver', False)],
          'shavernes': [('shaver', False)],
          'shavers': [('shaver', False)],
          'shaves': [('shave', False)],
          'shavets': [('shav', False)],
          'sheden': [('shed', False)],
          'shedens': [('shed', False)],
          'sheder': [('shed', False)],
          'shederne': [('shed', False)],
          'shedernes': [('shed', False)],
          'sheders': [('shed', False)],
          'shen': [('sh', False)],
          'shens': [('sh', False)],
          'sher': [('sh', False)],
          'sherne': [('sh', False)],
          'shernes': [('sh', False)],
          'shers': [('sh', False)],
          'shet': [('sh', False)],
          'shets': [('sh', False)],
          'shis': [('shi', False)],
          'shjerter': [('shjerte', False)],
          'shjerterne': [('shjerte', False)],
          'shjerternes': [('shjerte', False)],
          'shjerters': [('shjerte', False)],
          'sholterne': [('sholt', False)],
          'sholters': [('sholt', False)],
          'shoppen': [('shop', True)],
          'shoppens': [('shop', True)],
          'shopper': [('shop', True)],
          'shopperne': [('shop', False)],
          'shoppernes': [('shop', False)],
          'shoppers': [('shop', False)],
          'shunter': [('shunt', True)],
          'shunterne': [('shunt', True)],
          'shunters': [('shunt', True)],
          'shus': [('shus', False)],
          'shvarren': [('shvarre', False)],
          'shvarrernes': [('shvarre', False)],
          'shvirvler': [('shvirvel', False)],
          'shvirvlerne': [('shvirvel', False)],
          'shvirvlernes': [('shvirvel', False)],
          'shvirvlers': [('shvirvel', False)],
          'shærens': [('shær', False)],
          'shøjder': [('shøjde', False)],
          'shøjderne': [('shøjde', False)],
          'shøjdernes': [('shøjde', False)],
          'shøjders': [('shøjde', False)],
          'si': [('si', False)],
          'sianer': [('sian', False)],
          'sianerne': [('sianer', False)],
          'sianernes': [('sianer', False)],
          'sianers': [('sian', False)],
          'sians': [('sian', False)],
          'sias': [('sias', False)],
          'siben': [('siben', True)],
          'sibens': [('siben', True)],
          'sici': [('siko', False)],
          'siciene': [('siko', False)],
          'sicienes': [('sikus', False)],
          'sicis': [('siko', False)],
          'sidden': [('sidden', False)],
          'siddens': [('sidden', False)],
          'sidder': [('sidder', False)],
          'sidders': [('sidder', False)],
          'side': [('side', False)],
          'siden': [('side', False)],
          'sidens': [('side', False)],
          'sider': [('side', False)],
          'siderne': [('side', True)],
          'sidernes': [('side', False)],
          'siders': [('side', False)],
          'sides': [('side', False)],
          'sidier': [('sidie', False)],
          'sidierne': [('sidier', False)],
          'sidiernes': [('sidier', False)],
          'sidiers': [('sidier', False)],
          'sidium': [('sidie', False)],
          'sidiums': [('sidie', False)],
          'sien': [('si', False)],
          'siens': [('si', False)],
          'sier': [('si', True)],
          'siere': [('sier', False)],
          'sieren': [('sier', False)],
          'sierens': [('sier', False)],
          'sierer': [('sier', False)],
          'siererne': [('sier', False)],
          'sierernes': [('sier', False)],
          'sierers': [('sier', False)],
          'sieres': [('sier', False)],
          'sieret': [('sier', False)],
          'sierets': [('sier', False)],
          'sierne': [('si', True)],
          'siernes': [('si', False)],
          'siers': [('si', False)],
          'siets': [('si', False)],
          'sigerne': [('siger', False)],
          'sigernes': [('siger', False)],
          'sigers': [('siger', False)],
          'siglen': [('sigel', True)],
          'siglens': [('sigel', True)],
          'sigler': [('sigel', True)],
          'siglerne': [('sigel', True)],
          'siglernes': [('sigel', True)],
          'siglers': [('sigel', True)],
          'signernes': [('signer', False)],
          'signet': [('signet', True)],
          'signets': [('signet', True)],
          'sigten': [('sigte', True)],
          'sigtens': [('sigte', True)],
          'sigter': [('sigte', True)],
          'sigterne': [('sigte', False)],
          'sigternes': [('sigte', True)],
          'sigters': [('sigte', False)],
          'sigtet': [('sigte', True)],
          'sigtets': [('sigte', True)],
          'sika': [('sikon', False)],
          'sikaliernes': [('sikalier', False)],
          'sikaner': [('sikaner', False)],
          'sikaners': [('sikaner', False)],
          'sikas': [('sikon', False)],
          'sikken': [('sik', False)],
          'sikkens': [('sikke', False)],
          'sikker': [('sikke', False)],
          'sikkerne': [('sik', False)],
          'sikkernes': [('sikke', False)],
          'sikkers': [('sikke', False)],
          'siklingen': [('siklinge', True)],
          'siklingens': [('siklinge', True)],
          'siklinger': [('siklinge', True)],
          'siklingerne': [('siklinge', True)],
          'siklingernes': [('siklinge', True)],
          'siklingers': [('siklinge', True)],
          'sikos': [('siko', False)],
          'sild': [('sild', False)],
          'silden': [('sild', False)],
          'sildens': [('sild', False)],
          'silds': [('sild', False)],
          'siler': [('sil', False)],
          'silets': [('sil', False)],
          'sillen': [('sil', False)],
          'sillens': [('sille', False)],
          'siller': [('sil', False)],
          'sillerne': [('sil', False)],
          'sillers': [('sil', False)],
          'silos': [('silo', True)],
          'sima': [('sima', False)],
          'simas': [('sima', False)],
          'sime': [('sime', False)],
          'simen': [('sime', False)],
          'simens': [('sime', False)],
          'simer': [('sime', False)],
          'simerne': [('sime', False)],
          'simernes': [('sime', False)],
          'simes': [('sime', False)],
          'simperiet': [('simperie', False)],
          'sims': [('sims', False)],
          'sina': [('sina', False)],
          'sinas': [('sina', False)],
          'sinde': [('sinde', True)],
          'sinderne': [('sind', False)],
          'sindernes': [('sind', False)],
          'sindes': [('sinde', True)],
          'sindet': [('sind', False)],
          'sindets': [('sind', False)],
          'sindskifter': [('sindskifte', False)],
          'sindskifterne': [('sindskifte', False)],
          'sindskifternes': [('sindskifte', False)],
          'sindskifters': [('sindskifte', False)],
          'sine': [('sine', False)],
          'sinen': [('sine', False)],
          'sinene': [('sin', False)],
          'sinens': [('sine', False)],
          'siner': [('sin', False)],
          'sinerne': [('sin', False)],
          'siners': [('sin', False)],
          'sines': [('sine', False)],
          'singen': [('sing', False)],
          'singens': [('sing', False)],
          'singer': [('sing', False)],
          'singerne': [('sing', False)],
          'singernes': [('sing', False)],
          'singlen': [('single', True)],
          'singlernes': [('single', True)],
          'singlers': [('single', True)],
          'sings': [('sing', False)],
          'sini': [('sini', False)],
          'sinien': [('sini', False)],
          'siniens': [('sini', False)],
          'siniere': [('sinier', False)],
          'sinieren': [('sinier', False)],
          'sinierens': [('sinier', False)],
          'sinieres': [('sinier', False)],
          'sinis': [('sini', False)],
          'sinkens': [('sinke', True)],
          'sinkernes': [('sinke', True)],
          'sinkers': [('sinke', True)],
          'sinten': [('sint', False)],
          'sintens': [('sint', False)],
          'sinter': [('sinter', True)],
          'sinterne': [('sint', False)],
          'sinternes': [('sint', False)],
          'sinters': [('sinter', True)],
          'sioner': [('sion', False)],
          'sionerne': [('sion', False)],
          'sionernes': [('sion', False)],
          'sioners': [('sion', False)],
          'sions': [('sion', False)],
          "sions'": [('sion', False)],
          'sippernes': [('sippe', True)],
          'sippers': [('sippe', True)],
          'sippes': [('sippe', True)],
          'siren': [('sir', False)],
          'sirene': [('sirene', True)],
          'sirenes': [('sirene', True)],
          'sirer': [('sir', False)],
          'sirerne': [('sir', False)],
          'sirernes': [('sir', False)],
          'sirers': [('sir', False)],
          'sis': [('si', False)],
          'sisers': [('sis', False)],
          'sisken': [('sisken', False)],
          'siskens': [('sisken', True)],
          'sismens': [('sisme', False)],
          'sissen': [('sis', False)],
          'sissens': [('sis', False)],
          'sisser': [('sis', False)],
          'sisserne': [('sis', False)],
          'sissernes': [('sis', False)],
          'sissers': [('sis', False)],
          'sisten': [('sist', False)],
          'sistens': [('sist', False)],
          'sister': [('sist', False)],
          'sisterne': [('sist', False)],
          'sisternes': [('sist', False)],
          'sisters': [('sist', False)],
          'sitats': [('sitats', False)],
          'siten': [('site', True)],
          'sitene': [('site', True)],
          'sitens': [('site', False)],
          'sitet': [('site', True)],
          'sitets': [('site', False)],
          'sitten': [('sit', False)],
          'sittens': [('sit', False)],
          'sitter': [('sitter', False)],
          'sitterne': [('sitter', False)],
          'sitternes': [('sit', False)],
          'sitters': [('sit', False)],
          'sitørerne': [('sitør', False)],
          'sitørernes': [('sitør', False)],
          'sitørers': [('sitør', False)],
          'sium': [('sie', False)],
          'siums': [('sie', False)],
          'siver': [('siv', False)],
          'siverne': [('siv', False)],
          'sivers': [('siv', False)],
          'sizer': [('sizer', False)],
          'sizers': [('sizer', False)],
          'sjakken': [('sjakke', False)],
          'sjakkerne': [('sjakke', False)],
          'sjanernes': [('sjaner', False)],
          'sjer': [('sje', False)],
          'sjerne': [('sjer', False)],
          'sjernes': [('sjer', False)],
          'sjers': [('sjer', False)],
          'sjet': [('sje', False)],
          'sjets': [('sje', False)],
          'sjorden': [('sjord', False)],
          'sjordens': [('sjord', False)],
          'sjos': [('sjos', False)],
          'sjovernes': [('sjover', True)],
          'sjovers': [('sjover', True)],
          'sjuks': [('sjuk', False)],
          'sk': [('sk', False)],
          'sk.': [('iseskefuld', False)],
          'skaber': [('skaber', False)],
          'skaberne': [('skaber', True)],
          'skabernes': [('skaber', True)],
          'skabers': [('skaber', True)],
          'skaffer': [('skaffer', True)],
          'skafferne': [('skaffer', True)],
          'skaffernes': [('skaffer', True)],
          'skaffers': [('skaffer', True)],
          'skagen': [('skage', False)],
          'skagens': [('skage', False)],
          'skalas': [('skala', False)],
          'skaler': [('skal', False)],
          'skalerne': [('skal', False)],
          'skalernes': [('skal', False)],
          'skalers': [('skal', False)],
          'skalke': [('skalk', True)],
          'skalken': [('skalk', True)],
          'skalkens': [('skalk', True)],
          'skalkes': [('skalk', True)],
          'skallen': [('skal', True), ('skalle', True)],
          'skallens': [('skal', True), ('skalle', True)],
          'skaller': [('skal', True), ('skalle', True)],
          'skallerne': [('skalle', True), ('skal', True)],
          'skallernes': [('skal', True), ('skalle', True)],
          'skallers': [('skalle', True), ('skal', True)],
          'skaner': [('skaner', False)],
          'skanerne': [('skaner', False)],
          'skanernes': [('skaner', False)],
          'skaners': [('skaner', False)],
          'skansen': [('skanse', True)],
          'skansens': [('skanse', True)],
          'skarens': [('skare', False)],
          'skarerne': [('skare', False)],
          'skarers': [('skare', False)],
          'skarpen': [('skarp', True)],
          'skarpens': [('skarp', True)],
          'skartoflerne': [('skartoffel', False)],
          'skartoflers': [('skartoffel', False)],
          'skaster': [('skaster', False)],
          'skasterne': [('skaster', False)],
          'skasternes': [('skaster', False)],
          'skasters': [('skaster', False)],
          'skaternes': [('skater', True)],
          'ske': [('ske', True)],
          'skeden': [('skede', True)],
          'skedens': [('skede', False)],
          'skeder': [('skede', True)],
          'skederne': [('skede', True)],
          'skedernes': [('skede', True)],
          'skeders': [('skede', True)],
          'skejser': [('skejs', True)],
          'skejserne': [('skejs', True)],
          'skejsernes': [('skejs', True)],
          'skejsers': [('skejs', True)],
          'skekutterne': [('skekutter', False)],
          'skekutternes': [('skekutter', False)],
          'skekutters': [('skekutter', False)],
          'skelen': [('skelen', True)],
          'skelens': [('skelen', True)],
          'skelets': [('skelet', True)],
          'skeleverne': [('skelever', False)],
          'skelevernes': [('skelever', False)],
          'skenes': [('sk', False)],
          'skens': [('ske', False)],
          'sker': [('sker', False)],
          'skerader': [('skerade', False)],
          'skeradernes': [('skerade', False)],
          'skere': [('sker', False)],
          'skeren': [('sker', False)],
          'skerens': [('sker', False)],
          'skeres': [('sker', False)],
          'skerne': [('sker', False)],
          'skernes': [('ske', False)],
          'skerten': [('skerte', False)],
          'skertens': [('skerte', False)],
          'skes': [('ske', True)],
          'sketer': [('sketer', False)],
          'sketers': [('sketer', False)],
          'sketten': [('skette', False)],
          'skettens': [('skette', False)],
          'sketter': [('sket', False)],
          'sketterne': [('skette', False)],
          'sketternes': [('skette', False)],
          'sketters': [('skette', False)],
          'skifte': [('skift', True)],
          'skifter': [('skift', True)],
          'skifterne': [('skift', True)],
          'skifternes': [('skift', True)],
          'skifters': [('skift', False)],
          'skiftes': [('skift', True)],
          'skiftet': [('skift', True)],
          'skiftets': [('skift', True)],
          'skiks': [('skik', False)],
          'skilder': [('skilde', False)],
          'skilderne': [('skilde', False)],
          'skildernes': [('skilde', False)],
          'skilders': [('skilde', False)],
          'skiller': [('skiller', False)],
          'skillerne': [('skiller', False)],
          'skillers': [('skiller', False)],
          'skillinger': [('skilling', True)],
          'skillingerne': [('skilling', True)],
          'skillingernes': [('skilling', False)],
          'skillingers': [('skilling', True)],
          'skinerne': [('skine', False)],
          'skiners': [('skine', False)],
          'skipper': [('skipper', False)],
          'skipperne': [('skipper', True)],
          'skippernes': [('skipper', False)],
          'skippers': [('skipper', True)],
          'skis': [('ski', False)],
          'skisten': [('skist', False)],
          'skistens': [('skiste', False)],
          'skister': [('skist', False)],
          'skisterne': [('skiste', False)],
          'skisternes': [('skiste', False)],
          'skisters': [('skist', False)],
          'skiven': [('skive', False)],
          'skivens': [('skive', False)],
          'skiverne': [('skive', False)],
          'sklavens': [('sklave', False)],
          'sklaver': [('sklave', False)],
          'sklavers': [('sklave', False)],
          'sklens': [('skel', False)],
          'skler': [('skel', False)],
          'sklingen': [('skling', False)],
          'sklingens': [('skling', False)],
          'sklinger': [('skling', False)],
          'sklingerne': [('skling', False)],
          'sklingernes': [('skling', False)],
          'sklingers': [('skling', False)],
          'sklipper': [('sklipper', False)],
          'sklipperne': [('sklipper', False)],
          'sklippernes': [('sklipper', False)],
          'sklippers': [('sklipper', False)],
          'skner': [('skner', False)],
          'sknerne': [('sken', False)],
          'sknernes': [('skner', False)],
          'skners': [('skner', False)],
          'skoks': [('skok', True)],
          'skoler': [('skole', False)],
          'skolerne': [('skole', False)],
          'skontroller': [('skontrol', False)],
          'skontrollerne': [('skontrol', False)],
          'skontrollernes': [('skontrol', False)],
          'skontrollers': [('skontrol', False)],
          'skoper': [('skop', False)],
          'skoperne': [('skop', False)],
          'skopernes': [('skop', False)],
          'skopers': [('skop', False)],
          'skopper': [('skop', False)],
          'skopperne': [('skop', False)],
          'skoppernes': [('skop', False)],
          'skoppers': [('skop', False)],
          'skornet': [('skorn', False)],
          'skornets': [('skorn', False)],
          'skors': [('skor', False)],
          'skorten': [('skorte', False)],
          'skortens': [('skorte', False)],
          'skorterne': [('skorte', False)],
          'skorters': [('skorte', False)],
          'skos': [('sko', True)],
          'skoser': [('skose', True)],
          'skossen': [('skosse', False)],
          'skossens': [('skosse', True)],
          'skosser': [('skosse', False)],
          'skosserne': [('skosse', False)],
          'skossernes': [('skosse', True)],
          'skossers': [('skosse', True)],
          'skotten': [('skotte', True)],
          'skottens': [('skotte', True)],
          'skotter': [('skotte', True), ('skot', True)],
          'skotterne': [('skot', True), ('skotte', True)],
          'skotternes': [('skotte', True), ('skot', True)],
          'skotters': [('skotte', True), ('skot', True)],
          'skove': [('skov', False)],
          'skoven': [('skov', False)],
          'skovens': [('skov', False)],
          'skoves': [('skov', False)],
          'skovs': [('skov', False)],
          'skovser': [('skovser', True)],
          'skovserne': [('skovser', True)],
          'skovsernes': [('skovser', True)],
          'skovsers': [('skovser', True)],
          'skralden': [('skralden', True), ('skralde', True)],
          'skrammer': [('skramme', True)],
          'skrammerne': [('skramme', True)],
          'skrammernes': [('skramme', True)],
          'skrammers': [('skramme', True)],
          'skrams': [('skrams', False)],
          'skranke': [('skranke', False)],
          'skranken': [('skranke', False)],
          'skrankens': [('skranke', False)],
          'skrankes': [('skranke', False)],
          'skrans': [('skrans', False)],
          'skreds': [('skred', True)],
          'skrige': [('skrige', False)],
          'skrigen': [('skrige', False)],
          'skrigens': [('skrige', False)],
          'skriger': [('skriger', True)],
          'skrigerne': [('skriger', True)],
          'skrigernes': [('skriger', True)],
          'skrigers': [('skriger', True)],
          'skriges': [('skrige', False)],
          'skrise': [('skrise', False)],
          'skrisen': [('skrise', False)],
          'skrisens': [('skrise', False)],
          'skriser': [('skrise', False)],
          'skriserne': [('skrise', False)],
          'skrisernes': [('skrise', False)],
          'skrisers': [('skrise', False)],
          'skrises': [('skrise', False)],
          'skrus': [('skru', False)],
          'skræfter': [('skræfter', False)],
          'skræfterne': [('skræfter', False)],
          'skræfternes': [('skraft', False)],
          'skræfters': [('skræfter', False)],
          'skræller': [('skræl', False)],
          'skrællerne': [('skræl', True)],
          'skrællernes': [('skræl', False)],
          'skrællers': [('skræl', True)],
          'sks': [('sk', False)],
          "sks'": [('sk', False)],
          'skuer': [('skue', True)],
          'skuerne': [('skue', False)],
          'skuernes': [('skue', False)],
          'skuers': [('skue', False)],
          'skuet': [('skue', False)],
          'skuets': [('skue', False)],
          'skuffen': [('skuffe', True)],
          'skuffens': [('skuffe', False)],
          'skuffer': [('skuffe', True)],
          'skufferne': [('skuffe', True)],
          'skuffernes': [('skuffe', False)],
          'skuffers': [('skuffe', False)],
          'skulden': [('skuld', False)],
          'skuldens': [('skuld', False)],
          'skummen': [('skum', False)],
          'skummens': [('skum', False)],
          'skummer': [('skummer', False)],
          'skummerne': [('skummer', False)],
          'skummernes': [('skummer', False)],
          'skummers': [('skummer', False)],
          'skummet': [('skum', False)],
          'skummets': [('skum', False)],
          'skure': [('skure', True), ('skur', True)],
          'skuren': [('skure', True)],
          'skurens': [('skure', True)],
          'skurer': [('skure', True)],
          'skurers': [('skure', True)],
          'skures': [('skure', True), ('skur', True)],
          'skurs': [('skur', True)],
          'skurser': [('skurs', False)],
          'skurserne': [('skurs', False)],
          'skursernes': [('skurs', False)],
          'skursers': [('skurs', False)],
          'skurve': [('skurve', False)],
          'skurven': [('skurv', False)],
          'skurvens': [('skurv', True)],
          'skurves': [('skurv', False)],
          'skus': [('skus', False)],
          'skussen': [('skus', False)],
          'skussens': [('skus', False)],
          'skutter': [('skutter', False)],
          'skvaler': [('skvaler', False)],
          'skvalerne': [('skvaler', False)],
          'skvalernes': [('skvaler', False)],
          'skvalers': [('skval', False)],
          'skvaren': [('skvare', False)],
          'skvarens': [('skvare', False)],
          'skvarer': [('skvare', False)],
          'skvarerne': [('skvare', False)],
          'skvarernes': [('skvare', False)],
          'skvarter': [('skvarter', False)],
          'skvarters': [('skvarter', False)],
          'skydernes': [('skyder', True)],
          'skyders': [('skyder', False)],
          'skys': [('sky', True)],
          'skytter': [('skytte', True)],
          'skytterne': [('skytte', True)],
          'skytternes': [('skytte', True)],
          'skytters': [('skytte', False)],
          'skåltaler': [('skåltaler', True), ('skåltale', True)],
          'skåltalerne': [('skåltaler', True), ('skåltale', True)],
          'skåltalernes': [('skåltaler', True), ('skåltale', True)],
          'skåltalers': [('skåltaler', True), ('skåltale', True)],
          'skæfte': [('skæfte', True)],
          'skæfter': [('skæfte', True)],
          'skæfterne': [('skæfte', True)],
          'skæfternes': [('skæfte', True)],
          'skæfters': [('skæfte', True)],
          'skæftes': [('skæfte', True)],
          'skæmper': [('skæmper', False)],
          'skæmperne': [('skæmper', False)],
          'skæmpernes': [('skæmper', False)],
          'skæmpers': [('skæmper', False)],
          'skæppe': [('skæppe', True)],
          'skæppen': [('skæppe', True)],
          'skæppens': [('skæppe', True)],
          'skæppes': [('skæppe', True)],
          'skærtens': [('skærte', False)],
          'skærterne': [('skærte', False)],
          'skærve': [('skærve', True)],
          'skærven': [('skærve', True), ('skærv', True)],
          'skærvens': [('skærve', True), ('skærv', True)],
          'skærves': [('skærve', True)],
          'skøbet': [('skøb', False)],
          'skød': [('skød', False)],
          'skøder': [('skød', True), ('skøde', True)],
          'skøderne': [('skød', True), ('skøde', True)],
          'skødernes': [('skød', True), ('skøde', True)],
          'skøders': [('skød', True), ('skøde', True)],
          'skødet': [('skød', True), ('skøde', True)],
          'skødets': [('skød', True), ('skøde', True)],
          'skøds': [('skød', False)],
          'skøjten': [('skøjte', True)],
          'skøjtens': [('skøjte', True)],
          'skøjter': [('skøjte', True)],
          'skøjterne': [('skøjte', True)],
          'skøjternes': [('skøjte', True)],
          'skøjters': [('skøjte', False)],
          'skørens': [('skøre', False)],
          'skører': [('skøre', False)],
          'skørerne': [('skøre', False)],
          'skørernes': [('skøre', False)],
          'skørers': [('skøre', False)],
          'slager': [('slager', False)],
          'slagerne': [('slager', True)],
          'slagernes': [('slager', True)],
          'slagers': [('slager', True)],
          'slaggen': [('slagge', True)],
          'slaggens': [('slagge', True)],
          'slags': [('slags', True), ('slag', True)],
          'slammen': [('slam', False)],
          'slange': [('slange', False)],
          'slangen': [('slang', True), ('slange', True)],
          'slangens': [('slang', True), ('slange', True)],
          'slangerne': [('slange', False)],
          'slanges': [('slange', False)],
          'slanter': [('slant', True)],
          'slanterne': [('slant', True)],
          'slanternes': [('slant', True)],
          'slanters': [('slant', True)],
          'slapper': [('slapper', True)],
          'slapperne': [('slapper', True)],
          'slappernes': [('slapper', True)],
          'slappers': [('slapper', True)],
          'slats': [('slat', True)],
          'slatten': [('slat', True)],
          'slattens': [('slat', True)],
          'slatter': [('slat', True)],
          'slatterne': [('slat', True)],
          'slatternes': [('slat', True)],
          'slatters': [('slat', True)],
          'slavearbejder': [('slavearbejder', True), ('slavearbejde', True)],
          'slavearbejderne': [('slavearbejder', True), ('slavearbejde', True)],
          'slavearbejdernes': [('slavearbejde', True), ('slavearbejder', True)],
          'slavearbejders': [('slavearbejde', True), ('slavearbejder', True)],
          'slavehandler': [('slavehandler', True), ('slavehandel', True)],
          'slavehandlerne': [('slavehandel', True), ('slavehandler', True)],
          'slavehandlernes': [('slavehandel', True), ('slavehandler', True)],
          'slavehandlers': [('slavehandler', True), ('slavehandel', True)],
          'slaven': [('slave', True)],
          'slavens': [('slave', True)],
          'slaver': [('slave', True), ('slaver', True)],
          'slaverne': [('slave', True), ('slaver', True)],
          'slavernes': [('slaver', True), ('slave', True)],
          'slavers': [('slave', True), ('slaver', True)],
          'sleboernes': [('slebo', False)],
          'sleder': [('sleder', False)],
          'sledernes': [('sleder', False)],
          'slegenes': [('sleg', False)],
          'slejer': [('sleje', False)],
          'slejerne': [('sleje', False)],
          'slejernes': [('sleje', False)],
          'slejers': [('sleje', False)],
          'slemmerne': [('slem', False)],
          'slemmers': [('slem', False)],
          'slen': [('sel', False)],
          'slene': [('sel', False)],
          'slenes': [('sel', False)],
          'slens': [('ssel', False)],
          'slere': [('sler', False)],
          'sleren': [('sler', False)],
          'slerens': [('sler', False)],
          'sleres': [('sler', False)],
          'slerne': [('sel', False)],
          'slernes': [('sel', False)],
          'slers': [('sel', False)],
          'slet': [('sel', False)],
          'slets': [('sel', False)],
          'slettens': [('slette', True)],
          'sletters': [('slette', True)],
          'sleve': [('slev', True)],
          'sleven': [('slev', True)],
          'sleverne': [('slever', False)],
          'slevernes': [('slever', False)],
          'sleves': [('slev', True)],
          'sliberier': [('sliberi', True)],
          'sliberierne': [('sliberi', True)],
          'sliberiernes': [('sliberi', True)],
          'sliberiers': [('sliberi', True)],
          'slicens': [('slice', True)],
          'slidens': [('slide', True)],
          'slids': [('slid', True), ('slids', True)],
          'slidsen': [('slids', True)],
          'slidsens': [('slids', True)],
          'slidser': [('slids', True)],
          'slidserne': [('slids', True)],
          'slidsernes': [('slids', True)],
          'slidsers': [('slids', True)],
          'slier': [('sli', False)],
          'slierne': [('sli', False)],
          'slighternes': [('slighter', False)],
          'slighters': [('slighter', False)],
          'slikkerne': [('slikker', False)],
          'slimen': [('slim', False)],
          'slimens': [('slim', True)],
          'slinger': [('slinger', True)],
          'slingers': [('slinger', True)],
          'slippen': [('slippe', True), ('slip', True)],
          'slippens': [('slippe', True), ('slip', True)],
          'slipper': [('slip', True), ('slippe', True)],
          'slipperne': [('slip', True), ('slippe', True)],
          'slippernes': [('slippe', True), ('slip', True)],
          'slippers': [('slippe', True), ('slippers', True), ('slip', True)],
          'slips': [('slips', True), ('slip', True)],
          'slisken': [('sliske', True), ('slisk', True)],
          'sliskens': [('slisk', True), ('sliske', True)],
          'slisker': [('slisk', True), ('sliske', True)],
          'sliskerne': [('slisk', True), ('sliske', True)],
          'sliskernes': [('slisk', True), ('sliske', True)],
          'sliskers': [('slisk', True), ('sliske', True)],
          'slisten': [('sliste', False)],
          'slistens': [('sliste', False)],
          'slister': [('sliste', False)],
          'slisterne': [('sliste', False)],
          'sloer': [('sloer', False)],
          'sloerne': [('sloer', False)],
          'sloernes': [('sloer', False)],
          'sloers': [('sloer', False)],
          'slomme': [('slomme', False)],
          'slommen': [('slomme', False)],
          'slommens': [('slomme', False)],
          'slommer': [('slom', False)],
          'slommerne': [('slomme', False)],
          'slommernes': [('slom', False)],
          'slommers': [('slom', False)],
          'slommes': [('slomme', False)],
          'slotte': [('slot', False)],
          'slottes': [('slot', False)],
          'slove': [('slov', False)],
          'sluger': [('sluger', False)],
          'slugerne': [('sluger', False)],
          'slugernes': [('sluger', False)],
          'slugers': [('sluger', False)],
          'slugters': [('slugt', True)],
          'slukker': [('slukker', False)],
          'slukkerne': [('slukker', False)],
          'slukkernes': [('slukker', False)],
          'slukkers': [('slukker', False)],
          'slummers': [('slummer', True)],
          'slurens': [('slur', False)],
          'slures': [('slur', False)],
          'slus': [('slus', False)],
          'slusen': [('sluse', True)],
          'slusens': [('sluse', True)],
          'sluser': [('sluser', True), ('sluse', True)],
          'sluserne': [('sluser', True), ('sluse', True)],
          'slusernes': [('sluser', True), ('sluse', True)],
          'slusers': [('sluser', True), ('sluse', True)],
          'slutter': [('slutter', False)],
          'slutterne': [('slutter', False)],
          'slutternes': [('slutter', False)],
          'slutters': [('slutter', False)],
          'slyde': [('slyd', False)],
          'slyden': [('slyd', False)],
          'slydens': [('slyd', False)],
          'slydes': [('slyd', False)],
          'slyngen': [('slynge', False)],
          'slyngens': [('slynge', False)],
          'slynger': [('slynge', False)],
          'slyngerne': [('slynge', True)],
          'slys': [('slys', False)],
          'slåen': [('slå', True), ('slåen', True)],
          'slåens': [('slåen', True), ('slå', True)],
          'slåer': [('slåer', True), ('slå', True)],
          'slåerne': [('slåer', True), ('slå', True)],
          'slåernes': [('slåer', True), ('slå', True)],
          'slåers': [('slåer', True), ('slå', True)],
          'slås': [('slå', True)],
          'slæber': [('slæber', True)],
          'slæberne': [('slæber', True)],
          'slæbernes': [('slæber', True)],
          'slæbers': [('slæber', True)],
          'slæder': [('slæde', False)],
          'slæderne': [('slæde', True)],
          'slædernes': [('slæde', False)],
          'slæders': [('slæde', True)],
          'slægens': [('slæge', False)],
          'slægerne': [('slæge', False)],
          'slægernes': [('slæge', False)],
          'slægers': [('slæge', False)],
          'slægten': [('slægt', False)],
          'slægtens': [('slægt', True)],
          'slægter': [('slægt', True)],
          'slægterne': [('slægt', False)],
          'slægternes': [('slægt', True)],
          'slægters': [('slægt', False)],
          'slænder': [('slænder', False)],
          'slænderne': [('slænder', False)],
          'slændernes': [('slænder', False)],
          'slænders': [('slænder', False)],
          'slærer': [('slærer', False)],
          'slærerne': [('slære', False)],
          'slærernes': [('slære', False)],
          'slærers': [('slære', False)],
          'sløfterne': [('sløfte', False)],
          'sløftet': [('sløfte', False)],
          'sløftets': [('sløfte', False)],
          'sløjer': [('sløjer', False)],
          'sløjerne': [('sløjer', False)],
          'sløjernes': [('sløjer', False)],
          'sløjers': [('sløjer', False)],
          'slørets': [('slør', False)],
          'smadder': [('smadder', True)],
          'smadders': [('smadder', True)],
          'smads': [('smad', False)],
          'smage': [('smag', True)],
          'smagen': [('smag', False)],
          'smagens': [('smag', False)],
          'smager': [('smager', False)],
          'smagerne': [('smager', False)],
          'smagernes': [('smager', False)],
          'smagers': [('smager', False)],
          'smages': [('smag', True)],
          'smakken': [('smakke', True)],
          'smakker': [('smakke', True)],
          'smakkerne': [('smakke', True)],
          'smakkernes': [('smakke', True)],
          'smakkers': [('smakke', True)],
          'smalten': [('smalte', True)],
          'smaltens': [('smalte', True)],
          'sman': [('sman', False)],
          'smanens': [('sman', False)],
          'smaner': [('sman', False)],
          'smaners': [('sman', False)],
          'smannerne': [('sman', False)],
          'smannernes': [('sman', False)],
          'smanners': [('sman', False)],
          'smans': [('sman', False)],
          'smarchen': [('smarch', False)],
          'smarchens': [('smarch', False)],
          'smarcher': [('smarch', False)],
          'smarcherne': [('smarch', False)],
          'smarinen': [('smarin', False)],
          'smarinens': [('smarin', False)],
          'smariner': [('smarin', False)],
          'smarinerne': [('smarin', False)],
          'smarinernes': [('smarin', False)],
          'smariners': [('smarin', False)],
          'smarker': [('smark', False)],
          'smarkerne': [('smark', False)],
          'smarkernes': [('smark', False)],
          'smarkers': [('smark', False)],
          'smas': [('sma', False)],
          'smasken': [('smaske', False)],
          'smaskens': [('smaske', False)],
          'smasker': [('smaske', False)],
          'smaskers': [('smaske', False)],
          'smede': [('smed', False)],
          'smeden': [('smed', False)],
          'smedens': [('smed', False)],
          'smedes': [('smed', True)],
          'smediciner': [('smediciner', False)],
          'smedicinerne': [('smediciner', False)],
          'smedicinernes': [('smediciner', False)],
          'smediciners': [('smediciner', False)],
          'smelet': [('smel', False)],
          'smen': [('sme', False)],
          'smens': [('sme', False)],
          'smer': [('smer', False)],
          'smere': [('smer', False)],
          'smeren': [('smer', False)],
          'smerens': [('smer', False)],
          'smeres': [('smer', False)],
          'smeret': [('smer', False)],
          'smerets': [('smer', False)],
          'smers': [('sme', False)],
          'smerten': [('smerte', True)],
          'smertens': [('smerte', False)],
          'smerter': [('smerte', True)],
          'smerterne': [('smerte', True)],
          'smerternes': [('smerte', False)],
          'smerters': [('smerte', False)],
          'smet': [('sme', False)],
          'smets': [('sme', False)],
          'smider': [('smider', False)],
          'smiderne': [('smider', False)],
          'smidernes': [('smider', False)],
          'smiders': [('smider', False)],
          'smidler': [('smiddel', False)],
          'smidlerne': [('smiddel', False)],
          'smidlernes': [('smiddel', False)],
          'smidlers': [('smiddel', False)],
          'smiks': [('smik', False)],
          'smilet': [('smil', True)],
          'smilets': [('smil', True)],
          'sminen': [('smin', False)],
          'sminens': [('smin', False)],
          'sminer': [('smin', False)],
          'sminerne': [('smin', False)],
          'sminernes': [('smin', False)],
          'sminers': [('smin', False)],
          'sminister': [('sminister', False)],
          'sministers': [('sminister', False)],
          'sminken': [('sminke', True)],
          'sminkens': [('sminke', False)],
          'smissen': [('smisse', False)],
          'smissens': [('smisse', False)],
          'smisser': [('smisse', False)],
          'smisserne': [('smisse', False)],
          'smissernes': [('smisse', False)],
          'smissers': [('smisse', False)],
          'smissioner': [('smission', False)],
          'smissionerne': [('smission', False)],
          'smissionernes': [('smission', False)],
          'smitter': [('smitter', False)],
          'smitterne': [('smitter', False)],
          'smitternes': [('smitter', False)],
          'smitters': [('smitter', False)],
          'smodet': [('smod', False)],
          'smodets': [('smod', False)],
          'smosen': [('smose', False)],
          'smosens': [('smose', False)],
          'smus': [('smus', False)],
          'smusen': [('smus', False)],
          'smusens': [('smus', False)],
          'smutten': [('smutte', False)],
          'smuttens': [('smutte', False)],
          'smutter': [('smutter', True)],
          'smutterne': [('smutter', True)],
          'smutternes': [('smutter', True)],
          'smutters': [('smutter', True), ('smutters', True)],
          'smykker': [('smykke', False)],
          'smykkerne': [('smykke', False)],
          'smækker': [('smæk', True)],
          'smækkerne': [('smæk', True)],
          'smækkernes': [('smæk', False)],
          'smækkers': [('smæk', False)],
          'smælder': [('smælder', True)],
          'smælderne': [('smælder', False)],
          'smældernes': [('smælder', False)],
          'smælders': [('smælder', True)],
          'smælken': [('smælk', False)],
          'smælkens': [('smælk', False)],
          'smænd': [('smand', False)],
          'smændene': [('smand', False)],
          'smændenes': [('smand', False)],
          'smænds': [('smand', False)],
          'smærkerne': [('smærke', False)],
          'smærkernes': [('smærke', False)],
          'smærkers': [('smærke', False)],
          'smøder': [('smøde', False)],
          'smøderne': [('smøde', False)],
          'smødernes': [('smøde', False)],
          'smøgen': [('smøg', True), ('smøge', True)],
          'smøgens': [('smøg', True), ('smøge', True)],
          'smøger': [('smøge', True), ('smøg', True)],
          'smøgerne': [('smøg', True), ('smøge', True)],
          'smøgernes': [('smøg', True), ('smøge', True)],
          'smøgers': [('smøg', True), ('smøge', True)],
          'smørens': [('smøre', True)],
          'smører': [('smører', True), ('smøre', True)],
          'smørerne': [('smører', True), ('smøre', True)],
          'smørernes': [('smøre', True), ('smører', True)],
          'smørers': [('smører', True), ('smøre', True)],
          'snadder': [('snadde', True)],
          'snadders': [('snadde', True)],
          'snakke': [('snak', True)],
          'snakken': [('snak', False)],
          'snakkens': [('snak', False)],
          'snakker': [('snakker', False)],
          'snakkerne': [('snakker', False)],
          'snakkernes': [('snakker', False)],
          'snakkers': [('snakker', False)],
          'snakkes': [('snak', True)],
          'snapper': [('snapper', False)],
          'snappers': [('snapper', False)],
          'snaps': [('snap', True), ('snaps', True)],
          'snarerne': [('snare', True)],
          'snarers': [('snare', True)],
          'snarre': [('snarre', False)],
          'snarren': [('snarre', False)],
          'snarrens': [('snar', False)],
          'snarrer': [('snarre', False)],
          'snarrerne': [('snarre', False)],
          'snarrernes': [('snarre', False)],
          'snarres': [('snarre', False)],
          'snavs': [('snavs', True), ('snav', True)],
          'sne': [('sne', True)],
          'snen': [('snen', False)],
          'snens': [('snen', False)],
          'sneppen': [('sneppe', False)],
          'sneppens': [('sneppe', False)],
          'snepperne': [('sneppe', True)],
          'sneppers': [('sneppe', True)],
          'sner': [('sen', False)],
          'snernes': [('sen', False)],
          'sners': [('sen', False)],
          'snes': [('snes', True), ('sne', True)],
          "snes'": [('snes', True)],
          'snese': [('snes', True)],
          'snesen': [('snes', True)],
          'snesene': [('snes', True)],
          'snesenes': [('snes', True)],
          'snesens': [('snes', True)],
          'sneses': [('snes', True)],
          'snet': [('sen', False)],
          'snets': [('sen', False)],
          'snierne': [('snier', False)],
          'sniernes': [('snier', False)],
          'snilden': [('snilde', True)],
          'snildens': [('snilde', True)],
          'sningers': [('sning', False)],
          'snippen': [('snippe', True), ('snip', True)],
          'snippens': [('snippe', True), ('snip', True)],
          'snipper': [('snippe', True), ('snip', True)],
          'snipperne': [('snippe', True), ('snip', True)],
          'snippernes': [('snip', True), ('snippe', True)],
          'snippers': [('snip', True), ('snippe', True)],
          'snips': [('snip', True)],
          'snittens': [('snitte', False)],
          'snitter': [('snitte', False)],
          'snitterne': [('snitte', False)],
          'snitternes': [('snitte', True)],
          'snitters': [('snitte', True)],
          'snogen': [('snog', False)],
          'snogens': [('snog', True)],
          'snuen': [('snue', True)],
          'snuens': [('snue', True)],
          'snus': [('snus', True)],
          'snusen': [('snus', True)],
          'snusens': [('snus', True)],
          'snørens': [('snøre', True)],
          'snørerne': [('snøre', False)],
          'so': [('so', False)],
          'soden': [('sod', True)],
          'sodens': [('sod', True)],
          'soders': [('sode', False)],
          'sodi': [('sodi', False)],
          'sodier': [('sodi', False)],
          'sodierne': [('sodi', False)],
          'sodiers': [('sodi', False)],
          'soen': [('so', False)],
          'soens': [('so', False)],
          'soer': [('so', False)],
          'soerne': [('so', False)],
          'soernes': [('so', False)],
          'soers': [('so', False)],
          'soffer': [('sof', False)],
          'soffers': [('sof', False)],
          'sofret': [('soffer', False)],
          'sofrets': [('soffer', False)],
          'sogne': [('sogn', False)],
          'sognes': [('sogn', False)],
          'soirer': [('soir', False)],
          'soirernes': [('soir', False)],
          'soiret': [('soir', False)],
          'soirets': [('soir', False)],
          'sokken': [('sok', False)],
          'sokker': [('sok', False)],
          'sokkerne': [('sok', False)],
          'sokkernes': [('sok', False)],
          'sokkers': [('sok', True)],
          'soklens': [('sokkel', True)],
          'sokser': [('sokse', False)],
          'solden': [('sold', True)],
          'soldene': [('sold', True)],
          'soldenes': [('sold', True)],
          'soldens': [('sold', True)],
          'sole': [('sol', True)],
          'solen': [('sol', True)],
          'solens': [('sol', True)],
          'soler': [('sol', False)],
          'solerne': [('sol', False)],
          'solernes': [('sol', True)],
          'solers': [('sol', True)],
          'soles': [('sol', True)],
          'soliene': [('solo', True)],
          'soliers': [('solie', False)],
          'solinger': [('soling', True)],
          'solingerne': [('soling', True)],
          'solingernes': [('soling', True)],
          'solis': [('solo', True)],
          'sollen': [('sol', False)],
          'sollens': [('solle', False)],
          'soller': [('sol', False)],
          'sollerne': [('sol', False)],
          'sollernes': [('sol', True)],
          'sollers': [('sol', True)],
          'sollets': [('sol', True)],
          'solos': [('solo', True)],
          'somalier': [('somalier', True)],
          'somaliernes': [('somalier', True)],
          'somaliers': [('somalier', True)],
          'somkostninger': [('somkostninger', False)],
          'somkostningernes': [('somkostninger', False)],
          'somkostningers': [('somkostninger', False)],
          'sommer': [('sommer', False)],
          'sonaler': [('sonale', False)],
          'sonalerne': [('sonale', False)],
          'sonalernes': [('sonale', False)],
          'sonalers': [('sonale', False)],
          'sonalet': [('sonale', False)],
          'sonalets': [('sonale', False)],
          'sonarbejderne': [('sonarbejde', False)],
          'sonarbejdernes': [('sonarbejde', False)],
          'sonater': [('sonate', True)],
          'sonaterne': [('sonate', True)],
          'sonaters': [('sonate', True)],
          'sonder': [('sonde', True)],
          'sonderne': [('sonde', False)],
          'sondernes': [('sonde', True)],
          'soner': [('soner', False)],
          'sonerne': [('soner', False)],
          'sonernes': [('soner', False)],
          'soners': [('soner', False)],
          'sonet': [('sonet', True)],
          'sonets': [('sonet', True)],
          'sonten': [('sont', False)],
          'sontens': [('sont', False)],
          'sonterne': [('sont', False)],
          'sonternes': [('sont', False)],
          'sonters': [('sont', False)],
          'sopras': [('sopras', False)],
          'soraner': [('soraner', False)],
          'soraners': [('soraner', True)],
          'sordnernes': [('sorden', False)],
          'sordrer': [('sordre', False)],
          'sordrerne': [('sordre', False)],
          'sordrernes': [('sordre', False)],
          'sorers': [('sor', False)],
          'sorgen': [('sorg', False)],
          'sorger': [('sorg', False)],
          'sorgerne': [('sorg', True)],
          'sorgernes': [('sorg', False)],
          'sorgers': [('sorg', False)],
          'sorgiernes': [('sorgie', False)],
          'sorier': [('sorium', False)],
          'sorierne': [('sorium', False)],
          'soriernes': [('sorium', False)],
          'soriers': [('sorie', False)],
          'soriet': [('sorium', False)],
          'soriets': [('sorium', False)],
          'sorium': [('sorie', False)],
          'soriums': [('sorie', False)],
          'sorlover': [('sorlov', False)],
          'sorloverne': [('sorlov', False)],
          'sorte': [('sort', False)],
          'sorten': [('sort', False)],
          'sortens': [('sort', False)],
          'sorter': [('sort', False)],
          'sorterne': [('sort', False)],
          'sorternes': [('sort', True)],
          'sorters': [('sort', True)],
          'sortes': [('sort', False)],
          'sortet': [('sort', False)],
          'sortets': [('sort', False)],
          'sortier': [('sortie', True)],
          'sortierne': [('sortie', True)],
          'sortiernes': [('sortie', True)],
          'sortiers': [('sortie', True)],
          'sorts': [('sort', False)],
          'sos': [('so', False)],
          "sos'": [('so', False)],
          'soste': [('sost', False)],
          'sotangens': [('sotang', False)],
          'sover': [('sover', False)],
          'soverne': [('sover', False)],
          'sovs': [('sovs', False)],
          'sovse': [('sovs', True)],
          'sovsen': [('sovs', False)],
          'sovser': [('sovs', False)],
          'sovserne': [('sovs', False)],
          'sovsernes': [('sovs', False)],
          'sovses': [('sovs', False)],
          'spakker': [('spakke', False)],
          'spakkerne': [('spakke', False)],
          'spakkernes': [('spakke', False)],
          'spakkers': [('spakke', False)],
          'spalmens': [('spalme', False)],
          'spalten': [('spalt', True), ('spalte', True)],
          'spaltens': [('spalte', True), ('spalt', True)],
          'spande': [('spand', False)],
          'spanden': [('spand', True)],
          'spandens': [('spand', False)],
          'spander': [('spander', False)],
          'spanderne': [('spander', False)],
          'spandernes': [('spander', False)],
          'spanders': [('spander', False)],
          'spandes': [('spand', False)],
          'spange': [('spange', True), ('spang', True)],
          'spangen': [('spange', True), ('spang', True)],
          'spangens': [('spange', True), ('spang', True)],
          'spanges': [('spange', True), ('spang', True)],
          'spanter': [('spant', True)],
          'spanterne': [('spant', True)],
          'spanternes': [('spant', True)],
          'spanters': [('spant', True)],
          'sparens': [('spar', True)],
          'sparer': [('spar', True), ('sparer', True)],
          'sparerne': [('sparer', True), ('spar', True)],
          'sparernes': [('spar', True), ('sparer', True)],
          'sparers': [('spar', True), ('sparer', True)],
          'sparket': [('spark', False)],
          'sparkets': [('spark', False)],
          'spas': [('spas', True), ('spa', True)],
          'spasens': [('spas', True)],
          'spatien': [('spatie', True)],
          'spatiens': [('spatie', True)],
          'spatier': [('spatie', True)],
          'spatierne': [('spatie', True)],
          'spatiernes': [('spatie', True)],
          'spatiers': [('spatie', True)],
          'spatten': [('spat', False)],
          'spattens': [('spat', False)],
          'spe': [('spe', True)],
          'species': [('specie', True), ('species', True)],
          'spekter': [('spekter', True)],
          'spekters': [('spekter', True)],
          'spels': [('spel', False)],
          'spen': [('sp', False)],
          'spene': [('sp', False)],
          'spenes': [('sp', False)],
          'spens': [('sp', False)],
          'spenser': [('spenser', False)],
          'spensernes': [('spenser', False)],
          'spensers': [('spenser', False)],
          'sper': [('sp', False)],
          'spere': [('sper', False)],
          'sperens': [('sper', False)],
          'speres': [('sper', False)],
          'sperne': [('sp', False)],
          'spernes': [('sp', False)],
          'spers': [('sp', False)],
          'spes': [('sp', False)],
          'spet': [('sp', False)],
          'spets': [('sp', False)],
          'spiber': [('spibe', False)],
          'spiberne': [('spibe', False)],
          'spibernes': [('spibe', False)],
          'spibers': [('spibe', False)],
          'spicen': [('spic', False)],
          'spicens': [('spic', False)],
          'spids': [('spids', True), ('spid', True)],
          'spidser': [('spids', True)],
          'spidserne': [('spids', False)],
          'spidsernes': [('spids', True)],
          'spidsers': [('spids', True)],
          'spiger': [('spiger', True)],
          'spigerne': [('spiger', True)],
          'spigernes': [('spiger', True)],
          'spigers': [('spiger', True)],
          'spild': [('spild', True)],
          'spildet': [('spild', True)],
          'spildets': [('spild', True)],
          'spilds': [('spild', True)],
          'spiller': [('spiller', False)],
          'spillerne': [('spiller', False)],
          'spillernes': [('spiller', False)],
          'spillers': [('spiller', False)],
          'spillets': [('spil', False)],
          'spils': [('spil', False)],
          'spindler': [('spindler', True), ('spindel', True)],
          'spindlerne': [('spindel', True), ('spindler', True)],
          'spindlernes': [('spindel', True), ('spindler', True)],
          'spindlers': [('spindler', True), ('spindel', True)],
          'spioner': [('spion', True)],
          'spioners': [('spion', False)],
          'spiren': [('spire', False)],
          'spirers': [('spire', True)],
          'spis': [('spis', False)],
          'spiser': [('spise', True)],
          'spiserne': [('spise', True)],
          'spisernes': [('spise', True)],
          'spisers': [('spise', True)],
          'spits': [('spit', False)],
          'splanet': [('splan', False)],
          'splanets': [('splan', False)],
          'splanter': [('splante', False)],
          'splanterne': [('splante', False)],
          'splanternes': [('splante', False)],
          'splanters': [('splante', False)],
          'splatter': [('splatter', True)],
          'splatterne': [('splatter', True)],
          'splatternes': [('splatter', True)],
          'splatters': [('splatter', True)],
          'splejer': [('spleje', False)],
          'splejerne': [('spleje', False)],
          'splejernes': [('spleje', False)],
          'splejers': [('spleje', False)],
          'splen': [('spel', False)],
          'splens': [('spel', False)],
          'spler': [('spel', False)],
          'splers': [('spel', False)],
          'spolen': [('spole', False)],
          'spolens': [('spole', True)],
          'spoler': [('spole', True)],
          'spolerne': [('spole', False)],
          'spolernes': [('spole', False)],
          'spolers': [('spole', False)],
          'sporer': [('spore', True)],
          'sporerne': [('spore', True)],
          'sporernes': [('spore', True)],
          'sporers': [('spore', False)],
          'spors': [('spor', False)],
          'sporterne': [('sport', False)],
          'sporternes': [('sport', False)],
          'sporters': [('sport', False)],
          'sposers': [('spose', False)],
          'sposter': [('spost', False)],
          'sposterne': [('spost', False)],
          'sposternes': [('spost', False)],
          'sposters': [('spost', False)],
          'spoten': [('spot', False)],
          'spotens': [('spot', False)],
          'spoter': [('spot', False)],
          'spoterne': [('spot', False)],
          'spoternes': [('spot', False)],
          'spoters': [('spot', False)],
          'spotten': [('spot', True)],
          'spottens': [('spot', False)],
          'spotter': [('spotter', False)],
          'spotterne': [('spotter', False)],
          'spotternes': [('spotter', True)],
          'spotters': [('spotter', True)],
          'spover': [('spove', False)],
          'spoverne': [('spove', True)],
          'spressen': [('spres', False)],
          'spressens': [('spresse', False)],
          'spresser': [('spresse', False)],
          'spresserne': [('spresser', False)],
          'spressernes': [('spresse', False)],
          'spressers': [('spresser', False)],
          'springers': [('springer', False)],
          'sprisen': [('spris', False)],
          'sprisens': [('spris', False)],
          'spriser': [('spris', False)],
          'spriserne': [('spris', False)],
          'sprisernes': [('spris', False)],
          'sprisers': [('spris', False)],
          'sprocenter': [('sprocent', False)],
          'sprocenters': [('sprocent', False)],
          'sproglærer': [('sproglærer', True), ('sproglære', True)],
          'sproglærerne': [('sproglære', True), ('sproglærer', True)],
          'sproglærernes': [('sproglære', True), ('sproglærer', True)],
          'sproglærers': [('sproglærer', True), ('sproglære', True)],
          'sprutten': [('sprut', True)],
          'spruttens': [('sprut', True)],
          'sprutter': [('sprutte', False)],
          'sprutterne': [('sprutte', False)],
          'sprutternes': [('sprutte', False)],
          'sprutters': [('sprutte', False)],
          'sps': [('sp', False)],
          'spumpen': [('spumpe', False)],
          'spumpens': [('spumpe', False)],
          'spumperne': [('spumpe', False)],
          'spuns': [('spuns', True)],
          'sputten': [('sput', False)],
          'sputtens': [('sput', False)],
          'sputter': [('sput', False)],
          'sputterne': [('sput', False)],
          'sputternes': [('sput', False)],
          'sputters': [('sput', False)],
          'spænder': [('spænde', True)],
          'spænderne': [('spænde', True)],
          'spændernes': [('spænde', True)],
          'spænders': [('spænde', True)],
          'spændet': [('spænd', True), ('spænde', True)],
          'spændets': [('spænd', True), ('spænde', True)],
          'spørger': [('spørger', False)],
          'spørgerne': [('spørger', False)],
          'spørgernes': [('spørger', False)],
          'spørgers': [('spørger', True)],
          'sramme': [('sramme', False)],
          'srammen': [('sramme', False)],
          'srammens': [('sramme', False)],
          'srammer': [('sramme', False)],
          'srammernes': [('sramme', False)],
          'srammes': [('sramme', False)],
          'sraterne': [('srate', False)],
          'sraters': [('srate', False)],
          'srede': [('srede', False)],
          'sreden': [('srede', False)],
          'sredens': [('srede', False)],
          'sreder': [('sreder', False)],
          'srederne': [('srede', False)],
          'sredernes': [('sreder', False)],
          'sreders': [('srede', False)],
          'sredes': [('srede', False)],
          'srejser': [('srejse', False)],
          'srenser': [('srenser', False)],
          'srensernes': [('srenser', False)],
          'sret': [('sret', False)],
          'srets': [('sret', False)],
          'sretter': [('sret', False)],
          'sretterne': [('sretter', False)],
          'sretternes': [('sretter', False)],
          'sretters': [('sretter', False)],
          'srigerne': [('srige', False)],
          'srigernes': [('srige', False)],
          'srigers': [('srige', False)],
          'sringer': [('sring', False)],
          'sringerne': [('sring', False)],
          'sringernes': [('sring', False)],
          'sringers': [('sring', False)],
          'sroden': [('srod', False)],
          'srodens': [('srod', False)],
          'srods': [('srod', False)],
          'sroen': [('sro', False)],
          'sroens': [('sro', False)],
          'sroer': [('sroer', False)],
          'sroerne': [('sroer', False)],
          'sroernes': [('sroer', False)],
          'sroers': [('sroer', False)],
          'srollen': [('srolle', False)],
          'sroller': [('srolle', False)],
          'srollerne': [('srolle', False)],
          'srollers': [('srolle', False)],
          'sros': [('sro', False)],
          'srosen': [('srose', False)],
          'srosens': [('srose', False)],
          'srottens': [('srotte', False)],
          'srotter': [('srotte', False)],
          'srotternes': [('srotte', False)],
          'srotters': [('srotte', False)],
          'sruder': [('srude', False)],
          'sruderne': [('srude', False)],
          'srudernes': [('srude', False)],
          'sruders': [('srude', False)],
          'sruller': [('srulle', False)],
          'srullers': [('srulle', False)],
          'srummet': [('srum', False)],
          'srummets': [('srum', False)],
          'srunde': [('srunde', False)],
          'srunden': [('srunde', False)],
          'srundens': [('srunde', False)],
          'srunders': [('srunde', False)],
          'srundes': [('srunde', False)],
          'srus': [('srus', False)],
          'sruse': [('srus', False)],
          'srusen': [('srus', False)],
          'srusens': [('srus', False)],
          'sruses': [('srus', False)],
          'sråden': [('sråd', False)],
          'srådens': [('sråd', False)],
          'sråders': [('sråd', False)],
          'srådet': [('sråd', False)],
          'srækker': [('srække', False)],
          'sræs': [('sræs', False)],
          'srønne': [('srøn', False)],
          'srønnen': [('srøn', False)],
          'srønnens': [('srøn', False)],
          'srønnes': [('srøn', False)],
          'srøret': [('srør', False)],
          'srørets': [('srør', False)],
          'srøver': [('srøver', False)],
          'srøvernes': [('srøver', False)],
          'srøvers': [('srøver', False)],
          'ss': [('ss', False)],
          "ss'": [('ss', False)],
          'ssagen': [('ssag', False)],
          'ssagens': [('ssage', False)],
          'ssager': [('ssage', False)],
          'ssagerne': [('ssage', False)],
          'ssagernes': [('ssage', False)],
          'ssagers': [('ssag', False)],
          'ssalierne': [('ssalie', False)],
          'ssaliernes': [('ssalie', False)],
          'ssanger': [('ssanger', False)],
          'ssarien': [('ssarius', False)],
          'ssariens': [('ssarius', False)],
          'ssarier': [('ssarium', False)],
          'ssarierne': [('ssarius', False)],
          'ssariernes': [('ssarius', False)],
          'ssariers': [('ssarium', False)],
          'ssats': [('ssat', False)],
          'sseer': [('sseer', False)],
          'ssejerne': [('ssej', False)],
          'sselen': [('ssel', False)],
          'sselens': [('ssel', False)],
          'sselet': [('ssel', False)],
          'sselinerne': [('sselin', False)],
          'sseliners': [('sselin', False)],
          'sselinet': [('sselin', False)],
          'sselinets': [('sselin', False)],
          'sselærer': [('sselærer', False)],
          'sselærers': [('sselærer', False)],
          'sseners': [('ssene', False)],
          'ssentens': [('ssent', False)],
          'ssere': [('sser', False)],
          'sseredernes': [('ssereder', False)],
          'sseren': [('sser', False)],
          'sserens': [('sser', False)],
          'sserers': [('sserer', False)],
          'sseres': [('sser', False)],
          'sserier': [('sseri', False)],
          'sserierne': [('sseri', False)],
          'sseriernes': [('sseri', False)],
          'sseriers': [('sseri', False)],
          'ssers': [('sse', False)],
          'ssesten': [('ssesten', False)],
          'ssianerne': [('ssian', False)],
          'ssianernes': [('ssian', False)],
          'ssier': [('ssier', False)],
          'ssiers': [('ssier', False)],
          'ssikkens': [('ssik', False)],
          'ssinen': [('ssin', False)],
          'ssinens': [('ssin', False)],
          'ssinernes': [('ssin', False)],
          'ssingers': [('ssing', False)],
          'ssinier': [('ssinier', False)],
          'ssinierne': [('ssinier', False)],
          'ssiniernes': [('ssini', False)],
          'ssiniers': [('ssini', False)],
          'ssis': [('ssis', False)],
          'sskaber': [('sskab', False)],
          'sskaberne': [('sskab', False)],
          'sskabernes': [('sskab', False)],
          'sskabers': [('sskab', False)],
          'sskallen': [('sskal', False)],
          'sskallens': [('sskal', False)],
          'sskaller': [('sskal', False)],
          'sskallerne': [('sskal', False)],
          'sskallernes': [('sskal', False)],
          'sskallers': [('sskal', False)],
          'sskifte': [('sskifte', False)],
          'sskifter': [('sskifte', False)],
          'sskifterne': [('sskifte', False)],
          'sskifternes': [('sskift', False)],
          'sskifters': [('sskifte', False)],
          'sskiftes': [('sskift', False)],
          'sskiftet': [('sskift', False)],
          'sskiftets': [('sskifte', False)],
          'sskurven': [('sskurve', False)],
          'sskurvens': [('sskurve', False)],
          'sskurves': [('sskurve', False)],
          'sslags': [('sslag', False)],
          'sslangen': [('sslange', False)],
          'sslangens': [('sslange', False)],
          'ssole': [('ssol', False)],
          'ssolens': [('ssol', False)],
          'ssollen': [('ssolle', False)],
          'ssoller': [('ssolle', False)],
          'ssollerne': [('ssolle', False)],
          'ssollernes': [('ssolle', False)],
          'ssollers': [('ssolle', False)],
          'ssorier': [('ssorie', False)],
          'ssorierne': [('ssorie', False)],
          'ssoriernes': [('ssorie', False)],
          'ssories': [('ssorie', False)],
          'ssoriet': [('ssorie', False)],
          'ssoriets': [('ssorie', False)],
          'sspidser': [('sspidser', False)],
          'sspidserne': [('sspidser', False)],
          'sspidsernes': [('sspidser', False)],
          'sspidsers': [('sspidser', False)],
          'sspild': [('sspilde', False)],
          'sspildet': [('sspilde', False)],
          'sspildets': [('sspilde', False)],
          'sspilds': [('sspilde', False)],
          'sstave': [('sstav', False)],
          'sstaven': [('sstav', False)],
          'sstavens': [('sstav', False)],
          'sstaves': [('sstav', False)],
          'sstemmer': [('sstemme', False)],
          'sstemmerne': [('sstemme', False)],
          'sstemmernes': [('sstemme', False)],
          'sstemmers': [('sstemme', False)],
          'sstempler': [('sstempel', False)],
          'sstemplerne': [('sstempel', False)],
          'sstemplernes': [('sstempel', False)],
          'sstemplers': [('sstempel', False)],
          'ssten': [('ssten', False)],
          'sstens': [('ssten', False)],
          'ssti': [('ssti', False)],
          'sstien': [('sstien', False)],
          'sstiens': [('ssti', False)],
          'sstifter': [('sstifter', False)],
          'sstifterne': [('sstifter', False)],
          'sstifternes': [('sstifter', False)],
          'sstifters': [('sstifter', False)],
          'sstraffe': [('sstraf', False)],
          'sstraffene': [('sstraf', False)],
          'sstraffenes': [('sstraf', False)],
          'sstraffes': [('sstraf', False)],
          'sstykkernes': [('sstykke', False)],
          'sstykkers': [('sstykke', False)],
          'sstyrer': [('sstyre', False)],
          'sstyrerne': [('sstyre', False)],
          'sstyrernes': [('sstyre', False)],
          'sstyrers': [('sstyre', False)],
          'sstyret': [('sstyre', False)],
          'sstyrets': [('sstyre', False)],
          'sstænger': [('sstang', False)],
          'sstængerne': [('sstang', False)],
          'sstængernes': [('sstang', False)],
          'sstængers': [('sstang', False)],
          'ssummer': [('ssum', False)],
          'ssummerne': [('ssum', False)],
          'ssummernes': [('ssum', False)],
          'ssummers': [('ssum', False)],
          'ssuren': [('ssur', False)],
          'ssurens': [('ssur', False)],
          'ssurer': [('ssur', False)],
          'ssurerne': [('ssur', False)],
          'ssurernes': [('ssur', False)],
          'ssurers': [('ssur', False)],
          'ssus': [('ssus', False)],
          'ssvensker': [('ssvensker', False)],
          'ssvenskerne': [('ssvensker', False)],
          'ssvenskernes': [('ssvensker', False)],
          'ssvenskers': [('ssvensker', False)],
          'ssynder': [('ssynd', False)],
          'ssynderne': [('ssynd', False)],
          'ssyndernes': [('ssynd', False)],
          'ssynders': [('ssynd', False)],
          'ssyren': [('ssyre', False)],
          'ssyrens': [('ssyre', False)],
          'ssyrer': [('ssyrer', False)],
          'ssyrerne': [('ssyre', False)],
          'ssyrernes': [('ssyrer', False)],
          'ssyrers': [('ssyrer', False)],
          'ssøren': [('ssør', False)],
          'ssørens': [('ssør', False)],
          'ssører': [('ssør', False)],
          'ssørernes': [('ssør', False)],
          'stabe': [('stab', True)],
          'staben': [('stab', False)],
          'stabenes': [('stab', False)],
          'stabens': [('stab', True)],
          'staber': [('stabe', False)],
          'staberne': [('stabe', False)],
          'stabernes': [('stabe', False)],
          'stabers': [('stabe', False)],
          'stabes': [('stab', True)],
          'stabler': [('stabel', True), ('stabler', True)],
          'stablerne': [('stabel', True), ('stabler', True)],
          'stablernes': [('stabler', True), ('stabel', True)],
          'stablers': [('stabel', True), ('stabler', True)],
          'stabs': [('stab', False)],
          'staden': [('stad', False)],
          'stadens': [('stad', False)],
          'stads': [('stads', True), ('stad', True)],
          'stage': [('stage', True)],
          'stagen': [('stage', True)],
          'stagens': [('stage', False)],
          'stager': [('stage', False)],
          'stagere': [('stager', False)],
          'stageren': [('stager', False)],
          'stagerens': [('stager', False)],
          'stageres': [('stager', False)],
          'stagerne': [('stage', False)],
          'stagernes': [('stage', False)],
          'stagers': [('stage', False)],
          'stages': [('stage', True)],
          'staklen': [('stakkel', True)],
          'staklerne': [('stakkel', True)],
          'staklernes': [('stakkel', True)],
          'staklers': [('stakkel', True)],
          'staks': [('stak', False)],
          'stalens': [('stal', False)],
          'staler': [('stal', False)],
          'stalerne': [('stale', False)],
          'stalernes': [('stale', False)],
          'stalers': [('stal', False)],
          'staller': [('staller', False)],
          'stallerne': [('stal', False)],
          'stallernes': [('stal', False)],
          'stallers': [('staller', False)],
          'stamenter': [('stamente', False)],
          'stamenterne': [('stament', False)],
          'stamenternes': [('stament', False)],
          'stamenters': [('stament', False)],
          'stamentet': [('stamente', False)],
          'stamentets': [('stamente', False)],
          'stammen': [('stammen', True), ('stamme', True)],
          'stammens': [('stammen', True), ('stamme', True)],
          'stammer': [('stammer', True), ('stamme', True)],
          'stammerne': [('stammer', True), ('stamme', True)],
          'stammernes': [('stammer', True), ('stamme', True)],
          'stammers': [('stammer', True), ('stamme', True)],
          'stampe': [('stampe', True)],
          'stan': [('stan', False)],
          'stande': [('stand', True)],
          'standen': [('stand', False)],
          'standens': [('stand', False)],
          'stander': [('stander', False)],
          'standerne': [('stander', False)],
          'standernes': [('stander', False)],
          'standers': [('stander', False)],
          'standes': [('stand', False)],
          'stanen': [('stan', False)],
          'stanerne': [('staner', False)],
          'stanernes': [('staner', False)],
          'stangen': [('stang', False)],
          'stangens': [('stang', False)],
          'stanger': [('stang', False)],
          'stangerne': [('stang', False)],
          'stangernes': [('stang', False)],
          'stangers': [('stang', False)],
          'stanke': [('stank', True)],
          'stanken': [('stank', False)],
          'stankens': [('stank', True)],
          'stanker': [('stanke', False)],
          'stankerne': [('stanker', False)],
          'stankernes': [('stanke', False)],
          'stankers': [('stanke', False)],
          'stankes': [('stank', True)],
          'stans': [('stan', False)],
          'stansen': [('stanse', True)],
          'stansens': [('stanse', True)],
          'stanser': [('stanse', True)],
          'stanserne': [('stanse', True)],
          'stansernes': [('stanse', True)],
          'stansers': [('stanse', True)],
          'stanten': [('stant', False)],
          'stantens': [('stant', False)],
          'stanter': [('stant', False)],
          'stanterne': [('stant', False)],
          'stanternes': [('stant', False)],
          'stanters': [('stant', False)],
          'stapper': [('stap', False)],
          'stapperne': [('stap', False)],
          'stappernes': [('stap', False)],
          'stappers': [('stap', False)],
          'starbejder': [('starbejder', False)],
          'starbejderne': [('starbejder', False)],
          'starter': [('starter', True), ('start', True)],
          'starterne': [('start', True), ('starter', True)],
          'starternes': [('starter', True), ('start', True)],
          'starters': [('start', True), ('starter', True)],
          'stas': [('sta', False)],
          'staten': [('stat', False)],
          'statens': [('stat', False)],
          'stater': [('stat', False)],
          'staterne': [('stat', False)],
          'staternes': [('stat', False)],
          'staters': [('stat', False)],
          'stats': [('stat', False)],
          'stave': [('stave', True), ('stav', True)],
          'staven': [('stave', True), ('stav', True)],
          'stavens': [('stave', True), ('stav', True)],
          'staver': [('stave', True), ('staver', True)],
          'staverne': [('stave', True), ('staver', True)],
          'stavernes': [('staver', True), ('stave', True)],
          'stavers': [('stave', True), ('staver', True)],
          'staves': [('stave', True), ('stav', True)],
          'stavlen': [('stavle', False)],
          'stavlens': [('stavle', False)],
          'stboerne': [('stboer', False)],
          'stboernes': [('stboer', False)],
          'stboers': [('stboer', False)],
          'stcyklen': [('stcykel', False)],
          'ste': [('st', False)],
          'steater': [('steater', False)],
          'steaters': [('steater', False)],
          'steder': [('sted', False)],
          'stederne': [('sted', False)],
          'stedernes': [('sted', True)],
          'steders': [('sted', False)],
          'stefarens': [('stefar', False)],
          'stefædre': [('stefar', False)],
          'stefædrenes': [('stefar', False)],
          'stege': [('steg', False)],
          'stegen': [('steg', False)],
          'stegens': [('steg', False)],
          'stehandler': [('stehandler', False)],
          'stehandlers': [('stehandler', False)],
          'steinernes': [('steiner', False)],
          'stelen': [('stele', True)],
          'stelens': [('stele', True)],
          'stelerne': [('stele', True)],
          'stellens': [('stel', False)],
          'stellerne': [('stel', False)],
          'stellernes': [('stel', False)],
          'steltene': [('stelten', False)],
          'steltenes': [('stelten', False)],
          'steløber': [('steløbe', False)],
          'steløbernes': [('steløbe', False)],
          'stemer': [('stem', False)],
          'stemerne': [('stem', False)],
          'stemernes': [('stem', False)],
          'stemers': [('stem', False)],
          'stemmen': [('stemme', False)],
          'stemmens': [('stemme', False)],
          'stemmer': [('stemme', True), ('stemmer', True)],
          'stemmerne': [('stemme', True), ('stemmer', True)],
          'stemmernes': [('stemme', True), ('stemmer', True)],
          'stemmers': [('stemme', True), ('stemmer', True)],
          'stempler': [('stempler', True), ('stempel', True)],
          'stemplerne': [('stempler', True), ('stempel', True)],
          'stemplernes': [('stempel', True), ('stempler', True)],
          'stemplers': [('stempler', True), ('stempel', True)],
          'sten': [('sten', True)],
          'stene': [('sten', True)],
          'stenernes': [('stener', False)],
          'stenes': [('sten', True)],
          'stens': [('sten', True)],
          'stenserne': [('stens', False)],
          'stenten': [('stente', True)],
          'stentens': [('stente', True)],
          'stenter': [('stente', True)],
          'stenterne': [('stente', True)],
          'stenternes': [('stente', True)],
          'stenters': [('stente', True)],
          'steppen': [('steppe', True)],
          'steppens': [('steppe', True)],
          'stepper': [('steppe', True)],
          'stepperne': [('steppe', True)],
          'steppernes': [('steppe', True)],
          'steppers': [('steppe', True)],
          'ster': [('st', False)],
          'sterer': [('ster', False)],
          'stererne': [('ster', False)],
          'sterernes': [('ster', False)],
          'sterers': [('ster', False)],
          'steret': [('ster', False)],
          'sterets': [('ster', False)],
          'sterier': [('sterie', False)],
          'sterierne': [('sterie', False)],
          'steriernes': [('sterie', False)],
          'steriers': [('sterie', False)],
          'sterne': [('st', False)],
          'sternen': [('sterne', False)],
          'sternens': [('sterne', False)],
          'sterner': [('sterne', False)],
          'sternerne': [('sterne', False)],
          'sternernes': [('sterne', False)],
          'sterners': [('sterne', False)],
          'sternes': [('st', False)],
          'steroider': [('steroid', True)],
          'steroiderne': [('steroid', True)],
          'steroidernes': [('steroid', True)],
          'steroiders': [('steroid', True)],
          'sters': [('st', False)],
          "sters'": [('ster', False)],
          'stes': [('st', False)],
          'stet': [('st', False)],
          'steten': [('stet', False)],
          'stetens': [('stet', False)],
          'steterne': [('stet', False)],
          'steternes': [('stet', False)],
          'stets': [('st', False)],
          'stfangerne': [('stfanger', False)],
          'sthandler': [('sthandel', False)],
          'sthandlers': [('sthandel', False)],
          'sthuset': [('sthus', False)],
          'sti': [('sti', True)],
          'sticen': [('stic', False)],
          'sticens': [('stic', False)],
          'stichen': [('stiche', False)],
          'stichens': [('stiche', False)],
          'sticher': [('stiche', False)],
          'sticherne': [('stiche', False)],
          'stichers': [('stiche', False)],
          'stiden': [('stid', False)],
          'stider': [('stid', False)],
          'stiderne': [('stid', False)],
          'stidernes': [('stid', False)],
          'stiders': [('stid', False)],
          'stids': [('stid', False)],
          'stien': [('sti', True)],
          'stiene': [('sto', False)],
          'stienes': [('sto', False)],
          'stiens': [('sti', True)],
          'stier': [('sti', False)],
          'stierne': [('sti', True)],
          'stiernes': [('sti', True)],
          'stiers': [('sti', True)],
          'sties': [('stie', False)],
          'stifter': [('stifter', True), ('stift', True)],
          'stifterne': [('stifter', True), ('stift', True)],
          'stifternes': [('stift', True), ('stifter', True)],
          'stifters': [('stift', True), ('stifter', True)],
          'stiger': [('stige', True)],
          'stigerne': [('stige', False)],
          'stigernes': [('stige', True)],
          'stigers': [('stige', True)],
          'stika': [('stika', False)],
          'stikaene': [('stikon', False)],
          'stikaenes': [('stikon', False)],
          'stikken': [('stikken', True), ('stik', True)],
          'stikkens': [('stik', False)],
          'stikker': [('stikker', True), ('stik', True)],
          'stikkere': [('stikker', True)],
          'stikkeren': [('stikker', True)],
          'stikkerens': [('stikker', True)],
          'stikkeres': [('stikker', True)],
          'stikkerne': [('stikkerne', True), ('stik', True), ('stikker', True)],
          'stikkernes': [('stikker', True), ('stik', True)],
          'stikkers': [('stik', True), ('stikker', True)],
          'stikon': [('stikon', False)],
          'stikons': [('stikon', False)],
          'stiks': [('stik', False)],
          'stilens': [('stil', False)],
          'stilet': [('stilet', True)],
          'stilets': [('stilet', True)],
          'stilisternes': [('stilist', True)],
          'stilisters': [('stilist', True)],
          'stillen': [('stil', False)],
          'stillens': [('stil', False)],
          'stiller': [('stiller', False)],
          'stillerne': [('stiller', False)],
          'stillernes': [('stiller', True)],
          'stillers': [('stiller', False)],
          'stillids': [('stillids', True)],
          'stimer': [('stime', False)],
          'stimerne': [('stime', False)],
          'stimernes': [('stime', False)],
          'stimers': [('stime', True)],
          'stinens': [('stinens', False)],
          'stinenser': [('stinenser', False)],
          'stinensernes': [('stinenser', False)],
          'stinensers': [('stinenser', False)],
          'stiner': [('stiner', False)],
          'stinernes': [('stiner', False)],
          'stis': [('sti', True)],
          'stits': [('stits', False)],
          'stiverne': [('stiver', True)],
          'stivers': [('stiver', False)],
          'stk.': [('styk', True), ('stykke', True)],
          'stlens': [('stel', False)],
          'stler': [('stel', False)],
          'stlerne': [('stler', False)],
          'stlernes': [('stler', False)],
          'stlers': [('stler', False)],
          'stlærer': [('stlære', False)],
          'stlærers': [('stlære', False)],
          'stner': [('stner', False)],
          'stnernes': [('stner', False)],
          'stners': [('stner', False)],
          'stnet': [('stnet', False)],
          'stnets': [('stnet', False)],
          'stningen': [('stning', False)],
          'stninger': [('stning', False)],
          'stningerne': [('stning', False)],
          'stningernes': [('stning', False)],
          'stoer': [('sto', False)],
          'stoerne': [('sto', False)],
          'stoernes': [('sto', False)],
          'stoers': [('sto', False)],
          'stoget': [('stog', False)],
          'stole': [('stol', False)],
          'stolen': [('stol', True)],
          'stolens': [('stol', False)],
          'stolernes': [('stol', False)],
          'stolers': [('stol', False)],
          'stoles': [('stol', False)],
          'stollen': [('stolle', True)],
          'stoller': [('stolle', True)],
          'stollers': [('stolle', True)],
          'stonen': [('ston', False)],
          'stonens': [('ston', False)],
          'stoner': [('ston', False)],
          'stonerne': [('ston', False)],
          'stonernes': [('ston', False)],
          'stoners': [('ston', False)],
          'stopperne': [('stopper', False)],
          'storis': [('storis', True)],
          'storium': [('storium', False)],
          'storiums': [('storium', False)],
          'stra': [('stra', False)],
          'straffe': [('straffe', True), ('straf', True)],
          'straffene': [('straffe', True), ('straf', True)],
          'straffenes': [('straffe', True), ('straf', True)],
          'straffes': [('straffe', True), ('straf', True)],
          'stras': [('stra', False)],
          'straten': [('strate', False)],
          'stratens': [('strate', False)],
          'strater': [('strate', False)],
          'straterne': [('strate', False)],
          'straternes': [('strate', False)],
          'straters': [('strate', False)],
          'stremme': [('strem', False)],
          'stremmen': [('strem', False)],
          'stremmens': [('strem', False)],
          'stremmes': [('strem', False)],
          'stren': [('ster', False)],
          'strene': [('ster', False)],
          'strenes': [('ster', False)],
          'strers': [('strer', False)],
          'stres': [('ster', False)],
          'stressen': [('stress', True)],
          'stressens': [('stress', True)],
          'strier': [('stri', False)],
          'strierne': [('stri', False)],
          'striernes': [('stri', False)],
          'strigerne': [('striger', False)],
          'strigernes': [('striger', False)],
          'strikke': [('strikke', True), ('strik', True)],
          'strikken': [('strikke', True), ('strik', True)],
          'strikkens': [('strikke', True), ('strik', True)],
          'strikker': [('strik', True), ('strikker', True), ('strikke', True)],
          'strikkerne': [('strikke', True), ('strik', True), ('strikker', True)],
          'strikkernes': [('strik', True), ('strikker', True), ('strikke', True)],
          'strikkers': [('strik', True), ('strikke', True), ('strikker', True)],
          'strikkes': [('strik', True), ('strikke', True)],
          'stringens': [('stringens', True)],
          'strisser': [('strisser', True)],
          'strisserne': [('strisser', True)],
          'strissernes': [('strisser', True)],
          'strissers': [('strisser', True)],
          'stronen': [('strone', False)],
          'stronens': [('strone', False)],
          'stropper': [('strop', False)],
          'stropperne': [('strop', False)],
          'stroppernes': [('strop', False)],
          'stroppers': [('strop', False)],
          'stros': [('stro', False)],
          'struder': [('struder', False)],
          'struderne': [('struder', False)],
          'strudernes': [('struder', False)],
          'struders': [('struder', False)],
          'strum': [('strum', False)],
          'strummernes': [('strum', False)],
          'strummers': [('strum', False)],
          'strums': [('strum', False)],
          'strupper': [('strupper', False)],
          'strupperne': [('strupper', False)],
          'struppernes': [('strupper', False)],
          'struppers': [('strupper', False)],
          'strus': [('stru', False)],
          'stræders': [('stræde', True)],
          'strækken': [('strække', False)],
          'strækkens': [('strække', False)],
          'strækker': [('strække', False)],
          'strækkerne': [('strække', False)],
          'strækkernes': [('strække', False)],
          'strækkers': [('strække', False)],
          'strømper': [('strømpe', False)],
          'strømperne': [('strømpe', True)],
          'strømpernes': [('strømpe', False)],
          'strømpers': [('strømpe', True)],
          'sts': [('st', False)],
          "sts'": [('st', False)],
          'sttaler': [('sttale', False)],
          'sttalers': [('sttale', False)],
          'sttiden': [('sttid', False)],
          'studen': [('stud', True)],
          'studens': [('stud', True)],
          'studes': [('stud', True)],
          'studies': [('studie', False)],
          'studiet': [('studie', False)],
          'studs': [('studs', True), ('stud', True)],
          'studse': [('studs', True)],
          'studsen': [('studs', True)],
          'studsens': [('studs', True)],
          'studser': [('studs', True)],
          'studserne': [('studs', True)],
          'studsernes': [('studs', True)],
          'studsers': [('studs', True)],
          'studses': [('studs', True)],
          'stuen': [('stue', False)],
          'stuens': [('stue', False)],
          'stuer': [('stue', False)],
          'stuerne': [('stue', False)],
          'stuernes': [('stue', False)],
          'stuers': [('stue', False)],
          'stugen': [('stuge', False)],
          'stugens': [('stuge', False)],
          'stuger': [('stuge', False)],
          'stugerne': [('stuge', False)],
          'stugernes': [('stuge', False)],
          'stugers': [('stuge', False)],
          'stumpen': [('stump', True)],
          'stumpens': [('stump', True)],
          'stumper': [('stump', True)],
          'stumperne': [('stump', False)],
          'stumpernes': [('stump', False)],
          'stumpers': [('stump', False)],
          'stunderne': [('stund', True)],
          'stundernes': [('stund', True)],
          'sture': [('stur', False)],
          'sturen': [('stur', False)],
          'sturenes': [('stur', False)],
          'sturens': [('stur', False)],
          'sturer': [('stur', False)],
          'sturerne': [('stur', False)],
          'sturernes': [('stur', False)],
          'sturers': [('stur', False)],
          'stures': [('stur', False)],
          'stus': [('stus', False)],
          'stuts': [('stuts', True)],
          'stykker': [('stykke', False)],
          'stykkerne': [('stykke', False)],
          'stykkernes': [('stykke', True)],
          'stykkers': [('stykke', True)],
          'stypens': [('stype', False)],
          'stypers': [('stype', False)],
          'styre': [('styre', False)],
          'styren': [('styren', True)],
          'styrens': [('styren', True)],
          'styrer': [('styre', True), ('styrer', True)],
          'styrerne': [('styre', True), ('styrer', True)],
          'styrernes': [('styre', True), ('styrer', True)],
          'styrers': [('styrer', True), ('styre', True)],
          'styres': [('styre', True)],
          'styret': [('styre', True), ('styr', True)],
          'styrets': [('styre', True), ('styr', True)],
          'styrken': [('styrke', False)],
          'styrkens': [('styrke', False)],
          'styrker': [('styrke', False)],
          'styrkerne': [('styrke', True)],
          'styrkernes': [('styrke', False)],
          'styrkers': [('styrke', False)],
          'styve': [('styv', False)],
          'styves': [('styv', False)],
          'ståen': [('ståen', False)],
          'ståens': [('ståen', False)],
          'ståls': [('stål', False)],
          'ståren': [('ståre', False)],
          'stårens': [('ståre', False)],
          'stæder': [('stad', True)],
          'stænder': [('stand', True)],
          'stænderne': [('stand', False)],
          'stændernes': [('stand', False)],
          'stænders': [('stand', True)],
          'stænger': [('stænge', True), ('stang', True)],
          'stængerne': [('stænge', True), ('stang', True)],
          'stængernes': [('stænge', True), ('stang', True)],
          'stængers': [('stænge', True), ('stang', True)],
          'stære': [('stær', True)],
          'stæren': [('stær', True)],
          'stævne': [('stævne', True), ('stævn', True)],
          'stævnes': [('stævne', True), ('stævn', True)],
          'stømmer': [('stømmer', False)],
          'stømmerne': [('stømmer', False)],
          'stømmernes': [('stømmer', False)],
          'stømmers': [('stømmer', False)],
          'stønder': [('stønde', False)],
          'stønders': [('stønde', False)],
          'støre': [('stør', True)],
          'stører': [('stør', True)],
          'støres': [('stør', True)],
          'støvler': [('støvle', True)],
          'støvlerne': [('støvle', True)],
          'støvlernes': [('støvle', True)],
          'støvlers': [('støvle', False)],
          'suder': [('suder', True)],
          'suderne': [('suder', True)],
          'sudernes': [('suder', True)],
          'suders': [('suder', True)],
          'suen': [('su', False)],
          'suens': [('su', False)],
          'suer': [('su', False)],
          'suerne': [('su', False)],
          'suernes': [('su', False)],
          'suers': [('su', False)],
          'suge': [('suge', False)],
          'sugen': [('suge', False)],
          'suger': [('suger', True)],
          'sugerne': [('suger', False)],
          'sugernes': [('suger', True)],
          'sugers': [('suger', False)],
          'suges': [('suge', False)],
          'suglerne': [('sugle', False)],
          'suglers': [('sugle', False)],
          'suiten': [('suite', True)],
          'suitens': [('suite', True)],
          'suiterne': [('suite', False)],
          'suiternes': [('suite', False)],
          'sukker': [('sukker', False)],
          'sukkernes': [('sukker', False)],
          'sulden': [('suld', False)],
          'sule': [('sule', True)],
          'sulen': [('sule', True)],
          'sulens': [('sule', True)],
          'suler': [('sule', True)],
          'sulerne': [('sule', True)],
          'sulernes': [('sule', True)],
          'sulers': [('sule', True)],
          'sules': [('sule', True)],
          'sulet': [('sul', True)],
          'sulten': [('sult', False)],
          'sultens': [('sult', False)],
          'sum': [('sum', False)],
          'sumets': [('sum', False)],
          'summen': [('sum', False)],
          'summens': [('sum', False)],
          'summer': [('summer', True), ('sum', True)],
          'summerne': [('summer', True), ('sum', True)],
          'summernes': [('summer', True), ('sum', True)],
          'summers': [('summer', True), ('sum', True)],
          'sumpe': [('sump', True)],
          'sumpen': [('sump', True)],
          'sumpens': [('sump', True)],
          'sumpes': [('sump', True)],
          'sums': [('sum', False)],
          'sunde': [('sund', True)],
          'sunderne': [('sunder', False)],
          'sunders': [('sunder', False)],
          'sundes': [('sund', True)],
          'sunerne': [('sun', False)],
          'suners': [('sun', False)],
          'suns': [('sun', False)],
          'supiner': [('supinum', True)],
          'supinernes': [('supinum', True)],
          'supper': [('suppe', False)],
          'suppernes': [('suppe', True)],
          'suppes': [('suppe', False)],
          'sure': [('sure', False)],
          'suren': [('sure', False)],
          'surens': [('sure', False)],
          'surer': [('sure', False)],
          'surerne': [('sure', False)],
          'surernes': [('sure', False)],
          'surers': [('sure', False)],
          'sures': [('sure', False)],
          'suret': [('sur', False)],
          'surets': [('sur', False)],
          'surier': [('surium', False)],
          'surierne': [('surium', False)],
          'suriernes': [('surium', False)],
          'suriers': [('surium', False)],
          'surrets': [('sur', True)],
          'surs': [('sur', False)],
          'surser': [('surse', False)],
          'surserne': [('surse', False)],
          'sursernes': [('surse', False)],
          'sursers': [('surse', False)],
          'surter': [('surt', False)],
          'sus': [('sus', True)],
          'sussen': [('sus', False)],
          'sussens': [('sus', False)],
          'susser': [('sus', False)],
          'susserne': [('sus', False)],
          'sutten': [('sut', True)],
          'suttens': [('sut', True)],
          'sutterne': [('sut', False)],
          'sutternes': [('sut', True)],
          'sutters': [('sut', True)],
          'suturen': [('sutur', True)],
          'suturens': [('sutur', True)],
          'svaberne': [('svaber', True)],
          'svalen': [('svale', True)],
          'svalens': [('svale', True)],
          'svaler': [('svale', True)],
          'svanen': [('svane', False)],
          'svanens': [('svane', False)],
          'svaner': [('svane', True)],
          'svanerne': [('svane', False)],
          'svanernes': [('svane', True)],
          'svaners': [('svane', False)],
          'svangen': [('svang', True)],
          'svangens': [('svang', True)],
          'svans': [('svans', False)],
          'svarer': [('svarer', False)],
          'svarerne': [('svarer', False)],
          'svarernes': [('svarer', False)],
          'svarers': [('svarer', False)],
          'sveden': [('sved', False)],
          'svedens': [('sved', False)],
          'sveders': [('sveder', True)],
          'sveje': [('svej', False)],
          'svejens': [('svej', False)],
          'svejes': [('svej', False)],
          'svellen': [('svelle', True)],
          'sveller': [('svelle', True)],
          'svellerne': [('svelle', True)],
          'svellers': [('svelle', True)],
          'sven': [('sven', False)],
          'svens': [('sven', False)],
          'svensken': [('svenske', True), ('svensken', True)],
          'svenskens': [('svenske', True), ('svensken', True)],
          'svensker': [('svenske', True), ('svensker', True)],
          'svenskerne': [('svenske', True), ('svensker', True)],
          'svenskernes': [('svenske', True), ('svensker', True)],
          'svenskers': [('svenske', True), ('svensker', True)],
          'svesten': [('svest', False)],
          'svestens': [('svest', False)],
          'svidens': [('sviden', False)],
          'svien': [('svie', True)],
          'sviens': [('svie', True)],
          'svier': [('svie', True)],
          'svierne': [('svie', True)],
          'sviernes': [('svie', True)],
          'sviers': [('svie', True)],
          'svikler': [('svikkel', True)],
          'sviklerne': [('svikkel', True)],
          'sviklernes': [('svikkel', True)],
          'sviklers': [('svikkel', True)],
          'svinden': [('svind', False)],
          'svindens': [('svind', False)],
          'svinder': [('svinder', False)],
          'svinderne': [('svinder', False)],
          'svindernes': [('svinder', False)],
          'svinders': [('svinder', False)],
          'svinen': [('svin', False)],
          'svinens': [('svin', False)],
          'svines': [('svin', False)],
          'svinger': [('svinger', True)],
          'svingerne': [('svinger', True)],
          'svingernes': [('svinger', True)],
          'svingers': [('svinger', True)],
          'svins': [('svin', False)],
          'sviren': [('svir', True)],
          'svirens': [('svir', True)],
          'sviser': [('svise', False)],
          'sviserne': [('svise', False)],
          'svisernes': [('svise', False)],
          'svisers': [('svise', False)],
          'svits': [('svit', False)],
          'svortes': [('svorte', False)],
          'svåbnerne': [('svåben', False)],
          'svågers': [('svåge', False)],
          'svælden': [('svælde', False)],
          'svældet': [('svælde', False)],
          'svældets': [('svælde', False)],
          'sværen': [('svær', True)],
          'sværens': [('svær', False)],
          'sværet': [('svær', False)],
          'sværets': [('svær', False)],
          'sværge': [('sværge', False)],
          'sværgen': [('sværge', False)],
          'sværker': [('sværker', False)],
          'sværkerne': [('sværker', False)],
          'sværkernes': [('sværker', False)],
          'sværkers': [('sværker', False)],
          'sværs': [('svær', True)],
          'sværten': [('sværte', False)],
          'sværtens': [('sværte', True)],
          'sværter': [('sværte', False)],
          'sværterne': [('sværte', True)],
          'sværternes': [('sværte', True)],
          'sværters': [('sværte', False)],
          'svøben': [('svøbe', True)],
          'svøbens': [('svøbe', True)],
          'swinger': [('swinger', True)],
          'swingerne': [('swinger', True)],
          'swingernes': [('swinger', True)],
          'swingers': [('swinger', True)],
          'syden': [('syden', True)],
          'sydens': [('syden', True)],
          'syderne': [('syder', False)],
          'syen': [('sy', False)],
          'syens': [('sy', False)],
          'sygen': [('syge', False)],
          'syger': [('syge', True)],
          'sykerne': [('syke', False)],
          'sylden': [('syld', True)],
          'syldens': [('syld', True)],
          'sylenes': [('syl', False)],
          'symposier': [('symposium', True), ('symposie', True), ('symposion', True)],
          'symposierne': [('symposium', True), ('symposion', True), ('symposie', True)],
          'symposiernes': [('symposion', True), ('symposie', True), ('symposium', True)],
          'symposiers': [('symposie', True), ('symposion', True), ('symposium', True)],
          'symposiet': [('symposion', True), ('symposium', True), ('symposie', True)],
          'symposiets': [('symposion', True), ('symposium', True), ('symposie', True)],
          'synden': [('synd', False)],
          'syndens': [('synd', True)],
          'synder': [('synder', True), ('synd', True)],
          'synderne': [('synder', True), ('synd', True)],
          'syndernes': [('synd', True), ('synder', True)],
          'synders': [('synd', True), ('synder', True)],
          'synerne': [('syn', True)],
          'syners': [('syn', False)],
          'syre': [('syre', False)],
          'syren': [('syren', True), ('syre', True)],
          'syrens': [('syren', True), ('syre', True)],
          'syrer': [('syrer', True), ('syre', True)],
          'syrerne': [('syrer', True), ('syre', True)],
          'syrernes': [('syrer', True), ('syre', True)],
          'syrers': [('syrer', True), ('syre', True)],
          'sys': [('sy', False)],
          'syslerne': [('syssel', True)],
          'syslers': [('syssel', False)],
          'såler': [('sål', False)],
          'sålerne': [('sål', False)],
          'sålers': [('sål', False)],
          'sånden': [('sånd', False)],
          'såndens': [('sånd', False)],
          'sånders': [('sånd', False)],
          'såre': [('såre', False)],
          'sårens': [('såre', False)],
          'sårer': [('såre', False)],
          'sårerne': [('såre', False)],
          'sårernes': [('såre', False)],
          'sårers': [('såre', False)],
          'såtten': [('såt', False)],
          'såttens': [('såt', False)],
          'såtternes': [('såt', False)],
          'såtters': [('såt', False)],
          'sæbens': [('sæbe', False)],
          'sæberne': [('sæbe', False)],
          'sæbers': [('sæbe', True)],
          'sæbler': [('sæble', False)],
          'sæden': [('sæd', False)],
          'sædens': [('sæd', True)],
          'sæder': [('sæd', True), ('sæde', True)],
          'sæderne': [('sæd', True), ('sæde', True)],
          'sædernes': [('sæd', True), ('sæde', True)],
          'sæders': [('sæd', True), ('sæde', True)],
          'sæers': [('sæer', False)],
          'sægge': [('sæg', False)],
          'sægges': [('sæg', False)],
          'sække': [('sæk', False)],
          'sækken': [('sæk', False)],
          'sækkes': [('sæk', False)],
          'sænkens': [('sænke', True)],
          'sænkerne': [('sænke', True)],
          'sænkernes': [('sænke', True)],
          'sænkers': [('sænke', True)],
          'særen': [('sær', False)],
          'særens': [('sær', False)],
          'særer': [('sær', False)],
          'særers': [('sær', False)],
          'særke': [('særk', True)],
          'særken': [('særk', False)],
          'særker': [('særk', False)],
          'særkerne': [('særk', False)],
          'særkernes': [('særk', False)],
          'særkers': [('særk', False)],
          'særkes': [('særk', True)],
          'sæter': [('sæter', True)],
          'sæternes': [('sæter', True)],
          'sætter': [('sætter', True)],
          'sætterne': [('sætter', False)],
          'sætternes': [('sætter', True)],
          'sætters': [('sætter', False)],
          'søbo': [('søbo', False)],
          'søboen': [('søbo', False)],
          'søboens': [('søbo', False)],
          'søboer': [('søbo', False)],
          'søboerne': [('søbo', False)],
          'søboernes': [('søbo', False)],
          'søboers': [('søbo', False)],
          'søbos': [('søbo', False)],
          'søen': [('sø', False)],
          'søens': [('sø', False)],
          'søer': [('so', True), ('sø', True)],
          'søerne': [('so', True), ('sø', True)],
          'søernes': [('so', True), ('sø', True)],
          'søers': [('so', True), ('sø', True)],
          'søgerne': [('søger', False)],
          'søgernes': [('søger', False)],
          'søgers': [('søger', False)],
          'søje': [('søje', False)],
          'søjes': [('søje', False)],
          'søjet': [('søje', False)],
          'søjlerne': [('søjle', False)],
          'søjlernes': [('søjle', False)],
          'søjnes': [('søje', False)],
          'søle': [('søle', True)],
          'sølen': [('søle', True)],
          'sølens': [('søle', True)],
          'søles': [('søle', True)],
          'sølets': [('søle', True)],
          'søllen': [('søl', False)],
          'sømme': [('søm', False)],
          'sømmen': [('søm', False)],
          'sømmens': [('søm', False)],
          'sømmes': [('søm', False)],
          'sønnen': [('søn', False)],
          'sønnens': [('søn', True)],
          'sønner': [('søn', False)],
          'sønnerne': [('søn', False)],
          'sønners': [('søn', False)],
          'søre': [('søre', False)],
          'søren': [('søren', True)],
          'sørens': [('søren', True)],
          'sører': [('søre', False)],
          'sørerne': [('sør', False)],
          'sørernes': [('søre', False)],
          'sørers': [('sør', False)],
          'søres': [('søre', False)],
          'søret': [('søret', True)],
          'sørets': [('søret', True)],
          'søs': [('sø', False)],
          'søse': [('søse', False)],
          'søser': [('søse', False)],
          'søsers': [('søse', False)],
          'søses': [('søse', False)],
          'søsters': [('søster', False)],
          "t'erne": [('t', True)],
          't-': [('tsektion', False)],
          't.': [('t.', False)],
          'ta': [('ta', False)],
          'tabasen': [('tabase', False)],
          'tabasens': [('tabase', False)],
          'tabaser': [('tabase', False)],
          'tabaserne': [('tabase', False)],
          'tabasernes': [('tabase', False)],
          'tabellen': [('tabel', False)],
          'tabeller': [('tabel', False)],
          'tabellers': [('tabel', True)],
          'tabene': [('tab', True)],
          'tabener': [('tabene', False)],
          'tabeners': [('tabene', False)],
          'tabenes': [('tab', True)],
          'taber': [('taber', True)],
          'taberne': [('taber', True)],
          'tabernes': [('taber', True)],
          'tabers': [('taber', True)],
          'tabet': [('tab', False)],
          'tabiliers': [('tabil', False)],
          'table': [('table', False)],
          'tabs': [('tab', True)],
          "tabs'": [('tabs', False)],
          'tabus': [('tabu', True)],
          'tade': [('tade', False)],
          'tadellen': [('tadel', False)],
          'taderne': [('tade', False)],
          'taders': [('tade', False)],
          'tades': [('tade', False)],
          'tadet': [('tade', False)],
          'tadets': [('tade', False)],
          'tadien': [('tadie', False)],
          'tadiens': [('tadie', False)],
          'tadier': [('tadie', False)],
          'tadierne': [('tadie', False)],
          'tadiernes': [('tadie', False)],
          'tadies': [('tadie', False)],
          'tadium': [('tadie', False)],
          'tadiums': [('tadie', False)],
          'tados': [('tado', False)],
          "tads'": [('tads', False)],
          'tadset': [('tads', False)],
          'tadsets': [('tads', False)],
          'taen': [('ta', False)],
          'taene': [('ta', False)],
          'taens': [('ta', False)],
          'taer': [('ta', False)],
          'taerne': [('ta', False)],
          'taernes': [('ta', False)],
          'taers': [('ta', False)],
          'tafet': [('tafet', False)],
          'tafets': [('tafet', False)],
          'taffen': [('taf', False)],
          'taffer': [('taf', False)],
          'taffernes': [('taf', False)],
          'taffers': [('taf', False)],
          'tafler': [('taffel', True)],
          'taflerne': [('taffel', True)],
          'taflernes': [('taffel', False)],
          'taflers': [('taffel', False)],
          'taften': [('taft', True)],
          'taftens': [('taft', True)],
          'tafterne': [('taft', True)],
          'tafternes': [('taft', True)],
          'tafters': [('taft', True)],
          'tage': [('tag', True)],
          'tagen': [('tage', False)],
          'tagens': [('tagen', False)],
          'tager': [('tager', False)],
          'tagererne': [('tagere', False)],
          'tagerernes': [('tagere', False)],
          'tagerers': [('tagere', False)],
          'tagerne': [('tager', False)],
          'tagernes': [('tager', False)],
          'tagers': [('tager', False)],
          'tages': [('tag', True)],
          'tagner': [('tagner', False)],
          'tagnerne': [('tagner', False)],
          'tagnernes': [('tagner', False)],
          'tagners': [('tagner', False)],
          'tagnet': [('tagnet', False)],
          'tagnets': [('tagnet', False)],
          'tainer': [('tainer', False)],
          'takater': [('takater', False)],
          'takaterne': [('takater', False)],
          'takaters': [('takater', False)],
          'takene': [('take', False)],
          'takenes': [('take', False)],
          'takes': [('take', False)],
          "takes'": [('take', False)],
          'takke': [('tak', False)],
          'takken': [('tak', False)],
          'takkerne': [('tak', False)],
          'takkes': [('tak', False)],
          'taklen': [('takel', False)],
          'taklens': [('takkel', False)],
          'takler': [('takkel', False)],
          'taklerne': [('takel', False)],
          'taklernes': [('takel', False)],
          'taklers': [('takel', False)],
          'taks': [('taks', True), ('tak', True)],
          "taks'": [('taks', False)],
          'taksen': [('taks', False)],
          'taksens': [('taks', True)],
          'takser': [('taks', False)],
          'takserne': [('taks', False)],
          'taksernes': [('taks', False)],
          'taksers': [('taks', False)],
          'takter': [('takt', False)],
          'takterne': [('takt', False)],
          'takternes': [('takt', False)],
          'takters': [('takt', False)],
          'talde': [('tald', False)],
          'talden': [('tald', False)],
          'taldens': [('tald', False)],
          'taldes': [('tald', False)],
          'tale': [('tale', False)],
          'talen': [('tale', False)],
          'talens': [('tale', True)],
          'taler': [('tale', True), ('taler', True)],
          'talerne': [('tale', True), ('taler', True)],
          'talernes': [('taler', True), ('tale', True)],
          'talers': [('taler', True), ('tale', True)],
          'tales': [('tale', False)],
          'talgen': [('talg', True)],
          'talgens': [('talg', True)],
          'taliernes': [('talier', False)],
          'talken': [('talk', False)],
          'talkens': [('talk', True)],
          'talker': [('talker', False)],
          'talkerne': [('talker', False)],
          'talkernes': [('talker', False)],
          'talkers': [('talker', False)],
          'tallen': [('tal', False)],
          'tallens': [('tal', False)],
          'taller': [('tal', False)],
          'tallers': [('tal', False)],
          'talogens': [('talog', False)],
          'talten': [('talt', False)],
          'taltens': [('talt', False)],
          'talter': [('talt', False)],
          'talterne': [('talt', False)],
          'talternes': [('talt', False)],
          'talters': [('talt', False)],
          'tamanden': [('tamand', True)],
          'tamandens': [('tamand', True)],
          'tamen': [('tam', False)],
          'tamens': [('tam', False)],
          'tamenter': [('tament', False)],
          'tamentet': [('tament', False)],
          'tamentets': [('tament', False)],
          'tamiler': [('tamil', True), ('tamiler', True)],
          'tamilerne': [('tamil', True), ('tamiler', True)],
          'tamilernes': [('tamiler', True), ('tamil', True)],
          'tamilers': [('tamiler', True), ('tamil', True)],
          'taminer': [('tamin', False)],
          'taminerne': [('tamin', False)],
          'taminernes': [('tamin', False)],
          'taminers': [('tamin', False)],
          'tammer': [('tam', False)],
          'tammernes': [('tam', False)],
          'tampe': [('tamp', True)],
          'tampen': [('tamp', False)],
          'tampens': [('tamp', True)],
          'tamper': [('tamper', False)],
          'tampere': [('tamper', False)],
          'tamperes': [('tamper', False)],
          'tamperne': [('tamper', False)],
          'tampes': [('tamp', True)],
          'tampet': [('tamp', False)],
          'tampets': [('tamp', False)],
          'tande': [('tande', True)],
          'tanden': [('tande', True), ('tand', True)],
          'tandens': [('tande', True), ('tand', True)],
          'tander': [('tande', True)],
          'tanderne': [('tande', True)],
          'tandernes': [('tande', True)],
          'tanders': [('tande', True)],
          'tandes': [('tande', True)],
          'tanens': [('tan', False)],
          'taner': [('taner', False)],
          'tanerne': [('tan', False)],
          'tanernes': [('tan', False)],
          'taners': [('taner', False)],
          'tanettet': [('tanet', False)],
          'tanettets': [('tanet', False)],
          'tangas': [('tanga', True)],
          'tangen': [('tange', True), ('tang', True)],
          'tangens': [('tange', True), ('tangens', True), ('tang', True)],
          'tanger': [('tange', True)],
          'tangerne': [('tange', True)],
          'tangernes': [('tange', True)],
          'tangers': [('tange', False)],
          'tangler': [('tangel', False)],
          'tanglerne': [('tangel', False)],
          'tanglernes': [('tangel', False)],
          'tanglers': [('tangel', False)],
          'tanier': [('tani', False)],
          'tanierne': [('tanier', False)],
          'taniernes': [('tani', False)],
          'taniers': [('tanier', False)],
          'taniet': [('tani', False)],
          'taniets': [('tani', False)],
          'tanis': [('tani', False)],
          'tanister': [('tanist', False)],
          'tanisters': [('tanist', False)],
          'tanke': [('tanke', True), ('tank', True)],
          'tanken': [('tanke', True), ('tank', True)],
          'tankens': [('tank', True), ('tanke', True)],
          'tanker': [('tanke', True), ('tanker', True)],
          'tankerne': [('tanker', True), ('tanke', True)],
          'tankernes': [('tanker', True), ('tanke', True)],
          'tankers': [('tanker', True), ('tanke', True)],
          'tankes': [('tanke', True), ('tank', True)],
          'tanks': [('tank', False)],
          "tanks'": [('tank', True)],
          "tans'": [('tans', False)],
          'tansen': [('tans', False)],
          'tansens': [('tans', False)],
          'tanser': [('tans', False)],
          'tansernes': [('tans', False)],
          'tansers': [('tans', False)],
          'tanten': [('tante', True)],
          'tantens': [('tante', True)],
          'tanter': [('tante', True)],
          'tanterne': [('tante', True)],
          'tanternes': [('tante', True)],
          'tanters': [('tante', True)],
          'tants': [('tant', False)],
          'tanzer': [('tanze', False)],
          'tanzers': [('tanze', False)],
          'taper': [('tape', False)],
          'taperne': [('tape', False)],
          'tappe': [('tap', True)],
          'tappen': [('tap', False)],
          'tappens': [('tap', True)],
          'tapper': [('tapper', True), ('tap', True)],
          'tapperne': [('tap', True), ('tapper', True)],
          'tappernes': [('tapper', True), ('tap', True)],
          'tappers': [('tap', True), ('tapper', True)],
          'tarakter': [('tarakt', False)],
          'tarakters': [('tarakt', False)],
          'tarbejder': [('tarbejde', False)],
          'tarbejderne': [('tarbejde', False)],
          'tarbejdernes': [('tarbejder', False)],
          'tarbejders': [('tarbejder', False)],
          'tarerne': [('tar', False)],
          'tarers': [('tar', False)],
          'taret': [('taret', False)],
          'tarets': [('taret', False)],
          'tarier': [('tarium', False)],
          'tarierne': [('tarie', False)],
          'tariernes': [('tarie', False)],
          'tariers': [('tarie', False)],
          'tariet': [('tarium', False)],
          'tariets': [('tarium', False)],
          'tariner': [('tarin', False)],
          'tariners': [('tarin', False)],
          'tarium': [('tarie', False)],
          'tariums': [('tarie', False)],
          'tarmens': [('tarm', False)],
          'tarmes': [('tarm', False)],
          'tarotter': [('tarot', True)],
          'tarotternes': [('tarot', True)],
          'tarten': [('tart', False)],
          'tartens': [('tart', False)],
          'tarter': [('tart', False)],
          'tarterne': [('tart', False)],
          'tarts': [('tart', False)],
          'tarven': [('tarv', False)],
          'tarvens': [('tarv', False)],
          "tas'": [('ta', False)],
          'tase': [('tase', False)],
          'tasen': [('tase', False)],
          'tasens': [('tase', False)],
          'taser': [('tase', False)],
          'taserne': [('tase', False)],
          'tasernes': [('tase', False)],
          'tasers': [('tase', False)],
          'tases': [('tase', False)],
          'tasien': [('tasi', False)],
          'tasiens': [('tasi', False)],
          'tasier': [('tasi', False)],
          'tasierne': [('tasi', False)],
          'tasiernes': [('tasi', False)],
          'tasiers': [('tasi', False)],
          'tasis': [('tasi', False)],
          'taske': [('taske', False)],
          'tasken': [('taske', False)],
          'taskens': [('taske', False)],
          'taskernes': [('taske', False)],
          'taskes': [('taske', False)],
          'tassen': [('tas', False)],
          'tassens': [('tas', False)],
          'tasten': [('tast', True)],
          'tastene': [('tasten', False)],
          'tastenes': [('tasten', False)],
          'tastens': [('tast', True)],
          'taster': [('tast', False)],
          'tasterne': [('tast', False)],
          'tasternes': [('tast', False)],
          'tasters': [('tast', True)],
          'tastiks': [('tastik', False)],
          'tata': [('tata', False)],
          'tatarerne': [('tatar', True)],
          'tatarers': [('tatar', True)],
          'tater': [('tater', True)],
          'taterne': [('tater', True)],
          'taternes': [('tater', True)],
          'taters': [('tater', True)],
          'tates': [('tate', False)],
          'tatronen': [('tatron', False)],
          'tatronens': [('tatron', False)],
          'tatronerne': [('tatron', False)],
          'tatronernes': [('tatron', False)],
          'tatroners': [('tatron', False)],
          'tats': [('tats', False)],
          "tats'": [('tats', False)],
          'tatuers': [('tatue', False)],
          'tauder': [('taude', False)],
          'taudernes': [('taude', False)],
          'tauer': [('tau', True)],
          'tauerne': [('tau', True)],
          'tauernes': [('tau', True)],
          'tauers': [('tau', True)],
          'taurer': [('taur', False)],
          'taurerne': [('taur', False)],
          'taurernes': [('taur', False)],
          'taurers': [('taur', False)],
          'tave': [('tave', False)],
          'taven': [('tave', True)],
          'tavene': [('tav', False)],
          'tavenes': [('tav', False)],
          'tavens': [('tave', False)],
          'taver': [('tave', True)],
          'taverne': [('taverne', True), ('tave', True)],
          'tavernes': [('taverne', True), ('tave', True)],
          'tavers': [('tave', True)],
          'taves': [('tave', False)],
          'tavet': [('tav', False)],
          'tavlen': [('tavle', True)],
          'tavlene': [('tavl', True)],
          'tavlenes': [('tavl', True)],
          'tavlens': [('tavle', True)],
          'tavler': [('tavle', True)],
          'tavlerne': [('tavle', False)],
          'tavlernes': [('tavle', False)],
          'tavlers': [('tavle', False)],
          'tavne': [('tavn', False)],
          'tavnen': [('tavn', False)],
          'tavnens': [('tavn', False)],
          'tavnes': [('tavn', False)],
          'tballer': [('tbal', False)],
          'tballerne': [('tbal', False)],
          'tballernes': [('tbal', False)],
          'tballers': [('tbal', False)],
          'tballet': [('tbal', False)],
          'tballets': [('tbal', False)],
          'tbanken': [('tbank', False)],
          'tbankens': [('tbank', False)],
          'tbanker': [('tbank', False)],
          'tbankerne': [('tbank', False)],
          'tbankernes': [('tbank', False)],
          'tbankers': [('tbank', False)],
          'tbilens': [('tbil', False)],
          'tbilerne': [('tbil', False)],
          'tbilernes': [('tbil', False)],
          'tbilers': [('tbil', False)],
          'tbo': [('tboer', False)],
          'tboen': [('tboer', False)],
          'tboens': [('tboer', False)],
          'tboer': [('tboer', False)],
          'tboerne': [('tbo', False)],
          'tboernes': [('tbo', False)],
          'tboers': [('tbo', False)],
          'tbomber': [('tbombe', False)],
          'tbomberne': [('tbombe', False)],
          'tbombernes': [('tbombe', False)],
          'tbombers': [('tbombe', False)],
          'tboret': [('tbor', False)],
          'tborets': [('tbor', False)],
          'tbos': [('tboer', False)],
          'tbrodde': [('tbrod', False)],
          'tbrodden': [('tbrod', False)],
          'tbroddens': [('tbrod', False)],
          'tbroddes': [('tbrod', False)],
          'tbroder': [('tbroder', False)],
          'tbroderen': [('tbroder', False)],
          'tbroderens': [('tbroder', False)],
          'tbroders': [('tbroder', False)],
          'tbrødre': [('tbroder', False)],
          'tbrødrene': [('tbroder', False)],
          'tbrødrenes': [('tbroder', False)],
          'tbrødres': [('tbroder', False)],
          'tbukser': [('tbukser', False)],
          'tbukserne': [('tbukser', False)],
          'tbuksernes': [('tbukser', False)],
          'tbuksers': [('tbukser', False)],
          'tbunker': [('tbunke', False)],
          'tbunkerne': [('tbunke', False)],
          'tbunkernes': [('tbunke', False)],
          'tbunkers': [('tbunke', False)],
          'tbutters': [('tbutter', False)],
          'tbøderne': [('tbøde', False)],
          'tbødernes': [('tbøde', False)],
          'tbøders': [('tbøde', False)],
          'tbøllen': [('tbølle', False)],
          'tbørs': [('tbørs', False)],
          'tceller': [('tcelle', False)],
          'tcellers': [('tcelle', False)],
          'tcentre': [('tcenter', False)],
          'tcentrene': [('tcenter', False)],
          'tcentrenes': [('tcenter', False)],
          'tcentres': [('tcenter', False)],
          'tcentret': [('tcenter', False)],
          'tcentrets': [('tcenter', False)],
          'tchernes': [('tch', False)],
          'tches': [('tches', False)],
          'tcyklen': [('tcyklus', False)],
          'tcyklens': [('tcykel', False)],
          'tcykler': [('tcykel', False)],
          'tcyklerne': [('tcykel', False)],
          'tcyklernes': [('tcykel', False)],
          'tcyklers': [('tcykel', False)],
          'tdage': [('tdag', False)],
          'tdagen': [('tdag', False)],
          'tdagene': [('tdag', False)],
          'tdagenes': [('tdag', False)],
          'tdages': [('tdag', False)],
          'tdansernes': [('tdanser', False)],
          'tdansers': [('tdanser', False)],
          'tdukkens': [('tdukke', False)],
          'tdækker': [('tdækker', False)],
          'tdækkerne': [('tdækker', False)],
          'tdækkernes': [('tdækker', False)],
          'tdækkers': [('tdækker', False)],
          'te': [('te', False)],
          "teaks'": [('teak', False)],
          'tearbejdernes': [('tearbejder', False)],
          'tearbejders': [('tearbejder', False)],
          'teaser': [('teaser', True)],
          'teaserne': [('teaser', True)],
          'teasernes': [('teaser', True)],
          'teasers': [('teaser', True)],
          'teater': [('teater', True)],
          'teaterne': [('teat', False)],
          'teaters': [('teater', True)],
          'tebakker': [('tebakke', False)],
          'tebakkernes': [('tebakke', False)],
          'tebakkers': [('tebakke', False)],
          'tebens': [('teben', False)],
          'tebroderen': [('tebroder', False)],
          'tebroer': [('tebroer', False)],
          'tebroers': [('tebroer', False)],
          'tedagens': [('tedag', False)],
          'tede': [('ted', False)],
          'teder': [('teder', False)],
          'teders': [('teder', False)],
          'tedret': [('teder', False)],
          'tedømmernes': [('tedømme', False)],
          'tedømmers': [('tedømme', False)],
          'teen': [('te', False)],
          'teens': [('te', False)],
          'teer': [('te', False)],
          'teerne': [('te', False)],
          'teernes': [('te', True)],
          'teers': [('te', False)],
          'tefaderen': [('tefar', False)],
          'tefaderens': [('tefar', False)],
          'tefaren': [('tefar', False)],
          'tefarens': [('tefare', False)],
          'tefarerne': [('tefare', False)],
          'tefarernes': [('tefare', False)],
          'tefædre': [('tefader', False)],
          'tefædrene': [('tefar', False)],
          'tefædrenes': [('tefader', False)],
          'tefædres': [('tefar', False)],
          'tefødder': [('tefødder', False)],
          'tege': [('tege', False)],
          'tegen': [('tege', False)],
          'tegens': [('tege', False)],
          'teger': [('tege', False)],
          'tegerne': [('tege', False)],
          'tegernes': [('tege', False)],
          'tegers': [('teg', False)],
          'teges': [('teg', False)],
          'tegier': [('tegi', False)],
          'tegierne': [('tegi', False)],
          'tegiernes': [('tegi', False)],
          'tegiers': [('tegi', False)],
          'teglen': [('tegl', True)],
          'tegner': [('tegner', False)],
          'tegnernes': [('tegner', False)],
          'tegnet': [('tegn', False)],
          'tegnets': [('tegn', False)],
          'tegrene': [('tegren', False)],
          'tegrenes': [('tegren', False)],
          'tegrever': [('tegrever', False)],
          'tegreverne': [('tegrever', False)],
          'tegrevernes': [('tegrever', False)],
          'tehandler': [('tehandel', False)],
          'tehandlerne': [('tehandler', False)],
          'tehandlernes': [('tehandler', False)],
          'tehandlers': [('tehandel', False)],
          'tehaver': [('tehave', False)],
          'tehaverne': [('tehave', False)],
          'tehavernes': [('tehave', False)],
          'tehavers': [('tehave', False)],
          'tehaves': [('tehave', False)],
          'teiner': [('teiner', False)],
          'teinerne': [('teiner', False)],
          'teinernes': [('tein', False)],
          'teiners': [('teiner', False)],
          'teje': [('teje', False)],
          'tejer': [('tej', False)],
          'tejerne': [('tej', False)],
          'tejernes': [('tej', False)],
          'tejers': [('tej', False)],
          'tejes': [('teje', False)],
          'tejlerne': [('tejle', False)],
          'tejlernes': [('tejle', False)],
          'tejlers': [('tejle', False)],
          'tek': [('tek', False)],
          'teker': [('teker', False)],
          'tekerne': [('teker', False)],
          'tekernes': [('teker', False)],
          'tekers': [('teker', False)],
          'tekkerne': [('tek', False)],
          'teklæder': [('teklæder', False)],
          'teklædernes': [('teklæder', False)],
          'teklæders': [('teklæder', False)],
          'tekonger': [('tekonge', False)],
          'tekongers': [('tekonge', False)],
          'teks': [('tek', False)],
          'tekster': [('tekster', True), ('tekst', True)],
          'teksterne': [('tekster', True), ('tekst', True)],
          'teksternes': [('tekster', True), ('tekst', True)],
          'teksters': [('tekster', True), ('tekst', True)],
          'tekter': [('tekt', False)],
          'tekterne': [('tekt', False)],
          'tekternes': [('tekt', False)],
          'tekters': [('tekt', False)],
          'tekturen': [('tektur', False)],
          'tekturens': [('tektur', False)],
          'tekturer': [('tektur', False)],
          'tekturerne': [('tektur', False)],
          'tekturernes': [('tektur', False)],
          'tekturers': [('tektur', False)],
          'tekunsterne': [('tekunst', False)],
          'tekunsters': [('tekunst', False)],
          'tekurs': [('tekur', False)],
          'tele': [('tele', False)],
          'telenet': [('telenet', True)],
          'telenets': [('telenet', True)],
          'teler': [('tele', False)],
          'telerne': [('tel', False)],
          'telernes': [('tele', False)],
          'telers': [('tele', False)],
          'teles': [('tele', False)],
          'telet': [('telet', False)],
          'telets': [('tel', False)],
          'televerne': [('telev', False)],
          'televernes': [('telev', False)],
          'telien': [('teli', False)],
          'teliens': [('teli', False)],
          'teliers': [('telier', False)],
          'telis': [('teli', False)],
          'telisten': [('telist', False)],
          'telistens': [('telist', False)],
          'telister': [('telist', False)],
          'telisterne': [('telist', False)],
          'telisternes': [('teliste', False)],
          'telisters': [('teliste', False)],
          'teliternes': [('telite', False)],
          'telle': [('telle', False)],
          'tellen': [('tel', False)],
          'teller': [('tel', False)],
          'tellers': [('tel', False)],
          'telles': [('telle', False)],
          'telsers': [('telse', False)],
          'teltene': [('telt', True)],
          'teltenes': [('telt', False)],
          'telukkerne': [('telukker', False)],
          'telukkers': [('telukker', False)],
          'telvers': [('telvers', False)],
          'telærerne': [('telærer', False)],
          'telærernes': [('telærer', False)],
          'telæs': [('telæs', False)],
          'teløber': [('teløber', False)],
          'teløberne': [('teløbe', False)],
          'teløbernes': [('teløber', False)],
          'teløbers': [('teløbe', False)],
          'temager': [('temage', False)],
          'temagerne': [('temager', False)],
          'temagernes': [('temager', False)],
          'temagers': [('temager', False)],
          'temaler': [('temaler', False)],
          'temalerne': [('temaler', False)],
          'temalernes': [('temaler', False)],
          'temalers': [('temaler', False)],
          'temanden': [('temand', False)],
          'temandens': [('temand', False)],
          'temer': [('temum', False)],
          'temerne': [('temum', False)],
          'temernes': [('temum', False)],
          'temers': [('temum', False)],
          'teminister': [('teminister', False)],
          'temmelser': [('temmelse', False)],
          'temmelserne': [('temmelse', False)],
          'temmelsernes': [('temmelse', False)],
          'temmen': [('tem', False)],
          'temmens': [('tem', False)],
          'templer': [('tempel', False)],
          'templerne': [('tempel', True)],
          'templernes': [('tempel', True)],
          'templers': [('tempel', True)],
          'ten': [('ten', True)],
          'tenden': [('tend', False)],
          'tendens': [('tendens', True)],
          'tender': [('tender', False)],
          'tenderne': [('tender', False)],
          'tendernes': [('tender', False)],
          'tenders': [('tender', True)],
          'tene': [('ten', True)],
          'tenen': [('ten', False)],
          'tenens': [('ten', False)],
          'tener': [('tener', False)],
          'tenerne': [('tener', False)],
          'tenernes': [('ten', False)],
          'teners': [('tener', False)],
          'tenes': [('ten', True)],
          'teniens': [('teni', False)],
          'tenier': [('teni', False)],
          'tenis': [('teni', False)],
          'tennerne': [('tenne', False)],
          'tens': [('ten', True)],
          "tens'": [('tens', False)],
          'tensen': [('tens', False)],
          'tensens': [('tens', False)],
          'tenser': [('tens', False)],
          'tenserne': [('tenser', False)],
          'tensernes': [('tens', False)],
          'tensers': [('tens', False)],
          'tensions': [('tension', True)],
          'tenten': [('tent', False)],
          'tentens': [('tent', False)],
          'tenter': [('tente', False)],
          'tenterne': [('tent', False)],
          'tenternes': [('tent', False)],
          'tenters': [('tent', False)],
          'tentet': [('tent', False)],
          'tentets': [('tent', False)],
          'tentrets': [('tentret', False)],
          'tentures': [('tentur', False)],
          'teoner': [('teon', False)],
          'teonerne': [('teon', False)],
          'teonernes': [('teon', False)],
          'teoners': [('teon', False)],
          'tepers': [('teper', False)],
          'teplagen': [('teplag', False)],
          'teplagens': [('teplag', False)],
          'teplages': [('teplag', False)],
          'teposen': [('tepose', True)],
          'teposens': [('tepose', False)],
          'teposer': [('tepose', True)],
          'teposerne': [('tepose', True)],
          'teposernes': [('tepose', True)],
          'tepottens': [('tepotte', True)],
          'tepotter': [('tepotte', False)],
          'tepotterne': [('tepotte', False)],
          'teprisens': [('tepris', False)],
          'tepriser': [('tepris', False)],
          'tepriserne': [('tepris', False)],
          'teprisernes': [('tepris', False)],
          'teraber': [('teraber', False)],
          'terabernes': [('teraber', False)],
          'terabers': [('teraber', False)],
          'teranerne': [('teran', False)],
          'teranernes': [('teran', False)],
          'terans': [('teran', False)],
          'terarbejdernes': [('terarbejde', False)],
          'terarbejders': [('terarbejde', False)],
          'terede': [('teret', False)],
          'teredernes': [('terede', False)],
          'terene': [('ter', False)],
          'terenes': [('ter', False)],
          'teret': [('teret', False)],
          'terets': [('teret', False)],
          'teretten': [('teret', False)],
          'terettens': [('teret', False)],
          'teretterne': [('teret', False)],
          'teretternes': [('teret', False)],
          'teretters': [('teret', False)],
          'terferens': [('terferens', False)],
          'terianerne': [('terianer', False)],
          'terianernes': [('terianer', False)],
          'terien': [('teri', False)],
          'teriens': [('teri', False)],
          'terier': [('teri', False)],
          'terierne': [('teri', False)],
          'teriernes': [('teri', False)],
          'teriers': [('teri', False)],
          'teriet': [('teri', False)],
          'teriets': [('teri', False)],
          'teriget': [('terige', False)],
          'terigets': [('terige', False)],
          'teris': [('teri', False)],
          'terium': [('terie', False)],
          'teriums': [('terie', False)],
          'terivarer': [('terivare', False)],
          'terivarerne': [('terivarer', False)],
          'terivarernes': [('terivare', False)],
          'terivarers': [('terivare', False)],
          'terkurser': [('terkursus', False)],
          'terkurserne': [('terkursus', False)],
          'terkursers': [('terkursus', False)],
          'termen': [('term', True), ('terme', True)],
          'termens': [('terme', True), ('term', True)],
          'termer': [('terme', True), ('term', True)],
          'termerne': [('term', True), ('terme', True)],
          'termernes': [('terme', True), ('term', True)],
          'termers': [('term', True), ('terme', True)],
          'terminen': [('termin', True)],
          'terminens': [('termin', True)],
          'terminer': [('termin', True)],
          'terminerne': [('termin', True)],
          'terminernes': [('termin', True)],
          'terminister': [('terminist', False)],
          'termænd': [('termand', False)],
          'termændene': [('termand', False)],
          'termændenes': [('termand', False)],
          'termænds': [('termand', False)],
          'terne': [('terne', True)],
          'ternen': [('terne', True), ('tern', True)],
          'ternens': [('terne', True), ('tern', True)],
          'terner': [('terne', True), ('tern', True)],
          'ternerne': [('tern', True), ('terne', True)],
          'ternernes': [('tern', True), ('terne', True)],
          'terners': [('terne', True), ('tern', True)],
          'ternes': [('terne', True)],
          'ternet': [('tern', False)],
          'ternets': [('tern', False)],
          'ternissens': [('ternisse', False)],
          'ternisser': [('ternisse', False)],
          'ternisserne': [('ternisse', False)],
          'ternissernes': [('ternisse', False)],
          'ternissers': [('ternisse', False)],
          'teroen': [('tero', False)],
          'teroens': [('tero', False)],
          'teros': [('tero', False)],
          'terpas': [('terpas', False)],
          'terper': [('terper', True)],
          'terperne': [('terper', True)],
          'terret': [('terret', False)],
          'terrets': [('terre', False)],
          'terrinen': [('terrin', True), ('terrine', True)],
          'terrinens': [('terrin', True), ('terrine', True)],
          'terriner': [('terrine', True), ('terrin', True)],
          'terrinerne': [('terrine', True), ('terrin', True)],
          'terrinernes': [('terrine', True), ('terrin', True)],
          'terriners': [('terrine', True), ('terrin', True)],
          "ters'": [('ters', False)],
          'tersen': [('ters', False)],
          'tersens': [('ters', False)],
          'terserne': [('ters', False)],
          'tersernes': [('ters', False)],
          'tersken': [('terske', False)],
          'tersker': [('terske', False)],
          'terskerne': [('terske', False)],
          'terskers': [('terske', False)],
          'tertankers': [('tertanke', False)],
          'tervals': [('terval', False)],
          'terves': [('terve', False)],
          'tes': [('te', False)],
          "tes'": [('te', False)],
          'tesager': [('tesag', False)],
          'tesagerne': [('tesag', False)],
          'tesans': [('tesans', False)],
          'tese': [('tese', True)],
          'tesen': [('tese', False)],
          'tesens': [('tese', True)],
          'teser': [('tese', True)],
          'teserne': [('tese', False)],
          'tesernes': [('tese', True)],
          'tesers': [('tese', True)],
          'teserven': [('teserv', False)],
          'teservens': [('teserv', False)],
          'teserver': [('teserv', False)],
          'teserverne': [('teserv', False)],
          'teservernes': [('teserv', False)],
          'teses': [('tese', False)],
          'tesierne': [('tesi', False)],
          'tesiernes': [('tesi', False)],
          'tesiers': [('tesi', False)],
          'tesis': [('tesi', False)],
          'tespiller': [('tespiller', False)],
          'tespillerne': [('tespiller', False)],
          'tespillernes': [('tespiller', False)],
          'tespillers': [('tespiller', False)],
          'tessens': [('tesse', False)],
          'tesser': [('tesse', False)],
          'tesserne': [('tesse', False)],
          'tessernes': [('tesse', False)],
          'tessers': [('tesse', False)],
          'testarter': [('testarter', False)],
          'testarternes': [('testarter', False)],
          'testen': [('test', False)],
          'testenes': [('test', False)],
          'testens': [('test', False)],
          'tester': [('tester', True)],
          'testerne': [('tester', True)],
          'testernes': [('tester', True)],
          'testers': [('tester', True)],
          'testier': [('testi', False)],
          'testrømper': [('testrømpe', False)],
          'testrømperne': [('testrømpe', False)],
          'testrømpernes': [('testrømpe', False)],
          'testrømpers': [('testrømpe', False)],
          'testyrers': [('testyre', False)],
          'teten': [('tete', True)],
          'tetens': [('tete', True)],
          'teter': [('tet', False)],
          'teterne': [('tete', False)],
          'teternes': [('tete', False)],
          'teters': [('tet', False)],
          'tetes': [('tete', False)],
          'tetiden': [('tetid', False)],
          'tetre': [('teter', False)],
          'tetret': [('teter', False)],
          'tetrets': [('teter', False)],
          'tetten': [('tet', False)],
          'tettens': [('tet', False)],
          'tetter': [('tet', False)],
          'tetterne': [('tet', False)],
          'tetternes': [('tet', False)],
          'tetters': [('tet', False)],
          'teuser': [('teuser', False)],
          'teuserne': [('teuser', False)],
          'teusernes': [('teuser', False)],
          'teusers': [('teuser', False)],
          'teven': [('teven', False)],
          'tevens': [('teven', False)],
          'tevinden': [('tevind', False)],
          'tevindens': [('tevind', False)],
          'tevindes': [('tevind', False)],
          'teviser': [('tevise', False)],
          'teviserne': [('tevise', False)],
          'tevælden': [('tevæld', False)],
          'tfanger': [('tfanger', False)],
          'tfangerne': [('tfange', False)],
          'tfangernes': [('tfanger', False)],
          'tfangers': [('tfanger', False)],
          'tfase': [('tfase', False)],
          'tfasen': [('tfase', False)],
          'tfasens': [('tfase', False)],
          'tfaser': [('tfase', False)],
          'tfaserne': [('tfase', False)],
          'tfasernes': [('tfase', False)],
          'tfasers': [('tfase', False)],
          'tfases': [('tfase', False)],
          'tfilets': [('tfilet', False)],
          'tfilter': [('tfilter', False)],
          'tfilters': [('tfilter', False)],
          'tfladen': [('tflade', False)],
          'tfladens': [('tflade', False)],
          'tflys': [('tfly', False)],
          'tfolien': [('tfolio', False)],
          'tfoliens': [('tfolio', False)],
          'tfolier': [('tfolio', False)],
          'tfolierne': [('tfolio', False)],
          'tfoliernes': [('tfolio', False)],
          'tfoliers': [('tfolio', False)],
          'tformer': [('tform', False)],
          'tformerne': [('tform', False)],
          'tformernes': [('tform', False)],
          'tformers': [('tform', False)],
          'tforummerne': [('tforum', False)],
          'tforummers': [('tforum', False)],
          'tforummet': [('tforum', False)],
          'tforummets': [('tforum', False)],
          'tforældre': [('tforælder', False)],
          'tfragternes': [('tfragt', False)],
          'tfruers': [('tfrue', False)],
          'tfylden': [('tfylde', False)],
          'tfyldens': [('tfylde', False)],
          'tfærden': [('tfærd', False)],
          'tfærdens': [('tfærd', False)],
          'tførerne': [('tfører', False)],
          'tgarder': [('tgarde', False)],
          'tgarderne': [('tgarde', False)],
          'tgardernes': [('tgarde', False)],
          'tgarders': [('tgarde', False)],
          "tgas'": [('tgas', False)],
          'tgen': [('tgen', False)],
          'tgrøden': [('tgrød', False)],
          'tgrødens': [('tgrød', False)],
          'tgænger': [('tgænger', False)],
          'tgængerne': [('tgænger', False)],
          'tgængernes': [('tgænger', False)],
          'tgængers': [('tgænger', False)],
          'th': [('th', False)],
          'thallen': [('thal', False)],
          'thallens': [('thal', False)],
          'thaller': [('thal', False)],
          'thallerne': [('thal', False)],
          'thallernes': [('thal', False)],
          'thallers': [('thal', False)],
          'thals': [('thal', False)],
          'thandler': [('thandler', False)],
          'thandlerne': [('thandel', False)],
          'thandlernes': [('thandel', False)],
          'thandlers': [('thandler', False)],
          'thans': [('thans', False)],
          'thas': [('thas', False)],
          "thas'": [('thas', False)],
          'thase': [('thas', False)],
          'thasen': [('thas', False)],
          'thasens': [('thas', False)],
          'thaser': [('thas', False)],
          'thaserne': [('thas', False)],
          'thasernes': [('thas', False)],
          'thasers': [('thas', False)],
          'thases': [('thas', False)],
          'thave': [('thave', False)],
          'thaver': [('thaver', False)],
          'thaverne': [('thaver', False)],
          'thavernes': [('thaver', False)],
          'thavers': [('thaver', False)],
          'thaves': [('thave', False)],
          'theden': [('thed', False)],
          'thedens': [('thed', False)],
          'theder': [('thed', False)],
          'thederne': [('thed', False)],
          'thedernes': [('thed', False)],
          'theders': [('thed', False)],
          'then': [('th', False)],
          'thens': [('th', False)],
          'ther': [('th', False)],
          'therne': [('th', False)],
          'thernes': [('th', False)],
          'thers': [('th', False)],
          'thien': [('thie', False)],
          'thiens': [('thie', False)],
          'thier': [('thie', False)],
          'thierne': [('thie', False)],
          'thiernes': [('thie', False)],
          'thiers': [('thie', False)],
          'thinde': [('thinde', False)],
          'thinden': [('thinde', False)],
          'thindens': [('thinde', False)],
          'thinder': [('thinde', False)],
          'thinderne': [('thinde', False)],
          'thindernes': [('thinde', False)],
          'thinders': [('thinde', False)],
          'thindes': [('thinde', False)],
          'thippen': [('thippe', False)],
          'thippens': [('thippe', False)],
          'tholterne': [('tholt', False)],
          'tholters': [('tholt', False)],
          'thuen': [('thue', False)],
          'thuens': [('thue', False)],
          'thus': [('thus', False)],
          'thuset': [('thuset', False)],
          'thvarren': [('thvar', False)],
          'thvarrens': [('thvar', False)],
          'thvarrer': [('thvar', False)],
          'thvarrerne': [('thvar', False)],
          'thvarrernes': [('thvar', False)],
          'thvarrers': [('thvar', False)],
          'thøjder': [('thøjde', False)],
          'thøjderne': [('thøjde', False)],
          'thøjdernes': [('thøjde', False)],
          'thøjders': [('thøjde', False)],
          'thøster': [('thøster', False)],
          'thøsterne': [('thøster', False)],
          'thøsternes': [('thøster', False)],
          'thøsters': [('thøster', False)],
          'ti': [('ti', False)],
          'tialer': [('tial', False)],
          'tialerne': [('tial', False)],
          'tialernes': [('tial', False)],
          'tialers': [('tial', False)],
          'tialet': [('tial', False)],
          'tialets': [('tial', False)],
          'tianerne': [('tianer', False)],
          'tianernes': [('tianer', False)],
          'tias': [('tias', False)],
          'tiater': [('tiat', False)],
          'tiaterne': [('tiat', False)],
          'tiaters': [('tiat', False)],
          'ticen': [('tice', False)],
          'ticene': [('tic', True)],
          'ticenes': [('tic', True)],
          'ticens': [('tice', False)],
          'ticer': [('tic', False)],
          'ticernes': [('tic', False)],
          'tices': [('tice', False)],
          'tichen': [('tich', False)],
          'tichens': [('tich', False)],
          'ticher': [('tich', False)],
          'ticherne': [('tich', False)],
          'tichernes': [('tiche', False)],
          'tichers': [('tich', False)],
          'ticker': [('ticker', False)],
          'tickernes': [('ticker', False)],
          'ticket': [('tick', False)],
          'tickets': [('tick', False)],
          'tide': [('tide', False)],
          'tiden': [('tid', True)],
          'tidender': [('tidende', True)],
          'tidenderne': [('tidende', True)],
          'tidendernes': [('tidende', True)],
          'tidenders': [('tidende', True)],
          'tidens': [('tid', False)],
          'tider': [('tid', True)],
          'tiderne': [('tid', True)],
          'tidernes': [('tid', True)],
          'tiders': [('tid', True)],
          'tides': [('tide', False)],
          'tids': [('tids', True), ('tid', True)],
          'tien': [('ti', False)],
          'tiens': [('ti', False)],
          'tienserne': [('tiens', False)],
          'tier': [('tier', True)],
          'tiere': [('tier', True)],
          'tieren': [('tier', False)],
          'tierens': [('tier', False)],
          'tierer': [('tier', False)],
          'tiererne': [('tier', False)],
          'tierernes': [('tier', False)],
          'tierers': [('tier', False)],
          'tieres': [('tier', False)],
          'tierne': [('tier', True)],
          'tiernes': [('tier', True)],
          'tiers': [('tier', True)],
          'ties': [('ty', False)],
          'tiet': [('ti', False)],
          'tiets': [('ti', False)],
          'tif': [('tif', False)],
          'tiffer': [('tif', False)],
          'tiffernes': [('tif', False)],
          'tiffers': [('tif', False)],
          'tiften': [('tift', False)],
          'tiftens': [('tift', False)],
          'tiftet': [('tift', False)],
          'tiftets': [('tift', False)],
          'tige': [('tige', False)],
          'tigen': [('tige', False)],
          'tigens': [('tige', False)],
          'tiger': [('tiger', True)],
          'tigerne': [('tiger', True)],
          'tigernes': [('tiger', False)],
          'tigers': [('tiger', True)],
          'tiges': [('tige', False)],
          'tigger': [('tigger', True)],
          'tiggers': [('tigger', True)],
          'tights': [('tights', False)],
          "tights'": [('tights', True)],
          'tigre': [('tiger', True)],
          'tika': [('tikum', False)],
          'tikaene': [('tikum', False)],
          'tikaenes': [('tikum', False)],
          'tikas': [('tikon', False)],
          'tiket': [('tiket', False)],
          'tikets': [('tiket', False)],
          'tikken': [('tik', False)],
          'tikkerne': [('tik', False)],
          'tiklen': [('tikel', False)],
          'tiklerne': [('tikel', False)],
          'tiklernes': [('tikel', False)],
          'tiklers': [('tikel', False)],
          'tikronerne': [('tikrone', True)],
          'tikroners': [('tikrone', True)],
          'tiks': [('tik', True)],
          "tiks'": [('tiks', False)],
          'tiksen': [('tiks', False)],
          'tiksens': [('tiks', False)],
          'tikum': [('tikum', False)],
          'tikums': [('tikum', False)],
          'tikvaren': [('tikvar', False)],
          'tikvarens': [('tikvar', False)],
          'tikvarer': [('tikvar', False)],
          'tikvarerne': [('tikvar', False)],
          'tikvarernes': [('tikvar', False)],
          'tilden': [('tilde', True)],
          'tildens': [('tilde', True)],
          'tilder': [('tilde', True)],
          'tilderne': [('tilde', True)],
          'tildernes': [('tilde', True)],
          'tilders': [('tilde', True)],
          'tiler': [('til', False)],
          'tilets': [('til', False)],
          'tilettens': [('tilet', False)],
          'tiletters': [('tilet', False)],
          'tilisten': [('tilist', False)],
          'tilistens': [('tilist', False)],
          'tilister': [('tilist', False)],
          'tilisterne': [('tilist', False)],
          'tilisternes': [('tiliste', False)],
          'tilisters': [('tiliste', False)],
          'tilke': [('tilk', False)],
          'tilken': [('tilk', False)],
          'tilkens': [('tilk', False)],
          'tilkes': [('tilk', False)],
          'tillene': [('till', False)],
          'tillenes': [('till', False)],
          'tiller': [('til', False)],
          'tillerne': [('til', False)],
          'tillers': [('til', False)],
          'tillids': [('tillid', False)],
          'tillingers': [('tilling', False)],
          'tillister': [('tillist', False)],
          'tillisternes': [('tillist', False)],
          'tillisters': [('tillist', False)],
          'timanden': [('timand', False)],
          'timandens': [('timand', False)],
          'time': [('time', False)],
          'timen': [('time', False)],
          'timens': [('time', False)],
          'timenterne': [('timent', False)],
          'timentet': [('timent', False)],
          'timentets': [('timent', False)],
          'timer': [('timer', True), ('time', True)],
          'timerne': [('timer', True), ('time', True)],
          'timernes': [('timer', True), ('time', True)],
          'timers': [('timer', True), ('time', True)],
          'times': [('time', False)],
          'timmer': [('timmer', False)],
          'timmerne': [('timmer', False)],
          'tina': [('tina', False)],
          'tinas': [('tina', False)],
          'tinder': [('tinde', False)],
          'tinderne': [('tinde', False)],
          'tindernes': [('tinde', False)],
          'tinders': [('tinde', False)],
          'tine': [('tine', False)],
          'tinearbejder': [('tinearbejde', False)],
          'tinearbejderne': [('tinearbejde', False)],
          'tinen': [('tine', False)],
          'tinens': [('tine', False)],
          'tiner': [('tine', False)],
          'tinerne': [('tiner', False)],
          'tinernes': [('tine', False)],
          'tiners': [('tiner', False)],
          'tines': [('tine', False)],
          'tinet': [('tinet', False)],
          'tinets': [('tinet', False)],
          'tingen': [('ting', False)],
          'tingens': [('ting', False)],
          'tingenserne': [('tingens', False)],
          'tingensers': [('tingens', False)],
          'tinger': [('ting', False)],
          'tingerne': [('ting', False)],
          'tingernes': [('ting', False)],
          'tings': [('ting', False)],
          "tings'": [('ting', False)],
          'tingsteder': [('tingsted', True)],
          'tingstederne': [('tingsted', True)],
          'tingstedernes': [('tingsted', True)],
          'tingsteders': [('tingsted', True)],
          'tini': [('tini', False)],
          'tinien': [('tini', False)],
          'tiniens': [('tini', False)],
          'tinier': [('tini', False)],
          'tinierne': [('tini', False)],
          'tinis': [('tini', False)],
          'tinister': [('tinist', False)],
          'tinisters': [('tinist', False)],
          'tinker': [('tinker', False)],
          'tinkerne': [('tinker', False)],
          'tinter': [('tinte', True)],
          'tinternes': [('tinte', True)],
          'tionaler': [('tional', False)],
          'tionalerne': [('tional', False)],
          'tionalernes': [('tional', False)],
          'tionalers': [('tional', False)],
          'tionalet': [('tional', False)],
          'tionalets': [('tional', False)],
          'tioner': [('tion', False)],
          'tionerne': [('tion', False)],
          'tionernes': [('tion', False)],
          'tioners': [('tion', False)],
          'tions': [('tion', False)],
          "tions'": [('tion', False)],
          'tipierne': [('tipi', True)],
          'tipiers': [('tipi', True)],
          'tipler': [('tiplum', False)],
          'tiplerne': [('tiplum', False)],
          'tiplernes': [('tiplum', False)],
          'tiplers': [('tiplum', False)],
          'tippe': [('tip', False)],
          'tippen': [('tip', True)],
          'tippens': [('tip', False)],
          'tipper': [('tipper', True), ('tip', True)],
          'tipperne': [('tipper', True), ('tip', True)],
          'tippernes': [('tipper', True), ('tip', True)],
          'tippers': [('tip', True), ('tipper', True)],
          'tips': [('tip', True), ('tips', True)],
          "tips'": [('tips', True), ('tip', True)],
          'tirens': [('tire', False)],
          'tirer': [('tire', False)],
          'tirerne': [('tire', False)],
          'tirernes': [('tire', False)],
          'tirers': [('tire', False)],
          'tis': [('tis', True)],
          'tise': [('tise', False)],
          'tisen': [('tise', False)],
          'tisens': [('tise', False)],
          'tiser': [('tise', False)],
          'tiserne': [('tise', False)],
          'tisernes': [('tise', False)],
          'tises': [('tise', False)],
          'tismen': [('tisme', False)],
          'tismens': [('tisme', False)],
          'tisolens': [('tisol', False)],
          'tissen': [('tis', False)],
          'tissens': [('tis', False)],
          'tisser': [('tis', False)],
          'tisserne': [('tis', False)],
          'tissernes': [('tis', False)],
          'tissers': [('tis', False)],
          'tisten': [('tist', False)],
          'tistens': [('tist', False)],
          'tister': [('tist', False)],
          'tisterne': [('tist', False)],
          'tisternes': [('tist', False)],
          'tisters': [('tist', False)],
          'titanens': [('titan', True)],
          'titanerne': [('titan', True)],
          'titanernes': [('titan', True)],
          'titans': [('titan', True)],
          'titiden': [('titiden', False)],
          'titlen': [('titel', False)],
          'titlerne': [('titel', False)],
          'titlernes': [('titel', True)],
          'titlers': [('titel', False)],
          'tits': [('tit', True)],
          "tits'": [('tits', False)],
          'titsen': [('tits', False)],
          'titsens': [('tits', False)],
          'titser': [('tits', False)],
          'titserne': [('tits', False)],
          'titsernes': [('tits', False)],
          'titsers': [('tits', False)],
          'titten': [('tit', False)],
          'tittens': [('tit', False)],
          'titternes': [('tit', False)],
          'titters': [('tit', False)],
          'titurets': [('titur', False)],
          'titørerne': [('titør', False)],
          'titørernes': [('titør', False)],
          'titørers': [('titør', False)],
          'tiver': [('tiver', False)],
          'tiverne': [('tiv', False)],
          'tivernes': [('tiver', False)],
          'tivers': [('tiv', False)],
          'tizerne': [('tiz', False)],
          'tizernes': [('tiz', False)],
          'tiøren': [('tiøre', True)],
          'tiørens': [('tiøre', True)],
          'tiørerne': [('tiøre', True)],
          'tiørernes': [('tiøre', True)],
          'tiørers': [('tiøre', True)],
          'tjans': [('tjans', False)],
          'tjas': [('tja', False)],
          'tjen': [('tj', False)],
          'tjens': [('tj', False)],
          'tjer': [('tj', False)],
          'tjerne': [('tjerne', False)],
          'tjerner': [('tjerne', False)],
          'tjernerne': [('tjerne', False)],
          'tjernernes': [('tjerne', False)],
          'tjernes': [('tjerne', False)],
          'tjers': [('tj', False)],
          'tjerterne': [('tjert', False)],
          'tjerternes': [('tjert', False)],
          'tjerters': [('tjert', False)],
          'tjs': [('tj', False)],
          'tkagen': [('tkage', False)],
          'tkagens': [('tkage', False)],
          'tkenderne': [('tkender', False)],
          'tkendernes': [('tkender', False)],
          'tkisten': [('tkiste', False)],
          'tkistens': [('tkiste', False)],
          'tkisternes': [('tkiste', False)],
          'tklatters': [('tklat', False)],
          'tklokker': [('tklokke', False)],
          'tklokkerne': [('tklokke', False)],
          'tklokkernes': [('tklokke', False)],
          'tklokkers': [('tklokke', False)],
          'tkornet': [('tkorn', False)],
          'tkornets': [('tkorn', False)],
          'tkronen': [('tkrone', False)],
          'tkroner': [('tkrone', False)],
          'tkronerne': [('tkrone', False)],
          'tkronernes': [('tkrone', False)],
          'tkurser': [('tkursus', False)],
          'tkurserne': [('tkursus', False)],
          'tkursernes': [('tkursus', False)],
          'tkursers': [('tkursus', False)],
          'tkurve': [('tkurve', False)],
          'tkvarter': [('tkvarter', False)],
          'tkvarters': [('tkvarter', False)],
          'tkæmper': [('tkæmper', False)],
          'tkæmperne': [('tkæmper', False)],
          'tkæmpernes': [('tkæmper', False)],
          'tkæmpers': [('tkæmper', False)],
          'tkæs': [('tkæs', False)],
          'tkød': [('tkød', False)],
          'tkøds': [('tkød', False)],
          'tkørerne': [('tkører', False)],
          'tkørers': [('tkører', False)],
          'tlagen': [('tlage', False)],
          'tlagens': [('tlage', False)],
          'tlager': [('tlage', False)],
          'tlagerne': [('tlage', False)],
          'tlagernes': [('tlage', False)],
          'tlagers': [('tlage', False)],
          'tlaks': [('tlak', False)],
          'tlas': [('tlas', False)],
          'tlasser': [('tlas', False)],
          'tlassernes': [('tlas', False)],
          'tlassers': [('tlas', False)],
          'tle': [('tel', False)],
          'tledernes': [('tleder', False)],
          'tlen': [('tel', False)],
          'tlene': [('tel', False)],
          'tlenes': [('tel', False)],
          'tler': [('tler', False)],
          'tlere': [('tler', False)],
          'tleren': [('tler', False)],
          'tlerens': [('tler', False)],
          'tleres': [('tler', False)],
          'tlerne': [('tel', False)],
          'tlernes': [('tel', False)],
          'tlers': [('tel', False)],
          'tles': [('tel', False)],
          'tlet': [('tlet', False)],
          'tlets': [('tel', False)],
          'tletten': [('tlet', False)],
          'tlettens': [('tlet', False)],
          'tlime': [('tlim', False)],
          'tlimen': [('tlim', False)],
          'tlimene': [('tlim', False)],
          'tlimenes': [('tlim', False)],
          'tlimens': [('tlim', False)],
          'tlimes': [('tlim', False)],
          'tlinene': [('tline', False)],
          'tlinenes': [('tline', False)],
          'tlingers': [('tling', False)],
          'tlinien': [('tlinie', False)],
          'tlisten': [('tliste', False)],
          'tlistens': [('tliste', False)],
          'tlisterne': [('tliste', False)],
          'tlodder': [('tlod', False)],
          'tlodderne': [('tlod', False)],
          'tloddernes': [('tlod', False)],
          'tlodders': [('tlod', False)],
          'tlods': [('tlod', False)],
          'tlomme': [('tlomme', False)],
          'tlommen': [('tlomme', False)],
          'tlommens': [('tlomme', False)],
          'tlommer': [('tlomme', False)],
          'tlommerne': [('tlomme', False)],
          'tlommernes': [('tlomme', False)],
          'tlommers': [('tlomme', False)],
          'tlommes': [('tlomme', False)],
          'tlove': [('tlov', False)],
          'tlugernes': [('tluge', False)],
          'tluskernes': [('tlusker', False)],
          'tlys': [('tlys', False)],
          'tlysen': [('tlys', False)],
          'tlysens': [('tlys', False)],
          'tlås': [('tlås', False)],
          'tlægens': [('tlæge', False)],
          'tlægernes': [('tlæge', False)],
          'tlænder': [('tlænder', False)],
          'tlænderne': [('tlænder', False)],
          'tlændernes': [('tlænder', False)],
          'tlænders': [('tlænder', False)],
          'tlærer': [('tlærer', False)],
          'tlærerne': [('tlære', False)],
          'tlærernes': [('tlære', False)],
          'tlærers': [('tlærer', False)],
          'tlæsernes': [('tlæser', False)],
          'tløberne': [('tløber', False)],
          'tløbers': [('tløber', False)],
          'tløfter': [('tløfter', False)],
          'tløfterne': [('tløfter', False)],
          'tløfternes': [('tløfter', False)],
          'tløfters': [('tløfter', False)],
          'tmaden': [('tmad', False)],
          'tmads': [('tmad', False)],
          'tmager': [('tmager', False)],
          'tmagerne': [('tmager', False)],
          'tmagernes': [('tmager', False)],
          'tmagers': [('tmager', False)],
          'tman': [('tman', False)],
          'tmappen': [('tmappe', False)],
          'tmappens': [('tmap', False)],
          'tmarchen': [('tmarch', False)],
          'tmarcher': [('tmarch', False)],
          'tmarcherne': [('tmarch', False)],
          'tmarsker': [('tmarsker', False)],
          'tmarskerne': [('tmarsker', False)],
          'tmarskernes': [('tmarsker', False)],
          'tmarskers': [('tmarsker', False)],
          'tmas': [('tma', False)],
          'tmasken': [('tmaske', False)],
          'tmaskens': [('tmaske', False)],
          'tmasker': [('tmaske', False)],
          'tmaskerne': [('tmaske', False)],
          'tmaskers': [('tmaske', False)],
          'tmassens': [('tmasse', False)],
          'tmasser': [('tmasse', False)],
          'tmaster': [('tmaster', False)],
          'tmasterne': [('tmaster', False)],
          'tmasternes': [('tmaster', False)],
          'tmasters': [('tmaster', False)],
          'tmediciner': [('tmedicin', False)],
          'tmedicinerne': [('tmedicin', False)],
          'tmedicinernes': [('tmedicin', False)],
          'tmediciners': [('tmedicin', False)],
          'tmejsen': [('tmejse', False)],
          'tmejsens': [('tmejse', False)],
          'tmejser': [('tmejse', False)],
          'tmejserne': [('tmejse', False)],
          'tmejsernes': [('tmejse', False)],
          'tmejsers': [('tmejse', False)],
          'tmen': [('tme', False)],
          'tmens': [('tme', False)],
          'tmers': [('tme', False)],
          'tmeter': [('tmeter', False)],
          'tmeters': [('tmeter', False)],
          'tmetre': [('tmeter', False)],
          'tmetrene': [('tmeter', False)],
          'tmetrenes': [('tmeter', False)],
          'tmetres': [('tmeter', False)],
          'tmetret': [('tmeter', False)],
          'tmetrets': [('tmeter', False)],
          'tmidler': [('tmiddel', False)],
          'tmidlerne': [('tmiddel', False)],
          'tmiks': [('tmik', False)],
          'tmis': [('tmi', False)],
          'tmoralen': [('tmoral', False)],
          'tmoralens': [('tmoral', False)],
          'tmælken': [('tmælk', False)],
          'tmælkens': [('tmælk', False)],
          'tmænd': [('tmand', False)],
          'tmændene': [('tmand', False)],
          'tmændenes': [('tmand', False)],
          'tmænds': [('tmand', False)],
          'tmøderne': [('tmøde', False)],
          'tmødernes': [('tmøde', False)],
          'tmøller': [('tmølle', False)],
          'tmøllerne': [('tmølle', False)],
          'tmøllernes': [('tmølle', False)],
          'tmøllers': [('tmølle', False)],
          'tnakke': [('tnakke', False)],
          'tnakkernes': [('tnakke', False)],
          'tnanter': [('tnant', False)],
          'tner': [('ten', False)],
          'tneret': [('tner', False)],
          'tnerets': [('tner', False)],
          'tnerier': [('tneri', False)],
          'tnerierne': [('tneri', False)],
          'tneriernes': [('tneri', False)],
          'tneriers': [('tneri', False)],
          'tnerne': [('tner', False)],
          'tnernes': [('ten', False)],
          'tners': [('ten', False)],
          'tnet': [('t', False)],
          'tnets': [('t', False)],
          "tniks'": [('tnik', False)],
          'tningers': [('tning', False)],
          'tnissen': [('tnisse', False)],
          'tnisser': [('tnisse', False)],
          'tnissernes': [('tnisse', False)],
          'tnissers': [('tnisse', False)],
          'tnoten': [('tnote', False)],
          'tnotens': [('tnote', False)],
          'tnoter': [('tnote', False)],
          'tnoterne': [('tnote', False)],
          'tnoternes': [('tnote', False)],
          'tnoters': [('tnote', False)],
          'tnummers': [('tnummer', False)],
          'to': [('to', False)],
          'tober': [('tober', False)],
          'todder': [('todder', False)],
          'todderne': [('todder', False)],
          'toddernes': [('todder', False)],
          'todders': [('todder', False)],
          'toden': [('tode', False)],
          'toders': [('tode', False)],
          'toen': [('to', False)],
          'toens': [('to', False)],
          'toer': [('toer', True)],
          'toerne': [('toer', True)],
          'toernes': [('toer', True)],
          'toers': [('toer', True)],
          'toet': [('to', False)],
          'toets': [('to', False)],
          'toffer': [('tof', False)],
          'toffers': [('tof', False)],
          'toffet': [('tof', False)],
          'toften': [('toft', True), ('tofte', True)],
          'toftens': [('toft', True), ('tofte', True)],
          'tofter': [('tofte', True), ('toft', True)],
          'tofterne': [('toft', True), ('tofte', True)],
          'tofternes': [('toft', True), ('tofte', True)],
          'tofters': [('toft', True), ('tofte', True)],
          'togas': [('toga', True)],
          'toget': [('tog', True)],
          'togets': [('tog', False)],
          'togter': [('togt', False)],
          'togterne': [('togt', True)],
          'togternes': [('togt', False)],
          'toider': [('toid', False)],
          'toiderne': [('toid', False)],
          'toidernes': [('toid', False)],
          'toiders': [('toid', False)],
          'toiletter': [('toilette', True), ('toilet', True)],
          'toiletterne': [('toilette', True), ('toilet', True)],
          'toiletternes': [('toilette', True), ('toilet', True)],
          'toiletters': [('toilette', True), ('toilet', True)],
          'toilettet': [('toilette', True), ('toilet', True)],
          'toilettets': [('toilette', True), ('toilet', True)],
          'toirer': [('toire', False)],
          'toirerne': [('toire', False)],
          'toirernes': [('toire', False)],
          'toirers': [('toire', False)],
          'toires': [('toire', False)],
          'tokke': [('tok', False)],
          'tokken': [('tok', False)],
          'tokkes': [('tok', False)],
          'tolde': [('told', False)],
          'tolden': [('told', True)],
          'toldene': [('told', False)],
          'toldenes': [('told', False)],
          'toldens': [('told', True)],
          'tolders': [('tolder', True)],
          'toldes': [('told', False)],
          'toler': [('tol', False)],
          'tolerne': [('tol', False)],
          'tolernes': [('toler', False)],
          'tolers': [('toler', False)],
          'toliers': [('tolie', False)],
          'tolkens': [('tolk', True)],
          'tollen': [('tol', False)],
          'tollens': [('tolle', False)],
          'toller': [('tol', False)],
          'tollerne': [('tolle', False)],
          'tollernes': [('tolle', False)],
          'tollers': [('tol', False)],
          'tollets': [('tol', False)],
          'tomaner': [('toman', False)],
          'tomanerne': [('toman', False)],
          'tomanernes': [('toman', False)],
          'tomaners': [('toman', False)],
          'tomber': [('tombe', False)],
          'tomberne': [('tombe', False)],
          'tombernes': [('tombe', False)],
          'tomen': [('tom', False)],
          'tomens': [('tom', False)],
          'tomer': [('tomer', False)],
          'tomers': [('tomer', False)],
          'tometerne': [('tometer', False)],
          'tometernes': [('tometer', False)],
          'tomier': [('tomi', False)],
          'tomierne': [('tomi', False)],
          'tomiernes': [('tomi', False)],
          'tomiers': [('tomi', False)],
          'tomkostningers': [('tomkostning', False)],
          'tomlen': [('tommel', True)],
          'tomlens': [('tommel', True)],
          'tomlerne': [('tommel', True)],
          'tomlernes': [('tommel', True)],
          'tomlers': [('tommel', True)],
          'tommer': [('tomme', True)],
          'tommerne': [('tomme', True)],
          'tommernes': [('tomme', True)],
          'tommers': [('tomme', True)],
          'tonarbejder': [('tonarbejder', False)],
          'tonarbejders': [('tonarbejder', False)],
          'tonen': [('tone', False)],
          'tonens': [('tone', False)],
          'toner': [('toner', True), ('tone', True)],
          'tonerne': [('toner', True), ('tone', True)],
          'tonernes': [('toner', True), ('tone', True)],
          'toners': [('toner', True), ('tone', True)],
          'tonet': [('tonet', False)],
          'tonets': [('tonet', False)],
          'tongen': [('tong', False)],
          'tongens': [('tong', False)],
          'tonger': [('tong', False)],
          'tongerne': [('tong', False)],
          'tongernes': [('tong', False)],
          'tonien': [('toni', False)],
          'toniens': [('toni', False)],
          'tonier': [('tonie', False)],
          'tonierne': [('tonie', False)],
          'toniernes': [('tonie', False)],
          'toniers': [('tonie', False)],
          'tonika': [('tonikum', True), ('tonika', True)],
          'tonikas': [('tonikum', True), ('tonika', True)],
          'tonis': [('toni', False)],
          'tonnen': [('ton', False)],
          'tonnens': [('ton', False)],
          'tonner': [('tonner', False)],
          'tonnerne': [('tonner', False)],
          'tonnernes': [('tonner', False)],
          'tonners': [('tonner', False)],
          'tonnet': [('ton', False)],
          'tonnets': [('ton', False)],
          'tonomen': [('tonom', False)],
          'topens': [('top', False)],
          'toppe': [('top', True)],
          'toppen': [('top', True)],
          'toppens': [('top', False)],
          'topper': [('topper', False)],
          'topperne': [('top', False)],
          'toppernes': [('topper', False)],
          'toppers': [('topper', False)],
          'tops': [('top', True)],
          "tops'": [('tops', False)],
          'topsen': [('tops', False)],
          'topsens': [('tops', False)],
          'topser': [('tops', False)],
          'topserne': [('tops', False)],
          'topsernes': [('tops', False)],
          'tora': [('tora', True)],
          'toralen': [('torale', False)],
          'toralens': [('torale', False)],
          'toraler': [('torale', False)],
          'toralerne': [('torale', False)],
          'toralernes': [('torale', False)],
          'toralers': [('torale', False)],
          'toras': [('tora', True)],
          'tordrernes': [('tordre', False)],
          'torers': [('tor', False)],
          'tores': [('tores', False)],
          'toret': [('toret', False)],
          'torets': [('toret', False)],
          'toretten': [('toret', False)],
          'torettens': [('toret', False)],
          'torianerne': [('torianer', False)],
          'torianernes': [('torianer', False)],
          'torier': [('tori', False)],
          'torierne': [('torium', False)],
          'toriernes': [('tori', False)],
          'toriers': [('torium', False)],
          'toriet': [('torium', False)],
          'toriets': [('torium', False)],
          'toris': [('tori', False)],
          'torium': [('torie', False)],
          'toriums': [('torie', False)],
          'torken': [('tork', False)],
          'torkens': [('tork', False)],
          'torkøbet': [('torkøb', False)],
          'tormer': [('tormer', False)],
          'torne': [('torn', False)],
          'tornen': [('torn', False)],
          'tornens': [('torn', False)],
          'tornes': [('torn', False)],
          'torpen': [('torp', True)],
          'torpens': [('torp', True)],
          'torper': [('torp', True)],
          'torperne': [('torp', True)],
          'torpernes': [('torp', True)],
          'torpers': [('torp', True)],
          'torps': [('torp', True)],
          'torrens': [('torrens', False)],
          'torten': [('tort', True)],
          'tortens': [('tort', True)],
          'torter': [('tort', False)],
          'torterne': [('tort', False)],
          'torters': [('tort', False)],
          'torts': [('tort', False)],
          'torvarers': [('torvare', False)],
          'torvejen': [('torvej', False)],
          'torvejes': [('torvej', False)],
          'torvet': [('torv', False)],
          'torvets': [('torv', False)],
          'tos': [('to', False)],
          "tos'": [('to', False)],
          'tosen': [('tose', False)],
          'tosens': [('tose', False)],
          'toser': [('tose', False)],
          'toserne': [('tose', False)],
          'tosernes': [('tose', False)],
          'tosers': [('tose', False)],
          'tossen': [('tosse', True)],
          'tossens': [('tosse', True)],
          'tossernes': [('tosse', False)],
          'tossers': [('tosse', False)],
          'toste': [('tost', False)],
          'tosten': [('tost', False)],
          'tostens': [('tost', False)],
          'toster': [('tost', False)],
          'tosterne': [('tost', False)],
          'tosternes': [('tost', False)],
          'tosters': [('tost', False)],
          'tostes': [('tost', False)],
          'toten': [('tote', False)],
          'totens': [('tote', False)],
          'toter': [('tote', False)],
          'toterne': [('tote', False)],
          'toternes': [('tote', False)],
          'toters': [('tote', False)],
          'totes': [('tote', False)],
          'totten': [('tot', True)],
          'tottens': [('tot', False)],
          'totter': [('tot', False)],
          'totterne': [('tot', True)],
          'totternes': [('tot', False)],
          'totters': [('tot', True)],
          'totypen': [('totype', False)],
          'totyper': [('totype', False)],
          'totyperne': [('totype', False)],
          'toucher': [('touche', True)],
          'toucherne': [('touche', True)],
          'touchers': [('touche', True)],
          'touten': [('tout', False)],
          'toutens': [('tout', False)],
          'touterne': [('tout', False)],
          'touternes': [('tout', True)],
          'touters': [('tout', False)],
          "tp'er": [("tp'er", False)],
          "tp'erne": [("tp'er", False)],
          "tp'ernes": [("tp'er", False)],
          "tp'ers": [("tp'er", False)],
          'tpants': [('tpants', False)],
          'tpen': [('tpen', False)],
          'tpiber': [('tpibe', False)],
          'tpiberne': [('tpibe', False)],
          'tpibernes': [('tpibe', False)],
          'tpibers': [('tpibe', False)],
          'tpigerne': [('tpige', False)],
          'tpigers': [('tpige', False)],
          'tpiks': [('tpik', False)],
          'tpillen': [('tpille', False)],
          'tpillernes': [('tpille', False)],
          'tpils': [('tpil', False)],
          'tplage': [('tplag', False)],
          'tplagen': [('tplag', False)],
          'tplagens': [('tplag', False)],
          'tplages': [('tplag', False)],
          'tpollen': [('tpoll', False)],
          'tpollens': [('tpoll', False)],
          'tportieren': [('tportier', False)],
          'tportierens': [('tportier', False)],
          'tportierer': [('tportier', False)],
          'tportiererne': [('tportier', False)],
          'tportierernes': [('tportier', False)],
          'tportierers': [('tportier', False)],
          'tposers': [('tpose', False)],
          'tposter': [('tpost', False)],
          'tposterne': [('tpost', False)],
          'tposternes': [('tpost', False)],
          'tposters': [('tpost', False)],
          'tpotten': [('tpotte', False)],
          'tpottens': [('tpotte', False)],
          'tpotter': [('tpotte', False)],
          'tpotterne': [('tpotte', False)],
          'tpotternes': [('tpotte', False)],
          'tpotters': [('tpotte', False)],
          'tpresser': [('tpresser', False)],
          'tpresserne': [('tpresser', False)],
          'tpressernes': [('tpresser', False)],
          'tpressers': [('tpresser', False)],
          'tprisen': [('tpris', False)],
          'tprisens': [('tpris', False)],
          'tpriser': [('tpris', False)],
          'tpriserne': [('tpris', False)],
          'tprisernes': [('tpris', False)],
          'tprisers': [('tpris', False)],
          'tprocenter': [('tprocent', False)],
          'tprocenters': [('tprocent', False)],
          'tr.': [('truktion', False)],
          'tra': [('trum', False)],
          'trade': [('trade', False)],
          'traden': [('trade', False)],
          'tradens': [('trade', False)],
          'trader': [('trade', False)],
          'traderne': [('trade', False)],
          'tradernes': [('trade', False)],
          'traders': [('trade', False)],
          'trades': [('trade', False)],
          'traene': [('trum', False)],
          'traenes': [('trum', False)],
          'traffer': [('traffe', False)],
          'traffernes': [('traffe', False)],
          'tragter': [('tragter', False)],
          'tragterne': [('tragter', False)],
          'tragternes': [('tragter', False)],
          'trailerne': [('trailer', True)],
          'trailernes': [('trailer', True)],
          'trailers': [('trailer', True)],
          'tralen': [('tral', False)],
          'traler': [('tral', False)],
          'tralerne': [('tral', False)],
          'tralernes': [('tral', False)],
          'tralers': [('tral', False)],
          'tralier': [('tralier', False)],
          'tralierne': [('tralier', False)],
          'traliernes': [('tralier', False)],
          'traliers': [('tralier', False)],
          'trammer': [('trammer', False)],
          'trammerne': [('trammer', False)],
          'trammernes': [('trammer', False)],
          'trammers': [('trammer', False)],
          'trancen': [('trance', True)],
          'trancens': [('trance', True)],
          'tranens': [('trane', True)],
          'traner': [('trane', True)],
          'tranerne': [('trane', True)],
          'tranernes': [('trane', True)],
          'traners': [('trane', True)],
          'tranet': [('tranet', False)],
          'tranets': [('tranet', False)],
          'trangen': [('trang', False)],
          'trangens': [('trang', True)],
          'trans': [('tran', False)],
          'transporter': [('transporter', True), ('transport', True)],
          'transporterne': [('transport', True), ('transporter', True)],
          'transporternes': [('transporter', True), ('transport', True)],
          'transporters': [('transport', True), ('transporter', True)],
          'trappen': [('trappe', False)],
          'trappens': [('trappe', False)],
          'trapper': [('trappe', True)],
          'trapperne': [('trappe', True)],
          'trappernes': [('trappe', True)],
          'trappers': [('trappe', False)],
          'traps': [('trap', False)],
          'tras': [('trum', False)],
          'traster': [('trast', False)],
          'trasterne': [('trast', False)],
          'trasternes': [('trast', False)],
          'trasters': [('trast', False)],
          'trata': [('tratum', False)],
          'trater': [('trat', False)],
          'traterne': [('trat', False)],
          'traternes': [('trat', False)],
          'traters': [('trat', False)],
          'traven': [('trave', True)],
          'travene': [('trav', False)],
          'travenes': [('trav', False)],
          'travens': [('trave', True)],
          'traver': [('traver', True), ('trave', True)],
          'traverne': [('trave', True), ('traver', True)],
          'travernes': [('traver', True), ('trave', True)],
          'travers': [('traver', True), ('travers', True), ('trave', True)],
          'travet': [('trav', True)],
          'travets': [('trav', False)],
          'tre': [('ter', False)],
          'treben': [('treben', False)],
          'treder': [('treder', False)],
          'trederne': [('treder', False)],
          'tredernes': [('treder', False)],
          'treders': [('treder', False)],
          'treer': [('treer', True)],
          'treerne': [('treer', True)],
          'treernes': [('treer', False)],
          'treers': [('treer', False)],
          'trejfer': [('trejfer', False)],
          'trejferne': [('trejfer', False)],
          'trejfernes': [('trejfer', False)],
          'trejfers': [('trejfer', False)],
          'tremer': [('trem', False)],
          'tremerne': [('trem', False)],
          'tremernes': [('trem', False)],
          'tremers': [('trem', False)],
          'tremme': [('tremme', True)],
          'tremmen': [('tremme', True)],
          'tremmens': [('tremme', True)],
          'tremmer': [('tremme', True)],
          'tremmerne': [('tremme', True)],
          'tremmers': [('tremme', True)],
          'tremmes': [('tremme', True)],
          'tremser': [('tremse', False)],
          'tremserne': [('tremse', False)],
          'tremsernes': [('tremse', False)],
          'tren': [('tre', False)],
          'trenden': [('trend', True)],
          'trendens': [('trend', True)],
          'trender': [('trend', True)],
          'trenderne': [('trend', True)],
          'trendernes': [('trend', True)],
          'trenders': [('trend', True)],
          'trene': [('tter', False)],
          'trenes': [('tter', False)],
          'trens': [('ter', False)],
          'trensen': [('trense', True)],
          'trensens': [('trense', True)],
          'trenser': [('trense', True)],
          'trenserne': [('trense', True)],
          'trensernes': [('trense', True)],
          'trensers': [('trense', True)],
          'trer': [('trer', False)],
          'trerne': [('trer', False)],
          'trernes': [('trer', False)],
          'trers': [('tre', False)],
          "tres'": [('tres', False)],
          'tressen': [('tresse', False)],
          'tressens': [('tresse', True)],
          'tresser': [('tresser', True), ('tresse', True)],
          'tresserne': [('tresser', True), ('tresse', True)],
          'tressernes': [('tresser', True), ('tresse', True)],
          'tressers': [('tresser', True), ('tresse', True)],
          'tret': [('ter', False)],
          'tretiden': [('tretiden', True)],
          'trets': [('ter', False)],
          'trevlen': [('trevl', True)],
          'trevlens': [('trevl', True)],
          'trevler': [('trevl', True)],
          'trevlerne': [('trevl', True)],
          'trevlernes': [('trevl', True)],
          'trevlers': [('trevl', True)],
          'trias': [('trias', True)],
          'triben': [('tribe', False)],
          'tribens': [('tribe', False)],
          'triber': [('tribe', False)],
          'triberne': [('tribe', False)],
          'tribernes': [('tribe', False)],
          'tribunen': [('tribun', True), ('tribune', True)],
          'tribunens': [('tribun', True), ('tribune', True)],
          'tribuner': [('tribun', True), ('tribune', True)],
          'tribunerne': [('tribune', True), ('tribun', True)],
          'tribunernes': [('tribun', True), ('tribune', True)],
          'tribuners': [('tribune', True), ('tribun', True)],
          'trice': [('trice', False)],
          'tricer': [('trice', False)],
          'triden': [('trid', False)],
          'tridens': [('trid', False)],
          'trids': [('trid', False)],
          'triers': [('tri', False)],
          'triet': [('trium', False)],
          'triets': [('trium', False)],
          'triferien': [('triferie', False)],
          'triferier': [('triferie', False)],
          'triferierne': [('triferie', False)],
          'triger': [('triger', False)],
          'trigerne': [('trige', False)],
          'trigernes': [('trige', False)],
          'trigers': [('triger', False)],
          'triggernes': [('trigger', False)],
          'triglen': [('trigle', False)],
          'triglens': [('trigle', False)],
          'trigler': [('trigle', False)],
          'triglerne': [('trigle', False)],
          'triglernes': [('trigle', False)],
          'triglers': [('trigle', False)],
          'trikkens': [('trik', False)],
          'triks': [('trik', False)],
          'trille': [('trille', False)],
          'trillen': [('trille', False)],
          'triller': [('trille', False)],
          'trillerne': [('trille', True)],
          'trillernes': [('trille', False)],
          'trillers': [('trille', True)],
          'trilles': [('trille', True)],
          'trimen': [('trime', False)],
          'trimens': [('trime', False)],
          'trimers': [('trime', False)],
          'trinen': [('trin', False)],
          'trinens': [('trin', False)],
          'trinerne': [('trin', False)],
          'trinernes': [('trin', False)],
          'trinet': [('trin', False)],
          'trinets': [('trin', False)],
          'tringer': [('tring', False)],
          'tringerne': [('tring', False)],
          'tringernes': [('tring', False)],
          'tringers': [('tring', False)],
          'trins': [('trin', False)],
          'trio': [('trio', True)],
          'trioer': [('trio', True)],
          'trioerne': [('trio', True)],
          'trioernes': [('trio', True)],
          'trioers': [('trio', True)],
          'trios': [('trio', True)],
          'trippernes': [('tripper', False)],
          'trippers': [('tripper', False)],
          'tris': [('tri', False)],
          'trissen': [('trisse', True)],
          'trissens': [('trisse', False)],
          'trisser': [('trisse', False)],
          'trisserne': [('trisse', False)],
          'trissernes': [('trisse', True)],
          'trissers': [('trisse', True)],
          'trister': [('trist', False)],
          'tristerne': [('trist', False)],
          'tristernes': [('trist', False)],
          'tristers': [('trist', False)],
          'tritis': [('tritis', False)],
          'tritter': [('trit', False)],
          'tritterne': [('trit', False)],
          'tritternes': [('trit', False)],
          'tritters': [('trit', False)],
          'trium': [('trium', False)],
          'triums': [('trium', False)],
          'troden': [('trode', False)],
          'trodens': [('trode', False)],
          'troder': [('trode', False)],
          'trods': [('trods', True)],
          'troen': [('tro', False)],
          'troens': [('tro', False)],
          'troer': [('tro', False)],
          'troerne': [('tro', False)],
          'troernes': [('tro', False)],
          'troers': [('tro', False)],
          'trogen': [('trogen', False)],
          'trollen': [('trol', False)],
          'trollens': [('trol', False)],
          'trommen': [('tromme', False)],
          'trommens': [('tromme', False)],
          'trommer': [('tromme', False)],
          'trommerne': [('tromme', False)],
          'trommernes': [('tromme', False)],
          'trommers': [('tromme', False)],
          'trompeter': [('trompet', True), ('trompeter', True)],
          'trompeterne': [('trompeter', True), ('trompet', True)],
          'trompeternes': [('trompeter', True), ('trompet', True)],
          'trompeters': [('trompet', True), ('trompeter', True)],
          'tronen': [('trone', True)],
          'tronens': [('trone', True)],
          'troner': [('trone', True)],
          'tronerne': [('trone', True)],
          'tronernes': [('trone', True)],
          'troners': [('trone', True)],
          'tronomens': [('tronom', False)],
          'tropen': [('trope', True)],
          'tropens': [('trope', True)],
          'troper': [('trope', True), ('troper', True)],
          'troperne': [('troper', True), ('trope', True)],
          'tropernes': [('trope', True), ('troper', True)],
          'tropers': [('troper', True), ('trope', True)],
          'tropper': [('tropper', True)],
          'tropperne': [('tropper', False)],
          'troppernes': [('tropper', True)],
          'troppers': [('tropper', False)],
          'trops': [('trop', False)],
          'tros': [('tro', True), ('tros', True)],
          'trosen': [('tros', False)],
          'trosens': [('tros', False)],
          'troser': [('tros', False)],
          'troserne': [('tros', False)],
          'trosernes': [('tros', False)],
          'trosers': [('tros', False)],
          'trossen': [('trosse', True)],
          'trossens': [('trosse', True)],
          'trosser': [('trosse', True)],
          'trosserne': [('trosse', True)],
          'trossernes': [('trosse', True)],
          'trossers': [('trosse', True)],
          'trotten': [('trot', False)],
          'trottens': [('trot', False)],
          'trotter': [('trotter', False)],
          'trotterne': [('trotter', False)],
          'trotternes': [('trotter', False)],
          'trotters': [('trot', False)],
          'trovers': [('trovers', False)],
          'truben': [('trube', False)],
          'trubens': [('trube', False)],
          'truber': [('trube', False)],
          'truberne': [('trube', False)],
          'trubernes': [('trube', False)],
          'truder': [('trude', False)],
          'truderne': [('trude', False)],
          'trudernes': [('trude', False)],
          'truders': [('trude', False)],
          'truers': [('tru', False)],
          'trum': [('ter', False)],
          'trummer': [('trum', False)],
          'trummerne': [('trum', False)],
          'trummet': [('trum', False)],
          'trummets': [('trum', False)],
          'trums': [('ter', False)],
          'trunde': [('trunde', False)],
          'trundens': [('trunde', False)],
          'trunders': [('trunde', False)],
          'trundes': [('trunde', False)],
          'trupper': [('trup', True)],
          'trupperne': [('trup', True)],
          'truppernes': [('trup', False)],
          'truppers': [('trup', True)],
          'truppes': [('trup', False)],
          'trus': [('trus', False)],
          'trussen': [('trusse', False)],
          'trussens': [('trusse', True)],
          'trusser': [('trusse', True), ('trusser', True)],
          'trusserne': [('trusser', True), ('trusse', True)],
          'trussernes': [('trusser', True), ('trusse', True)],
          'trussers': [('trusse', True), ('trusser', True)],
          'trutter': [('trut', False)],
          'trykkerne': [('trykker', False)],
          'trykkernes': [('trykker', False)],
          'trynerne': [('tryne', False)],
          'tryners': [('tryne', False)],
          'tråde': [('tråd', False)],
          'tråden': [('tråd', False)],
          'trådens': [('tråd', False)],
          'trådes': [('tråd', False)],
          'trålerne': [('tråle', False)],
          'træder': [('træde', False)],
          'træderne': [('træde', False)],
          'trædernes': [('træde', False)],
          'træders': [('træder', False)],
          'træer': [('træ', False)],
          'træerne': [('træ', False)],
          'træernes': [('træ', False)],
          'træers': [('træ', False)],
          'trækken': [('træk', True)],
          'trækkens': [('træk', True)],
          'trækker': [('trækker', False)],
          'trækkerne': [('trækker', False)],
          'trækkernes': [('trækker', False)],
          'trækkers': [('trækker', False)],
          'træner': [('træner', False)],
          'trænernes': [('træner', False)],
          'træs': [('træ', False)],
          'trætten': [('trætte', True)],
          'trættens': [('trætte', True)],
          'trætter': [('trætte', True)],
          'trætterne': [('trætte', True)],
          'trætternes': [('trætte', True)],
          'trætters': [('trætte', True)],
          'trøjer': [('trøje', False)],
          'trøret': [('trør', False)],
          'trørets': [('trør', False)],
          'trøsken': [('trøske', True)],
          'trøskens': [('trøske', True)],
          'trøster': [('trøster', True)],
          'trøsterne': [('trøster', True)],
          'trøsternes': [('trøster', True)],
          'trøsters': [('trøster', True)],
          "ts'": [('ts', False)],
          'ts-': [('tspolitik', False)],
          'tsagen': [('tsag', False)],
          'tsagernes': [('tsag', False)],
          'tsagers': [('tsag', False)],
          'tschen': [('tsch', False)],
          'tschens': [('tsch', False)],
          'tscher': [('tsch', False)],
          'tscherne': [('tsch', False)],
          'tschers': [('tsch', False)],
          'tsdage': [('tsdage', False)],
          'tsdagene': [('tsdage', False)],
          'tsdagenes': [('tsdage', False)],
          'tsdages': [('tsdage', False)],
          'tse': [('ts', False)],
          'tseerne': [('tseer', False)],
          'tsellers': [('tseller', False)],
          'tsen': [('ts', False)],
          'tsene': [('ts', False)],
          'tsenes': [('ts', False)],
          'tsens': [('ts', False)],
          'tser': [('ts', False)],
          'tserers': [('tserer', False)],
          'tserne': [('ts', False)],
          'tsernes': [('ts', False)],
          'tsers': [('ts', False)],
          'tses': [('ts', False)],
          'tset': [('ts', False)],
          'tsets': [('ts', False)],
          'tsetter': [('tsetter', False)],
          'tshandler': [('tshandel', False)],
          'tshandlers': [('tshandel', False)],
          'tsias': [('tsia', False)],
          'tsider': [('tsider', False)],
          'tsiderne': [('tsider', False)],
          'tsidernes': [('tsider', False)],
          'tsiders': [('tsider', False)],
          'tsigter': [('tsigte', False)],
          'tsigtet': [('tsigte', False)],
          'tsigtets': [('tsigte', False)],
          'tsjer': [('tsjer', False)],
          'tsk.': [('teskefuld', True)],
          'tskaber': [('tskab', False)],
          'tskaberne': [('tskab', False)],
          'tskabernes': [('tskab', False)],
          'tskabers': [('tskab', False)],
          'tskallen': [('tskalle', False)],
          'tskallens': [('tskalle', False)],
          'tskaller': [('tskalle', False)],
          'tskallerne': [('tskalle', False)],
          'tskallernes': [('tskalle', False)],
          'tskallers': [('tskalle', False)],
          'tskifte': [('tskifte', False)],
          'tskifter': [('tskifte', False)],
          'tskifterne': [('tskifte', False)],
          'tskifternes': [('tskifte', False)],
          'tskifters': [('tskifte', False)],
          'tskiftes': [('tskifte', False)],
          'tskiftet': [('tskifte', False)],
          'tskiftets': [('tskifte', False)],
          'tskillinger': [('tskilling', False)],
          'tskillingerne': [('tskilling', False)],
          'tskistens': [('tskist', False)],
          'tskisterne': [('tskist', False)],
          'tskisternes': [('tskist', False)],
          'tskreds': [('tskreds', False)],
          'tskrige': [('tskrig', False)],
          'tskrigen': [('tskrig', False)],
          'tskrigens': [('tskrig', False)],
          'tskriges': [('tskrig', False)],
          'tslags': [('tslag', False)],
          'tslangen': [('tslange', False)],
          'tslangens': [('tslange', False)],
          'tslærers': [('tslærer', False)],
          'tsne': [('tsne', False)],
          'tsnes': [('tsne', False)],
          'tsomkostninger': [('tsomkostning', False)],
          'tsomkostningerne': [('tsomkostning', False)],
          'tsomkostningernes': [('tsomkostning', False)],
          'tsomkostningers': [('tsomkostning', False)],
          'tsorden': [('tsorden', False)],
          'tsordens': [('tsorden', False)],
          'tspidser': [('tspidser', False)],
          'tspidserne': [('tspidser', False)],
          'tspidsernes': [('tspidser', False)],
          'tspidsers': [('tspidser', False)],
          'tspressen': [('tspresse', False)],
          'tsretterne': [('tsret', False)],
          'tsretternes': [('tsret', False)],
          'tsretters': [('tsret', False)],
          'tssagens': [('tssag', False)],
          'tssager': [('tssag', False)],
          'tssagerne': [('tssag', False)],
          'tssagernes': [('tssag', False)],
          'tsselen': [('tssele', False)],
          'tsselens': [('tssele', False)],
          'tstammen': [('tstamme', False)],
          'tstammens': [('tstamme', False)],
          'tstammer': [('tstamme', False)],
          'tstammerne': [('tstamme', False)],
          'tstammernes': [('tstamme', False)],
          'tstammers': [('tstamme', False)],
          'tstarter': [('tstart', False)],
          'tstarterne': [('tstart', False)],
          'tstarternes': [('tstart', False)],
          'tstarters': [('tstart', False)],
          'tstemmer': [('tstemme', False)],
          'tstemmerne': [('tstemme', False)],
          'tstemmernes': [('tstemme', False)],
          'tstemmers': [('tstemme', False)],
          'tstempler': [('tstempel', False)],
          'tstemplerne': [('tstempel', False)],
          'tstemplernes': [('tstempel', False)],
          'tstemplers': [('tstempel', False)],
          'tstens': [('tsten', False)],
          'tstifter': [('tstifter', False)],
          'tstifterne': [('tstift', False)],
          'tstifternes': [('tstift', False)],
          'tstifters': [('tstift', False)],
          'tstraffe': [('tstraf', False)],
          'tstraffene': [('tstraf', False)],
          'tstraffenes': [('tstraf', False)],
          'tstraffes': [('tstraf', False)],
          'tstykkernes': [('tstykke', False)],
          'tstykkers': [('tstykke', False)],
          'tstyret': [('tstyr', False)],
          'tstyrets': [('tstyr', False)],
          'tstænger': [('tstang', False)],
          'tstængerne': [('tstang', False)],
          'tstængernes': [('tstang', False)],
          'tstængers': [('tstang', False)],
          'tstøvlerne': [('tstøvle', False)],
          'tstøvlernes': [('tstøvle', False)],
          'tsummer': [('tsum', False)],
          'tsummerne': [('tsum', False)],
          'tsummernes': [('tsum', False)],
          'tsummers': [('tsum', False)],
          'tsure': [('tsur', False)],
          'tsures': [('tsur', False)],
          'tsus': [('tsu', False)],
          'tsværker': [('tsværk', False)],
          'tsværkerne': [('tsværk', False)],
          'tsværkernes': [('tsværk', False)],
          'tsværkers': [('tsværk', False)],
          'tsynder': [('tsynder', False)],
          'tsynderne': [('tsynder', False)],
          'tsyndernes': [('tsynder', False)],
          'tsynders': [('tsynder', False)],
          'tsyren': [('tsyre', False)],
          'tsyrens': [('tsyre', False)],
          'tsyrer': [('tsyre', False)],
          'tsyrerne': [('tsyre', False)],
          'tsyrernes': [('tsyre', False)],
          'tsyrers': [('tsyre', False)],
          'tsæder': [('tsæde', False)],
          'tsæderne': [('tsæde', False)],
          'tsædernes': [('tsæde', False)],
          'tsæders': [('tsæde', False)],
          'tsætter': [('tsætter', False)],
          'tsøer': [('tsø', False)],
          'tsøerne': [('tsø', False)],
          'tsøernes': [('tsø', False)],
          'tsøers': [('tsø', False)],
          'ttaenes': [('tta', False)],
          'ttagen': [('ttag', False)],
          'ttagens': [('ttag', False)],
          'ttagere': [('ttager', False)],
          'ttageren': [('ttager', False)],
          'ttagerens': [('ttager', False)],
          'ttageres': [('ttager', False)],
          'ttaks': [('ttak', False)],
          'ttalens': [('ttale', False)],
          'ttaler': [('ttaler', False)],
          'ttalerne': [('ttale', False)],
          'ttalernes': [('ttale', False)],
          'ttalers': [('ttaler', False)],
          'ttallerne': [('ttal', False)],
          'ttallernes': [('ttal', False)],
          'ttanden': [('ttand', False)],
          'ttandens': [('ttand', False)],
          'ttanten': [('ttant', False)],
          'ttantens': [('ttant', False)],
          'ttanter': [('ttant', False)],
          'ttanterne': [('ttant', False)],
          'ttanternes': [('ttant', False)],
          'ttanters': [('ttant', False)],
          'ttapper': [('ttap', False)],
          'ttapperne': [('ttap', False)],
          'ttappernes': [('ttap', False)],
          'ttappers': [('ttap', False)],
          'ttas': [('tta', False)],
          'ttaver': [('ttave', False)],
          'ttaverne': [('ttave', False)],
          'ttavernes': [('ttave', False)],
          'ttavlen': [('ttavle', False)],
          'ttavlens': [('ttavle', False)],
          'tteater': [('tteater', False)],
          'ttefaren': [('ttefare', False)],
          'ttefødder': [('ttefod', False)],
          'ttehandlerne': [('ttehandel', False)],
          'ttehandlernes': [('ttehandel', False)],
          'ttelen': [('ttel', False)],
          'ttelens': [('ttel', False)],
          'ttelys': [('ttelys', False)],
          'ttemager': [('ttemager', False)],
          'ttemplerne': [('ttempel', False)],
          'ttemplernes': [('ttempel', False)],
          'ttemplers': [('ttempel', False)],
          'ttendens': [('ttend', False)],
          'ttender': [('ttend', False)],
          'ttenderne': [('ttend', False)],
          'ttendernes': [('ttend', False)],
          'ttenders': [('ttend', False)],
          'ttene': [('t', False)],
          'ttenernes': [('ttener', False)],
          'ttenes': [('t', False)],
          'ttenter': [('ttent', False)],
          'tter': [('tte', False)],
          'tterede': [('tterede', False)],
          'tteredes': [('tteret', False)],
          'tterne': [('tte', False)],
          'tternen': [('ttern', False)],
          'tternens': [('ttern', False)],
          'tterner': [('ttern', False)],
          'tternerne': [('ttern', False)],
          'tternernes': [('ttern', False)],
          'tterners': [('ttern', False)],
          'ttester': [('ttest', False)],
          'ttesterne': [('ttest', False)],
          'ttesternes': [('ttest', False)],
          'ttesters': [('ttest', False)],
          'ttet': [('t', False)],
          'ttetiden': [('ttetiden', False)],
          'ttets': [('t', False)],
          'ttiden': [('ttiden', False)],
          'ttider': [('ttid', False)],
          'ttiderne': [('ttid', False)],
          'ttiders': [('ttid', False)],
          'ttids': [('ttid', False)],
          'ttiene': [('tto', False)],
          'ttienes': [('tto', False)],
          'ttier': [('tti', False)],
          'ttierne': [('tti', False)],
          'ttiernes': [('tti', False)],
          'ttiers': [('tti', False)],
          'ttika': [('ttika', False)],
          'ttikas': [('ttika', False)],
          'ttiner': [('ttiner', False)],
          'ttinernes': [('ttiner', False)],
          'ttings': [('ttings', False)],
          "ttings'": [('ttings', False)],
          'ttoer': [('tto', False)],
          'ttoerne': [('tto', False)],
          'ttoernes': [('tto', False)],
          'ttoers': [('tto', False)],
          'ttoget': [('ttog', False)],
          'ttoiletter': [('ttoilet', False)],
          'ttoiletterne': [('ttoilet', False)],
          'ttoiletternes': [('ttoilet', False)],
          'ttoiletters': [('ttoilet', False)],
          'ttoilettet': [('ttoilet', False)],
          'ttoilettets': [('ttoilet', False)],
          'ttoner': [('ttone', False)],
          'ttonerne': [('ttone', False)],
          'ttonernes': [('ttone', False)],
          'ttoners': [('ttone', False)],
          'ttorper': [('ttorper', False)],
          'ttorperne': [('ttorper', False)],
          'ttorpernes': [('ttorper', False)],
          'ttorpers': [('ttorper', False)],
          'ttrappen': [('ttrap', False)],
          'ttrappens': [('ttrap', False)],
          'ttrapper': [('ttrap', False)],
          'ttrapperne': [('ttrap', False)],
          'ttrappernes': [('ttrap', False)],
          'ttrappers': [('ttrap', False)],
          "tts'": [('t', False)],
          'ttuner': [('ttun', False)],
          'ttunerne': [('ttun', False)],
          'ttunernes': [('ttun', False)],
          'ttuners': [('ttun', False)],
          'ttungens': [('ttunge', False)],
          'tture': [('ttur', False)],
          'tturen': [('ttur', False)],
          'tturene': [('ttur', False)],
          'ttures': [('ttur', False)],
          'ttus': [('ttus', False)],
          'ttyden': [('ttyde', False)],
          'ttydens': [('ttyde', False)],
          'ttyder': [('ttyde', False)],
          'ttyderne': [('ttyde', False)],
          'ttypens': [('ttype', False)],
          'ttypernes': [('ttype', False)],
          'ttyve': [('ttyv', False)],
          'ttyves': [('ttyv', False)],
          'ttænder': [('ttand', False)],
          'ttænderne': [('ttand', False)],
          'ttændernes': [('ttand', False)],
          'ttænders': [('ttand', False)],
          'ttøjers': [('ttøj', False)],
          'ttønder': [('ttønde', False)],
          'ttønders': [('ttønde', False)],
          'ttører': [('ttør', False)],
          'tualer': [('tual', False)],
          'tualerne': [('tual', False)],
          'tualernes': [('tual', False)],
          'tualers': [('tual', False)],
          'tualet': [('tual', False)],
          'tualets': [('tual', False)],
          'tubbe': [('tub', False)],
          'tubbens': [('tub', False)],
          'tubbes': [('tub', False)],
          'tubers': [('tube', True)],
          'tude': [('tud', True)],
          'tuden': [('tud', True)],
          'tudens': [('tud', True)],
          'tuderne': [('tude', False)],
          'tuders': [('tude', False)],
          'tudes': [('tud', True)],
          'tudierne': [('tudie', False)],
          'tudium': [('tudie', False)],
          'tudiums': [('tudie', False)],
          'tuds': [('tud', True)],
          'tudse': [('tudse', True)],
          'tudsen': [('tudse', True)],
          'tudsens': [('tudse', True)],
          'tudser': [('tudse', True)],
          'tudserne': [('tudse', True)],
          'tudsernes': [('tudse', False)],
          'tudsers': [('tudse', True)],
          'tudses': [('tudse', True)],
          'tudsteder': [('tudsteder', False)],
          'tudstederne': [('tudsteder', False)],
          'tudstedernes': [('tudsteder', False)],
          'tudsteders': [('tudsteder', False)],
          'tuen': [('tue', True)],
          'tuens': [('tue', True)],
          'tuer': [('tue', True)],
          'tuerne': [('tue', True)],
          'tuernes': [('tue', True)],
          'tuers': [('tue', True)],
          'tuet': [('tu', False)],
          'tuets': [('tu', False)],
          'tuetten': [('tuette', False)],
          'tuettens': [('tuette', False)],
          'tuetterne': [('tuette', False)],
          'tuetternes': [('tuette', False)],
          'tuetters': [('tuette', False)],
          'tuffer': [('tuf', True)],
          'tufferne': [('tuf', True)],
          'tuffernes': [('tuf', True)],
          'tuffers': [('tuf', True)],
          'tuge': [('tuge', False)],
          'tugen': [('tug', False)],
          'tugens': [('tug', False)],
          'tuger': [('tug', False)],
          'tugerne': [('tug', False)],
          'tugernes': [('tug', False)],
          'tugers': [('tug', False)],
          'tuges': [('tuge', False)],
          'tuglens': [('tugle', False)],
          'tuglerne': [('tugle', False)],
          'tuglers': [('tugle', False)],
          'tukken': [('tuk', False)],
          'tullens': [('tulle', True)],
          'tullerne': [('tulle', True)],
          'tullernes': [('tulle', False)],
          'tum': [('tum', False)],
          'tumet': [('tume', False)],
          'tumlen': [('tummel', True)],
          'tumlens': [('tummel', True)],
          'tummen': [('tum', False)],
          'tummens': [('tum', False)],
          'tummernes': [('tum', False)],
          'tummers': [('tum', False)],
          'tumpen': [('tumpe', True)],
          'tumpens': [('tumpe', True)],
          'tumper': [('tumpe', True)],
          'tumperne': [('tumpe', True)],
          'tumpernes': [('tumpe', True)],
          'tumpers': [('tumpe', True)],
          'tums': [('tum', False)],
          'tunden': [('tund', False)],
          'tundens': [('tund', False)],
          'tunder': [('tund', False)],
          'tunderne': [('tunde', False)],
          'tundernes': [('tunde', False)],
          'tunders': [('tund', False)],
          'tuner': [('tuner', True)],
          'tunerne': [('tuner', True)],
          'tunernes': [('tuner', True)],
          'tuners': [('tuner', True)],
          'tungen': [('tunge', True)],
          'tungens': [('tunge', True)],
          'tunger': [('tunge', True)],
          'tungerne': [('tunge', True)],
          'tungernes': [('tunge', True)],
          'tungers': [('tunge', False)],
          'tuns': [('tun', False)],
          'tuos': [('tuos', False)],
          'tuppen': [('tup', False)],
          'tuppens': [('tup', False)],
          'tupperne': [('tup', False)],
          'tuppers': [('tup', False)],
          'ture': [('tur', True)],
          'turen': [('tur', True)],
          'turene': [('tur', True)],
          'turenes': [('tur', True)],
          'turens': [('tur', True)],
          'tures': [('tur', True)],
          'turets': [('tur', False)],
          'turger': [('turg', False)],
          'turgernes': [('turg', False)],
          'turgers': [('turg', False)],
          'turret': [('turret', False)],
          'turs': [('tur', False)],
          'turter': [('turt', False)],
          'turterne': [('turt', False)],
          'tus': [('tus', True)],
          'tusinder': [('tusind', True)],
          'tusinders': [('tusind', False)],
          'tussen': [('tus', False)],
          'tussens': [('tus', False)],
          'tusser': [('tus', False)],
          'tusserne': [('tus', False)],
          'tuts': [('tut', True)],
          "tuts'": [('tuts', False)],
          'tutsene': [('tuts', False)],
          'tutsenes': [('tuts', False)],
          'tutten': [('tut', False)],
          'tuttens': [('tut', False)],
          'tutterne': [('tut', False)],
          'tutternes': [('tut', False)],
          'tutters': [('tut', False)],
          "tv'et": [('tv', True)],
          "tv'ets": [('tv', True)],
          'tvanen': [('tvane', False)],
          'tvanens': [('tvane', False)],
          'tvaner': [('tvane', False)],
          'tvanerne': [('tvane', False)],
          'tvanernes': [('tvane', False)],
          'tvaners': [('tvane', False)],
          'tvangen': [('tvang', False)],
          'tvangens': [('tvang', False)],
          'tvarers': [('tvare', False)],
          'tveders': [('tveder', False)],
          'tvejens': [('tvej', False)],
          'tvejes': [('tvej', False)],
          'tveksler': [('tveksel', False)],
          'tvekslerne': [('tveksel', False)],
          'tvekslernes': [('tveksel', False)],
          'tvekslers': [('tveksel', False)],
          'tvinde': [('tvind', False)],
          'tvinden': [('tvind', False)],
          'tvindens': [('tvind', False)],
          'tvindes': [('tvind', False)],
          'tvine': [('tvin', False)],
          'tvinen': [('tvin', False)],
          'tvinens': [('tvin', False)],
          'tvines': [('tvin', False)],
          'tvinger': [('tvinge', False)],
          'tvingerne': [('tvinge', True)],
          'tvins': [('tvin', False)],
          'tviser': [('tviser', False)],
          'tviserne': [('tviser', False)],
          'tvisernes': [('tviser', False)],
          'tvisers': [('tviser', False)],
          'tvs': [('tvs', True)],
          "tx'er": [("tx'er", False)],
          "tx'erne": [("tx'er", False)],
          "tx'ernes": [("tx'er", False)],
          "tx'ers": [("tx'er", False)],
          'tyde': [('tyde', False)],
          'tyden': [('tyd', True)],
          'tydens': [('tyd', True)],
          'tyder': [('tyder', False)],
          'tyderne': [('tyder', False)],
          'tydernes': [('tyde', False)],
          'tyders': [('tyde', False)],
          'tydes': [('tyde', False)],
          'tyen': [('ty', False)],
          'tyens': [('ty', False)],
          'tyer': [('ty', False)],
          'tyerne': [('ty', False)],
          'tyernes': [('ty', False)],
          'tyers': [('ty', False)],
          'tygger': [('tygger', False)],
          'tyggerne': [('tygger', False)],
          'tyggernes': [('tygger', False)],
          'tykkernes': [('tykke', False)],
          'tykkers': [('tykke', False)],
          'tykket': [('tykke', False)],
          'tykkets': [('tykke', False)],
          'tyklisten': [('tykliste', False)],
          'tyklistens': [('tykliste', False)],
          'tyklisterne': [('tykliste', False)],
          'tylenet': [('tylen', False)],
          'tyllen': [('tyl', True), ('tylle', True)],
          'tyllens': [('tylle', True), ('tyl', True)],
          'tyller': [('tyl', True), ('tylle', True)],
          'tyllerne': [('tylle', True), ('tyl', True)],
          'tyllernes': [('tylle', True), ('tyl', True)],
          'tyllers': [('tyl', True), ('tylle', True)],
          'tymen': [('tyme', False)],
          'tymens': [('tyme', False)],
          'tymer': [('tyme', False)],
          'tymerne': [('tyme', False)],
          'tymernes': [('tyme', False)],
          'tymers': [('tyme', False)],
          'tynder': [('tynder', False)],
          'tynderne': [('tynder', False)],
          'tyndernes': [('tynder', False)],
          'tynders': [('tynder', False)],
          'typen': [('type', False)],
          'typens': [('type', True)],
          'typer': [('type', True)],
          'typerne': [('type', False)],
          'typernes': [('type', True)],
          'typers': [('type', True)],
          'tyre': [('tyr', True)],
          'tyren': [('tyr', True)],
          'tyrens': [('tyr', True)],
          'tyrers': [('tyrer', False)],
          'tyres': [('tyr', True)],
          'tyrken': [('tyrker', True)],
          'tyrkens': [('tyrker', True)],
          'tyrker': [('tyrker', True)],
          'tyrkerne': [('tyrker', True)],
          'tyrkernes': [('tyrker', True)],
          'tyrkers': [('tyrker', True)],
          'tys': [('ty', False)],
          'tysker': [('tysker', True)],
          'tyskerne': [('tysker', True)],
          'tyskernes': [('tysker', True)],
          'tyskers': [('tysker', True)],
          'tysten': [('tyst', False)],
          'tystens': [('tyst', False)],
          'tyster': [('tyst', False)],
          'tysterne': [('tyst', False)],
          'tysternes': [('tyst', False)],
          'tysters': [('tyst', False)],
          'tyve': [('tyv', True)],
          'tyves': [('tyv', True)],
          'tyveører': [('tyveøre', False)],
          'tyveørernes': [('tyveøre', False)],
          'tyveørers': [('tyveøre', False)],
          'tzen': [('tz', False)],
          'tzens': [('tz', False)],
          'tzer': [('tz', False)],
          'tzerne': [('tz', False)],
          'tzernes': [('tz', False)],
          'tzers': [('tz', False)],
          'tåbers': [('tåbe', True)],
          'tåen': [('tå', True)],
          'tåens': [('tå', True)],
          'tåge': [('tåge', False)],
          'tågen': [('tåge', False)],
          'tåger': [('tåge', False)],
          'tågers': [('tåge', False)],
          'tåls': [('tåls', True)],
          'tåre': [('tåre', False)],
          'tåren': [('tåre', True), ('tår', True)],
          'tårens': [('tår', True), ('tåre', True)],
          'tårer': [('tåre', False)],
          'tårerne': [('tåre', False)],
          'tårernes': [('tåre', False)],
          'tårers': [('tåre', False)],
          'tås': [('tå', False)],
          'tæbler': [('tæble', False)],
          'tæder': [('tæder', False)],
          'tæderne': [('tad', False)],
          'tædernes': [('tad', False)],
          'tæders': [('tad', False)],
          'tæer': [('tå', False)],
          'tæerne': [('tå', False)],
          'tæernes': [('tå', True)],
          'tæers': [('tå', False)],
          'tæet': [('tæ', False)],
          'tæets': [('tæ', False)],
          'tæfte': [('tæft', True)],
          'tæftes': [('tæft', True)],
          'tæge': [('tæge', True)],
          'tægen': [('tæge', True)],
          'tæger': [('tæge', True)],
          'tægten': [('tægt', False)],
          'tægtens': [('tægt', False)],
          'tægter': [('tægt', False)],
          'tægterne': [('tægt', False)],
          'tægternes': [('tægt', False)],
          'tægters': [('tægt', False)],
          'tækker': [('tækker', False)],
          'tækkernes': [('tækker', False)],
          'tækkers': [('tækker', True)],
          'tælet': [('tæl', False)],
          'tælets': [('tæl', False)],
          'tællens': [('tælle', True)],
          'tæller': [('tæller', True)],
          'tællers': [('tæller', False)],
          'tæmmer': [('tæmmer', False)],
          'tæmmerne': [('tæmmer', False)],
          'tænder': [('tænder', True), ('tand', True)],
          'tændere': [('tænder', False)],
          'tænderen': [('tænder', False)],
          'tænderens': [('tænder', False)],
          'tænderes': [('tænder', False)],
          'tænderne': [('tand', True), ('tænder', True)],
          'tændernes': [('tænder', True), ('tand', True)],
          'tænders': [('tænder', True), ('tand', True)],
          'tænen': [('tæne', False)],
          'tænens': [('tæne', False)],
          'tæner': [('tæne', False)],
          'tænerne': [('tæne', False)],
          'tænernes': [('tæne', False)],
          'tænger': [('tang', True)],
          'tængerne': [('tang', False)],
          'tængernes': [('tang', True)],
          'tængers': [('tang', True)],
          'tænker': [('tænker', False)],
          'tæppes': [('tæppe', False)],
          'tæppet': [('tæppe', False)],
          'tæppets': [('tæppe', False)],
          'tære': [('tære', False)],
          'tærens': [('tær', False)],
          'tærer': [('tær', False)],
          'tærers': [('tær', False)],
          'tæres': [('tær', False)],
          'tærkerne': [('tærker', False)],
          'tærkernes': [('tærker', False)],
          'tærkers': [('tærker', False)],
          'tærten': [('tærte', True)],
          'tærtens': [('tærte', True)],
          'tærter': [('tærte', True)],
          'tærterne': [('tærte', False)],
          'tærternes': [('tærte', True)],
          'tærters': [('tærte', False)],
          'tæs': [('tæ', False)],
          'tæter': [('tæt', False)],
          'tæterne': [('tæt', False)],
          'tæternes': [('tæt', False)],
          'tæters': [('tæt', False)],
          'tæve': [('tæve', False)],
          'tæven': [('tæven', True), ('tæve', True)],
          'tævens': [('tæve', True)],
          'tæver': [('tæve', False)],
          'tæverne': [('tæve', True)],
          'tævernes': [('tæve', True)],
          'tævers': [('tæve', True)],
          'tæves': [('tæve', True)],
          'tævner': [('tævne', False)],
          'tævners': [('tævne', False)],
          'tøber': [('tøber', False)],
          'tøbernes': [('tøber', False)],
          'tøder': [('tøder', False)],
          'tøderne': [('tøder', False)],
          'tødernes': [('tøder', False)],
          'tøders': [('tøder', False)],
          'tødet': [('tød', False)],
          'tødets': [('tød', False)],
          'tøer': [('tøer', False)],
          'tøerne': [('tøer', False)],
          'tøernes': [('tøer', False)],
          'tøers': [('tøer', False)],
          'tøjer': [('tøj', False)],
          'tøjerne': [('tøj', True)],
          'tøjernes': [('tøj', False)],
          'tøjers': [('tøj', True)],
          'tøjet': [('tøj', True)],
          'tøjets': [('tøj', False)],
          'tøjlerne': [('tøjle', True)],
          'tøjlernes': [('tøjle', True)],
          'tøjter': [('tøjte', True)],
          'tøjterne': [('tøjte', True)],
          'tøjternes': [('tøjte', True)],
          'tøllen': [('tøl', False)],
          'tøller': [('tøl', False)],
          'tøllers': [('tøl', False)],
          'tømmer': [('tømme', True), ('tømmer', True)],
          'tømmermænd': [('tømmermænd', True), ('tømmermand', True)],
          'tømmermændene': [('tømmermænd', True), ('tømmermand', True)],
          'tømmermændenes': [('tømmermænd', True), ('tømmermand', True)],
          'tømmermænds': [('tømmermænd', True), ('tømmermand', True)],
          'tømmerne': [('tømme', True)],
          'tømmernes': [('tømme', True)],
          'tømmers': [('tømme', True), ('tømmer', True)],
          'tønder': [('tønder', True), ('tønde', True)],
          'tønderne': [('tønde', False)],
          'tøndernes': [('tønde', False)],
          'tønders': [('tønder', True), ('tønde', True)],
          'tønner': [('tønner', False)],
          'tønnerne': [('tønner', False)],
          'tønnernes': [('tønner', False)],
          'tønners': [('tønner', False)],
          'tøre': [('tøre', False)],
          'tøren': [('tør', False)],
          'tørene': [('tør', False)],
          'tørenes': [('tør', False)],
          'tørens': [('tør', False)],
          'tørerne': [('tør', False)],
          'tørernes': [('tør', False)],
          'tørers': [('tør', False)],
          'tøres': [('tøre', False)],
          'tøret': [('tøre', False)],
          'tørets': [('tøre', False)],
          'tørken': [('tørke', True)],
          'tørkens': [('tørke', True)],
          'tørnet': [('tørn', True)],
          'tørnets': [('tørn', True)],
          'tørsten': [('tørst', False)],
          'tøs': [('tø', True), ('tøs', True)],
          'tøse': [('tøs', True)],
          'tøsen': [('tøs', True)],
          'tøsens': [('tøs', True)],
          'tøser': [('tøs', True)],
          'tøserne': [('tøs', True)],
          'tøsernes': [('tøs', True)],
          'tøsers': [('tøs', True)],
          'tøses': [('tøs', True)],
          "u'erne": [('u', True)],
          'ua': [('ua', False)],
          'uaen': [('ua', False)],
          'uaens': [('ua', False)],
          'uaer': [('ua', False)],
          'uaerne': [('ua', False)],
          'uaernes': [('ua', False)],
          'uaers': [('ua', False)],
          'uakken': [('uak', False)],
          'uakkerne': [('uak', False)],
          'uaks': [('uak', False)],
          'ualen': [('ual', False)],
          'ualens': [('ual', False)],
          'ualer': [('uale', False)],
          'ualerne': [('uale', False)],
          'ualernes': [('uale', False)],
          'ualers': [('uale', False)],
          'ualet': [('uale', False)],
          'ualets': [('uale', False)],
          'ualiernes': [('ualier', False)],
          'uana': [('uana', False)],
          'uanen': [('uan', False)],
          'uanens': [('uan', False)],
          'uaner': [('uaner', False)],
          'uanerne': [('uaner', False)],
          'uanernes': [('uaner', False)],
          'uaners': [('uaner', False)],
          'uarerne': [('uar', False)],
          'uarers': [('uar', False)],
          'uas': [('ua', False)],
          'uatten': [('uat', False)],
          'uattens': [('uat', False)],
          'uatternes': [('uat', False)],
          'uatters': [('uat', False)],
          'uatuer': [('uatuer', False)],
          'uatuerne': [('uatuer', False)],
          'uatuernes': [('uatuer', False)],
          'uayer': [('uayer', False)],
          'uayerne': [('uayer', False)],
          'uayernes': [('uayer', False)],
          'uayers': [('uayer', False)],
          'ubaner': [('ubaner', False)],
          'ubanerne': [('ubaner', False)],
          'ubanernes': [('ubaner', False)],
          'ubaners': [('ubaner', False)],
          'ubanke': [('ubank', False)],
          'ubanken': [('ubank', False)],
          'ubankens': [('ubank', False)],
          'ubankes': [('ubank', False)],
          'ubas': [('uba', False)],
          'ubbe': [('ubbe', False)],
          'ubben': [('ub', False)],
          'ubbens': [('ubbe', False)],
          'ubber': [('ubber', False)],
          'ubberne': [('ub', False)],
          'ubbernes': [('ubbe', False)],
          'ubbers': [('ubbe', False)],
          'ubbes': [('ubbe', False)],
          'uben': [('ube', False)],
          'ubens': [('ube', False)],
          'uber': [('ube', False)],
          'uberne': [('ube', False)],
          'ubernes': [('ube', False)],
          'ubier': [('ubier', False)],
          'ubierne': [('ubier', False)],
          'ubiernes': [('ubier', False)],
          'ubiers': [('ubier', False)],
          'ubiks': [('ubik', False)],
          'ubinen': [('ubin', False)],
          'ubinens': [('ubin', False)],
          'ubiner': [('ubine', False)],
          'ubinerne': [('ubin', False)],
          'ubinernes': [('ubin', False)],
          'ubiners': [('ubine', False)],
          'ubits': [('ubits', False)],
          "ubits'": [('ubits', False)],
          'ublen': [('uble', False)],
          'ublens': [('ubel', False)],
          'ublerne': [('uble', False)],
          'ublers': [('uble', False)],
          'ubles': [('uble', False)],
          'ublet': [('ublet', False)],
          'ublets': [('ublet', False)],
          'ubriks': [('ubrik', False)],
          'ubs': [('ub', False)],
          "ubs'": [('ub', False)],
          'uburets': [('ubur', False)],
          'ucenter': [('ucent', False)],
          'ucenters': [('ucent', False)],
          'ucer': [('ucer', False)],
          'ucerne': [('ucer', False)],
          'ucernen': [('ucerne', False)],
          'ucernens': [('ucerne', False)],
          'ucerner': [('ucerne', False)],
          'ucernernes': [('ucerne', False)],
          'ucernes': [('ucer', False)],
          'ucers': [('ucer', False)],
          'uces': [('uce', False)],
          'uche': [('uche', False)],
          'uchen': [('uchen', False)],
          'uchens': [('uche', False)],
          'ucher': [('uche', False)],
          'ucherne': [('uche', False)],
          'uchers': [('uche', False)],
          'uches': [('uche', False)],
          'uchos': [('ucho', False)],
          'uciner': [('uciner', False)],
          'uciners': [('uciner', False)],
          'ucker': [('uck', False)],
          'uckerne': [('ucker', False)],
          'uckernes': [('uck', False)],
          'uckers': [('ucker', False)],
          'ud': [('ud', False)],
          'udanter': [('udant', False)],
          'udas': [('udas', False)],
          "udas'": [('udas', False)],
          'udbytter': [('udbytter', True), ('udbytte', True)],
          'udbytterne': [('udbytter', True), ('udbytte', True)],
          'udbytternes': [('udbytter', True), ('udbytte', True)],
          'udbytters': [('udbytter', True), ('udbytte', True)],
          'udder': [('udder', False)],
          'udderne': [('udder', False)],
          'uddernes': [('udder', False)],
          'ude': [('ud', False)],
          'udehandlerne': [('udehandel', False)],
          'udehandlernes': [('udehandel', False)],
          'uden': [('ud', False)],
          'udene': [('ud', False)],
          'udenes': [('ud', False)],
          'udens': [('ud', False)],
          'udenten': [('udent', False)],
          'udentens': [('udent', False)],
          'udenter': [('udent', False)],
          'udenterne': [('udent', False)],
          'udenternes': [('udent', False)],
          'udenters': [('udent', False)],
          'uder': [('ude', False)],
          'udere': [('uder', False)],
          'uderen': [('uder', False)],
          'uderens': [('uder', False)],
          'uderes': [('uder', False)],
          'uderne': [('ud', False)],
          'udernes': [('ude', False)],
          'uders': [('ud', False)],
          'udes': [('ud', False)],
          'udet': [('ud', False)],
          'udets': [('ud', False)],
          'udianer': [('udianer', False)],
          'udianers': [('udianer', False)],
          'udien': [('udie', False)],
          'udiens': [('udie', False)],
          'udier': [('udie', False)],
          'udierne': [('udium', False)],
          'udiernes': [('udie', False)],
          'udiers': [('udie', False)],
          "udies'": [('udy', False)],
          'udiets': [('udie', False)],
          'udiner': [('udine', False)],
          'udinerne': [('udine', False)],
          'udiners': [('udine', False)],
          'uditorier': [('uditorie', False)],
          'uditorierne': [('uditorie', False)],
          'uditoriernes': [('uditorie', False)],
          'uditoriers': [('uditorie', False)],
          'uditoriet': [('uditorie', False)],
          'uditoriets': [('uditorie', False)],
          'uditten': [('udit', False)],
          'udium': [('udium', False)],
          'udiums': [('udium', False)],
          'udkopper': [('udkop', False)],
          'udkopperne': [('udkop', False)],
          'udkoppers': [('udkop', False)],
          'udlejerne': [('udlejer', True)],
          'udlejernes': [('udlejer', True)],
          'udlejers': [('udlejer', True)],
          'udlen': [('uddel', False)],
          'udlens': [('udel', False)],
          'udler': [('udel', False)],
          'udlerne': [('uddel', False)],
          'udlernes': [('uddel', False)],
          'udlers': [('udel', False)],
          'udmarker': [('udmark', True)],
          'udmarkerne': [('udmark', True)],
          'udomme': [('udom', False)],
          'udrivene': [('udriv', True)],
          'udrivenes': [('udriv', True)],
          'udråber': [('udråber', True)],
          'udråberne': [('udråber', True)],
          'udråbernes': [('udråber', True)],
          'udråbers': [('udråber', True)],
          'uds': [('ud', False)],
          'udserne': [('udser', False)],
          'udsernes': [('udser', False)],
          'udskallens': [('udskalle', False)],
          'udskallerne': [('udskalle', False)],
          'udskifter': [('udskifter', True)],
          'udspørger': [('udspørger', True)],
          'udspørgerne': [('udspørger', True)],
          'udspørgernes': [('udspørger', True)],
          'udspørgers': [('udspørger', True)],
          'udsteder': [('udsted', True), ('udsteder', True)],
          'udstederne': [('udsted', True), ('udsteder', True)],
          'udstedernes': [('udsted', True), ('udsteder', True)],
          'udsteders': [('udsted', True), ('udsteder', True)],
          'udstikken': [('udstikke', False)],
          'udstikker': [('udstikke', False)],
          'udstikkerne': [('udstikke', False)],
          'udstikkers': [('udstikke', False)],
          'udstykker': [('udstykker', True)],
          'udstykkerne': [('udstykker', True)],
          'udstykkernes': [('udstykker', True)],
          'udstykkers': [('udstykker', True)],
          'udsuger': [('udsuger', True)],
          'udsugerne': [('udsuger', True)],
          'udsugernes': [('udsuger', True)],
          'udsugers': [('udsuger', True)],
          'uduen': [('udu', False)],
          'uduens': [('udu', False)],
          'uduer': [('udu', False)],
          'uduerne': [('udu', False)],
          'uduernes': [('udu', False)],
          'uduers': [('udu', False)],
          'udus': [('udu', False)],
          'udvortes': [('udvortes', True)],
          'udørken': [('udørken', True)],
          'udørkens': [('udørken', True)],
          'ue': [('ue', False)],
          'uebens': [('ueben', False)],
          'uebirkes': [('uebirk', False)],
          'uekerne': [('uekerne', False)],
          'uekernes': [('uekerne', False)],
          'uellen': [('uel', False)],
          'ueller': [('uel', False)],
          'uellers': [('uel', False)],
          'uelsers': [('uelse', False)],
          'uen': [('ue', False)],
          'uencer': [('uencer', False)],
          'uencerne': [('uencer', False)],
          'uencernes': [('uencer', False)],
          'uencers': [('uencer', False)],
          'uenden': [('uend', False)],
          'uendens': [('uend', False)],
          'uender': [('uend', False)],
          'uenderne': [('uend', False)],
          'uendernes': [('uend', False)],
          'uenders': [('uend', False)],
          'uene': [('u', False)],
          'uenen': [('uen', False)],
          'uenens': [('uen', False)],
          'uenes': [('u', False)],
          'uens': [('ue', False)],
          "uens'": [('uens', False)],
          'uensen': [('uens', False)],
          'uensens': [('uens', False)],
          'uenser': [('uens', False)],
          'uenserne': [('uensis', False)],
          'uensernes': [('uens', False)],
          'uensers': [('uens', False)],
          'uenten': [('uent', False)],
          'uentens': [('uent', False)],
          'uenter': [('uent', False)],
          'uenterne': [('uent', False)],
          'uenternes': [('uent', False)],
          'uenters': [('uent', False)],
          'uer': [('ue', False)],
          'ueret': [('ueret', False)],
          'uerets': [('ueret', False)],
          'ueretten': [('ueret', False)],
          'uerettens': [('ueret', False)],
          'ueretterne': [('ueret', False)],
          'ueretternes': [('ueret', False)],
          'ueretters': [('ueret', False)],
          'ueritterne': [('uerit', False)],
          'uerne': [('ue', False)],
          'uernes': [('ue', False)],
          'uers': [('ue', False)],
          'ues': [('ue', False)],
          "ues'": [('ue', False)],
          'ueskytternes': [('ueskytte', False)],
          'ueskytters': [('ueskytte', False)],
          'uespiller': [('uespiller', False)],
          'uespillerne': [('uespiller', False)],
          'uespillernes': [('uespiller', False)],
          'uespillers': [('uespiller', False)],
          'uestilens': [('uestil', False)],
          'uet': [('ue', False)],
          'ueter': [('uete', False)],
          'ueterne': [('uete', False)],
          'ueternes': [('uete', False)],
          'ueters': [('uete', False)],
          'uetes': [('uete', False)],
          'uets': [('ue', False)],
          'uetten': [('uet', False)],
          'uettens': [('uet', False)],
          'uetter': [('uette', False)],
          'uetterne': [('uet', False)],
          'uetternes': [('uet', False)],
          'uetters': [('uet', False)],
          'uf': [('uf', False)],
          'uffen': [('uf', False)],
          'uffene': [('uf', False)],
          'uffenes': [('uf', False)],
          'uffens': [('uf', False)],
          'uffer': [('uffe', False)],
          'ufferens': [('uffer', False)],
          'ufferne': [('uffe', False)],
          'uffernes': [('uffe', False)],
          'uffers': [('uffe', False)],
          'uffes': [('uffe', False)],
          'uffet': [('uffet', False)],
          'uffets': [('uf', False)],
          'ufis': [('ufi', False)],
          'ufoliernes': [('ufolie', False)],
          'ufos': [('ufo', True)],
          'ufter': [('uft', False)],
          'ug': [('ug', False)],
          "ug'er": [('ug', True)],
          'ugarer': [('ugar', False)],
          'ugarernes': [('ugar', False)],
          'ugaret': [('ugar', False)],
          'ugarets': [('ugar', False)],
          'ugas': [('uga', False)],
          'ugaten': [('ugat', False)],
          'ugatens': [('ugat', False)],
          'ugden': [('ugde', False)],
          'ugdens': [('ugde', False)],
          'ugdernes': [('ugde', False)],
          'ugders': [('ugde', False)],
          'uge': [('uge', True)],
          'ugemoders': [('ugemor', False)],
          'ugen': [('uge', True)],
          'ugene': [('ug', False)],
          'ugenes': [('ug', False)],
          'ugens': [('uge', False)],
          'uger': [('uge', True)],
          'ugere': [('uger', False)],
          'ugeren': [('uger', False)],
          'ugerens': [('uger', False)],
          'ugeres': [('uger', False)],
          'ugerne': [('uge', False)],
          'ugernes': [('uge', False)],
          'ugers': [('uge', True)],
          'uges': [('uge', True)],
          'uget': [('ug', False)],
          'ugets': [('ug', False)],
          'ugge': [('ugge', False)],
          'uggen': [('ugge', False)],
          'uggenes': [('ug', False)],
          'uggens': [('ugge', False)],
          'ugger': [('ugge', False)],
          'uggerne': [('ugge', False)],
          'uggernes': [('ugger', False)],
          'uggers': [('ugger', False)],
          'ugges': [('ugge', False)],
          'ugier': [('ugie', False)],
          'ugierne': [('ugie', False)],
          'ugiernes': [('ugie', False)],
          'ugiers': [('ugie', False)],
          'ugiet': [('ugie', False)],
          'ugiets': [('ugie', False)],
          'ugkiks': [('ugkik', False)],
          'ugle': [('ugle', False)],
          'uglen': [('ugle', False)],
          'uglens': [('ugle', True)],
          'ugler': [('ugle', True)],
          'uglerne': [('ugle', True)],
          'uglernes': [('ugle', False)],
          'uglers': [('ugle', True)],
          'ugles': [('ugle', False)],
          'ugs': [('ug', False)],
          "ugs'": [('ug', False)],
          'ugsene': [('ug', False)],
          'ugsenes': [('ug', False)],
          'ugsten': [('ugst', False)],
          'ugstens': [('ugst', False)],
          'ugster': [('ugst', False)],
          'ugsterne': [('ugst', False)],
          'ugsternes': [('ugst', False)],
          'ugsters': [('ugst', False)],
          'ugter': [('ugter', False)],
          'ugterne': [('ugter', False)],
          'ugternes': [('ugter', False)],
          'ugters': [('ugt', False)],
          'uh': [('uh', False)],
          'uhinde': [('uhinde', False)],
          'uhinden': [('uhinde', False)],
          'uhindens': [('uhinde', False)],
          'uhinder': [('uhinde', False)],
          'uhinderne': [('uhinde', False)],
          'uhindernes': [('uhinde', False)],
          'uhinders': [('uhinde', False)],
          'uhindes': [('uhinde', False)],
          'ui': [('ui', False)],
          'uicen': [('uice', False)],
          'uicens': [('uice', False)],
          'uices': [('uice', False)],
          'uichernes': [('uiche', False)],
          'uide': [('uide', False)],
          'uiden': [('uide', False)],
          'uidens': [('uide', False)],
          'uider': [('uide', False)],
          'uiderne': [('uide', False)],
          'uidernes': [('uide', False)],
          'uiders': [('uide', False)],
          'uides': [('uide', False)],
          'uier': [('ui', False)],
          'uierne': [('ui', False)],
          'uiernes': [('ui', False)],
          'uiers': [('ui', False)],
          'uiet': [('ui', False)],
          'uiets': [('ui', False)],
          'uilders': [('uilder', False)],
          'uillens': [('uille', False)],
          'uiller': [('uille', False)],
          'uillerne': [('uille', False)],
          'uillernes': [('uille', False)],
          'uillers': [('uille', False)],
          'uiner': [('uin', False)],
          'uinerne': [('uin', False)],
          'uiners': [('uin', False)],
          'uis': [('ui', False)],
          'uise': [('uise', False)],
          'uisene': [('uise', False)],
          'uisenes': [('uise', False)],
          'uisers': [('uis', False)],
          'uises': [('uise', False)],
          'uiset': [('uise', False)],
          'uisets': [('uise', False)],
          'uismen': [('uisme', False)],
          'uismens': [('uisme', False)],
          'uisten': [('uist', False)],
          'uistens': [('uist', False)],
          'uister': [('uist', False)],
          'uisterne': [('uist', False)],
          'uisternes': [('uist', False)],
          'uisters': [('uist', False)],
          'uiten': [('uite', False)],
          'uitenes': [('uit', False)],
          'uitens': [('uite', False)],
          'uiter': [('uite', False)],
          'uiterne': [('uit', False)],
          'uiternes': [('uit', False)],
          'uiters': [('uite', False)],
          'uitten': [('uit', False)],
          'uittens': [('uit', False)],
          'uitternes': [('uit', False)],
          'uitters': [('uit', False)],
          'ujas': [('uja', False)],
          'ujets': [('ujet', False)],
          'uk': [('uk', False)],
          'ukanen': [('ukan', False)],
          'ukanens': [('ukan', False)],
          'ukaner': [('ukan', False)],
          'ukanerne': [('ukan', False)],
          'ukanernes': [('ukan', False)],
          'ukaners': [('ukan', False)],
          'ukans': [('ukan', False)],
          'ukater': [('ukat', False)],
          'ukaterne': [('ukat', False)],
          'ukaters': [('ukat', False)],
          'ukens': [('uke', False)],
          'ukerne': [('uke', False)],
          'ukernes': [('uke', False)],
          'ukers': [('uke', False)],
          'uket': [('uket', False)],
          'ukets': [('uket', False)],
          'uketter': [('uket', False)],
          'ukisten': [('ukist', False)],
          'ukistens': [('ukist', False)],
          'ukister': [('ukist', False)],
          'ukisterne': [('ukist', False)],
          'ukisternes': [('ukist', False)],
          'ukisters': [('ukist', False)],
          'ukke': [('ukke', False)],
          'ukken': [('ukke', False)],
          'ukkens': [('uk', False)],
          'ukker': [('uk', False)],
          'ukkerne': [('ukker', False)],
          'ukkernes': [('uk', False)],
          'ukkers': [('ukker', False)],
          'ukkes': [('ukke', False)],
          'ukket': [('uk', False)],
          'ukkets': [('uk', False)],
          'uklatter': [('uklatter', False)],
          'uklatters': [('uklatter', False)],
          'uklen': [('ukkel', False)],
          'ukler': [('ukkel', False)],
          'uklerne': [('ukkel', False)],
          'uklernes': [('ukkel', False)],
          'uklers': [('ukkel', False)],
          'ukrater': [('ukrat', False)],
          'ukraterne': [('ukrat', False)],
          'ukraternes': [('ukrat', False)],
          'ukraters': [('ukrat', False)],
          'uks': [('uk', False)],
          'ukser': [('uks', False)],
          'uktans': [('uktans', False)],
          'ukture': [('uktur', False)],
          'ukurs': [('ukur', False)],
          'ukæer': [('ukæer', False)],
          'ukæerne': [('ukæer', False)],
          'ukæernes': [('ukæer', False)],
          'ukæers': [('ukæer', False)],
          'ul': [('ul', False)],
          'ula': [('ulum', False)],
          'ulader': [('ulade', False)],
          'uladerne': [('ulade', False)],
          'uladernes': [('ulade', False)],
          'uladers': [('ulade', False)],
          'ulaks': [('ulak', False)],
          'ulammen': [('ulam', False)],
          'ulancer': [('ulance', False)],
          'ulancerne': [('ulance', False)],
          'ulancernes': [('ulance', False)],
          'ulancers': [('ulance', False)],
          'ulanens': [('ulan', False)],
          'ulaner': [('ulan', False)],
          'ulaners': [('ulan', False)],
          'ulans': [('ulan', False)],
          'ulansen': [('ulans', False)],
          'ulansens': [('ulans', False)],
          'ulanser': [('ulans', False)],
          'ulanserne': [('ulans', False)],
          'ulansernes': [('ulans', False)],
          'ulansers': [('ulans', False)],
          'ulanter': [('ulant', False)],
          'ulanterne': [('ulant', False)],
          'ulanternes': [('ulant', False)],
          'ulanters': [('ulant', False)],
          'ularer': [('ular', False)],
          'ularernes': [('ular', False)],
          'ularet': [('ular', False)],
          'ularets': [('ular', False)],
          'ularier': [('ularium', False)],
          'ularierne': [('ularium', False)],
          'ulariernes': [('ularium', False)],
          'ulariers': [('ularium', False)],
          'ularium': [('ularium', False)],
          'ulariums': [('ularium', False)],
          'ulars': [('ular', False)],
          'ulas': [('ulum', False)],
          'ulatens': [('ulat', False)],
          'ulats': [('ulat', False)],
          'ulatten': [('ulat', False)],
          'ulattens': [('ulat', False)],
          'ulatter': [('ulat', False)],
          'ulatterne': [('ulat', False)],
          'ulatternes': [('ulat', False)],
          'ulatters': [('ulat', False)],
          'ulde': [('ulde', False)],
          'ulden': [('uld', True)],
          'uldene': [('uld', False)],
          'uldens': [('uld', True)],
          'ulder': [('ulder', False)],
          'uldes': [('ulde', False)],
          'uldre': [('ulder', False)],
          'uldrers': [('uldre', False)],
          'uldres': [('uldre', False)],
          'ule': [('ul', False)],
          'uleboer': [('uleboer', False)],
          'uleboerne': [('uleboer', False)],
          'uleboers': [('uleboer', False)],
          'ulege': [('ulege', False)],
          'ulegen': [('ulege', False)],
          'ulegens': [('ulege', False)],
          'uleges': [('ulege', False)],
          'ulemærkerne': [('ulemærke', False)],
          'ulemærkernes': [('ulemærke', False)],
          'ulemærkers': [('ulemærke', False)],
          'ulen': [('ul', False)],
          'ulene': [('ul', False)],
          'ulenes': [('ul', False)],
          'ulens': [('ulens', False)],
          'ulenserne': [('ulens', False)],
          'uler': [('ule', False)],
          'ulere': [('uler', False)],
          'uleren': [('uler', False)],
          'ulerens': [('uler', False)],
          'uleres': [('uler', False)],
          'ulerne': [('ule', False)],
          'ulernes': [('ule', False)],
          'ulers': [('ul', False)],
          'ules': [('ul', False)],
          'ulet': [('ulet', False)],
          'ulets': [('ul', False)],
          'ulettens': [('ulet', False)],
          'uletter': [('ulet', False)],
          'uletterne': [('ulet', False)],
          'uletternes': [('ulet', False)],
          'uletters': [('ulet', False)],
          'ulfarter': [('ulfart', False)],
          'ulfarterne': [('ulfart', False)],
          'ulfarters': [('ulfart', False)],
          'ulfilters': [('ulfilter', False)],
          'ulhedens': [('ulhed', False)],
          'uli': [('ulus', False)],
          'ulienes': [('ulus', False)],
          'ulier': [('uli', False)],
          'ulierne': [('uli', False)],
          'uliers': [('ulier', False)],
          'ulinde': [('ulinde', False)],
          'ulinden': [('ulinde', False)],
          'ulindens': [('ulinde', False)],
          'ulindes': [('ulinde', False)],
          'ulinen': [('ulin', False)],
          'ulinens': [('ulin', False)],
          'uliner': [('ulinum', False)],
          'ulinerne': [('ulinum', False)],
          'ulinernes': [('ulinum', False)],
          'uliners': [('ulinum', False)],
          'ulinets': [('ulin', False)],
          'ulingers': [('uling', False)],
          'ulisen': [('ulis', False)],
          'ulisens': [('ulis', False)],
          'ulismen': [('ulisme', False)],
          'ulissen': [('ulisse', False)],
          'ulissens': [('ulisse', False)],
          'ulisser': [('ulisse', False)],
          'ulisserne': [('ulisse', False)],
          'ulissernes': [('ulisse', False)],
          'ulissers': [('ulisse', False)],
          'ulisten': [('ulist', False)],
          'ulistens': [('ulist', False)],
          'ulister': [('ulist', False)],
          'ulisterne': [('ulist', False)],
          'ulisternes': [('ulist', False)],
          'ulisters': [('ulist', False)],
          'ulitis': [('ulitis', False)],
          'uljen': [('ulje', False)],
          'ulker': [('ulk', False)],
          'ulkerne': [('ulk', False)],
          'ulkernes': [('ulker', False)],
          'ulkers': [('ulk', False)],
          'ulle': [('ulle', False)],
          'ulleder': [('ulleder', False)],
          'ullederne': [('ulleder', False)],
          'ulleders': [('ulleder', False)],
          'ullen': [('ulle', False)],
          'ullene': [('ul', False)],
          'ullenes': [('ul', False)],
          'uller': [('ulle', False)],
          'ullerne': [('ul', False)],
          'ullernes': [('ul', False)],
          'ullers': [('ulle', False)],
          'ulles': [('ulle', False)],
          'ullet': [('ul', False)],
          'ullets': [('ul', False)],
          'ullettens': [('ullet', False)],
          'ullisten': [('ullist', False)],
          'ullistens': [('ullist', False)],
          'ullisterne': [('ullist', False)],
          'ulminens': [('ulmine', False)],
          'ulos': [('ulos', False)],
          "ulos'": [('ulos', False)],
          'ulpe': [('ulpe', False)],
          'ulpen': [('ulpe', False)],
          'ulpens': [('ulpe', False)],
          'ulper': [('ulpe', False)],
          'ulperne': [('ulpe', False)],
          'ulpes': [('ulpe', False)],
          'uls': [('ul', False)],
          'ulsernes': [('uls', False)],
          'ulsers': [('uls', False)],
          'ulsten': [('ulst', False)],
          'ulstens': [('ulst', False)],
          'ulster': [('ulster', True)],
          'ulsterne': [('ulster', True)],
          'ulsternes': [('ulster', True)],
          'ulsters': [('ulster', True)],
          'ulte': [('ulte', False)],
          'ultene': [('ult', False)],
          'ulter': [('ulter', False)],
          'ulters': [('ult', False)],
          'ultes': [('ulte', False)],
          'ultet': [('ultet', False)],
          'ultets': [('ultet', False)],
          'uluen': [('ulu', False)],
          'uluens': [('ulu', False)],
          'uluer': [('ulu', False)],
          'uluerne': [('ulu', False)],
          'uluernes': [('ulu', False)],
          'uluers': [('ulu', False)],
          'uluner': [('ulun', False)],
          'ulunerne': [('ulun', False)],
          'ulunernes': [('ulun', False)],
          'uluners': [('ulun', False)],
          'ulunet': [('ulun', False)],
          'ulunets': [('ulun', False)],
          'uluns': [('ulun', False)],
          'ulus': [('ulu', False)],
          'ulussen': [('ulus', False)],
          'ulussens': [('ulus', False)],
          'ulveje': [('ulvej', False)],
          'ulvejes': [('ulvej', False)],
          'ulvinde': [('ulvinde', True)],
          'ulvinder': [('ulvinde', True)],
          'ulvinderne': [('ulvinde', True)],
          'ulvindernes': [('ulvinde', True)],
          'ulvinders': [('ulvinde', True)],
          'ulæren': [('ulær', False)],
          'ulærens': [('ulær', False)],
          'ulører': [('ulør', False)],
          'ulørernes': [('ulør', False)],
          'uma': [('ume', False)],
          'umagens': [('umage', True)],
          'umager': [('umage', False)],
          'umagerne': [('umage', False)],
          'umagernes': [('umage', False)],
          'umagers': [('umage', False)],
          'umakkens': [('umak', False)],
          'umakker': [('umak', False)],
          'umakkerne': [('umak', False)],
          'umakkernes': [('umak', False)],
          'umakkers': [('umak', False)],
          'umas': [('ume', False)],
          'umbers': [('umbe', False)],
          'umblernes': [('umbler', False)],
          'umen': [('umen', False)],
          'umener': [('umen', False)],
          'umenerne': [('umen', False)],
          'umeners': [('umen', False)],
          'umens': [('umen', False)],
          'umentarier': [('umentarium', False)],
          'umentariet': [('umentarium', False)],
          'umentariets': [('umentarium', False)],
          'umenten': [('ument', False)],
          'umentens': [('ument', False)],
          'umenter': [('ument', False)],
          'umenterne': [('ument', False)],
          'umenternes': [('ument', False)],
          'umenters': [('ument', False)],
          'umers': [('ume', False)],
          'umet': [('um', False)],
          'umets': [('ume', False)],
          'umfen': [('umf', False)],
          'umfens': [('umf', False)],
          'umfer': [('umf', False)],
          'umhus': [('umhus', False)],
          'umien': [('umie', False)],
          'umiens': [('umie', False)],
          'umier': [('umier', False)],
          'umiere': [('umiere', False)],
          'umieres': [('umiere', False)],
          'umierne': [('umie', False)],
          'umiernes': [('umie', False)],
          'umiers': [('umier', False)],
          'uminen': [('umen', False)],
          'uminens': [('umen', False)],
          'uminer': [('umen', False)],
          'uminerne': [('umen', False)],
          'uminernes': [('umen', False)],
          'uminers': [('umen', False)],
          'uminet': [('umin', False)],
          'uminets': [('umin', False)],
          'umle': [('umle', False)],
          'umlen': [('umle', False)],
          'umlens': [('umle', False)],
          'umler': [('umler', False)],
          'umlerne': [('umler', False)],
          'umlernes': [('umler', False)],
          'umlers': [('umler', False)],
          'umles': [('umle', False)],
          'umme': [('umme', False)],
          'ummen': [('umme', False)],
          'ummens': [('umme', False)],
          'ummer': [('um', False)],
          'ummerne': [('um', False)],
          'ummernes': [('umme', False)],
          'ummers': [('ummer', False)],
          'ummes': [('umme', False)],
          'ummet': [('um', False)],
          'ummets': [('um', False)],
          'ummis': [('ummi', False)],
          'umner': [('umne', False)],
          'umnernes': [('umne', False)],
          'umonierne': [('umoni', False)],
          'umoniernes': [('umoni', False)],
          'umoniers': [('umoni', False)],
          'umoralen': [('umoral', True)],
          'umoralens': [('umoral', True)],
          'umorer': [('umor', False)],
          'umorernes': [('umor', False)],
          'umpe': [('umpe', False)],
          'umpen': [('umpe', False)],
          'umpens': [('umpe', False)],
          'umper': [('umpe', False)],
          'umperne': [('umpe', False)],
          'umpernes': [('umper', False)],
          'umpers': [('umper', False)],
          'umpes': [('umpe', False)],
          'umplerne': [('umpel', False)],
          'umplernes': [('umpel', False)],
          'umplers': [('umpel', False)],
          'umse': [('umse', False)],
          'umsen': [('umse', False)],
          'umsens': [('umse', False)],
          'umser': [('umse', False)],
          'umserne': [('umse', False)],
          'umsernes': [('umse', False)],
          'umsers': [('umse', False)],
          'umses': [('umse', False)],
          'umulten': [('umult', False)],
          'umultens': [('umult', False)],
          'umulter': [('umult', False)],
          'umulterne': [('umult', False)],
          'umulternes': [('umult', False)],
          'umulters': [('umult', False)],
          'umus': [('umus', False)],
          'umænerne': [('umæner', False)],
          'umænernes': [('umæner', False)],
          'umørets': [('umør', False)],
          'un': [('un', False)],
          'unaler': [('unal', False)],
          'unalerne': [('unal', False)],
          'unalernes': [('unal', False)],
          'unalers': [('unal', False)],
          'unalet': [('unal', False)],
          'unalets': [('unal', False)],
          'unas': [('una', False)],
          'unater': [('unat', False)],
          'unaterne': [('unat', False)],
          'unaters': [('unat', False)],
          'unche': [('unch', False)],
          'unchen': [('unch', False)],
          'unchens': [('unch', False)],
          'uncher': [('unch', False)],
          'uncherne': [('unch', False)],
          'unchernes': [('unch', False)],
          'unchers': [('unch', False)],
          'unches': [('unch', False)],
          'undanten': [('undant', False)],
          'undantens': [('undant', False)],
          'undanterne': [('undant', False)],
          'undanternes': [('undant', False)],
          'undanters': [('undant', False)],
          'undats': [('undats', False)],
          'unde': [('unde', False)],
          'undedage': [('undedage', False)],
          'undedagene': [('undedage', False)],
          'undedagenes': [('undedage', False)],
          'undedages': [('undedage', False)],
          'unden': [('unde', False)],
          'undens': [('unde', False)],
          'undenserne': [('undenser', False)],
          'under': [('under', False)],
          'underkursernes': [('underkurs', True)],
          'underne': [('under', True)],
          'undernes': [('under', True)],
          'unders': [('under', True)],
          'undertaler': [('undertale', False)],
          'undertalernes': [('undertale', False)],
          'undes': [('unde', False)],
          'undiet': [('undium', False)],
          'undiets': [('undium', False)],
          'undkurser': [('undkurs', False)],
          'undkurserne': [('undkurs', False)],
          'undkursernes': [('undkurs', False)],
          'undkursers': [('undkursus', False)],
          'undus': [('undus', False)],
          'unellen': [('unelle', False)],
          'uneller': [('unelle', False)],
          'unellers': [('unelle', False)],
          'unen': [('un', False)],
          'unene': [('un', False)],
          'unenes': [('un', False)],
          'unens': [('un', False)],
          'uner': [('un', False)],
          'unerne': [('une', False)],
          'unernes': [('un', False)],
          'uners': [('une', False)],
          'uneser': [('uneser', False)],
          'uneserne': [('uneser', False)],
          'unesernes': [('uneser', False)],
          'unesten': [('unesten', False)],
          'unet': [('un', False)],
          'unets': [('un', False)],
          'unetten': [('unette', False)],
          'unettens': [('unette', False)],
          'unetter': [('unette', False)],
          'unetterne': [('unette', False)],
          'unetternes': [('unette', False)],
          'unetters': [('unette', False)],
          'ungarer': [('ungarer', True)],
          'ungarernes': [('ungarer', True)],
          'unge': [('unge', False)],
          'ungen': [('unge', False)],
          'ungens': [('unge', False)],
          'unger': [('unge', False)],
          'ungerne': [('unge', True)],
          'ungernes': [('unge', False)],
          'ungers': [('unge', True)],
          'unges': [('unge', False)],
          'unglens': [('ungle', False)],
          'ungler': [('ungle', False)],
          'unglerne': [('ungle', False)],
          'ungles': [('ungle', False)],
          'ungsten': [('ungsten', False)],
          'ungstens': [('ungsten', False)],
          'unier': [('unia', False)],
          'unierne': [('unia', False)],
          'uniernes': [('unia', False)],
          'uniers': [('unia', False)],
          'unika': [('unika', False)],
          'unikaenes': [('unika', True)],
          'unikas': [('unika', False)],
          'unikum': [('unika', True)],
          'unikums': [('unika', True)],
          'uningers': [('uning', False)],
          'unitten': [('unit', True)],
          'unittens': [('unit', True)],
          'unitter': [('unit', True)],
          'unitterne': [('unit', True)],
          'unitternes': [('unit', True)],
          'unitters': [('unit', True)],
          'unium': [('unium', False)],
          'uniums': [('unium', False)],
          'unke': [('unke', False)],
          'unken': [('unke', False)],
          'unkens': [('unk', False)],
          'unker': [('unker', False)],
          'unkerne': [('unke', False)],
          'unkernes': [('unker', False)],
          'unkers': [('unk', False)],
          'unkes': [('unke', False)],
          'unket': [('unk', False)],
          'unkets': [('unk', False)],
          'unklerne': [('unkel', False)],
          'unklernes': [('unkel', False)],
          'unklers': [('unkel', False)],
          'unnen': [('unnen', False)],
          'unnens': [('unnen', False)],
          'unner': [('unner', False)],
          'unners': [('unner', False)],
          'unomen': [('unom', False)],
          'unomens': [('unom', False)],
          'unomer': [('unom', False)],
          'unomerne': [('unom', False)],
          'unomernes': [('unom', False)],
          'unomers': [('unom', False)],
          "uns'": [('un', False)],
          'unsene': [('uns', False)],
          'unserne': [('uns', False)],
          'unslerne': [('unsel', False)],
          'unslernes': [('unsel', False)],
          'unslers': [('unsel', False)],
          'unsten': [('unst', False)],
          'unstens': [('unst', False)],
          'unster': [('unst', False)],
          'unsterne': [('unst', False)],
          'unsternes': [('unst', False)],
          'unsters': [('unst', False)],
          'unta': [('unta', False)],
          'unte': [('unte', False)],
          'unten': [('unte', False)],
          'untens': [('unte', False)],
          'unterne': [('unte', False)],
          'unters': [('unte', False)],
          'untes': [('unte', False)],
          'untierne': [('untius', False)],
          'untiers': [('untius', False)],
          'untingens': [('unting', False)],
          'uodes': [('uodes', False)],
          "uodes'": [('uodes', False)],
          'uoen': [('uo', False)],
          'uoens': [('uo', False)],
          'uoer': [('uo', False)],
          'uoerne': [('uo', False)],
          'uoernes': [('uo', False)],
          'uoers': [('uo', False)],
          'uole': [('uole', False)],
          'uolen': [('uole', False)],
          'uolens': [('uole', False)],
          'uolernes': [('uole', False)],
          'uolers': [('uole', False)],
          'uoles': [('uole', False)],
          'uoliers': [('uolie', False)],
          'uoridens': [('uorid', False)],
          'uos': [('uo', False)],
          'uosa': [('uosa', False)],
          'uosaene': [('uosa', False)],
          'uosaenes': [('uosa', False)],
          'uosas': [('uosa', False)],
          'uoser': [('uos', False)],
          'uoserne': [('uos', False)],
          'uosernes': [('uos', False)],
          'uosers': [('uos', False)],
          'upanter': [('upant', False)],
          'upanterne': [('upant', False)],
          'upanternes': [('upant', False)],
          'upanters': [('upant', False)],
          'upels': [('upel', False)],
          'uper': [('uper', False)],
          'uperens': [('uper', False)],
          'upet': [('upet', False)],
          'upeterne': [('upet', False)],
          'upeternes': [('upet', False)],
          'upets': [('upet', False)],
          'upien': [('upi', False)],
          'upiens': [('upi', False)],
          'upierne': [('upie', False)],
          'upiernes': [('upi', False)],
          'upillen': [('upil', False)],
          'upillens': [('upil', False)],
          'upiller': [('upil', False)],
          'upillerne': [('upil', False)],
          'upillernes': [('upil', False)],
          'upillers': [('upil', False)],
          'upils': [('upil', False)],
          'upinen': [('upin', False)],
          'upinens': [('upin', False)],
          'upiner': [('upin', False)],
          'upinerne': [('upinum', False)],
          'upinernes': [('upin', False)],
          'upiners': [('upinum', False)],
          'upis': [('upi', False)],
          'uplen': [('upel', False)],
          'uplens': [('upel', False)],
          'upler': [('uppel', False)],
          'uplerne': [('uppel', False)],
          'uplernes': [('uppel', False)],
          'upons': [('upon', False)],
          'uppe': [('uppe', False)],
          'uppen': [('uppe', False)],
          'uppens': [('uppe', False)],
          'upper': [('up', False)],
          'upperne': [('uppe', False)],
          'uppernes': [('up', False)],
          'uppers': [('uppe', False)],
          'uppet': [('up', False)],
          'uppets': [('up', False)],
          'uppiners': [('uppiner', False)],
          'upporterne': [('upporter', False)],
          'upporternes': [('upporter', False)],
          'uprisen': [('upris', False)],
          'uprisens': [('upris', False)],
          'upriser': [('upris', False)],
          'upriserne': [('upris', False)],
          'uprisernes': [('upris', False)],
          'uprisers': [('upris', False)],
          'ups': [('up', False)],
          "ups'": [('up', False)],
          'ur': [('ur', False)],
          'uralen': [('ural', False)],
          'uraler': [('ural', False)],
          'uralerne': [('ural', False)],
          'uralernes': [('ural', False)],
          'uralers': [('ural', False)],
          'uralier': [('uralier', False)],
          'uralierne': [('uralier', False)],
          'uraliernes': [('uralier', False)],
          'uraliers': [('uralier', False)],
          'urancen': [('urance', False)],
          'urancens': [('urance', False)],
          'uranen': [('uran', True)],
          'uranerne': [('uraner', False)],
          'uranernes': [('uraner', False)],
          'uranet': [('uran', True)],
          'uranets': [('uran', True)],
          'urans': [('uran', True)],
          'urarbejdernes': [('urarbejder', False)],
          'urarbejders': [('urarbejder', False)],
          'urasiernes': [('urasier', False)],
          'urasiers': [('urasier', False)],
          'uratorier': [('uratorium', False)],
          'uratoriernes': [('uratorium', False)],
          'uratorium': [('uratorium', False)],
          'uratoriums': [('uratorium', False)],
          'urbier': [('urbi', False)],
          'urbierne': [('urbi', False)],
          'urbiernes': [('urbi', False)],
          'urbiers': [('urbi', False)],
          'urder': [('urder', False)],
          'urderne': [('urder', False)],
          'urdernes': [('urder', False)],
          'urders': [('urder', False)],
          'urdus': [('urdu', True)],
          'ure': [('ur', False)],
          'urede': [('urede', True)],
          'uredes': [('urede', True)],
          'urejser': [('urejse', False)],
          'uren': [('ur', False)],
          'urene': [('ur', False)],
          'urener': [('urener', False)],
          'urenerne': [('urener', False)],
          'urenernes': [('urener', False)],
          'ureners': [('urener', False)],
          'urenes': [('ur', False)],
          'urens': [('ur', False)],
          'urer': [('ur', False)],
          'urerer': [('urer', False)],
          'urererne': [('urer', False)],
          'urerernes': [('urer', False)],
          'urerers': [('urer', False)],
          'urerne': [('ur', False)],
          'urernes': [('ur', False)],
          'urers': [('ur', False)],
          'ures': [('ur', False)],
          'uresers': [('urese', False)],
          'uret': [('uret', True), ('ur', True)],
          'urets': [('uret', True), ('ur', True)],
          'uretten': [('uret', True)],
          'urettens': [('uret', True)],
          'uretter': [('uret', False)],
          'urferens': [('urfer', False)],
          'urfernes': [('urfer', False)],
          'urfers': [('urfer', False)],
          'urgens': [('urg', False)],
          'urger': [('urger', False)],
          'urgerne': [('urg', False)],
          'urgernes': [('urger', False)],
          'urgers': [('urger', False)],
          'urgier': [('urgi', False)],
          'urgierne': [('urgi', False)],
          'urgiernes': [('urgi', False)],
          'urgiers': [('urgi', False)],
          'urhandlernes': [('urhandler', False)],
          'urien': [('urie', False)],
          'uriens': [('urie', False)],
          'urier': [('urie', False)],
          'urierne': [('urie', False)],
          'uriernes': [('urie', False)],
          'uriers': [('uri', False)],
          'uries': [('urie', False)],
          'uriet': [('urium', False)],
          'uriets': [('urium', False)],
          'urinen': [('urin', False)],
          'urinens': [('urin', False)],
          'urinerne': [('urin', True)],
          'urinernes': [('urin', False)],
          'uringer': [('uring', False)],
          'uringerne': [('uring', False)],
          'uringernes': [('uring', False)],
          'uringers': [('uring', False)],
          'urins': [('urin', True)],
          'uris': [('uri', False)],
          'urister': [('urist', False)],
          'uristerne': [('urist', False)],
          'uristernes': [('urist', False)],
          'uristers': [('urist', False)],
          'urium': [('urium', False)],
          'uriums': [('urium', False)],
          'urkens': [('urk', False)],
          'urkers': [('urk', False)],
          'urkisens': [('urkis', False)],
          'urkisers': [('urkis', False)],
          'urler': [('urler', False)],
          'urlerne': [('urler', False)],
          'urlernes': [('urler', False)],
          'urlers': [('urler', False)],
          'urmet': [('urmet', False)],
          'urminister': [('urminister', False)],
          'urne': [('urne', False)],
          'urnen': [('urne', False)],
          'urnens': [('urne', False)],
          'urner': [('urne', False)],
          'urnernes': [('urne', False)],
          'urnes': [('urne', False)],
          'urnure': [('urnure', False)],
          'urnures': [('urnure', False)],
          'urnusser': [('urnus', False)],
          'urnusserne': [('urnus', False)],
          'urocenter': [('urocenter', True)],
          'uroen': [('uro', False)],
          'uroens': [('uro', True)],
          'uroer': [('uro', True)],
          'uroerne': [('uro', False)],
          'uroernes': [('uro', False)],
          'uroers': [('uro', False)],
          'uroffer': [('uroffer', False)],
          'uroffers': [('uroffer', False)],
          'uromagernes': [('uromager', True)],
          'uroner': [('uron', False)],
          'uronerne': [('uron', False)],
          'uronernes': [('uron', False)],
          'uroners': [('uron', False)],
          'uros': [('uro', False)],
          'urosen': [('urose', False)],
          'urosens': [('urose', False)],
          'urre': [('urre', False)],
          'urrens': [('urre', False)],
          'urrenten': [('urrent', False)],
          'urrentens': [('urrent', False)],
          'urrenternes': [('urrent', False)],
          'urrer': [('urre', False)],
          'urrerne': [('urre', False)],
          'urrernes': [('urre', False)],
          'urret': [('ur', False)],
          'urrets': [('urret', False)],
          'urrier': [('urri', False)],
          'urrierne': [('urri', False)],
          'urriernes': [('urri', False)],
          'urriers': [('urri', False)],
          'urris': [('urri', False)],
          'urs': [('ur', True)],
          'ursen': [('urse', False)],
          'ursene': [('ur', False)],
          'ursenes': [('ur', False)],
          'ursens': [('urse', False)],
          'urses': [('urse', False)],
          'urset': [('ursus', False)],
          'urstens': [('ursten', False)],
          'urtage': [('urtage', False)],
          'urtages': [('urtage', False)],
          'urter': [('urt', True)],
          'urterne': [('urt', True)],
          'urternes': [('urt', False)],
          'urters': [('urt', True)],
          'urtier': [('urtie', False)],
          'urtierne': [('urtie', False)],
          'urtiers': [('urtie', False)],
          'urtisaners': [('urtisane', False)],
          'urtium': [('urtie', False)],
          'urtiums': [('urtie', False)],
          'uruer': [('uruer', False)],
          'uruerne': [('uruer', False)],
          'uruernes': [('uruer', False)],
          'uruers': [('uru', False)],
          'urummer': [('urum', False)],
          'urummerne': [('urum', False)],
          'urummet': [('urum', False)],
          'urummets': [('urum', False)],
          'urundierne': [('urundier', False)],
          'urundiernes': [('urundier', False)],
          'urus': [('urus', False)],
          'urusser': [('urus', False)],
          'urusserne': [('urus', False)],
          'urussernes': [('urus', False)],
          'urussers': [('urus', False)],
          'urver': [('urve', False)],
          'urverne': [('urve', False)],
          'urvernes': [('urve', False)],
          'urvers': [('urve', False)],
          'urværker': [('urværk', True)],
          'urværkerne': [('urværk', True)],
          'urværkernes': [('urværk', True)],
          'urværkers': [('urværk', True)],
          'uryds': [('uryd', True)],
          'uræer': [('uræer', False)],
          'uræerne': [('uræer', False)],
          'uræernes': [('uræer', False)],
          'uræers': [('uræer', False)],
          'uræmis': [('uræmi', True)],
          'urænerne': [('uræne', False)],
          'uræners': [('uræne', False)],
          'us': [('us', False)],
          "us'": [('us', False)],
          'usalter': [('usalter', False)],
          'usarbejder': [('usarbejde', False)],
          'usarbejderne': [('usarbejde', False)],
          'usarbejdernes': [('usarbejde', False)],
          'uschen': [('usch', False)],
          'uschens': [('usch', False)],
          'uscher': [('usch', False)],
          'uscherne': [('usch', False)],
          'uschers': [('usch', False)],
          'use': [('us', False)],
          'useer': [('useum', False)],
          'useerne': [('useum', False)],
          'useernes': [('useum', False)],
          'useers': [('useum', False)],
          'usejer': [('usejer', False)],
          'usejerne': [('usejer', False)],
          'usejernes': [('usejer', False)],
          'usejers': [('usejer', False)],
          'uselen': [('usel', False)],
          'uselens': [('usel', False)],
          'useller': [('usel', False)],
          'usellerne': [('usel', False)],
          'usellernes': [('usel', False)],
          'usen': [('us', False)],
          'usene': [('us', False)],
          'usenes': [('us', False)],
          'usens': [('us', False)],
          'user': [('user', False)],
          'usere': [('user', False)],
          'useren': [('user', False)],
          'userens': [('user', False)],
          'useres': [('user', False)],
          'userier': [('useri', False)],
          'userierne': [('useri', False)],
          'useriernes': [('useri', False)],
          'useriers': [('useri', False)],
          'userne': [('us', False)],
          'usernes': [('user', False)],
          'users': [('user', False)],
          'uses': [('us', False)],
          'uset': [('us', False)],
          'usets': [('us', False)],
          'usetten': [('usette', False)],
          'usettens': [('usette', False)],
          'usetter': [('usette', False)],
          'usetterne': [('usette', False)],
          'usetternes': [('usette', False)],
          'usetters': [('usette', False)],
          'usfader': [('usfar', False)],
          'usfaderen': [('usfar', False)],
          'usfaderens': [('usfar', False)],
          'usfaders': [('usfar', False)],
          'usfaren': [('usfar', False)],
          'usfædrene': [('usfar', False)],
          'usfædres': [('usfar', False)],
          'usher': [('usher', False)],
          'usherne': [('usher', False)],
          'ushernes': [('usher', False)],
          'ushers': [('usher', False)],
          'usianer': [('usianer', False)],
          'usianers': [('usianer', False)],
          'usici': [('usikus', False)],
          'usiciene': [('usikus', False)],
          'usicis': [('usikus', False)],
          'usier': [('usi', False)],
          'usierne': [('usier', False)],
          'usiernes': [('usier', False)],
          'usiers': [('usier', False)],
          'usiet': [('usi', False)],
          'usika': [('usika', False)],
          'usikas': [('usika', False)],
          'usikkens': [('usik', False)],
          'usinde': [('usind', False)],
          'usindes': [('usind', False)],
          'usiner': [('usine', False)],
          'usinerne': [('usine', False)],
          'usinernes': [('usine', False)],
          'usiners': [('usine', False)],
          'uske': [('uske', False)],
          'uskelen': [('uskel', False)],
          'uskelens': [('uskel', False)],
          'usken': [('uske', False)],
          'uskene': [('usk', False)],
          'uskens': [('usk', False)],
          'usker': [('uske', False)],
          'uskeris': [('uskeri', False)],
          'uskerne': [('uske', False)],
          'uskernes': [('usker', False)],
          'uskers': [('usker', False)],
          'uskes': [('usk', False)],
          'usket': [('usk', False)],
          'uskets': [('usk', False)],
          'usketten': [('usket', False)],
          'uskettens': [('usket', False)],
          'usketterne': [('usket', False)],
          'usketternes': [('usket', False)],
          'usketters': [('usket', False)],
          'uskvalers': [('uskvaler', False)],
          'uslen': [('ussel', False)],
          'uslens': [('usel', False)],
          'usler': [('ussel', False)],
          'uslerne': [('ussel', False)],
          'uslernes': [('ussel', False)],
          'uslers': [('ussel', False)],
          'uslinger': [('usling', False)],
          'uslingerne': [('usling', False)],
          'uslingernes': [('usling', False)],
          'uslingers': [('usling', False)],
          'uslommer': [('uslomme', False)],
          'uslommernes': [('uslomme', False)],
          'uslommers': [('uslomme', False)],
          'uslys': [('usly', False)],
          'uslærerne': [('uslærer', False)],
          'uslærernes': [('uslærer', False)],
          'uslærers': [('uslærer', False)],
          'usoner': [('uson', False)],
          'usonerne': [('uson', False)],
          'usonernes': [('uson', False)],
          'usoners': [('uson', False)],
          'usorden': [('usorden', False)],
          'usordens': [('usorden', False)],
          'usorier': [('usorie', False)],
          'usorierne': [('usorie', False)],
          'usoriernes': [('usorie', False)],
          'usories': [('usorie', False)],
          'ussen': [('usse', False)],
          'ussene': [('us', False)],
          'ussenes': [('us', False)],
          'ussens': [('usse', False)],
          'usser': [('usser', False)],
          'usserne': [('usse', False)],
          'ussernes': [('us', False)],
          'ussers': [('us', False)],
          'usset': [('us', False)],
          'ussets': [('us', False)],
          'ussioner': [('ussion', False)],
          'ussionerne': [('ussion', False)],
          'ussionernes': [('ussion', False)],
          'ussioners': [('ussion', False)],
          'ussyrer': [('ussyre', False)],
          'ussyrernes': [('ussyre', False)],
          'ussyrers': [('ussyre', False)],
          'ustaden': [('ustade', False)],
          'ustadens': [('ustade', False)],
          'ustage': [('ustag', False)],
          'ustages': [('ustage', False)],
          'uste': [('uste', False)],
          'ustelen': [('ustel', False)],
          'ustelens': [('ustel', False)],
          'usteltene': [('ustelt', False)],
          'usteltenes': [('ustelt', False)],
          'usten': [('usten', False)],
          'ustene': [('ust', False)],
          'ustenes': [('ust', False)],
          'ustens': [('uste', False)],
          'uster': [('uster', False)],
          'usterier': [('usteri', False)],
          'usterierne': [('usteri', False)],
          'usteriernes': [('usteri', False)],
          'usteriers': [('usteri', False)],
          'usteriet': [('usteri', False)],
          'usteriets': [('usteri', False)],
          'usterne': [('uster', False)],
          'usternes': [('uster', False)],
          'ustes': [('uste', False)],
          'ustikken': [('ustik', False)],
          'ustikker': [('ustik', False)],
          'ustikkerne': [('ustik', False)],
          'ustikkernes': [('ustik', False)],
          'ustikkers': [('ustik', False)],
          'ustlerne': [('ustel', False)],
          'ustlernes': [('ustel', False)],
          'ustlers': [('ustel', False)],
          'ustningers': [('ustning', False)],
          'ustre': [('uster', False)],
          'usulen': [('usul', False)],
          'usulens': [('usul', False)],
          'usuler': [('usul', False)],
          'usulerne': [('usul', False)],
          'usulernes': [('usul', False)],
          'usulers': [('usul', False)],
          'usus': [('usus', True)],
          'usvarer': [('usvare', False)],
          'usvarerne': [('usvare', False)],
          'usvarernes': [('usvare', False)],
          'usvarers': [('usvare', False)],
          'usøren': [('usør', False)],
          'usørens': [('usør', False)],
          'usører': [('usør', False)],
          'usørernes': [('usør', False)],
          'utage': [('utage', False)],
          'utagen': [('utagen', False)],
          'utagens': [('utage', False)],
          'utager': [('utage', False)],
          'utagerne': [('utage', False)],
          'utagernes': [('utage', False)],
          'utagers': [('utage', False)],
          'utages': [('utage', False)],
          'utaks': [('utak', True)],
          'utaler': [('utale', False)],
          'utalerne': [('utale', False)],
          'utalernes': [('utale', False)],
          'utalers': [('utale', False)],
          'utan': [('utan', False)],
          'utanen': [('utan', False)],
          'utaner': [('utan', False)],
          'utanerne': [('utaner', False)],
          'utanernes': [('utaner', False)],
          'utaners': [('utan', False)],
          'utangas': [('utangas', False)],
          'utangen': [('utang', False)],
          'utangens': [('utang', False)],
          'utanger': [('utang', False)],
          'utangerne': [('utang', False)],
          'utangernes': [('utang', False)],
          'utangers': [('utang', False)],
          'utans': [('utan', False)],
          'utanten': [('utant', False)],
          'utantens': [('utant', False)],
          'utanter': [('utant', False)],
          'utanterne': [('utant', False)],
          'utanternes': [('utant', False)],
          'utanters': [('utant', False)],
          'utas': [('uta', False)],
          'utasten': [('utasten', False)],
          'utastens': [('utasten', False)],
          'utches': [('utch', False)],
          'utelen': [('utel', False)],
          'utelens': [('utel', False)],
          'uteler': [('utel', False)],
          'utelernes': [('utel', False)],
          'utelers': [('utel', False)],
          'utelet': [('utel', False)],
          'uten': [('ut', False)],
          'utene': [('ut', False)],
          'utenes': [('ut', False)],
          'utens': [('ut', False)],
          'uter': [('ute', False)],
          'uteredes': [('uteret', False)],
          'uterium': [('uterium', False)],
          'uteriums': [('uterium', False)],
          'uterivarer': [('uterivarer', False)],
          'uterivarernes': [('uterivarer', False)],
          'uterivarers': [('uterivarer', False)],
          'uterne': [('ut', False)],
          'uternen': [('uterne', False)],
          'uternens': [('uterne', False)],
          'uterner': [('uterne', False)],
          'uternerne': [('uterne', False)],
          'uternernes': [('uterne', False)],
          'uterners': [('uterne', False)],
          'uternes': [('ut', False)],
          'uters': [('ut', False)],
          'utet': [('ut', False)],
          'utets': [('ut', False)],
          'utids': [('utid', False)],
          'utier': [('uti', False)],
          'utierne': [('uti', False)],
          'utiernes': [('utier', False)],
          'utiers': [('utier', False)],
          'utikas': [('utikum', False)],
          'utikkens': [('utik', False)],
          'utikker': [('utik', False)],
          'utikkernes': [('utik', False)],
          'utikkers': [('utik', False)],
          'utiks': [('utik', False)],
          'utilens': [('util', False)],
          'utinerne': [('utine', False)],
          'utiners': [('utine', False)],
          'utis': [('uti', False)],
          'utiver': [('utiv', False)],
          'utivernes': [('utiv', False)],
          'utlerne': [('utler', False)],
          'utlernes': [('utler', False)],
          'utlers': [('utler', False)],
          'utlets': [('utlet', False)],
          'utningen': [('utning', False)],
          'utninger': [('utning', False)],
          'utningerne': [('utning', False)],
          'utningernes': [('utning', False)],
          'utonen': [('uton', False)],
          'utonens': [('uton', False)],
          'utoner': [('uton', False)],
          'utonerne': [('uton', False)],
          'utonernes': [('uton', False)],
          'utoners': [('uton', False)],
          'utrias': [('utria', False)],
          'utringens': [('utring', False)],
          'utronen': [('utron', False)],
          'utronens': [('utron', False)],
          'utroner': [('utron', False)],
          'utronerne': [('utron', False)],
          'utronernes': [('utron', False)],
          'utroners': [('utron', False)],
          'utrum': [('utrum', False)],
          'utrummernes': [('utrum', False)],
          'utrummers': [('utrum', False)],
          'utrums': [('utrum', False)],
          'uts': [('ut', False)],
          "uts'": [('ut', False)],
          'utsene': [('ut', False)],
          'utsenes': [('ut', False)],
          'utte': [('utte', False)],
          'utten': [('utte', False)],
          'uttens': [('utte', False)],
          'utter': [('ut', False)],
          'utterne': [('utter', False)],
          'uttes': [('utte', False)],
          'utti': [('utti', False)],
          'uttiden': [('uttid', False)],
          'uttings': [('utting', False)],
          'uttis': [('utti', False)],
          'uture': [('utur', False)],
          'uturen': [('uture', False)],
          'uturene': [('uture', False)],
          'uturenes': [('uture', False)],
          'uturens': [('uture', False)],
          'uturer': [('utur', False)],
          'uturerne': [('utur', False)],
          'uturernes': [('utur', False)],
          'uturers': [('utur', False)],
          'utures': [('uture', False)],
          'uturet': [('utur', False)],
          'utysker': [('utyske', True)],
          'utyskerne': [('utyske', True)],
          'utyskernes': [('utyske', True)],
          'utyskers': [('utyske', True)],
          'utører': [('utør', False)],
          'uum': [('uum', False)],
          'uummernes': [('uum', False)],
          'uummers': [('uum', False)],
          'uums': [('uum', False)],
          'uvanen': [('uvane', True)],
          'uvanens': [('uvane', True)],
          'uvaner': [('uvane', True)],
          'uvanerne': [('uvane', True)],
          'uvanernes': [('uvane', True)],
          'uvaners': [('uvane', True)],
          'uven': [('uven', True)],
          'uvens': [('uven', True)],
          'uverter': [('uvert', False)],
          'uverternes': [('uvert', False)],
          'uvetten': [('uvette', False)],
          'uvettens': [('uvette', False)],
          'uvetternes': [('uvette', False)],
          'uvianer': [('uvianer', False)],
          'uvianers': [('uvianer', False)],
          'uvinen': [('uvin', False)],
          'uvines': [('uvin', False)],
          'uvins': [('uvin', False)],
          'uvre': [('uvre', False)],
          'uvs': [('uv', False)],
          'uxer': [('ux', False)],
          'uxerne': [('ux', False)],
          'uxernes': [('ux', False)],
          'uxers': [('ux', False)],
          'uzerne': [('uzer', False)],
          'uzernes': [('uzer', False)],
          'uzoens': [('uzo', False)],
          "v'erne": [('v', False)],
          'v.': [('v.', False)],
          'va': [('va', False)],
          'vabben': [('vabbe', False)],
          'vabberne': [('vabbe', False)],
          'vabe': [('vabe', False)],
          'vabens': [('vabe', False)],
          'vaber': [('vaber', False)],
          'vaberne': [('vabe', False)],
          'vabernes': [('vaber', False)],
          'vabers': [('vaber', False)],
          'vabler': [('vabel', True)],
          'vablerne': [('vabel', True)],
          'vablernes': [('vabel', True)],
          'vablers': [('vabel', True)],
          'vables': [('vabel', True)],
          'vadder': [('vadder', False)],
          'vadderne': [('vadder', False)],
          'vaddernes': [('vadder', False)],
          'vadders': [('vadder', False)],
          'vade': [('vade', False)],
          'vaden': [('vade', False)],
          'vadens': [('vade', True)],
          'vader': [('vade', True), ('vader', True)],
          'vaderne': [('vade', True), ('vader', True)],
          'vadernes': [('vader', True), ('vade', True)],
          'vaders': [('vade', True), ('vader', True)],
          'vades': [('vade', False)],
          'vadlen': [('vadel', False)],
          'vadre': [('vader', False)],
          'vaen': [('va', False)],
          'vaene': [('v', False)],
          'vaenes': [('v', False)],
          'vaens': [('va', False)],
          'vaer': [('va', False)],
          'vaerne': [('va', False)],
          'vaernes': [('va', False)],
          'vaers': [('va', False)],
          'vaffelis': [('vaffelis', True)],
          'vaflen': [('vaffel', True)],
          'vaflens': [('vaffel', False)],
          'vafler': [('vaffel', False)],
          'vaflerne': [('vaffel', True)],
          'vaflernes': [('vaffel', True)],
          'vaflers': [('vaffel', False)],
          'vaftalens': [('vaftale', False)],
          'vage': [('vage', True)],
          'vagen': [('vage', False)],
          'vagens': [('vage', False)],
          'vager': [('vager', True)],
          'vagerne': [('vager', True)],
          'vagernes': [('vager', True)],
          'vagers': [('vager', True)],
          'vages': [('vage', False)],
          'vagter': [('vagt', False)],
          'vagterne': [('vagt', False)],
          'vagternes': [('vagt', False)],
          'vajer': [('vajer', False)],
          'vajerne': [('vajer', False)],
          'vajernes': [('vajer', False)],
          'vajers': [('vajer', False)],
          'vakerne': [('vak', False)],
          'vakken': [('vak', False)],
          'vakkerne': [('vak', False)],
          'vaks': [('vak', False)],
          'valders': [('valder', False)],
          'valen': [('val', True)],
          'valens': [('val', True), ('valens', True)],
          'valer': [('valer', False)],
          'valerne': [('vale', False)],
          'valernes': [('vale', False)],
          'valers': [('vale', False)],
          'vales': [('vale', False)],
          'valet': [('valet', False)],
          'valets': [('valet', False)],
          'valiernes': [('valier', False)],
          'valke': [('valke', True), ('valk', True)],
          'valken': [('valk', True), ('valke', True)],
          'valkens': [('valk', True), ('valke', True)],
          'valker': [('valke', True)],
          'valkerne': [('valke', True)],
          'valkernes': [('valke', True)],
          'valkers': [('valke', True)],
          'valkes': [('valk', True), ('valke', True)],
          'vallen': [('valle', True)],
          'vallens': [('valle', True)],
          'valler': [('val', False)],
          'vallers': [('val', False)],
          'valme': [('valm', True)],
          'valmen': [('valm', True)],
          'valmens': [('valm', True)],
          'valmes': [('valm', True)],
          'valpe': [('valp', False)],
          'valpen': [('valp', False)],
          'valpens': [('valp', False)],
          'valpes': [('valp', False)],
          'vals': [('vals', True), ('val', True)],
          "vals'": [('vals', True)],
          'valse': [('valse', True), ('vals', True)],
          'valsen': [('valse', True), ('vals', True), ('valsen', True)],
          'valsens': [('vals', True), ('valse', True)],
          'valses': [('vals', True), ('valse', True)],
          'valter': [('valter', False)],
          'valterne': [('valter', False)],
          'valternes': [('valter', False)],
          'valters': [('valter', False)],
          'vampe': [('vamp', False)],
          'vampen': [('vamp', False)],
          'vampens': [('vamp', False)],
          'vampes': [('vamp', False)],
          'vams': [('vams', True)],
          "vams'": [('vams', True)],
          'vamse': [('vams', True)],
          'vamsen': [('vams', True)],
          'vamsens': [('vams', True)],
          'vamses': [('vams', True)],
          'vana': [('vana', False)],
          'vanchen': [('vanche', False)],
          'vanchens': [('vanche', False)],
          'vandaler': [('vandal', True)],
          'vandalers': [('vandal', True)],
          'vande': [('vand', False)],
          'vanden': [('vand', False)],
          'vandens': [('vand', False)],
          'vander': [('vand', True)],
          'vanderne': [('vand', False)],
          'vandernes': [('vand', False)],
          'vanders': [('vand', True)],
          'vandes': [('vand', False)],
          'vandet': [('vand', False)],
          'vandets': [('vand', False)],
          'vandpumper': [('vandpumpe', True)],
          'vandpumperne': [('vandpumpe', True)],
          'vandpumpernes': [('vandpumpe', True)],
          'vandpumpers': [('vandpumpe', True)],
          'vane': [('vane', False)],
          'vanen': [('vane', True), ('van', True)],
          'vanens': [('van', True), ('vane', True)],
          'vaner': [('van', True), ('vane', True)],
          'vanerne': [('van', True), ('vane', True)],
          'vanernes': [('van', True), ('vane', True)],
          'vaners': [('van', True), ('vane', True)],
          'vanes': [('vane', False)],
          'vange': [('vang', True), ('vange', True)],
          'vangen': [('vange', True), ('vang', True)],
          'vangens': [('vange', True), ('vang', True)],
          'vanger': [('vange', True)],
          'vangernes': [('vange', True)],
          'vangers': [('vange', True)],
          'vanges': [('vang', True), ('vange', True)],
          'vanken': [('vank', False)],
          'vankens': [('vank', False)],
          'vanker': [('vanker', False)],
          'vankerne': [('vank', False)],
          'vankernes': [('vank', False)],
          'vankers': [('vank', False)],
          'vanks': [('vank', False)],
          'vannen': [('van', False)],
          'vannens': [('vanne', False)],
          'vanner': [('van', False)],
          'vannerne': [('vanne', False)],
          'vannernes': [('vanne', False)],
          'vanners': [('van', False)],
          'vans': [('van', True)],
          "vans'": [('vans', False)],
          'vanse': [('vans', False)],
          'vansen': [('vans', False)],
          'vansenes': [('vans', False)],
          'vansens': [('vans', False)],
          'vanser': [('vans', False)],
          'vansernes': [('vans', False)],
          'vansers': [('vans', False)],
          'vanses': [('vans', False)],
          'vanten': [('vante', True)],
          'vantens': [('vante', True)],
          'vanter': [('vante', True), ('vant', True)],
          'vanterne': [('vante', True), ('vant', True)],
          'vanternes': [('vante', True), ('vant', True)],
          'vanters': [('vant', True), ('vante', True)],
          'vantet': [('vant', False)],
          'vantets': [('vant', True)],
          'vantiner': [('vantiner', False)],
          'vantinernes': [('vantiner', False)],
          'vants': [('vant', False)],
          'vaps': [('vaps', True)],
          "vaps'": [('vaps', True)],
          'vapsen': [('vaps', True)],
          'vapsens': [('vaps', True)],
          'vapser': [('vaps', True)],
          'vapserne': [('vaps', True)],
          'vapsernes': [('vaps', True)],
          'varbejder': [('varbejder', False)],
          'varbejderne': [('varbejder', False)],
          'varbejdernes': [('varbejde', False)],
          'varbejders': [('varbejder', False)],
          'varden': [('varde', True)],
          'vardens': [('varde', True)],
          'varder': [('varde', True)],
          'varderne': [('varde', True)],
          'vardernes': [('varde', True)],
          'varders': [('varde', True)],
          'varen': [('vare', False)],
          'varens': [('vare', False)],
          'varer': [('vare', False)],
          'varerne': [('vare', False)],
          'varernes': [('vare', False)],
          'varers': [('vare', True)],
          'varier': [('varie', False)],
          'varierne': [('varie', False)],
          'variernes': [('vari', False)],
          'variers': [('varie', False)],
          'variet': [('varium', False)],
          'variets': [('varium', False)],
          'varis': [('vari', False)],
          'varium': [('varie', False)],
          'variums': [('varie', False)],
          'varker': [('vark', False)],
          'varkerne': [('vark', False)],
          'varme': [('varme', False)],
          'varmen': [('varme', False)],
          'varmens': [('varme', False)],
          'varmer': [('varmer', False)],
          'varmes': [('varme', False)],
          'varpe': [('varp', False)],
          'varper': [('varp', False)],
          'varperne': [('varp', False)],
          'varres': [('varre', False)],
          'varten': [('vart', False)],
          'vartens': [('vart', False)],
          'varterne': [('vart', False)],
          'varternes': [('varter', False)],
          'vas': [('va', False)],
          'vase': [('vase', True)],
          'vasen': [('vase', False)],
          'vasens': [('vase', True)],
          'vaser': [('vase', True)],
          'vaserne': [('vase', False)],
          'vasernes': [('vase', True)],
          'vasers': [('vase', True)],
          'vases': [('vase', False)],
          'vaske': [('vask', False)],
          'vasken': [('vask', False)],
          'vaskens': [('vask', False)],
          'vasker': [('vasker', False)],
          'vaskerne': [('vasker', False)],
          'vaskernes': [('vasker', False)],
          'vaskers': [('vasker', True)],
          'vaskes': [('vask', False)],
          'vassen': [('vas', False)],
          'vassens': [('vas', False)],
          'vaste': [('vast', False)],
          'vasten': [('vast', False)],
          'vastens': [('vast', False)],
          'vaster': [('vast', False)],
          'vasterne': [('vast', False)],
          'vasternes': [('vast', False)],
          'vasters': [('vast', False)],
          'vastes': [('vast', False)],
          'vaten': [('vaten', False)],
          'vatens': [('vaten', False)],
          'vater': [('vater', True)],
          'vaterier': [('vateri', False)],
          'vaterierne': [('vateri', False)],
          'vateriernes': [('vateri', False)],
          'vateriers': [('vateri', False)],
          'vaternes': [('vat', False)],
          'vatinen': [('vatine', False)],
          'vatinens': [('vatine', False)],
          'vatiner': [('vatine', False)],
          'vatinernes': [('vatine', False)],
          'vatiners': [('vatine', False)],
          'vatorier': [('vatorie', False)],
          'vatoriernes': [('vatorie', False)],
          'vatorium': [('vatorie', False)],
          'vatoriums': [('vatorie', False)],
          'vatten': [('vat', False)],
          'vattens': [('vat', False)],
          'vatternes': [('vat', False)],
          'vatters': [('vat', False)],
          'vballen': [('vballe', False)],
          'vballens': [('vballe', False)],
          'vballer': [('vballe', False)],
          'vballerne': [('vballe', False)],
          'vballernes': [('vballe', False)],
          'vballers': [('vballe', False)],
          'vbede': [('vbede', False)],
          'vbedes': [('vbede', False)],
          'vboer': [('vbo', False)],
          'vboerne': [('vbo', False)],
          'vboernes': [('vbo', False)],
          'vboers': [('vbo', False)],
          'vbomber': [('vbombe', False)],
          'vbomberne': [('vbombe', False)],
          'vbombernes': [('vbombe', False)],
          'vbombers': [('vbombe', False)],
          'vbondens': [('vbonde', False)],
          'vbroderen': [('vbror', False)],
          'vbroers': [('vbro', False)],
          'vbrugs': [('vbrug', False)],
          'vbuks': [('vbuk', False)],
          'vcyklen': [('vcykel', False)],
          'vcyklens': [('vcykel', False)],
          'vcykler': [('vcykel', False)],
          'vcyklerne': [('vcykel', False)],
          'vcyklernes': [('vcykel', False)],
          'vcyklers': [('vcykel', False)],
          'vd': [('vd', False)],
          "vd'er": [('vd', False)],
          "vd'ernes": [('vd', False)],
          "vd'ers": [('vd', False)],
          'vdage': [('vdag', False)],
          'vdagen': [('vdag', False)],
          'vdagene': [('vdag', False)],
          'vdages': [('vdag', False)],
          'vdele': [('vdel', False)],
          'vdrager': [('vdrager', False)],
          'vdragerne': [('vdrager', False)],
          'vdragernes': [('vdrager', False)],
          'vdragers': [('vdrager', False)],
          'vds': [('vd', False)],
          'vduens': [('vdue', False)],
          'vduerne': [('vdue', False)],
          'vduernes': [('vdue', False)],
          'vduers': [('vdue', False)],
          've': [('ve', False)],
          'veasken': [('veaske', False)],
          'veaskes': [('veaske', False)],
          'vebakken': [('vebak', False)],
          'vebakkens': [('vebak', False)],
          'vebakkerne': [('vebak', False)],
          'vebens': [('veben', False)],
          'veboer': [('vebo', False)],
          'veboerne': [('vebo', False)],
          'veboers': [('vebo', False)],
          'vebus': [('vebus', False)],
          'vedage': [('vedage', False)],
          'vedagene': [('vedage', False)],
          'vedagenes': [('vedage', False)],
          'vedagens': [('vedag', False)],
          'vedages': [('vedage', False)],
          'vedans': [('vedans', False)],
          'vedanserne': [('vedanser', False)],
          'vedas': [('veda', True)],
          'vedden': [('ved', False)],
          'veddens': [('ved', False)],
          'vede': [('vede', False)],
          'veden': [('vede', False)],
          'vedens': [('vede', False)],
          'veder': [('veder', False)],
          'vederne': [('veder', False)],
          'vedernes': [('veder', False)],
          'veders': [('vede', False)],
          'vedes': [('vede', False)],
          'vedet': [('vedet', True)],
          'vedets': [('vedet', True)],
          'vedoren': [('vedore', False)],
          'vedorens': [('vedore', False)],
          'vedsagers': [('vedsag', False)],
          'vedømmernes': [('vedømme', False)],
          'vedømmers': [('vedømme', False)],
          'veen': [('ve', False)],
          'veens': [('ve', True)],
          'veer': [('ve', False)],
          'veerne': [('ve', True)],
          'veernes': [('ve', False)],
          'veers': [('ve', False)],
          'vees': [('vees', False)],
          "vees'": [('vees', False)],
          'vege': [('vege', False)],
          'vegen': [('vege', False)],
          'vegens': [('vege', False)],
          'veger': [('vege', False)],
          'vegerne': [('vege', False)],
          'vegernes': [('vege', False)],
          'vegers': [('vege', False)],
          'veges': [('vege', False)],
          'vegne': [('vegne', True)],
          'vegnes': [('vegne', True)],
          'vehals': [('vehals', False)],
          'veje': [('vej', True)],
          'vejen': [('vej', True)],
          'vejene': [('vej', True)],
          'vejenes': [('vej', True)],
          'vejens': [('vej', True)],
          'vejerne': [('vejer', False)],
          'vejes': [('vej', True)],
          'vejet': [('veje', False)],
          'vejets': [('veje', False)],
          'vejferne': [('vejf', False)],
          'vejfernes': [('vejf', False)],
          'vejfers': [('vejf', False)],
          'vejlen': [('vejle', True)],
          'vejlens': [('vejle', True)],
          'vejlerne': [('vejle', True)],
          'vejlernes': [('vejle', True)],
          'vejlers': [('vejle', True)],
          'vejser': [('vejser', False)],
          'vejserne': [('vejser', False)],
          'vejsernes': [('vejser', False)],
          'vekrige': [('vekrig', False)],
          'vekrigen': [('vekrig', False)],
          'vekrigens': [('vekrig', False)],
          'vekriges': [('vekrig', False)],
          'veksler': [('veksler', True), ('veksel', True)],
          'vekslerne': [('veksel', True), ('veksler', True)],
          'vekslernes': [('veksel', True), ('veksler', True)],
          'vekslers': [('veksler', True), ('veksel', True)],
          'velerne': [('vel', False)],
          'velever': [('velever', False)],
          'veleverne': [('velever', False)],
          'velevernes': [('velever', False)],
          'velevers': [('velever', False)],
          'veliner': [('velin', False)],
          'velinernes': [('velin', False)],
          'veliners': [('velin', False)],
          'velle': [('velle', False)],
          'vellen': [('vel', False)],
          'vellens': [('velle', False)],
          'veller': [('veller', False)],
          'vellerne': [('veller', False)],
          'vellernes': [('velle', False)],
          'vellers': [('vel', False)],
          'velles': [('velle', False)],
          'velsers': [('velse', False)],
          'velærerne': [('velærer', False)],
          'velærernes': [('velærer', False)],
          'vemagerne': [('vemager', False)],
          'vemagernes': [('vemager', False)],
          'vemagers': [('vemager', False)],
          'vemanden': [('vemand', False)],
          'vemandens': [('vemand', False)],
          'ven': [('ven', True)],
          'vende': [('vend', False)],
          'venden': [('vend', False)],
          'vendens': [('vend', False)],
          'vender': [('vender', False)],
          'venderne': [('vender', True)],
          'vendernes': [('vender', True)],
          'venders': [('vender', True)],
          'vendes': [('vend', False)],
          'vendler': [('vendel', False)],
          'vendlers': [('vendel', False)],
          'vene': [('vene', True)],
          'venen': [('vene', False)],
          'venens': [('vene', True)],
          'vener': [('vene', True)],
          'venerne': [('vene', False)],
          'venernes': [('vene', True)],
          'veners': [('vene', False)],
          'venes': [('vene', True)],
          'venienserne': [('veniens', False)],
          'vennen': [('ven', False)],
          'vennens': [('ven', False)],
          'venner': [('ven', False)],
          'vennernes': [('ven', False)],
          'venners': [('ven', False)],
          'vens': [('ven', True)],
          "vens'": [('vens', False)],
          'vensen': [('vens', False)],
          'vensens': [('vens', False)],
          'venser': [('vens', False)],
          'vensernes': [('vens', False)],
          'vensers': [('vens', False)],
          'venten': [('vent', False)],
          'ventens': [('vent', False)],
          'venter': [('vent', False)],
          'venterne': [('vent', False)],
          'venternes': [('vent', False)],
          'venters': [('vent', False)],
          'ventet': [('vent', False)],
          'ventets': [('vent', False)],
          'venture': [('venture', False)],
          'venuen': [('venu', False)],
          'venuens': [('venu', False)],
          'venuer': [('venu', False)],
          'venuerne': [('venu', False)],
          'venuernes': [('venu', False)],
          'venuers': [('venu', False)],
          'venuet': [('venu', False)],
          'venus': [('venu', False)],
          'veoler': [('veole', False)],
          'veolerne': [('veole', False)],
          'veorgier': [('veorgie', False)],
          'veorgierne': [('veorgie', False)],
          'veorgiernes': [('veorgie', False)],
          'veorgiers': [('veorgie', False)],
          'veposen': [('vepose', False)],
          'veposens': [('vepose', False)],
          'veposer': [('vepose', False)],
          'veposerne': [('vepose', False)],
          'veposernes': [('vepose', False)],
          'veps': [('veps', False)],
          "veps'": [('veps', False)],
          'verber': [('verbum', False)],
          'verberne': [('verbum', False)],
          'verbernes': [('verbum', False)],
          'verbers': [('verbum', True)],
          'verbet': [('verbum', False)],
          'verbets': [('verbum', False)],
          'verbiernes': [('verbium', False)],
          'verbiers': [('verbium', False)],
          'verensernes': [('verens', False)],
          'verensers': [('verens', False)],
          'verer': [('verer', False)],
          'vererne': [('verer', False)],
          'verernes': [('verer', False)],
          'verers': [('verer', False)],
          'veret': [('veret', False)],
          'verets': [('veret', False)],
          'veretten': [('veret', False)],
          'verettens': [('veret', False)],
          'vergenserne': [('vergens', False)],
          'vergensers': [('vergens', False)],
          'verier': [('veri', False)],
          'verierne': [('veri', False)],
          'veriernes': [('veri', False)],
          'veriers': [('veri', False)],
          'veriet': [('veri', False)],
          'veriets': [('veri', False)],
          'veris': [('veri', False)],
          'verkløer': [('verkløer', False)],
          'verkursernes': [('verkurs', False)],
          'verlagen': [('verlagen', False)],
          'verlagens': [('verlagen', False)],
          'verlejer': [('verlej', False)],
          'verlejerne': [('verlej', False)],
          'verlejernes': [('verlej', False)],
          'verlejers': [('verlej', False)],
          'vermænd': [('vermand', False)],
          'vermændene': [('vermand', False)],
          'vermændenes': [('vermand', False)],
          'vermænds': [('vermand', False)],
          'vernerne': [('verne', False)],
          'verners': [('verne', False)],
          'verrede': [('verrede', False)],
          'verrottens': [('verrotte', False)],
          'verrotter': [('verrotte', False)],
          'verrotternes': [('verrotte', False)],
          'verrotters': [('verrotte', False)],
          'vers': [('vers', True)],
          "vers'": [('vers', False)],
          'versen': [('vers', False)],
          'versens': [('vers', False)],
          'verser': [('vers', False)],
          'verserne': [('vers', False)],
          'versernes': [('vers', False)],
          'versers': [('vers', False)],
          'versken': [('verske', False)],
          'versker': [('verske', False)],
          'verskerne': [('verske', False)],
          'verskers': [('verske', False)],
          'verstemmer': [('verstemme', False)],
          'verstemmerne': [('verstemme', False)],
          'verstemmernes': [('verstemme', False)],
          'verstemmers': [('verstemme', False)],
          'verstens': [('verst', True)],
          'verten': [('vert', False)],
          'vertens': [('vert', False)],
          'verter': [('verter', False)],
          'verterne': [('vert', False)],
          'verternes': [('verter', False)],
          'verters': [('vert', False)],
          'verts': [('vert', False)],
          'verturens': [('verture', False)],
          'verver': [('verver', False)],
          'ververne': [('verver', False)],
          'ververnes': [('verver', False)],
          'ververs': [('verver', False)],
          'verves': [('verve', True)],
          'ves': [('ve', False)],
          "ves'": [('ve', False)],
          'vesager': [('vesag', False)],
          'vesagerne': [('vesag', False)],
          'vesagernes': [('vesager', False)],
          'vesagers': [('vesager', False)],
          'veskens': [('veske', False)],
          'veskernes': [('veske', False)],
          'vesmerter': [('vesmerte', False)],
          'vespiller': [('vespiller', False)],
          'vespillerne': [('vespiller', False)],
          'vespillernes': [('vespiller', False)],
          'vespillers': [('vespiller', False)],
          'veste': [('vest', False)],
          'vesten': [('vest', True), ('vesten', True)],
          'vestenes': [('vest', False)],
          'vestens': [('vesten', True), ('vest', True)],
          'vester': [('vest', False)],
          'vesterne': [('vest', False)],
          'vesternes': [('vest', False)],
          'vesters': [('vest', False)],
          'vestes': [('vest', False)],
          'vestier': [('vesti', False)],
          'vestiernes': [('vesti', False)],
          'vestilens': [('vestil', False)],
          'vetanken': [('vetanke', False)],
          'vetankens': [('vetanke', False)],
          'vetanker': [('vetanke', False)],
          'vetankers': [('vetanke', False)],
          'vetankes': [('vetanke', False)],
          'veten': [('veten', False)],
          'vetiden': [('vetid', False)],
          'vetinen': [('vetine', False)],
          'vetinens': [('vetine', False)],
          'vetiner': [('vetine', False)],
          'vetinerne': [('vetine', False)],
          'vetinernes': [('vetine', False)],
          'vetiners': [('vetine', False)],
          'vetonen': [('vetone', False)],
          'vetonens': [('vetone', False)],
          'vetoner': [('vetone', False)],
          'vetonerne': [('vetone', False)],
          'vetonernes': [('vetone', False)],
          'vetoners': [('vetone', False)],
          'vetos': [('veto', True)],
          'vetten': [('vet', False)],
          'vettens': [('vet', False)],
          'vetter': [('vette', False)],
          'vetterne': [('vette', False)],
          'vetternes': [('vet', False)],
          'vetters': [('vette', False)],
          'vferierne': [('vferie', False)],
          'vferiers': [('vferie', False)],
          'vflugter': [('vflugter', False)],
          'vflugterne': [('vflugter', False)],
          'vflugternes': [('vflugter', False)],
          'vflugters': [('vflugter', False)],
          'vformer': [('vform', False)],
          'vformerne': [('vform', False)],
          'vformernes': [('vform', False)],
          'vformers': [('vform', False)],
          'vfruers': [('vfrue', False)],
          'vfærden': [('vfærd', False)],
          'vfærdens': [('vfærd', False)],
          'vgarder': [('vgarde', False)],
          'vgarderne': [('vgarde', False)],
          'vgardernes': [('vgarde', False)],
          'vgarders': [('vgarde', False)],
          "vgas'": [('vgas', False)],
          'vgassen': [('vgasse', False)],
          'vgassens': [('vgasse', False)],
          'vgasser': [('vgasse', False)],
          'vgasserne': [('vgasse', False)],
          'vgassernes': [('vgas', False)],
          'vgassers': [('vgasse', False)],
          'vgænger': [('vgænger', False)],
          'vgængerne': [('vgænger', False)],
          'vgængernes': [('vgænger', False)],
          'vgængers': [('vgænger', False)],
          'vheden': [('vhed', False)],
          'vhedens': [('vhed', False)],
          'vheder': [('vhed', False)],
          'vhederne': [('vhed', False)],
          'vhedernes': [('vhed', False)],
          'vheders': [('vhed', False)],
          'vhenter': [('vhenter', False)],
          'vhenterne': [('vhenter', False)],
          'vhenters': [('vhenter', False)],
          'vhus': [('vhus', False)],
          'vi': [('vi', True)],
          'vianer': [('vian', False)],
          'vianerne': [('vianer', False)],
          'vianernes': [('vianer', False)],
          'vianers': [('vian', False)],
          'vians': [('vian', False)],
          'viaturer': [('viatur', False)],
          'viaturerne': [('viatur', False)],
          'viaturernes': [('viatur', False)],
          'viaturers': [('viatur', False)],
          'vibe': [('vibe', True)],
          'vibers': [('vibe', True)],
          'vibes': [('vibe', True)],
          'vicen': [('vice', False)],
          'vicens': [('vice', False)],
          'vicer': [('vice', False)],
          'vicerne': [('vice', False)],
          'vicernes': [('vice', False)],
          'vicers': [('vice', False)],
          'vices': [('vice', False)],
          'vicet': [('vice', False)],
          'vicets': [('vice', False)],
          'vidder': [('vidde', True)],
          'vidderne': [('vidde', True)],
          'viddernes': [('vidde', False)],
          'vidders': [('vidde', False)],
          'vide': [('vide', False)],
          'viden': [('viden', False)],
          'videns': [('viden', True)],
          'vider': [('vide', False)],
          'viderne': [('vider', False)],
          'vidernes': [('vide', False)],
          'viders': [('vider', False)],
          'vides': [('vide', False)],
          'vidnet': [('vidne', False)],
          'vier': [('vi', False)],
          'viere': [('vier', False)],
          'vieren': [('vier', False)],
          'vierens': [('vier', False)],
          'vieres': [('vier', False)],
          'vierne': [('vi', True)],
          'viernes': [('vi', True)],
          'viers': [('vi', False)],
          "vies'": [('vie', False)],
          'viet': [('vi', True)],
          'viets': [('vi', True)],
          'viferens': [('vifer', False)],
          'vifers': [('vifer', False)],
          'vifter': [('vifte', True)],
          'vifters': [('vifte', True)],
          'viftet': [('vift', True)],
          'viftets': [('vift', True)],
          'vigerne': [('viger', False)],
          'vigernes': [('viger', False)],
          'vigers': [('viger', False)],
          'vigler': [('vigler', False)],
          'viglerne': [('vigler', False)],
          'viglernes': [('vigler', False)],
          'viglers': [('vigler', False)],
          'vigtet': [('vigt', False)],
          'vigtets': [('vigt', False)],
          'vikken': [('vikke', True)],
          'vikkens': [('vikke', False)],
          'vikker': [('vikke', True)],
          'vikkere': [('vikker', False)],
          'vikkeren': [('vikker', False)],
          'vikkerens': [('vikker', False)],
          'vikkeres': [('vikker', False)],
          'vikkerne': [('vikke', False)],
          'vikkernes': [('vikke', False)],
          'vikkers': [('vikke', False)],
          'viklens': [('vikkel', False)],
          'vikler': [('vikkel', True), ('vikler', True)],
          'viklerne': [('vikkel', True), ('vikler', True)],
          'viklernes': [('vikler', True), ('vikkel', True)],
          'viklers': [('vikler', True), ('vikkel', True)],
          'viktualiehandler': [('viktualiehandler', True), ('viktualiehandel', True)],
          'viktualiehandlerne': [('viktualiehandel', True), ('viktualiehandler', True)],
          'viktualiehandlernes': [('viktualiehandel', True), ('viktualiehandler', True)],
          'viktualiehandlers': [('viktualiehandler', True), ('viktualiehandel', True)],
          'vilden': [('vilden', True)],
          'vildthandler': [('vildthandler', True), ('vildthandel', True)],
          'vildthandlerne': [('vildthandel', True), ('vildthandler', True)],
          'vildthandlernes': [('vildthandel', True), ('vildthandler', True)],
          'vildthandlers': [('vildthandler', True), ('vildthandel', True)],
          'vile': [('vile', False)],
          'vilen': [('vile', False)],
          'vilens': [('vile', False)],
          'viles': [('vile', False)],
          'vilets': [('vil', False)],
          'vilisten': [('vilist', False)],
          'vilistens': [('vilist', False)],
          'vilister': [('vilist', False)],
          'vilisterne': [('vilist', False)],
          'villen': [('vil', False)],
          'villens': [('ville', False)],
          'viller': [('ville', False)],
          'villerne': [('vil', False)],
          'villernes': [('ville', False)],
          'villers': [('ville', False)],
          'villingers': [('villing', False)],
          'villisten': [('villiste', False)],
          'villistens': [('villiste', False)],
          'villisterne': [('villiste', False)],
          'vime': [('vime', False)],
          'vinde': [('vinde', True), ('vind', True)],
          'vinden': [('vinde', True), ('vind', True)],
          'vindens': [('vinde', True), ('vind', True)],
          'vinder': [('vinder', True), ('vinde', True)],
          'vinderne': [('vinde', True), ('vinder', True)],
          'vindernes': [('vinder', True), ('vinde', True)],
          'vinders': [('vinder', True), ('vinde', True)],
          'vindes': [('vinde', True), ('vind', True)],
          'vindet': [('vind', False)],
          'vindets': [('vind', False)],
          'vindlerne': [('vindler', False)],
          'vindlernes': [('vindler', False)],
          'vinduer': [('vindue', False)],
          'vinduerne': [('vindue', False)],
          'vinduernes': [('vindue', False)],
          'vinduers': [('vindue', False)],
          'vine': [('vin', True)],
          'vinen': [('vin', True)],
          'vinene': [('vin', False)],
          'vinens': [('vin', True)],
          'viner': [('vin', False)],
          'vinerne': [('vin', False)],
          'vinernes': [('vine', False)],
          'viners': [('vin', False)],
          'vines': [('vin', True)],
          'vingels': [('vingel', False)],
          'vingen': [('vinge', True)],
          'vingens': [('vinge', True)],
          'vinger': [('vinge', True)],
          'vingerne': [('vinge', True)],
          'vingernes': [('vinge', True)],
          'vingers': [('vinge', False)],
          'vinglens': [('vingel', False)],
          'vingler': [('vingel', False)],
          'vinglerne': [('vingel', False)],
          'vings': [('ving', False)],
          'vinhandler': [('vinhandler', True), ('vinhandel', True)],
          'vinhandlerne': [('vinhandler', True), ('vinhandel', True)],
          'vinhandlernes': [('vinhandel', True), ('vinhandler', True)],
          'vinhandlers': [('vinhandler', True), ('vinhandel', True)],
          'vinister': [('vinist', False)],
          'vinisters': [('vinist', False)],
          'vinkler': [('vinkel', False)],
          'vinks': [('vink', True)],
          'vins': [('vin', True)],
          "vins'": [('vins', False)],
          'vinsen': [('vins', False)],
          'vinsens': [('vins', False)],
          'vinser': [('vins', False)],
          'vinserne': [('vins', False)],
          'vinsernes': [('vins', False)],
          'vinsers': [('vins', False)],
          'vinsten': [('vinsten', True)],
          'vinstens': [('vinsten', True)],
          'vinten': [('vint', False)],
          'vintens': [('vint', False)],
          'vinter': [('vinter', True)],
          'vinterne': [('vint', False)],
          'vinternes': [('vint', False)],
          'vinters': [('vinter', False)],
          'vippen': [('vippe', True)],
          'vippens': [('vippe', True)],
          'vipper': [('vippe', True)],
          'vipperne': [('vippe', True)],
          'vippernes': [('vippe', True)],
          'vippers': [('vippe', False)],
          'vippes': [('vippe', False)],
          'vipser': [('vipser', False)],
          'vipsernes': [('vipser', False)],
          'vipsers': [('vipser', False)],
          'viren': [('vire', True)],
          'virens': [('vire', True)],
          'virer': [('vire', True)],
          'virerne': [('vire', True)],
          'virernes': [('vire', True)],
          'virers': [('vire', True)],
          'virken': [('virken', False)],
          'virkens': [('virken', False)],
          'virvler': [('virvel', False)],
          'virvlerne': [('virvel', False)],
          'virvlernes': [('virvel', False)],
          'virvlers': [('virvel', False)],
          'vis': [('vis', True), ('vi', True)],
          'visanders': [('visand', False)],
          'vise': [('vise', False)],
          'visen': [('vise', False)],
          'visens': [('vise', False)],
          'viser': [('vise', True), ('viser', True)],
          'viserne': [('viser', True), ('vise', True)],
          'visernes': [('vise', True), ('viser', True)],
          'visers': [('vise', True), ('viser', True)],
          'vises': [('vise', False)],
          'viske': [('visk', True)],
          'visken': [('visk', True)],
          'visker': [('visker', True)],
          'viskerne': [('visker', True)],
          'viskernes': [('visker', True)],
          'vismen': [('visme', False)],
          'vismens': [('visme', False)],
          'vissers': [('visse', True)],
          'viste': [('vist', False)],
          'visten': [('vist', False)],
          'vistens': [('vist', False)],
          'vister': [('vist', False)],
          'visterne': [('vist', False)],
          'visternes': [('vist', False)],
          'visters': [('vist', False)],
          'vistes': [('vist', False)],
          'vita': [('vita', True)],
          'vitas': [('vita', True)],
          'vitriner': [('vitrine', True)],
          'vitriners': [('vitrine', True)],
          'vits': [('vits', False)],
          "vits'": [('vits', True)],
          'vitsen': [('vits', False)],
          'vitsens': [('vits', True)],
          'vitser': [('vits', True)],
          'vitserne': [('vits', True)],
          'vitsernes': [('vits', True)],
          'vitsers': [('vits', False)],
          'vitten': [('vit', False)],
          'vittens': [('vit', False)],
          'vitternes': [('vit', False)],
          'vitters': [('vit', False)],
          'vium': [('vie', False)],
          'viums': [('vie', False)],
          'vivalens': [('vivalens', False)],
          'vk': [('vk', False)],
          'vkales': [('vkal', False)],
          'vkaster': [('vkaste', False)],
          'vkasterne': [('vkaste', False)],
          'vkasternes': [('vkaste', False)],
          'vkasters': [('vkaste', False)],
          'vken': [('vk', False)],
          'vkens': [('vk', False)],
          'vker': [('vk', False)],
          'vkerne': [('vk', False)],
          'vkernes': [('vk', False)],
          'vkers': [('vk', False)],
          'vkg': [('vkg', False)],
          'vkiks': [('vkiks', False)],
          'vklingers': [('vklinge', False)],
          'vkontroller': [('vkontrol', False)],
          'vkontrollerne': [('vkontrol', False)],
          'vkontrollernes': [('vkontrol', False)],
          'vkontrollers': [('vkontrol', False)],
          'vkrydser': [('vkrydser', False)],
          'vkrydserne': [('vkrydser', False)],
          'vkrydsernes': [('vkrydser', False)],
          'vkrydsers': [('vkrydser', False)],
          'vkræfternes': [('vkraft', False)],
          'vkræs': [('vkræ', False)],
          'vks': [('vk', False)],
          'vkurser': [('vkursus', False)],
          'vkurserne': [('vkursus', False)],
          'vkursernes': [('vkursus', False)],
          'vkursers': [('vkursus', False)],
          'vkøer': [('vko', False)],
          'vkøerne': [('vko', False)],
          'vkøernes': [('vko', False)],
          'vkøers': [('vko', False)],
          'vkøjen': [('vkøj', False)],
          'vkøjens': [('vkøj', False)],
          'vkøjer': [('vkøj', False)],
          'vkøjerne': [('vkøj', False)],
          'vkøjernes': [('vkøj', False)],
          'vkøjers': [('vkøj', False)],
          'vl': [('vl', False)],
          'vlaret': [('vlar', False)],
          'vlarets': [('vlar', False)],
          'vlars': [('vlar', False)],
          'vle': [('vl', False)],
          'vledernes': [('vleder', False)],
          'vlen': [('vl', False)],
          'vlene': [('vl', False)],
          'vlenes': [('vl', False)],
          'vlens': [('vl', False)],
          'vlere': [('vler', False)],
          'vleren': [('vler', False)],
          'vlerens': [('vler', False)],
          'vleres': [('vler', False)],
          'vlers': [('vler', False)],
          'vles': [('vl', False)],
          'vlet': [('vl', False)],
          'vlets': [('vl', False)],
          'vletten': [('vlet', False)],
          'vlettens': [('vlet', False)],
          'vletter': [('vlet', False)],
          'vletterne': [('vlet', False)],
          'vletternes': [('vlet', False)],
          'vletters': [('vlet', False)],
          'vlevers': [('vlevers', False)],
          'vliner': [('vline', False)],
          'vlinerne': [('vline', False)],
          'vlinernes': [('vline', False)],
          'vliners': [('vline', False)],
          'vlingers': [('vling', False)],
          'vlisten': [('vliste', False)],
          'vlistens': [('vliste', False)],
          'vlister': [('vliste', False)],
          'vlisterne': [('vliste', False)],
          'vlits': [('vlit', False)],
          'vlitter': [('vlit', False)],
          'vlove': [('vlov', False)],
          'vls': [('vl', False)],
          'vlyde': [('vlyd', False)],
          'vlyden': [('vlyd', False)],
          'vlydens': [('vlyd', False)],
          'vlydes': [('vlyd', False)],
          'vlægerne': [('vlæge', False)],
          'vlægernes': [('vlæge', False)],
          'vmasken': [('vmaske', False)],
          'vmaskens': [('vmaske', False)],
          'vmasker': [('vmaske', False)],
          'vmaskers': [('vmaske', False)],
          'vmelet': [('vmel', False)],
          'vmidlerne': [('vmiddel', False)],
          'vmidlernes': [('vmiddel', False)],
          'vmidlers': [('vmiddel', False)],
          'vmoder': [('vmor', False)],
          'vmoderne': [('vmor', False)],
          'vmodernes': [('vmor', False)],
          'vmoders': [('vmor', False)],
          'vmodet': [('vmod', False)],
          'vmodets': [('vmod', False)],
          'vmusen': [('vmus', False)],
          'vmusens': [('vmus', False)],
          'vmyren': [('vmyre', False)],
          'vmyrens': [('vmyre', False)],
          'vmyrer': [('vmyre', False)],
          'vmyrerne': [('vmyre', False)],
          'vmyrernes': [('vmyre', False)],
          'vmyrers': [('vmyre', False)],
          'vmænd': [('vmand', False)],
          'vmændene': [('vmand', False)],
          'vmændenes': [('vmand', False)],
          'vmærkernes': [('vmærke', False)],
          'vmærkers': [('vmærke', False)],
          'vmøder': [('vmøder', False)],
          'vmøderne': [('vmøder', False)],
          'vmødernes': [('vmøder', False)],
          'vmøders': [('vmøder', False)],
          'vmøller': [('vmølle', False)],
          'vmøllerne': [('vmølle', False)],
          'vmøllernes': [('vmølle', False)],
          'vmøllers': [('vmølle', False)],
          'vn': [('vn', False)],
          'vnakke': [('vnakke', False)],
          'vnakkerne': [('vnakke', False)],
          'vnakkernes': [('vnakke', False)],
          'vnakterne': [('vnakt', False)],
          'vnakternes': [('vnakt', False)],
          'vne': [('vn', False)],
          'vnearbejder': [('vnearbejder', False)],
          'vnearbejderne': [('vnearbejder', False)],
          'vnen': [('vn', False)],
          'vnene': [('vn', False)],
          'vnenes': [('vn', False)],
          'vnens': [('vn', False)],
          'vner': [('vn', False)],
          'vnerier': [('vneri', False)],
          'vnerierne': [('vneri', False)],
          'vneriernes': [('vneri', False)],
          'vneriers': [('vneri', False)],
          'vnes': [('vn', False)],
          'vnet': [('vn', False)],
          'vnets': [('vn', False)],
          'vningers': [('vning', False)],
          'vns': [('vn', False)],
          'vnsboernes': [('vnsbo', False)],
          'vnsboers': [('vnsbo', False)],
          'voen': [('vo', False)],
          'voens': [('vo', False)],
          'voger': [('voger', False)],
          'vogers': [('voger', False)],
          'vogne': [('vogn', False)],
          'vognen': [('vogn', False)],
          'vognens': [('vogn', False)],
          'vognes': [('vogn', False)],
          'vogters': [('vogter', False)],
          'voirer': [('voir', False)],
          'voirernes': [('voir', False)],
          'voiret': [('voir', False)],
          'voirets': [('voir', False)],
          'voks': [('voks', False)],
          "voks'": [('voks', True)],
          'voksen': [('voksen', True), ('voks', True)],
          'voksens': [('voksen', True), ('voks', True)],
          'vokser': [('voks', False)],
          'vokserne': [('voks', True)],
          'voksernes': [('voks', True)],
          'voksers': [('voks', False)],
          'volde': [('vold', False)],
          'volden': [('vold', False)],
          'voldene': [('vold', True)],
          'voldenes': [('vold', False)],
          'voldens': [('vold', False)],
          'volders': [('volder', False)],
          'voldes': [('vold', False)],
          'volfer': [('volfe', True)],
          'volferne': [('volfe', True)],
          'volfernes': [('volfe', True)],
          'volfers': [('volfe', True)],
          'voli': [('voli', False)],
          'volier': [('voli', False)],
          'volierne': [('voli', False)],
          'voliernes': [('voli', False)],
          'voliers': [('voli', False)],
          'voliet': [('voli', False)],
          'voliets': [('voli', False)],
          'volis': [('voli', False)],
          'volten': [('volte', True)],
          'voltens': [('volte', True)],
          'volter': [('volte', True)],
          'volterne': [('volte', True)],
          'volternes': [('volte', True)],
          'volters': [('volte', False)],
          'vomme': [('vom', False)],
          'vommen': [('vom', True)],
          'vommens': [('vom', True)],
          'vommes': [('vom', False)],
          'vons': [('vons', True)],
          'vordner': [('vordner', False)],
          'vordnerne': [('vordner', False)],
          'vordnernes': [('vordner', False)],
          'vordners': [('vordner', False)],
          'vorianerne': [('vorianer', False)],
          'vorianernes': [('vorianer', False)],
          'vorter': [('vorte', False)],
          'vorternes': [('vorte', False)],
          'vorters': [('vorte', False)],
          'vortes': [('vorte', True)],
          'vos': [('vo', False)],
          'voten': [('vote', False)],
          'votens': [('vote', False)],
          'voter': [('vote', False)],
          'voterne': [('vote', False)],
          'voternes': [('vote', False)],
          'voters': [('vote', False)],
          'votes': [('vote', False)],
          'votter': [('votte', False)],
          'votterne': [('votte', False)],
          'votternes': [('votte', False)],
          'votters': [('votte', False)],
          'vouchernes': [('voucher', True)],
          'vous': [('vous', False)],
          'vove': [('vove', True)],
          'voven': [('vove', True)],
          'vovens': [('vove', True)],
          'vover': [('vove', True)],
          'voverne': [('vove', True)],
          'vovernes': [('vove', True)],
          'vovers': [('vove', True)],
          'voves': [('vove', True)],
          'vovits': [('vovits', False)],
          'vovsens': [('vovse', True)],
          'vovsers': [('vovse', True)],
          'vpakker': [('vpakke', False)],
          'vpakkerne': [('vpakke', False)],
          'vpakkernes': [('vpakke', False)],
          'vpakkers': [('vpakke', False)],
          'vpiber': [('vpiber', False)],
          'vpiberne': [('vpiber', False)],
          'vpibernes': [('vpiber', False)],
          'vpibers': [('vpiber', False)],
          'vpillernes': [('vpille', False)],
          'vplager': [('vplager', False)],
          'vplagerne': [('vplager', False)],
          'vplagernes': [('vplager', False)],
          'vplagers': [('vplager', False)],
          'vpotten': [('vpotte', False)],
          'vpottens': [('vpotte', False)],
          'vpotter': [('vpotte', False)],
          'vpotterne': [('vpotte', False)],
          'vpotternes': [('vpotte', False)],
          'vpotters': [('vpotte', False)],
          'vpresser': [('vpresser', False)],
          'vpresserne': [('vpresser', False)],
          'vpressernes': [('vpresser', False)],
          'vpressers': [('vpresser', False)],
          'vprisen': [('vpris', False)],
          'vprisens': [('vpris', False)],
          'vpriser': [('vpris', False)],
          'vpriserne': [('vpris', False)],
          'vprisernes': [('vpris', False)],
          'vprisers': [('vpris', False)],
          'vrangen': [('vrange', True), ('vrang', True)],
          'vrangens': [('vrange', True), ('vrang', True)],
          'vrede': [('vrede', True)],
          'vreden': [('vrede', False)],
          'vredens': [('vrede', False)],
          'vredes': [('vrede', True)],
          'vregimenter': [('vregiment', False)],
          'vregimenterne': [('vregiment', False)],
          'vregimenternes': [('vregiment', False)],
          'vregimenters': [('vregiment', False)],
          'vregimentet': [('vregiment', False)],
          'vregimentets': [('vregiment', False)],
          'vrelser': [('vrelse', False)],
          'vrelserne': [('vrelse', False)],
          'vrelsernes': [('vrelse', False)],
          'vren': [('vre', False)],
          'vrene': [('vr', False)],
          'vrenes': [('vr', False)],
          'vrens': [('vre', False)],
          'vrenten': [('vrente', False)],
          'vrentens': [('vrente', False)],
          'vrenterne': [('vrente', False)],
          'vrenternes': [('vrente', False)],
          'vrentes': [('vrente', False)],
          'vrers': [('vre', False)],
          'vres': [('vre', False)],
          'vret': [('vret', False)],
          'vrets': [('vret', False)],
          'vretter': [('vret', False)],
          'vrider': [('vrider', False)],
          'vriderne': [('vrider', True)],
          'vridernes': [('vrider', False)],
          'vriders': [('vrider', False)],
          'vrids': [('vrid', True)],
          'vriks': [('vrik', True)],
          'vringer': [('vring', False)],
          'vringerne': [('vring', False)],
          'vringernes': [('vring', False)],
          'vringers': [('vring', False)],
          'vris': [('vris', True)],
          'vrister': [('vrist', True)],
          'vristerne': [('vrist', True)],
          'vristernes': [('vrist', True)],
          'vristers': [('vrist', False)],
          'vros': [('vros', False)],
          'vrosen': [('vros', False)],
          'vrosens': [('vros', False)],
          'vrs': [('vr', False)],
          'vrøret': [('vrør', False)],
          'vrørets': [('vrør', False)],
          "vs'": [('vs', False)],
          'vsanger': [('vsanger', False)],
          'vsbankens': [('vsbank', False)],
          'vsbankerne': [('vsbank', False)],
          'vsbankernes': [('vsbank', False)],
          'vsbankers': [('vsbank', False)],
          'vscyklen': [('vscyklus', False)],
          'vscyklernes': [('vscyklus', False)],
          'vscyklers': [('vscyklus', False)],
          'vse': [('vs', False)],
          'vsen': [('vs', False)],
          'vsene': [('vs', False)],
          'vsenes': [('vs', False)],
          'vsens': [('vsens', False)],
          'vser': [('vs', False)],
          'vsere': [('vser', False)],
          'vseren': [('vser', False)],
          'vserens': [('vser', False)],
          'vseres': [('vser', False)],
          'vserne': [('vs', False)],
          'vsernes': [('vs', False)],
          'vses': [('vs', False)],
          'vset': [('vs', False)],
          'vsets': [('vs', False)],
          'vsfarens': [('vsfare', False)],
          'vskaber': [('vskab', False)],
          'vskaberne': [('vskab', False)],
          'vskabernes': [('vskab', False)],
          'vskabers': [('vskab', False)],
          'vskriger': [('vskrige', False)],
          'vskrigerne': [('vskrige', False)],
          'vskrigernes': [('vskrige', False)],
          'vskrigers': [('vskrige', False)],
          'vskræfter': [('vskraft', False)],
          'vskræfterne': [('vskraft', False)],
          'vskræfters': [('vskraft', False)],
          'vslags': [('vslag', False)],
          'vslangen': [('vslange', False)],
          'vslangens': [('vslange', False)],
          'vslens': [('vsel', False)],
          'vspids': [('vspids', False)],
          'vspidser': [('vspids', False)],
          'vsreder': [('vsrede', False)],
          'vsredernes': [('vsrede', False)],
          'vssagens': [('vssag', False)],
          'vssager': [('vssag', False)],
          'vssagerne': [('vssag', False)],
          'vssagernes': [('vssag', False)],
          'vstarter': [('vstart', False)],
          'vstarterne': [('vstarter', False)],
          'vstarternes': [('vstarter', False)],
          'vstarters': [('vstarter', False)],
          'vstemmer': [('vstemme', False)],
          'vstemmerne': [('vstemme', False)],
          'vstemmernes': [('vstemme', False)],
          'vstemmers': [('vstemme', False)],
          'vsten': [('vst', False)],
          'vstens': [('vst', False)],
          'vstiers': [('vsti', False)],
          'vstiet': [('vsti', False)],
          'vstiets': [('vsti', False)],
          'vstikkens': [('vstikke', False)],
          'vstikker': [('vstikker', False)],
          'vstikkere': [('vstikker', False)],
          'vstikkerens': [('vstikker', False)],
          'vstikkeres': [('vstikker', False)],
          'vstikkerne': [('vstikker', False)],
          'vstikkernes': [('vstikker', False)],
          'vstikkers': [('vstikke', False)],
          'vstrikke': [('vstrik', False)],
          'vstrikken': [('vstrik', False)],
          'vstrikkens': [('vstrik', False)],
          'vstrikker': [('vstrik', False)],
          'vstrikkerne': [('vstrik', False)],
          'vstrikkernes': [('vstrik', False)],
          'vstrikkers': [('vstrik', False)],
          'vstrikkes': [('vstrik', False)],
          'vstykkernes': [('vstykke', False)],
          'vstykkers': [('vstykke', False)],
          'vstyrer': [('vstyre', False)],
          'vstyrerne': [('vstyre', False)],
          'vstyrernes': [('vstyre', False)],
          'vstyrers': [('vstyre', False)],
          'vstyret': [('vstyre', False)],
          'vstyrets': [('vstyre', False)],
          'vsyren': [('vsyre', False)],
          'vsyrens': [('vsyre', False)],
          'vsyrer': [('vsyre', False)],
          'vsyrerne': [('vsyre', False)],
          'vsyrernes': [('vsyre', False)],
          'vsyrers': [('vsyre', False)],
          'vsøer': [('vsø', False)],
          'vsøerne': [('vsø', False)],
          'vsøernes': [('vsø', False)],
          'vsøers': [('vsø', False)],
          'vtage': [('vtag', False)],
          'vtagere': [('vtager', False)],
          'vtageren': [('vtager', False)],
          'vtagerens': [('vtager', False)],
          'vtageres': [('vtager', False)],
          'vtallerne': [('vtal', False)],
          'vtallernes': [('vtal', False)],
          'vtanden': [('vtand', False)],
          'vtandens': [('vtand', False)],
          'vtanten': [('vtante', False)],
          'vtantens': [('vtante', False)],
          'vtanterne': [('vtante', False)],
          'vtanters': [('vtante', False)],
          'vten': [('vt', False)],
          'vtens': [('vt', False)],
          'vter': [('vt', False)],
          'vterne': [('vt', False)],
          'vternes': [('vt', False)],
          'vters': [('vt', False)],
          'vtiden': [('vtiden', False)],
          'vtids': [('vtid', False)],
          'vtoner': [('vtone', False)],
          'vtonerne': [('vtone', False)],
          'vtonernes': [('vtone', False)],
          'vtoners': [('vtone', False)],
          'vts': [('vt', False)],
          'vture': [('vtur', False)],
          'vturen': [('vtur', False)],
          'vtures': [('vtur', False)],
          'vtænder': [('vtand', False)],
          'vtænderne': [('vtand', False)],
          'vtændernes': [('vtand', False)],
          'vtænders': [('vtand', False)],
          'vtømmer': [('vtømmer', False)],
          'vtømmers': [('vtømmer', False)],
          'vuer': [('vue', True)],
          'vuerne': [('vue', True)],
          'vuernes': [('vue', True)],
          'vuers': [('vue', True)],
          'vuet': [('vue', True)],
          'vuets': [('vue', True)],
          'vuggernes': [('vugge', True)],
          'vuggers': [('vugge', True)],
          'vulster': [('vulst', False)],
          'vulsterne': [('vulst', False)],
          'vulsternes': [('vulst', False)],
          'vulsters': [('vulst', False)],
          'vunder': [('vunde', True)],
          'vunderne': [('vunde', True)],
          'vundernes': [('vunde', True)],
          'vunders': [('vunde', True)],
          'vupper': [('vupper', False)],
          'vupperne': [('vupper', False)],
          'vuppernes': [('vupper', False)],
          'vuppers': [('vupper', False)],
          'vure': [('vure', False)],
          'vuren': [('vure', False)],
          'vurens': [('vure', False)],
          'vurer': [('vure', False)],
          'vurerne': [('vure', False)],
          'vurernes': [('vure', False)],
          'vurers': [('vure', False)],
          'vures': [('vure', False)],
          'vus': [('vu', False)],
          'vvande': [('vvande', False)],
          'vvander': [('vvande', False)],
          'vvanderne': [('vvande', False)],
          'vvandernes': [('vvande', False)],
          'vvanders': [('vvande', False)],
          'vvandes': [('vvande', False)],
          'vveje': [('vvej', False)],
          'vvejen': [('vvej', False)],
          'vvejens': [('vvej', False)],
          'vvinder': [('vvinder', False)],
          'vvinderne': [('vvinder', False)],
          'vvindernes': [('vvinder', False)],
          'vvinders': [('vvinder', False)],
          'vyen': [('vy', False)],
          'vyens': [('vy', False)],
          'vyer': [('vy', True)],
          'vyerne': [('vy', False)],
          'vyernes': [('vy', False)],
          'vyers': [('vy', True)],
          'vys': [('vy', True)],
          'våben': [('våben', False)],
          'våbens': [('våben', False)],
          'våbner': [('våben', False)],
          'våbnerne': [('våben', True)],
          'våbnernes': [('våben', True)],
          'våbners': [('våben', False)],
          'våde': [('våde', True)],
          'våden': [('våde', True)],
          'vådens': [('våde', True)],
          'våders': [('våde', True)],
          'vådes': [('våde', True)],
          'våge': [('våge', False)],
          'vågen': [('våge', False)],
          'våger': [('våge', False)],
          'vågerne': [('våge', True)],
          'vågernes': [('våge', True)],
          'vågers': [('våge', True)],
          'vånde': [('vånd', True), ('vånde', True)],
          'vånden': [('vånd', True), ('vånde', True)],
          'våndens': [('vånd', True), ('vånde', True)],
          'vånder': [('vånde', True)],
          'vånderne': [('vånde', True)],
          'våndernes': [('vånde', True)],
          'vånders': [('vånde', True)],
          'våndes': [('vånd', True), ('vånde', True)],
          'vånernes': [('våner', False)],
          'våners': [('våner', False)],
          'våren': [('vår', True)],
          'vårens': [('vår', True)],
          'vås': [('vås', True)],
          'væbner': [('væbner', True)],
          'væbnerne': [('væbner', True)],
          'væbnernes': [('væbner', True)],
          'væbners': [('væbner', True)],
          'vædder': [('vædder', True)],
          'vædderne': [('vædder', True)],
          'væddernes': [('vædder', True)],
          'vædders': [('vædder', True)],
          'væden': [('væde', True)],
          'vædens': [('væde', False)],
          'væder': [('væder', False)],
          'væderne': [('væder', False)],
          'vædernes': [('væde', False)],
          'væders': [('væde', False)],
          'væge': [('væge', True)],
          'vægen': [('væge', True)],
          'væger': [('væge', True)],
          'vægge': [('væg', False)],
          'væggen': [('væg', False)],
          'væggens': [('væg', False)],
          'vægges': [('væg', False)],
          'vægte': [('vægt', False)],
          'vægten': [('vægt', False)],
          'vægtens': [('vægt', False)],
          'vægters': [('vægter', False)],
          'vægtes': [('vægt', False)],
          'vækker': [('vækker', True)],
          'vækkerne': [('vækker', True)],
          'vækkernes': [('vækker', True)],
          'vækkers': [('vækker', True)],
          'vælden': [('vælde', True)],
          'vældenes': [('væld', False)],
          'vældens': [('vælde', True)],
          'vældet': [('væld', True), ('vælde', True)],
          'vældets': [('væld', True), ('vælde', True)],
          'væler': [('væler', False)],
          'vælerne': [('væler', False)],
          'vælernes': [('væler', False)],
          'vælers': [('væler', False)],
          'væller': [('væller', False)],
          'vællers': [('væller', False)],
          'vælten': [('vælten', True)],
          'vænger': [('vænge', True)],
          'vængerne': [('vænge', True)],
          'vængernes': [('vænge', True)],
          'vængers': [('vænge', True)],
          'værdet': [('værd', False)],
          'værdets': [('værd', False)],
          'væren': [('væren', False)],
          'værens': [('væren', False)],
          'værer': [('vær', False)],
          'værers': [('vær', False)],
          'været': [('være', False)],
          'værets': [('være', False)],
          'værge': [('værge', True)],
          'værgen': [('værge', True)],
          'værgens': [('værge', True)],
          'værges': [('værge', True)],
          'værke': [('værk', False)],
          'værken': [('værk', False)],
          'værker': [('værk', False)],
          'værkerne': [('værk', False)],
          'værkernes': [('værk', False)],
          'værkers': [('værk', False)],
          'værkes': [('værk', False)],
          'værket': [('værk', False)],
          'værkets': [('værk', False)],
          'værme': [('værm', False)],
          'værmen': [('værm', False)],
          'værmens': [('værm', False)],
          'værmer': [('værmer', False)],
          'værmerne': [('værmer', False)],
          'værmernes': [('værmer', False)],
          'værmers': [('værmer', False)],
          'værmes': [('værm', False)],
          'værne': [('værn', False)],
          'værnen': [('værn', False)],
          'værnens': [('værn', False)],
          'værner': [('værner', True)],
          'værnernes': [('værner', True)],
          'værnes': [('værn', False)],
          'værs': [('værs', False)],
          'værten': [('vært', False)],
          'værtens': [('vært', False)],
          'værter': [('vært', False)],
          'værterne': [('vært', False)],
          'værternes': [('vært', True)],
          'værters': [('vært', False)],
          'væskens': [('væske', False)],
          'væskerne': [('væske', True)],
          'væskernes': [('væske', False)],
          'vætten': [('vætte', True)],
          'vættens': [('vætte', True)],
          'vætter': [('vætte', True)],
          'vætterne': [('vætte', True)],
          'vætternes': [('vætte', True)],
          'vætters': [('vætte', True)],
          'vøberne': [('vøbe', False)],
          'vøbers': [('vøbe', False)],
          'vøen': [('vø', False)],
          'vøens': [('vø', False)],
          'vøer': [('vø', False)],
          'vøers': [('vø', False)],
          'vømmer': [('vømmer', False)],
          'vømmerne': [('vømmer', False)],
          'vøren': [('vør', False)],
          'vørens': [('vør', False)],
          'vører': [('vør', False)],
          'vørerne': [('vør', False)],
          'vørernes': [('vør', False)],
          'vørers': [('vør', False)],
          'vørne': [('vørn', False)],
          'vørnenes': [('vørn', False)],
          'vøs': [('vø', False)],
          'vøse': [('vøse', False)],
          'vøser': [('vøse', False)],
          'vøserne': [('vøse', False)],
          'vøsernes': [('vøse', False)],
          'vøsers': [('vøse', False)],
          "w'erne": [('w', True)],
          "waders'": [('waders', True)],
          'wadien': [('wadi', True)],
          'wadiens': [('wadi', True)],
          'wadier': [('wadi', True)],
          'wadierne': [('wadi', True)],
          'wadiernes': [('wadi', True)],
          'wadiers': [('wadi', True)],
          'waen': [('wa', False)],
          'waens': [('wa', False)],
          'waer': [('wa', False)],
          'waerne': [('wa', False)],
          'waernes': [('wa', False)],
          'waers': [('wa', False)],
          'waiter': [('waiter', False)],
          'waiternes': [('waiter', False)],
          'waiters': [('waiter', False)],
          'walisers': [('waliser', True)],
          'walken': [('walk', False)],
          'walkens': [('walk', False)],
          'walkover': [('walkover', True)],
          'walkovers': [('walkover', True)],
          'wallen': [('wall', False)],
          'wallene': [('wall', False)],
          'wallenes': [('wall', False)],
          'wammen': [('wam', False)],
          'wammens': [('wam', False)],
          'wammer': [('wam', False)],
          'wammerne': [('wam', False)],
          'wammernes': [('wam', False)],
          'wammers': [('wam', False)],
          'wander': [('wander', False)],
          'waner': [('waner', False)],
          'wanerne': [('waner', False)],
          'wanernes': [('waner', False)],
          'waners': [('waner', False)],
          'wanzen': [('wanz', False)],
          'wanzens': [('wanz', False)],
          'wanzerne': [('wanz', False)],
          'wanzernes': [('wanz', False)],
          'warden': [('ward', False)],
          'wardens': [('ward', False)],
          'warderne': [('ward', False)],
          'wardernes': [('ward', False)],
          'waren': [('ware', False)],
          'warens': [('ware', False)],
          'waret': [('ware', False)],
          'warets': [('ware', False)],
          'was': [('wa', False)],
          'watts': [('watt', False)],
          'weaternes': [('weater', False)],
          'webben': [('web', True)],
          'webbens': [('web', True)],
          'weeder': [('weed', False)],
          'weederne': [('weed', False)],
          'weedernes': [('weed', False)],
          'weeders': [('weed', False)],
          'weeper': [('weeper', False)],
          'weeperne': [('weeper', False)],
          'weet': [('weet', False)],
          'weets': [('weet', False)],
          'weisserne': [('weiss', False)],
          'weissernes': [('weiss', False)],
          'wene': [('w', False)],
          'wenes': [('w', False)],
          'wer': [('wer', False)],
          'werne': [('wer', False)],
          'wernes': [('wer', False)],
          'wers': [('wer', False)],
          'wesen': [('wesen', False)],
          'wesens': [('wesen', False)],
          'wi': [('wi', False)],
          'wichen': [('wich', False)],
          'wichens': [('wich', False)],
          'wicher': [('wich', False)],
          'wicherne': [('wich', False)],
          'wichers': [('wich', False)],
          'wien': [('wi', False)],
          'wiens': [('wi', False)],
          'wier': [('wi', False)],
          'wiere': [('wier', False)],
          'wieren': [('wier', False)],
          'wierens': [('wier', False)],
          'wieres': [('wier', False)],
          'wierne': [('wi', False)],
          'wiernes': [('wi', False)],
          'wiers': [('wier', False)],
          'wikier': [('wiki', True)],
          'wikierne': [('wiki', True)],
          'wikiernes': [('wiki', True)],
          'wikiers': [('wiki', True)],
          'willen': [('will', False)],
          'willens': [('will', False)],
          'willet': [('will', False)],
          'willets': [('will', False)],
          'wingen': [('wing', True)],
          'wingens': [('wing', True)],
          'winger': [('wing', True)],
          'wingerne': [('wing', True)],
          'wingernes': [('wing', True)],
          'wingers': [('wing', True)],
          'wings': [('wing', True)],
          'winister': [('winist', False)],
          'winisters': [('winist', False)],
          'wirens': [('wire', True)],
          'wirer': [('wire', True)],
          'wirerne': [('wire', True)],
          'wirernes': [('wire', True)],
          'wirers': [('wire', True)],
          'wis': [('wi', False)],
          'wisten': [('wist', False)],
          'wistens': [('wist', False)],
          'wl': [('wl', False)],
          'wlas': [('wlas', False)],
          'wlasser': [('wlas', False)],
          'wlassernes': [('wlas', False)],
          'wlassers': [('wlas', False)],
          'wlen': [('wl', False)],
          'wlene': [('wl', False)],
          'wlenes': [('wl', False)],
          'wlens': [('wl', False)],
          'wler': [('wler', False)],
          'wlere': [('wler', False)],
          'wleren': [('wler', False)],
          'wlerens': [('wler', False)],
          'wleres': [('wler', False)],
          'wlers': [('wler', False)],
          'wlet': [('wl', False)],
          'wlets': [('wl', False)],
          'wlingers': [('wling', False)],
          'wls': [('wl', False)],
          'wmaster': [('wmaster', False)],
          'wmasterne': [('wmaster', False)],
          'wmasternes': [('wmaster', False)],
          'wmasters': [('wmaster', False)],
          'wn': [('wn', False)],
          'wnien': [('wnie', False)],
          'wniens': [('wnie', False)],
          'wnier': [('wnie', False)],
          'wnierne': [('wnie', False)],
          'wniernes': [('wnie', False)],
          'wniers': [('wnie', False)],
          'wningers': [('wning', False)],
          'wns': [('wn', False)],
          "wns'": [('wn', False)],
          'wobler': [('wobler', True)],
          'woblerne': [('wobler', True)],
          'woblernes': [('wobler', True)],
          'woblers': [('wobler', True)],
          'wokken': [('wok', True)],
          'wokker': [('wok', True)],
          'wokkerne': [('wok', True)],
          'wokkernes': [('wok', True)],
          'wokkers': [('wok', True)],
          'wraps': [('wrap', True)],
          "wraps'": [('wrap', True)],
          'writer': [('writer', False)],
          'writerne': [('writer', False)],
          'writernes': [('writer', False)],
          'writers': [('writer', False)],
          'ws': [('w', False)],
          "ws'": [('w', False)],
          'wser': [('wser', False)],
          'wsere': [('wser', False)],
          'wseren': [('wser', False)],
          'wserens': [('wser', False)],
          'wseres': [('wser', False)],
          'wserne': [('wser', False)],
          'wsernes': [('wser', False)],
          'wsers': [('wser', False)],
          'wværternes': [('wvært', False)],
          "x'er": [('x', True)],
          "x'erne": [('x', True)],
          "x'ernes": [('x', True)],
          "x'ers": [('x', True)],
          'xa': [('xa', False)],
          'xaen': [('xa', False)],
          'xaens': [('xa', False)],
          'xaer': [('xa', False)],
          'xaerne': [('xa', False)],
          'xaernes': [('xa', False)],
          'xaers': [('xa', False)],
          'xas': [('xa', False)],
          'xbomber': [('xbombe', False)],
          'xbomberne': [('xbombe', False)],
          'xbombernes': [('xbombe', False)],
          'xbombers': [('xbombe', False)],
          'xcellens': [('xcellens', False)],
          'xces': [('xces', False)],
          'xe': [('x', False)],
          'xene': [('x', False)],
          'xenes': [('x', False)],
          'xes': [('x', False)],
          "xes'": [('x', False)],
          'xi': [('xi', False)],
          'xidens': [('xid', False)],
          'xien': [('xi', False)],
          'xiens': [('xi', False)],
          'xier': [('xi', False)],
          'xierne': [('xi', False)],
          'xiernes': [('xi', False)],
          'xiers': [('xi', False)],
          'xiner': [('xin', False)],
          'xinerne': [('xin', False)],
          'xiners': [('xin', False)],
          'xingen': [('xing', False)],
          'xingens': [('xing', False)],
          'xings': [('xing', False)],
          'xis': [('xi', False)],
          'xismens': [('xisme', False)],
          'xisten': [('xist', False)],
          'xistens': [('xist', False)],
          'xister': [('xist', False)],
          'xisterne': [('xist', False)],
          'xisternes': [('xist', False)],
          'xisters': [('xist', False)],
          'xitten': [('xit', False)],
          'xittens': [('xit', False)],
          'xitternes': [('xit', False)],
          'xitters': [('xit', False)],
          'xlen': [('xel', False)],
          'xlens': [('xel', False)],
          'xler': [('xel', False)],
          'xlerne': [('xel', False)],
          'xlernes': [('xel', False)],
          'xlers': [('xel', False)],
          'xmeter': [('xmeter', False)],
          'xmeters': [('xmeter', False)],
          'xmetre': [('xmeter', False)],
          'xmetrene': [('xmeter', False)],
          'xmetrenes': [('xmeter', False)],
          'xmetres': [('xmeter', False)],
          'xmetret': [('xmeter', False)],
          'xmetrets': [('xmeter', False)],
          'xmodens': [('xmode', False)],
          'xmoder': [('xmode', False)],
          'xmoders': [('xmode', False)],
          'xningers': [('xning', False)],
          'xotes': [('xote', False)],
          'xpencer': [('xpence', False)],
          'xpencerne': [('xpence', False)],
          'xpencernes': [('xpence', False)],
          'xpencers': [('xpence', False)],
          'xtensions': [('xtensions', False)],
          'xtrotter': [('xtrot', False)],
          'xtrotterne': [('xtrot', False)],
          'xtrotternes': [('xtrot', False)],
          'xture': [('xture', False)],
          'xturen': [('xture', False)],
          'xturene': [('xture', False)],
          'xturenes': [('xture', False)],
          'xturens': [('xture', False)],
          'xtures': [('xture', False)],
          'xyen': [('xy', False)],
          'xyens': [('xy', False)],
          'xygens': [('xygen', False)],
          'xys': [('xy', False)],
          'xøbo': [('xøbo', False)],
          'xøboen': [('xøbo', False)],
          'xøboens': [('xøbo', False)],
          'xøboer': [('xøbo', False)],
          'xøboerne': [('xøbo', False)],
          'xøboernes': [('xøbo', False)],
          'xøboers': [('xøbo', False)],
          'xøbos': [('xøbo', False)],
          "y'erne": [('y', True)],
          'ya': [('ya', False)],
          'yade': [('yade', False)],
          'yaden': [('yade', False)],
          'yadens': [('yade', False)],
          'yaderne': [('yade', False)],
          'yaders': [('yade', False)],
          'yades': [('yade', False)],
          'yaen': [('ya', False)],
          'yaens': [('ya', False)],
          'yaer': [('ya', False)],
          'yaerne': [('ya', False)],
          'yaernes': [('ya', False)],
          'yaers': [('ya', False)],
          'yakken': [('yak', True)],
          'yakkerne': [('yak', True)],
          'yaks': [('yak', True)],
          'yams': [('yams', True)],
          "yams'": [('yams', True)],
          'yamsen': [('yams', True)],
          'yamsens': [('yams', True)],
          'yanen': [('yan', False)],
          'yanens': [('yan', False)],
          'yaner': [('yaner', False)],
          'yanerne': [('yaner', False)],
          'yanernes': [('yaner', False)],
          'yaners': [('yaner', False)],
          'yanten': [('yant', False)],
          'yantens': [('yant', False)],
          'yanterne': [('yant', False)],
          'yanternes': [('yant', False)],
          'yanters': [('yant', False)],
          'yants': [('yant', False)],
          'yarerne': [('yar', False)],
          'yarers': [('yar', False)],
          'yas': [('ya', False)],
          'yatiders': [('yatide', False)],
          'ybanke': [('ybanke', False)],
          'ybanken': [('ybanke', False)],
          'ybankens': [('ybanke', False)],
          'ybanker': [('ybanke', False)],
          'ybankerne': [('ybanke', False)],
          'ybankernes': [('ybanke', False)],
          'ybankers': [('ybanke', False)],
          'ybbe': [('ybbe', False)],
          'ybbens': [('ybbe', False)],
          'ybber': [('ybbe', False)],
          'ybbernes': [('ybbe', False)],
          'ybbers': [('ybbe', False)],
          'ybbes': [('ybbe', False)],
          'yben': [('yb', False)],
          'ybene': [('yb', False)],
          'ybener': [('yben', False)],
          'ybeners': [('yben', False)],
          'ybenes': [('yb', False)],
          'ybenet': [('yben', False)],
          'ybens': [('yb', False)],
          'ybet': [('yb', False)],
          'ybets': [('yb', False)],
          'yblens': [('ybel', False)],
          'ybler': [('ybel', False)],
          'yboerne': [('ybo', False)],
          'yboers': [('ybo', False)],
          'yborgen': [('yborg', False)],
          'yborgens': [('yborg', False)],
          'yborger': [('yborg', False)],
          'yborgerne': [('yborg', False)],
          'yborgernes': [('yborg', False)],
          'yborgers': [('yborg', False)],
          'ybs': [('yb', False)],
          'ybukser': [('ybukser', False)],
          'ybukserne': [('ybukser', False)],
          'ybuksernes': [('ybukser', False)],
          'ybuksers': [('ybukser', False)],
          'ybus': [('ybus', False)],
          'ycentre': [('ycenter', False)],
          'ycentrene': [('ycenter', False)],
          'ycentrenes': [('ycenter', False)],
          'ycentres': [('ycenter', False)],
          'ycentret': [('ycenter', False)],
          'ycentrets': [('ycenter', False)],
          'ycyklen': [('ycykel', False)],
          'ycyklens': [('ycykel', False)],
          'ycykler': [('ycykel', False)],
          'ycyklerne': [('ycykel', False)],
          'ycyklernes': [('ycykel', False)],
          'ycyklers': [('ycykel', False)],
          'yd': [('yd', False)],
          'ydder': [('ydder', False)],
          'ydderne': [('ydder', False)],
          'yddernes': [('ydder', False)],
          'ydebroderens': [('ydebroder', False)],
          'ydebrødre': [('ydebroder', False)],
          'ydebrødrene': [('ydebroder', False)],
          'ydebrødrenes': [('ydebroder', False)],
          'ydebrødres': [('ydebroder', False)],
          'yden': [('yd', False)],
          'ydene': [('yd', False)],
          'ydenes': [('yd', False)],
          'ydens': [('yd', False)],
          'yder': [('yder', True)],
          'ydere': [('yder', False)],
          'yderen': [('yder', False)],
          'yderens': [('yder', False)],
          'yderes': [('yder', False)],
          'yderne': [('yder', True)],
          'ydernes': [('yder', True)],
          'yders': [('yder', False)],
          'ydeske': [('ydeske', False)],
          'ydeskes': [('ydeske', False)],
          'ydet': [('yd', False)],
          'ydets': [('yd', False)],
          'ydhaves': [('ydhave', False)],
          'ydia': [('ydia', False)],
          'ydias': [('ydia', False)],
          'ydre': [('ydre', True)],
          'ydrenges': [('ydreng', False)],
          'ydrer': [('ydre', True)],
          'ydrerne': [('ydre', True)],
          'ydrernes': [('ydre', True)],
          'ydret': [('ydre', True)],
          'ydrogen': [('ydrogen', False)],
          'ydrogens': [('ydrogen', False)],
          'yds': [('yd', False)],
          'ydsorden': [('ydsord', False)],
          'ydsordens': [('ydsord', False)],
          'ydstager': [('ydstage', False)],
          'ydstagerne': [('ydstage', False)],
          'ydstagernes': [('ydstage', False)],
          'ydstagers': [('ydstage', False)],
          'ydækket': [('ydække', False)],
          'ydækkets': [('ydække', False)],
          'ye': [('ye', False)],
          'yeder': [('yeder', False)],
          'yeders': [('yeder', False)],
          'yeliner': [('yeliner', False)],
          'yelinerne': [('yeliner', False)],
          'yelinernes': [('yeliner', False)],
          'yelsers': [('yelse', False)],
          'yen': [('yen', False)],
          'yene': [('y', False)],
          'yenen': [('yen', False)],
          'yenens': [('yen', False)],
          'yener': [('yen', False)],
          'yenerne': [('yen', False)],
          'yenernes': [('yen', False)],
          'yeners': [('yen', False)],
          'yenes': [('y', False)],
          'yennen': [('yen', True)],
          'yennens': [('yen', True)],
          'yens': [('yen', True)],
          'yere': [('yere', False)],
          'yeren': [('yere', False)],
          'yerens': [('yere', False)],
          'yerer': [('yere', False)],
          'yererne': [('yere', False)],
          'yerernes': [('yere', False)],
          'yerers': [('yere', False)],
          'yeres': [('yere', False)],
          'yersken': [('yerske', False)],
          'yersker': [('yerske', False)],
          'yerskerne': [('yerske', False)],
          'yerskers': [('yerske', False)],
          'yes': [('ye', False)],
          'yester': [('yester', False)],
          'yesteret': [('yester', False)],
          'yesterets': [('yester', False)],
          'yesternes': [('yester', False)],
          'yf': [('yf', False)],
          'yfe': [('yfe', False)],
          'yfen': [('yfe', False)],
          'yfens': [('yf', False)],
          'yfer': [('yfe', False)],
          'yferierne': [('yferie', False)],
          'yferne': [('yfe', False)],
          'yfernes': [('yf', False)],
          'yfers': [('yf', False)],
          'yfes': [('yfe', False)],
          'yffen': [('yf', False)],
          'yffens': [('yf', False)],
          'yfferne': [('yf', False)],
          'yfilis': [('yfilis', False)],
          'yflosser': [('yfloss', False)],
          'yflosserne': [('yfloss', False)],
          'yflossernes': [('yfloss', False)],
          'yflossers': [('yfloss', False)],
          'yfonierne': [('yfoni', False)],
          'yfoniernes': [('yfoni', False)],
          'yfoniers': [('yfoni', False)],
          'yfons': [('yfon', False)],
          'yfus': [('yfus', False)],
          'yg': [('yg', False)],
          "ygas'": [('ygas', False)],
          'ygassernes': [('ygas', False)],
          'ygder': [('ygd', False)],
          'ygderne': [('ygd', False)],
          'ygen': [('ygen', False)],
          'ygene': [('yg', False)],
          'ygenes': [('yg', False)],
          'ygenets': [('ygen', False)],
          'ygens': [('yge', False)],
          'yger': [('yger', False)],
          'ygere': [('yger', False)],
          'ygeren': [('yger', False)],
          'ygerens': [('yger', False)],
          'ygeres': [('yger', False)],
          'ygerne': [('yge', False)],
          'ygernes': [('yge', False)],
          'ygers': [('yge', False)],
          'yges': [('yge', False)],
          'yget': [('yg', False)],
          'ygets': [('yg', False)],
          'ygge': [('ygge', False)],
          'yggen': [('ygge', False)],
          'yggenes': [('yg', False)],
          'yggens': [('ygge', False)],
          'ygger': [('ygge', False)],
          'yggeret': [('yggeret', False)],
          'yggerets': [('yggeret', False)],
          'yggerne': [('ygge', False)],
          'yggernes': [('ygge', False)],
          'yggers': [('ygger', False)],
          "yggers'": [('yggers', False)],
          'ygges': [('ygge', False)],
          'yghedens': [('yghed', False)],
          'ygklapperne': [('ygklapper', False)],
          'ygklappernes': [('ygklapper', False)],
          'yglans': [('yglans', False)],
          'ygler': [('ygel', False)],
          'yglerne': [('ygel', False)],
          'yglets': [('ygel', False)],
          'ygoter': [('ygote', False)],
          'ygoterne': [('ygote', False)],
          'ygoternes': [('ygote', False)],
          'ygoters': [('ygote', False)],
          'ygs': [('yg', False)],
          'ygte': [('ygte', False)],
          'ygten': [('ygte', False)],
          'ygtens': [('ygte', False)],
          'ygter': [('ygte', False)],
          'ygterne': [('ygte', False)],
          'ygternes': [('ygte', False)],
          'ygters': [('ygte', False)],
          'ygtes': [('ygte', False)],
          'ygtet': [('ygte', False)],
          'ygtets': [('ygte', False)],
          'yhallen': [('yhal', False)],
          'yheden': [('yhed', False)],
          'yhedens': [('yhed', False)],
          'yheder': [('yhed', False)],
          'yhederne': [('yhed', False)],
          'yhedernes': [('yhed', False)],
          'yheders': [('yhed', False)],
          'yhistorien': [('yhistori', False)],
          'yhistoriens': [('yhistori', False)],
          'yhuen': [('yhue', False)],
          'yhuens': [('yhue', False)],
          'yismen': [('yisme', False)],
          'yisten': [('yist', False)],
          'yistens': [('yist', False)],
          'yister': [('yist', False)],
          'yisterne': [('yist', False)],
          'yisternes': [('yist', False)],
          'yisters': [('yist', False)],
          'yk': [('yk', False)],
          'ykanden': [('ykand', False)],
          'ykandens': [('ykand', False)],
          'ykens': [('yke', False)],
          'ykerne': [('ykerne', False)],
          'ykernes': [('yke', False)],
          'ykers': [('yke', False)],
          'ykke': [('ykke', False)],
          'ykken': [('ykke', False)],
          'ykkens': [('yk', False)],
          'ykker': [('ykke', False)],
          'ykkerne': [('ykke', False)],
          'ykkernes': [('ykker', False)],
          'ykkes': [('ykke', False)],
          'ykket': [('yk', False)],
          'ykkets': [('yk', False)],
          'yklapper': [('yklap', False)],
          'yklapperne': [('yklap', False)],
          'yklappernes': [('yklap', False)],
          'yklappers': [('yklap', False)],
          'yklaps': [('yklap', False)],
          'yklerne': [('ykler', False)],
          'yklers': [('ykler', False)],
          'yklingen': [('ykling', False)],
          'yklingens': [('ykling', False)],
          'yklisten': [('yklist', False)],
          'yklistens': [('yklist', False)],
          'yklister': [('ykliste', False)],
          'yklisterne': [('yklist', False)],
          'yklisternes': [('ykliste', False)],
          'yklisters': [('ykliste', False)],
          'ykogen': [('ykogen', False)],
          'ykogens': [('ykogen', False)],
          'ykolen': [('ykol', False)],
          'ykolens': [('ykol', False)],
          'ykolernes': [('ykol', False)],
          'ykolers': [('ykol', False)],
          'ykoser': [('ykose', False)],
          'yks': [('yk', False)],
          'ykser': [('yks', False)],
          'ykørerne': [('ykører', False)],
          'ykørers': [('ykører', False)],
          'yl': [('yl', False)],
          'ylaksen': [('ylakse', False)],
          'ylaksens': [('ylakse', False)],
          'ylanter': [('ylant', False)],
          'ylanterne': [('ylant', False)],
          'ylanternes': [('ylant', False)],
          'ylanters': [('ylant', False)],
          'ylde': [('ylde', False)],
          'yldene': [('yld', False)],
          'ylder': [('ylde', False)],
          'ylderne': [('yld', False)],
          'yldernes': [('yld', False)],
          'ylders': [('ylde', False)],
          'yldes': [('ylde', False)],
          'yldesten': [('yldest', False)],
          'yle': [('yl', False)],
          'ylen': [('yl', False)],
          'ylene': [('yl', False)],
          'ylenen': [('ylen', False)],
          'ylenens': [('ylen', False)],
          'ylener': [('ylen', False)],
          'ylenerne': [('ylen', False)],
          'ylenernes': [('ylen', False)],
          'yleners': [('ylen', False)],
          'ylenes': [('ylene', False)],
          'ylenet': [('ylene', False)],
          'ylenets': [('ylen', False)],
          'ylens': [('yl', False)],
          'yler': [('yl', False)],
          'ylere': [('yler', False)],
          'yleren': [('yler', False)],
          'ylerens': [('yler', False)],
          'yleres': [('yler', False)],
          'ylerne': [('yl', False)],
          'ylernes': [('yl', False)],
          'ylers': [('yl', False)],
          'yles': [('yl', False)],
          'ylet': [('yl', False)],
          'ylets': [('yl', False)],
          'ylettens': [('ylette', True)],
          'ylfider': [('ylfide', False)],
          'ylfiderne': [('ylfide', False)],
          'ylfidernes': [('ylfide', False)],
          'ylfiders': [('ylfide', False)],
          'ylfilter': [('ylfilt', False)],
          'ylien': [('ylie', False)],
          'yliens': [('ylie', False)],
          'ylier': [('ylie', False)],
          'ylierne': [('ylie', False)],
          'yliernes': [('ylie', False)],
          'yliers': [('ylie', False)],
          'ylies': [('ylie', False)],
          'ylighter': [('ylight', False)],
          'ylighterne': [('ylight', False)],
          'ylighternes': [('ylight', False)],
          'ylighters': [('ylight', False)],
          'ylime': [('ylim', False)],
          'ylimen': [('ylim', False)],
          'ylimene': [('ylim', False)],
          'ylimenes': [('ylim', False)],
          'ylimens': [('ylim', False)],
          'ylimes': [('ylim', False)],
          'ylinder': [('ylinder', False)],
          'ylinderne': [('ylinder', False)],
          'ylindernes': [('ylinder', False)],
          'ylinders': [('ylinder', False)],
          'ylingers': [('yling', False)],
          'ylisten': [('ylist', False)],
          'ylistens': [('ylist', False)],
          'ylister': [('ylist', False)],
          'ylisterne': [('ylist', False)],
          'ylisternes': [('ylist', False)],
          'ylisters': [('ylist', False)],
          'ylke': [('ylke', False)],
          'ylker': [('ylke', False)],
          'ylkerne': [('ylke', False)],
          'ylkes': [('ylke', False)],
          'ylket': [('ylke', False)],
          'ylkets': [('ylke', False)],
          'ylle': [('ylle', False)],
          'yllen': [('ylle', False)],
          'yllene': [('yl', False)],
          'yllenes': [('yl', False)],
          'yllens': [('yl', False)],
          'yller': [('ylle', False)],
          'yllerne': [('yl', False)],
          'yllernes': [('yl', False)],
          'yllers': [('ylle', False)],
          'ylles': [('ylle', False)],
          'yllet': [('yl', False)],
          'yllets': [('yl', False)],
          'yllikers': [('ylliker', False)],
          'yllinger': [('ylling', False)],
          'yllingerne': [('ylling', False)],
          'yllingernes': [('ylling', False)],
          'ylonier': [('ylonier', False)],
          'ylper': [('ylp', False)],
          'ylperne': [('ylp', False)],
          'ylpernes': [('ylp', False)],
          'ylpers': [('ylp', False)],
          'yls': [('yl', False)],
          'ylte': [('ylte', False)],
          'ylten': [('ylte', False)],
          'yltene': [('ylt', False)],
          'yltens': [('ylte', False)],
          'ylter': [('ylte', False)],
          'ylterne': [('ylte', False)],
          'ylternes': [('ylte', False)],
          'ylters': [('ylte', False)],
          'yltes': [('ylte', False)],
          'ylæer': [('ylæer', False)],
          'ylæerne': [('ylæer', False)],
          'ylæernes': [('ylæer', False)],
          'ym': [('ym', False)],
          'ymajs': [('ymajs', False)],
          'yman': [('yman', False)],
          'ymbler': [('ymbel', False)],
          'ymblerne': [('ymbel', False)],
          'ymblernes': [('ymbel', False)],
          'ymblers': [('ymbel', False)],
          'ymen': [('ymen', False)],
          'ymens': [('yman', False)],
          'ymer': [('ymer', False)],
          'ymeren': [('ymer', True)],
          'ymerens': [('ymer', False)],
          'ymerer': [('ymer', False)],
          'ymererne': [('ymer', False)],
          'ymerernes': [('ymer', False)],
          'ymerers': [('ymer', False)],
          'ymerne': [('ym', False)],
          'ymernes': [('ym', False)],
          'ymers': [('ymer', True)],
          'ymet': [('ym', False)],
          'ymets': [('ym', False)],
          'ymfer': [('ymfe', False)],
          'ymferne': [('ymfe', False)],
          'ymfernes': [('ymfe', False)],
          'ymfers': [('ymfe', False)],
          'ymiks': [('ymik', False)],
          'ymis': [('ymi', False)],
          'ymner': [('ymne', False)],
          'ymnernes': [('ymne', False)],
          'ymosen': [('ymos', False)],
          'ymosens': [('ymos', False)],
          'ymper': [('ymper', False)],
          'ympernes': [('ymper', False)],
          'ympers': [('ymper', False)],
          'yms': [('ym', False)],
          'ymænd': [('ymand', False)],
          'yn': [('yn', False)],
          'ynapse': [('ynapse', False)],
          'ynapsen': [('ynapse', False)],
          'ynapsens': [('ynapse', False)],
          'ynapses': [('ynapse', False)],
          'ynde': [('ynde', False)],
          'ynden': [('ynde', False)],
          'yndens': [('ynde', False)],
          'ynder': [('ynde', True), ('ynder', True)],
          'ynderkurser': [('ynderkursus', False)],
          'ynderkurserne': [('ynderkursus', False)],
          'ynderkursers': [('ynderkursus', False)],
          'ynderne': [('ynde', True), ('ynder', True)],
          'yndernes': [('ynde', True), ('ynder', True)],
          'ynders': [('ynder', True), ('ynde', True)],
          'yndes': [('ynde', True)],
          'yndesten': [('yndest', True)],
          'ynen': [('yn', False)],
          'ynene': [('yn', False)],
          'ynenes': [('yn', False)],
          'ynens': [('yn', False)],
          'yner': [('yn', False)],
          'ynerne': [('yne', False)],
          'ynernes': [('yn', False)],
          'yners': [('yne', False)],
          'ynesierne': [('ynesier', False)],
          'ynesiernes': [('ynesier', False)],
          'ynesiers': [('ynesier', False)],
          'ynet': [('yn', False)],
          'ynets': [('yn', False)],
          'yngaler': [('yngal', False)],
          'yngalerne': [('yngal', False)],
          'ynge': [('ynge', False)],
          'yngen': [('ynge', False)],
          'yngens': [('ynge', False)],
          'ynger': [('ynge', False)],
          'yngerne': [('ynge', False)],
          'ynges': [('ynge', False)],
          'ynglen': [('yngel', False)],
          'ynglerne': [('yngel', False)],
          'ynglernes': [('yngel', False)],
          'ynglers': [('yngel', False)],
          'yniker': [('yniker', False)],
          'ynikerne': [('yniker', False)],
          'ynikernes': [('yniker', False)],
          'ynikers': [('yniker', False)],
          'yningers': [('yning', False)],
          'ynitten': [('ynit', False)],
          'ynittens': [('ynit', False)],
          'ynitter': [('ynit', False)],
          'ynitterne': [('ynit', False)],
          'ynitternes': [('ynit', False)],
          'ynitters': [('ynit', False)],
          'ynke': [('ynke', False)],
          'ynken': [('ynke', False)],
          'ynker': [('ynke', False)],
          'ynkerne': [('ynke', False)],
          'ynkes': [('ynke', False)],
          'ynket': [('ynk', False)],
          'ynkets': [('ynk', False)],
          'ynomier': [('ynomium', False)],
          'ynomierne': [('ynomium', False)],
          'ynomiernes': [('ynomium', False)],
          'ynomiers': [('ynomium', False)],
          'ynomiets': [('ynomium', False)],
          'yns': [('yn', False)],
          'ynse': [('ynse', False)],
          'ynses': [('ynse', False)],
          'ynskreds': [('ynskreds', False)],
          'yntagens': [('yntagen', False)],
          'ynte': [('ynte', False)],
          'ynten': [('ynte', False)],
          'yntens': [('ynte', False)],
          'ynter': [('ynt', False)],
          'ynterne': [('ynte', False)],
          'ynternes': [('ynte', False)],
          'ynters': [('ynte', False)],
          'yntes': [('ynte', False)],
          'yntesen': [('yntese', False)],
          'yntesens': [('yntese', False)],
          'ynteser': [('yntese', False)],
          'ynteserne': [('yntese', False)],
          'yoen': [('yo', False)],
          'yoens': [('yo', False)],
          'yoer': [('yo', False)],
          'yoerne': [('yo', False)],
          'yoernes': [('yo', False)],
          'yoers': [('yo', False)],
          'yoet': [('yo', False)],
          'yoets': [('yo', False)],
          'yogas': [('yoga', True)],
          'yogien': [('yogi', True)],
          'yogier': [('yogi', True)],
          'yogierne': [('yogi', True)],
          'yogiernes': [('yogi', True)],
          'yogiers': [('yogi', True)],
          'yorker': [('yorker', False)],
          'yorkerne': [('yorker', False)],
          'yorkernes': [('yorker', False)],
          'yorkers': [('yorker', False)],
          'yos': [('yo', False)],
          'yosen': [('yose', False)],
          'yosens': [('yose', False)],
          'yoser': [('yose', False)],
          'yoserne': [('yose', False)],
          'yosernes': [('yose', False)],
          'yosers': [('yose', False)],
          'youter': [('youter', False)],
          'youterne': [('youter', False)],
          'youternes': [('youter', False)],
          'youters': [('youter', False)],
          'yparkernes': [('ypark', False)],
          'yparkers': [('ypark', False)],
          'ypassager': [('ypassager', False)],
          'ypassagers': [('ypassager', False)],
          'ypens': [('ype', False)],
          'yper': [('yper', False)],
          'ypere': [('yper', False)],
          'yperens': [('yper', False)],
          'yperes': [('yper', False)],
          'yperne': [('yper', False)],
          'ypernes': [('ype', False)],
          'ypers': [('ype', False)],
          'ypes': [('ype', False)],
          'ypien': [('ypi', False)],
          'ypiens': [('ypi', False)],
          'ypier': [('ypi', False)],
          'ypierne': [('ypi', False)],
          'ypiernes': [('ypi', False)],
          'ypiers': [('ypi', False)],
          'ypis': [('ypi', False)],
          'ypoteker': [('ypotek', False)],
          'ypotekerne': [('ypotek', False)],
          'ypotekernes': [('ypotek', False)],
          'ypotekers': [('ypotek', False)],
          'ypper': [('yp', False)],
          'yppernes': [('yp', False)],
          'yppet': [('yp', False)],
          'yppets': [('yp', False)],
          'ypressen': [('ypres', False)],
          'ypressens': [('ypres', False)],
          'ypresser': [('ypres', False)],
          'ypresserne': [('ypres', False)],
          'ypressernes': [('ypres', False)],
          'ypressers': [('ypres', False)],
          'yprisen': [('ypris', False)],
          'yprisens': [('ypris', False)],
          'ypriser': [('ypris', False)],
          'ypriserne': [('ypris', False)],
          'yprisernes': [('ypris', False)],
          'yprisers': [('ypris', False)],
          'yps': [('yp', False)],
          'ypse': [('ypse', False)],
          'ypsen': [('ypse', False)],
          'ypsens': [('ypse', False)],
          'ypser': [('ypse', False)],
          'ypserne': [('ypse', False)],
          'ypsernes': [('ypse', False)],
          'ypsers': [('ypse', False)],
          'ypses': [('ypse', False)],
          'ypter': [('ypt', False)],
          'ypterne': [('ypter', False)],
          'ypternes': [('ypter', False)],
          'ypters': [('ypter', False)],
          'ypumpen': [('ypumpe', False)],
          'ypumpens': [('ypumpe', False)],
          'ypumper': [('ypumpe', False)],
          'ypumperne': [('ypumpe', False)],
          'yr': [('yr', False)],
          'yraften': [('yraften', False)],
          'yraftens': [('yraften', False)],
          'yranen': [('yran', False)],
          'yraner': [('yran', False)],
          'yraners': [('yran', False)],
          'yrans': [('yran', False)],
          'yras': [('yras', False)],
          'yrasser': [('yras', False)],
          'yrassernes': [('yras', False)],
          'yrassers': [('yras', False)],
          'yrde': [('yrde', False)],
          'yrden': [('yrde', False)],
          'yrdens': [('yrde', False)],
          'yrderne': [('yrde', False)],
          'yrders': [('yrde', False)],
          'yrdes': [('yrde', False)],
          'yre': [('yr', False)],
          'yrelser': [('yrelse', False)],
          'yrelserne': [('yrelse', False)],
          'yrelsernes': [('yrelse', False)],
          'yren': [('yr', False)],
          'yrene': [('yr', False)],
          'yrenen': [('yren', False)],
          'yrener': [('yren', False)],
          'yrenerne': [('yren', False)],
          'yrenernes': [('yren', False)],
          'yrenes': [('yr', False)],
          'yrens': [('yr', False)],
          'yrer': [('yr', False)],
          'yrerne': [('yrer', False)],
          'yrernes': [('yrer', False)],
          'yrers': [('yr', False)],
          'yres': [('yre', False)],
          'yresten': [('yresten', False)],
          'yrestens': [('yresten', False)],
          'yret': [('yr', False)],
          'yrets': [('yr', False)],
          'yretter': [('yret', False)],
          'yrien': [('yrie', False)],
          'yriens': [('yrie', False)],
          'yrier': [('yrie', False)],
          'yrierne': [('yrie', False)],
          'yriernes': [('yrie', False)],
          'yriers': [('yrie', False)],
          'yries': [('yrie', False)],
          'yriet': [('yrie', False)],
          'yriets': [('yrie', False)],
          'yrikkens': [('yrik', False)],
          'yrikker': [('yrik', False)],
          'yrikkernes': [('yrik', False)],
          'yrikkers': [('yrik', False)],
          'yriks': [('yrik', False)],
          'yringer': [('yring', False)],
          'yringerne': [('yring', False)],
          'yringernes': [('yring', False)],
          'yringers': [('yring', False)],
          'yrinterne': [('yrint', False)],
          'yrinters': [('yrint', False)],
          'yrk': [('yrker', False)],
          'yrke': [('yrke', False)],
          'yrkernes': [('yrker', False)],
          'yrkes': [('yrke', False)],
          'yrks': [('yrker', False)],
          'yrminen': [('yrmine', False)],
          'yrminens': [('yrmine', False)],
          'yrminer': [('yrmine', False)],
          'yrminerne': [('yrmine', False)],
          'yrminernes': [('yrmine', False)],
          'yroden': [('yrod', False)],
          'yrodens': [('yrod', False)],
          'yrods': [('yrod', False)],
          'yroen': [('yro', False)],
          'yroens': [('yro', False)],
          'yroer': [('yro', False)],
          'yroerne': [('yro', False)],
          'yroernes': [('yro', False)],
          'yroers': [('yro', False)],
          'yrolerne': [('yroler', False)],
          'yrolers': [('yroler', False)],
          'yrpassernes': [('yrpasser', False)],
          'yrpassers': [('yrpasser', False)],
          'yrren': [('yr', False)],
          'yrrers': [('yrrer', False)],
          'yrres': [('yr', False)],
          'yrs': [('yr', False)],
          'yrsten': [('yrste', False)],
          'yrte': [('yrte', False)],
          'yrten': [('yrte', False)],
          'yrtens': [('yrte', False)],
          'yrter': [('yrte', False)],
          'yrterne': [('yrte', False)],
          'yrternes': [('yrte', False)],
          'yrters': [('yrte', False)],
          'yrtes': [('yrte', False)],
          'yrummet': [('yrum', False)],
          'yrummets': [('yrum', False)],
          'yrus': [('yrus', False)],
          'yrusser': [('yrus', False)],
          'yrusserne': [('yrus', False)],
          'yrussernes': [('yrus', False)],
          'yrussers': [('yrus', False)],
          'yrådet': [('yråd', False)],
          'ys': [('ys', False)],
          "ys'": [('ys', False)],
          'ysager': [('ysager', False)],
          'ysagerne': [('ysager', False)],
          'ysagernes': [('ysager', False)],
          'ysagers': [('ysager', False)],
          'ysander': [('ysand', False)],
          'ysanderne': [('ysand', False)],
          'ysandernes': [('ysand', False)],
          'ysene': [('ys', False)],
          'ysenes': [('ys', False)],
          'yser': [('yser', False)],
          'ysere': [('yser', False)],
          'yseren': [('yser', False)],
          'yserens': [('yser', False)],
          'yseres': [('yser', False)],
          'yserne': [('yser', False)],
          'ysernes': [('yser', False)],
          'ysers': [('yse', False)],
          'yset': [('ys', False)],
          'ysets': [('ys', False)],
          'yshave': [('yshav', False)],
          'yshaves': [('yshav', False)],
          'ysier': [('ysier', False)],
          'ysierne': [('ysier', False)],
          'ysiernes': [('ysier', False)],
          'ysiers': [('ysier', False)],
          'ysikkens': [('ysik', False)],
          'ysikker': [('ysik', False)],
          'ysikkernes': [('ysik', False)],
          'ysikkers': [('ysik', False)],
          'ysitternes': [('ysitter', False)],
          'ysitters': [('ysitter', False)],
          'ysium': [('ysium', False)],
          'ysiums': [('ysium', False)],
          'ysken': [('yske', False)],
          'ysker': [('yske', False)],
          'yskerne': [('yske', False)],
          'yskers': [('yske', False)],
          'ysket': [('yske', False)],
          'yskets': [('yske', False)],
          'yskurve': [('yskurv', False)],
          'yskurvens': [('yskurv', False)],
          'yslen': [('yssel', False)],
          'ysler': [('yssel', False)],
          'yslerne': [('ysler', False)],
          'yslernes': [('yssel', False)],
          'yslers': [('ysler', False)],
          'yslet': [('yssel', False)],
          'yslets': [('yssel', False)],
          'ysmer': [('ysme', False)],
          'ysmerne': [('ysme', False)],
          'ysmernes': [('ysme', False)],
          'ysne': [('ysne', False)],
          'ysnes': [('ysne', False)],
          'ysnet': [('ysnet', False)],
          'ysnets': [('ysnet', False)],
          'yspen': [('yspen', False)],
          'yspens': [('yspen', False)],
          'yssen': [('ysse', False)],
          'yssene': [('ys', False)],
          'yssenes': [('ys', False)],
          'yssens': [('ysse', False)],
          'ysser': [('ysser', False)],
          'ysserne': [('ysse', False)],
          'yssernes': [('ys', False)],
          'yssers': [('ys', False)],
          'ysset': [('ys', False)],
          'yssets': [('ys', False)],
          'yssiniernes': [('yssinier', False)],
          'yssiniers': [('yssinier', False)],
          'ystaden': [('ystade', False)],
          'ystadens': [('ystade', False)],
          'ystaller': [('ystal', False)],
          'ystallers': [('ystal', False)],
          'ystave': [('ystav', False)],
          'ystaven': [('ystav', False)],
          'ystavens': [('ystav', False)],
          'ystaves': [('ystav', False)],
          'yste': [('yste', False)],
          'ysteder': [('ysteder', False)],
          'ystederne': [('ysteder', False)],
          'ystedernes': [('ysteder', False)],
          'ysteders': [('ysteder', False)],
          'ysten': [('ysten', False)],
          'ystene': [('yst', False)],
          'ystenes': [('yst', False)],
          'ystens': [('yste', False)],
          'ysteriet': [('ysteri', False)],
          'ysteriets': [('ysteri', False)],
          'ysternes': [('yste', False)],
          'ystes': [('yste', False)],
          'ystikken': [('ystik', False)],
          'ystningers': [('ystning', False)],
          'ystole': [('ystole', False)],
          'ystolen': [('ystole', False)],
          'ystolens': [('ystole', False)],
          'ystoles': [('ystole', False)],
          'ystre': [('yster', False)],
          'ystringens': [('ystring', False)],
          'ystyrer': [('ystyre', False)],
          'ystyrerne': [('ystyre', False)],
          'ystyrernes': [('ystyre', False)],
          'ystyrers': [('ystyre', False)],
          'ystyret': [('ystyre', False)],
          'ystyrets': [('ystyre', False)],
          'yten': [('yte', False)],
          'ytene': [('yte', False)],
          'ytenes': [('yte', False)],
          'ytens': [('yte', False)],
          'yter': [('yter', False)],
          'yterne': [('yte', False)],
          'yternes': [('yter', False)],
          'yters': [('yter', False)],
          'ytias': [('ytia', False)],
          'ytier': [('ytia', False)],
          'ytierne': [('ytia', False)],
          'ytiernes': [('ytia', False)],
          'ytiers': [('ytia', False)],
          'ytinet': [('ytin', False)],
          'ytinets': [('ytin', False)],
          'ytjen': [('ytje', False)],
          'ytjens': [('ytje', False)],
          'ytle': [('ytle', False)],
          'ytlen': [('ytle', False)],
          'ytlens': [('ytle', False)],
          'ytler': [('yttel', False)],
          'ytlerne': [('yttel', False)],
          'ytlernes': [('yttel', False)],
          'ytlers': [('ytle', False)],
          'ytles': [('ytle', False)],
          'ytningen': [('ytning', False)],
          'ytninger': [('ytning', False)],
          'ytningerne': [('ytning', False)],
          'ytningernes': [('ytning', False)],
          'ytonen': [('yton', False)],
          'ytonens': [('yton', False)],
          'ytoner': [('yton', False)],
          'ytonerne': [('yton', False)],
          'ytonernes': [('yton', False)],
          'ytoners': [('yton', False)],
          'ytringens': [('ytring', True)],
          'yts': [('yt', False)],
          'ytte': [('ytte', False)],
          'ytten': [('ytte', False)],
          'yttens': [('ytte', False)],
          'ytter': [('yt', False)],
          'ytteret': [('ytteret', False)],
          'ytterets': [('ytteret', False)],
          'ytterne': [('yt', False)],
          'ytternes': [('ytter', False)],
          'yttes': [('ytte', False)],
          'yttet': [('ytte', False)],
          'yttets': [('ytte', False)],
          'yturen': [('ytur', False)],
          'ytures': [('ytur', False)],
          'ytøjers': [('ytøj', False)],
          'yveler': [('yvel', False)],
          'yvelers': [('yvel', False)],
          'yven': [('yv', False)],
          'yvene': [('yv', False)],
          'yvenes': [('yv', False)],
          'yvens': [('yv', False)],
          'yver': [('yver', False)],
          'yverens': [('yver', False)],
          'yveret': [('yver', True)],
          'yverets': [('yver', True)],
          'yverne': [('yver', True)],
          'yvernes': [('yver', False)],
          'yvers': [('yver', False)],
          'yvetiden': [('yvetiden', False)],
          'yveører': [('yveører', False)],
          'yveørerne': [('yveøre', False)],
          'yveørernes': [('yveører', False)],
          'yveørers': [('yveører', False)],
          'yviser': [('yvise', False)],
          'yviserne': [('yvise', False)],
          'yvisernes': [('yvise', False)],
          'yvisers': [('yvise', False)],
          'yvlen': [('yvel', False)],
          'yvlens': [('yvel', False)],
          'yvler': [('yvel', False)],
          'yvlerne': [('yvel', False)],
          'yvlernes': [('yvel', False)],
          'yvlers': [('yvel', False)],
          'yvs': [('yv', False)],
          'yvstarterne': [('yvstart', False)],
          'yvstarternes': [('yvstart', False)],
          'yvstarters': [('yvstart', False)],
          'yænen': [('yæne', False)],
          'yænens': [('yæne', False)],
          'yæner': [('yæne', False)],
          'yænerne': [('yæne', False)],
          'yænernes': [('yæne', False)],
          'yæskernes': [('yæske', False)],
          'yæter': [('yæter', False)],
          'yæternes': [('yæter', False)],
          'yætylen': [('yætylen', False)],
          'yætylens': [('yætylen', False)],
          "z'er": [('z', True)],
          "z'erne": [('z', True)],
          "z'ernes": [('z', True)],
          "z'ers": [('z', True)],
          'za': [('za', False)],
          'zaen': [('za', False)],
          'zaens': [('za', False)],
          'zaer': [('za', False)],
          'zaerne': [('za', False)],
          'zaernes': [('za', False)],
          'zaers': [('za', False)],
          'zairer': [('zairer', True)],
          'zairerne': [('zairer', True)],
          'zairers': [('zairer', True)],
          'zakken': [('zak', False)],
          'zaks': [('zak', False)],
          'zaner': [('zaner', False)],
          'zanerne': [('zaner', False)],
          'zanernes': [('zaner', False)],
          'zaners': [('zaner', False)],
          'zanierne': [('zanier', False)],
          'zaniers': [('zanier', False)],
          'zapper': [('zapper', True)],
          'zapperne': [('zapper', True)],
          'zappernes': [('zapper', True)],
          'zappers': [('zapper', True)],
          'zarerne': [('zar', True)],
          'zarers': [('zar', True)],
          'zaret': [('zaret', False)],
          'zarets': [('zaret', False)],
          'zariner': [('zarin', False)],
          'zariners': [('zarin', False)],
          'zarussen': [('zarus', False)],
          'zarussens': [('zarus', False)],
          'zarusser': [('zarus', False)],
          'zarusserne': [('zarus', False)],
          'zas': [('za', False)],
          'zballet': [('zballet', False)],
          'zballets': [('zballet', False)],
          'ze': [('ze', False)],
          'zelle': [('zelle', False)],
          'zellen': [('zelle', False)],
          'zellens': [('zelle', False)],
          'zellerne': [('zelle', False)],
          'zellernes': [('zelle', False)],
          'zelles': [('zelle', False)],
          'zen': [('zen', True)],
          'zene': [('z', False)],
          'zenes': [('z', False)],
          'zens': [('zen', True)],
          'zer': [('zer', False)],
          'zers': [('zer', False)],
          'zes': [('ze', False)],
          'zet': [('zet', False)],
          'zets': [('zet', False)],
          'zetten': [('zet', False)],
          'zettens': [('zet', False)],
          'zetter': [('zet', False)],
          'zetterne': [('zet', False)],
          'zetternes': [('zet', False)],
          'zetters': [('zet', False)],
          'zianerne': [('zianer', False)],
          'zianernes': [('zianer', False)],
          'zien': [('zi', False)],
          'ziens': [('zi', False)],
          'zier': [('zi', False)],
          'zierne': [('zi', False)],
          'ziernes': [('zi', False)],
          'ziers': [('zi', False)],
          'zine': [('zine', False)],
          'zinen': [('zine', False)],
          'zinens': [('zine', False)],
          'ziner': [('zin', False)],
          'zinerne': [('zin', False)],
          'zinernes': [('zine', False)],
          'ziners': [('zin', False)],
          'zines': [('zine', False)],
          'zinken': [('zink', True)],
          'zinks': [('zink', True)],
          'zisten': [('zist', False)],
          'zistens': [('zist', False)],
          'zister': [('zist', False)],
          'zisterne': [('zist', False)],
          'zisternes': [('zist', False)],
          'zisters': [('zist', False)],
          'zlen': [('zel', False)],
          'zlens': [('zel', False)],
          'zler': [('zel', False)],
          'zlerne': [('zel', False)],
          'zlernes': [('zel', False)],
          'zlers': [('zel', False)],
          'zlys': [('zlys', False)],
          'zoblen': [('zobel', True)],
          'zobler': [('zobel', True)],
          'zoblerne': [('zobel', True)],
          'zoblernes': [('zobel', True)],
          'zoblers': [('zobel', True)],
          'zoen': [('zo', False)],
          'zoens': [('zoe', False)],
          'zoer': [('zo', False)],
          'zoerne': [('zo', False)],
          'zoernes': [('zo', False)],
          'zoers': [('zo', False)],
          'zoet': [('zo', False)],
          'zoets': [('zo', False)],
          'zonen': [('zone', False)],
          'zonens': [('zone', False)],
          'zoner': [('zone', False)],
          'zonerne': [('zone', False)],
          'zonernes': [('zone', False)],
          'zoners': [('zone', False)],
          'zos': [('zo', False)],
          'ztas': [('zta', False)],
          'zuli': [('zuli', False)],
          'zulis': [('zuli', False)],
          'zurs': [('zur', False)],
          'zværternes': [('zvært', False)],
          'zymer': [('zym', False)],
          'zymers': [('zym', False)],
          'zys': [('zy', False)],
          'zzen': [('zz', False)],
          'zzens': [('zz', False)],
          'zzer': [('z', False)],
          'zzerne': [('z', False)],
          'zzernes': [('z', False)],
          'zzers': [('z', False)],
          'zzi': [('zzi', False)],
          'zzinen': [('zzin', False)],
          'zzinens': [('zzin', False)],
          'zzinernes': [('zzin', False)],
          'zzis': [('zzi', False)],
          'zzoens': [('zzo', False)],
          "Å'erne": [('Å', True)],
          "Æ'erne": [('Æ', True)],
          "Ø'erne": [('Ø', True)],
          "å'erne": [('å', True)],
          'åalgens': [('åalge', False)],
          'åanden': [('åand', False)],
          'åben': [('åbe', False)],
          'åbene': [('åb', False)],
          'åbener': [('åben', False)],
          'åbeners': [('åben', False)],
          'åbenes': [('åb', False)],
          'åbenet': [('åben', False)],
          'åbenets': [('åben', False)],
          'åbens': [('åbe', False)],
          'åber': [('åbe', False)],
          'åberne': [('åbe', False)],
          'åbernes': [('åbe', False)],
          'åbet': [('åb', False)],
          'åbets': [('åb', False)],
          'åbner': [('åbner', True)],
          'åbnerne': [('åbner', True)],
          'åbnernes': [('åbner', True)],
          'åbners': [('åbner', False)],
          'åboer': [('åbo', False)],
          'åboerne': [('åbo', False)],
          'åboernes': [('åbo', False)],
          'åboers': [('åbo', False)],
          'åborgers': [('åborger', False)],
          'åbroder': [('åbroder', False)],
          'åbroderen': [('åbroder', False)],
          'åbroderens': [('åbroder', False)],
          'åbroders': [('åbroder', False)],
          'åbrokken': [('åbrok', False)],
          'åbrokkens': [('åbrok', False)],
          'åbrokker': [('åbrok', False)],
          'åbrokkerne': [('åbrok', False)],
          'åbrokkernes': [('åbrok', False)],
          'åbrokkers': [('åbrok', False)],
          'åbrødre': [('åbroder', False)],
          'åbrødrene': [('åbroder', False)],
          'åbrødrenes': [('åbroder', False)],
          'åbrødres': [('åbroder', False)],
          'åbs': [('åb', False)],
          'åbuks': [('åbuk', False)],
          'åd': [('åd', False)],
          'ådders': [('åd', False)],
          'åde': [('åd', False)],
          'ådele': [('ådele', False)],
          'ådelene': [('ådele', False)],
          'ådelenes': [('ådele', False)],
          'ådeles': [('ådele', False)],
          'åden': [('åd', False)],
          'ådene': [('åd', False)],
          'ådenes': [('åd', False)],
          'ådens': [('åd', False)],
          'åder': [('åde', False)],
          'åderne': [('åde', False)],
          'ådernes': [('åde', False)],
          'ådes': [('åd', False)],
          'ådnet': [('ådnet', False)],
          'ådomme': [('ådom', False)],
          'ådrenge': [('ådrenge', False)],
          'ådrengene': [('ådrenge', False)],
          'ådrengenes': [('ådrenge', False)],
          'ådrenges': [('ådrenge', False)],
          'åds': [('åd', False)],
          'åelsers': [('åelse', False)],
          'åen': [('å', True)],
          'åender': [('ående', False)],
          'åenderne': [('ående', False)],
          'åendernes': [('ående', False)],
          'åenders': [('ående', False)],
          'åene': [('å', False)],
          'åenes': [('å', False)],
          'åens': [('å', True)],
          'åenserne': [('åenser', False)],
          'åer': [('å', True)],
          'åerne': [('å', True)],
          'åernes': [('å', True)],
          'åers': [('å', True)],
          'åg': [('åg', False)],
          'åge': [('åg', False)],
          'ågen': [('åg', False)],
          'ågene': [('åg', True)],
          'ågenes': [('åg', False)],
          'ågens': [('åge', False)],
          'ågenser': [('ågenser', False)],
          'ågensernes': [('ågenser', False)],
          'åger': [('åger', False)],
          'ågere': [('åger', False)],
          'ågeren': [('åger', False)],
          'ågerens': [('åger', False)],
          'ågeres': [('åger', False)],
          'ågerne': [('åge', False)],
          'ågernes': [('åge', False)],
          'ågers': [('åger', True)],
          'åges': [('åge', False)],
          'åget': [('åg', False)],
          'ågets': [('åg', True)],
          'ågnen': [('ågnen', False)],
          'ågnens': [('ågnen', False)],
          'ågs': [('åg', False)],
          'ågænger': [('ågænger', False)],
          'ågængerne': [('ågænger', False)],
          'ågængernes': [('ågænger', False)],
          'ågængers': [('ågænger', False)],
          'åheden': [('åhed', False)],
          'åhedens': [('åhed', False)],
          'åheder': [('åhed', False)],
          'åhederne': [('åhed', False)],
          'åhedernes': [('åhed', False)],
          'åheders': [('åhed', False)],
          'åhejs': [('åhej', False)],
          'åhinde': [('åhind', False)],
          'åhinden': [('åhind', False)],
          'åhindens': [('åhind', False)],
          'åhinder': [('åhind', False)],
          'åhinderne': [('åhind', False)],
          'åhindernes': [('åhind', False)],
          'åhinders': [('åhind', False)],
          'åhindes': [('åhind', False)],
          'åhuen': [('åhue', False)],
          'åhuens': [('åhue', False)],
          'åhus': [('åhus', False)],
          'åhøjder': [('åhøjde', False)],
          'åhøjderne': [('åhøjde', False)],
          'åhøjdernes': [('åhøjde', False)],
          'åhøjders': [('åhøjde', False)],
          'åjorden': [('åjord', False)],
          'åjordens': [('åjord', False)],
          'åkaffer': [('åkaffe', False)],
          'åkafferne': [('åkaffe', False)],
          'åkaffernes': [('åkaffe', False)],
          'åkaffers': [('åkaffe', False)],
          'åkagen': [('åkage', False)],
          'åkagens': [('åkage', False)],
          'åkandernes': [('åkande', True)],
          'åkens': [('åke', False)],
          'åkerne': [('åke', False)],
          'åkernes': [('åke', False)],
          'åkers': [('åke', False)],
          'åklagens': [('åklage', False)],
          'åklager': [('åklage', False)],
          'åklagerne': [('åklage', False)],
          'åklagernes': [('åklage', False)],
          'åklagers': [('åklage', False)],
          'åklokker': [('åklokke', False)],
          'åklokkerne': [('åklokke', False)],
          'åklokkernes': [('åklokke', False)],
          'åklokkers': [('åklokke', False)],
          'åklæderne': [('åklæder', False)],
          'åklædernes': [('åklæder', False)],
          'åkornet': [('åkorn', False)],
          'åkornets': [('åkorn', False)],
          'åkød': [('åkød', False)],
          'ål': [('ål', False)],
          'åle': [('ål', False)],
          'ålen': [('ål', False)],
          'ålene': [('ål', False)],
          'ålenes': [('ål', False)],
          'ålens': [('ål', False)],
          'åler': [('åler', False)],
          'ålere': [('åler', False)],
          'åleren': [('åler', False)],
          'ålerens': [('åler', False)],
          'åleres': [('åler', False)],
          'åleret': [('åler', False)],
          'ålerets': [('åler', False)],
          'ålernes': [('ål', False)],
          'ålers': [('åler', False)],
          'åles': [('ål', False)],
          'ålet': [('ål', False)],
          'ålets': [('ål', False)],
          'ålingers': [('åling', False)],
          'ålisten': [('åliste', False)],
          'ålistens': [('åliste', False)],
          'ålister': [('åliste', False)],
          'ålisterne': [('åliste', False)],
          'ålommen': [('ålomme', False)],
          'ålommens': [('ålomme', False)],
          'ålommer': [('ålomme', False)],
          'ålommerne': [('ålomme', False)],
          'ålommernes': [('ålomme', False)],
          'ålommers': [('ålomme', False)],
          'ålommes': [('ålomme', False)],
          'åls': [('ål', False)],
          'ålys': [('ålys', False)],
          'åmejsen': [('åmejse', False)],
          'åmejsens': [('åmejse', False)],
          'åmejser': [('åmejse', False)],
          'åmejserne': [('åmejse', False)],
          'åmejsernes': [('åmejse', False)],
          'åmejsers': [('åmejse', False)],
          'åminder': [('åminder', False)],
          'åminderne': [('åminder', False)],
          'åmindernes': [('åminder', False)],
          'åminders': [('åminder', False)],
          'åmodet': [('åmod', False)],
          'åmodets': [('åmod', False)],
          'åmunke': [('åmunke', False)],
          'åmunken': [('åmunke', False)],
          'åmunkens': [('åmunke', False)],
          'åmunkes': [('åmunke', False)],
          'åmælken': [('åmælk', False)],
          'åmælkens': [('åmælk', False)],
          'åmænd': [('åmand', False)],
          'åmændene': [('åmand', False)],
          'ån': [('ån', False)],
          'åndarbejdernes': [('åndarbejde', False)],
          'åndarbejders': [('åndarbejde', False)],
          'ånde': [('ånde', False)],
          'ånden': [('ånd', True), ('ånde', True)],
          'åndens': [('ånd', True), ('ånde', True)],
          'ånder': [('ånd', False)],
          'ånderne': [('ånd', False)],
          'åndernes': [('ånd', False)],
          'ånders': [('ånd', True)],
          'åndes': [('ånde', False)],
          'åndværker': [('åndværker', False)],
          'åndværkerne': [('åndværker', False)],
          'åndværkernes': [('åndværker', False)],
          'åndværkers': [('åndværker', False)],
          'åndører': [('åndører', False)],
          'åndørers': [('åndører', False)],
          'åneder': [('åned', False)],
          'ånederne': [('åned', False)],
          'ånedernes': [('åned', False)],
          'åneders': [('åned', False)],
          'ånen': [('ån', False)],
          'ånene': [('ån', False)],
          'ånenes': [('ån', False)],
          'ånens': [('ån', False)],
          'åner': [('åner', False)],
          'ånerne': [('åner', False)],
          'ånernes': [('ån', False)],
          'åners': [('ån', False)],
          'ånesten': [('ånesten', False)],
          'ånet': [('ån', False)],
          'ånets': [('ån', False)],
          'åningers': [('åning', False)],
          'åns': [('ån', False)],
          'åntager': [('åntager', False)],
          'åntagerne': [('åntager', False)],
          'åntagernes': [('åntager', False)],
          'åntagers': [('åntager', False)],
          'åolierne': [('åolie', False)],
          'åoliers': [('åolie', False)],
          'åpakker': [('åpakke', False)],
          'åpakkerne': [('åpakke', False)],
          'åpakkernes': [('åpakke', False)],
          'åpakkers': [('åpakke', False)],
          'åpiger': [('åpiger', False)],
          'åpigerne': [('åpiger', False)],
          'åpigernes': [('åpiger', False)],
          'åpigers': [('åpiger', False)],
          'åpils': [('åpil', False)],
          'åplanet': [('åplanet', False)],
          'åplanets': [('åplanet', False)],
          'år': [('år', False)],
          'årbens': [('årben', False)],
          'årde': [('årde', False)],
          'ården': [('årde', False)],
          'årdens': [('årde', False)],
          'årderne': [('årde', False)],
          'årders': [('årde', False)],
          'årdes': [('årde', False)],
          'åre': [('åre', True)],
          'åren': [('åre', False)],
          'årene': [('år', False)],
          'årenes': [('år', False)],
          'årens': [('åre', True)],
          'årer': [('åre', True)],
          'årerne': [('åre', True)],
          'årernes': [('åre', True)],
          'årers': [('åre', True)],
          'åres': [('åre', False)],
          'året': [('år', False)],
          'årets': [('år', False)],
          'århals': [('århals', False)],
          'åringer': [('åring', False)],
          'åringerne': [('åring', False)],
          'åringernes': [('åring', False)],
          'åringers': [('åring', False)],
          'åris': [('åris', False)],
          'års': [('år', False)],
          'årsagens': [('årsag', False)],
          'årsager': [('årsag', False)],
          'årsagerne': [('årsag', False)],
          'årsagernes': [('årsag', False)],
          'årtier': [('årti', True)],
          'årtierne': [('årti', True)],
          'årtiernes': [('årti', True)],
          'årtiers': [('årti', True)],
          'årtiet': [('årti', True)],
          'årtiets': [('årti', True)],
          'ås': [('å', True), ('ås', True)],
          "ås'": [('ås', False)],
          'åse': [('ås', False)],
          'åsejerne': [('åsej', False)],
          'åsen': [('ås', False)],
          'åsene': [('ås', False)],
          'åsenes': [('ås', False)],
          'åsens': [('ås', False)],
          'åsere': [('åser', False)],
          'åseren': [('åser', False)],
          'åserens': [('åser', False)],
          'åseres': [('åser', False)],
          'åserier': [('åseri', False)],
          'åserierne': [('åseri', False)],
          'åseriernes': [('åseri', False)],
          'åseriers': [('åseri', False)],
          'åsers': [('åse', False)],
          'åses': [('ås', False)],
          'åset': [('ås', False)],
          'åsets': [('ås', False)],
          'åseøjne': [('åseøjne', False)],
          'åseøjnene': [('åseøjne', False)],
          'åseøjnenes': [('åseøjne', False)],
          'åseøjnes': [('åseøjne', False)],
          'åsken': [('åske', False)],
          'åsker': [('åske', False)],
          'åskerne': [('åske', False)],
          'åskers': [('åske', False)],
          'åskillinger': [('åskillinger', False)],
          'åskillingerne': [('åskillinger', False)],
          'åskillingernes': [('åskillinger', False)],
          'åskillingers': [('åskillinger', False)],
          'åsparer': [('åsparer', False)],
          'åsparerne': [('åsparer', False)],
          'åsparernes': [('åsparer', False)],
          'åsparers': [('åsparer', False)],
          'åspids': [('åspids', False)],
          'åspidser': [('åspids', False)],
          'åsten': [('åsten', False)],
          'åstens': [('åsten', False)],
          'åstrømperne': [('åstrømpe', False)],
          'åstykker': [('åstykker', False)],
          'åstykkerne': [('åstykker', False)],
          'åstykkernes': [('åstykker', False)],
          'åstykkers': [('åstykker', False)],
          'åsyren': [('åsyre', False)],
          'åsyrens': [('åsyre', False)],
          'åsætter': [('åsætter', False)],
          'åtage': [('åtag', False)],
          'åtages': [('åtag', False)],
          'åtaler': [('åtale', False)],
          'åtalerne': [('åtale', False)],
          'åtalernes': [('åtale', False)],
          'åtalers': [('åtale', False)],
          'åten': [('åt', False)],
          'åtens': [('åt', False)],
          'åter': [('åt', False)],
          'återne': [('åt', False)],
          'åternes': [('åt', False)],
          'åters': [('åt', False)],
          'åtids': [('åtid', False)],
          'åtoner': [('åtone', False)],
          'åtonerne': [('åtone', False)],
          'åtonernes': [('åtone', False)],
          'åtoners': [('åtone', False)],
          'åts': [('åt', False)],
          'åtte': [('åtte', False)],
          'åtten': [('åtte', False)],
          'åttens': [('åtte', False)],
          'åtter': [('åt', False)],
          'åtterne': [('åt', False)],
          'åtternes': [('åtte', False)],
          'åtters': [('åtte', False)],
          'åttes': [('åtte', False)],
          'åturen': [('åtur', False)],
          'åtures': [('åtur', False)],
          'åtåren': [('åtår', False)],
          'åtårens': [('åtår', False)],
          'åvarers': [('åvare', False)],
          'åænders': [('åand', False)],
          'åøens': [('åø', False)],
          'åøer': [('åø', False)],
          'åøje': [('åøje', False)],
          'åøjen': [('åøje', False)],
          'åøjens': [('åøje', False)],
          'åøjers': [('åøje', False)],
          'åøjes': [('åøje', False)],
          'åøs': [('åø', False)],
          "æ'erne": [('æ', True)],
          'æa': [('æa', False)],
          'æaen': [('æa', False)],
          'æaene': [('æa', False)],
          'æaenes': [('æa', False)],
          'æaens': [('æa', False)],
          'æaer': [('æa', False)],
          'æaerne': [('æa', False)],
          'æaernes': [('æa', False)],
          'æaers': [('æa', False)],
          'æas': [('æa', False)],
          'æbben': [('æb', False)],
          'æben': [('æbe', False)],
          'æbender': [('æbende', False)],
          'æbendernes': [('æbende', False)],
          'æbenders': [('æbende', False)],
          'æbene': [('æb', False)],
          'æbenes': [('æb', False)],
          'æbenet': [('æben', False)],
          'æbenets': [('æben', False)],
          'æbens': [('æb', False)],
          'æber': [('æbe', False)],
          'æberne': [('æber', False)],
          'æbernes': [('æbe', False)],
          'æbers': [('æber', False)],
          'æberstens': [('æbersten', False)],
          'æbet': [('æb', False)],
          'æbets': [('æb', False)],
          'æble': [('æble', False)],
          'æblens': [('æbel', False)],
          'æbler': [('æble', True)],
          'æblerne': [('æble', False)],
          'æblernes': [('æble', False)],
          'æblers': [('æble', False)],
          'æbles': [('æble', False)],
          'æbner': [('æbne', False)],
          'æbnerne': [('æbne', False)],
          'æbnernes': [('æbne', False)],
          'æbners': [('æbne', False)],
          'æbs': [('æb', False)],
          'æbuks': [('æbuk', False)],
          'æbukser': [('æbukser', False)],
          'æbukserne': [('æbukser', False)],
          'æbuksernes': [('æbukser', False)],
          'æbuksers': [('æbukser', False)],
          'æbyer': [('æbyer', False)],
          'æbyerne': [('æbyer', False)],
          'æbyernes': [('æbyer', False)],
          'æbyers': [('æbyer', False)],
          'æbælter': [('æbælte', False)],
          'æbælterne': [('æbælte', False)],
          'æbælternes': [('æbælte', False)],
          'æbælters': [('æbælte', False)],
          'æbæltet': [('æbælte', False)],
          'æbæltets': [('æbælte', False)],
          'æcen': [('æcen', False)],
          'æcenen': [('æcen', False)],
          'æcenens': [('æcen', False)],
          'æcener': [('æcen', False)],
          'æcenerne': [('æcen', False)],
          'æcenernes': [('æcen', False)],
          'æceners': [('æcen', False)],
          'æcens': [('æcen', False)],
          "æces'": [('æces', False)],
          'æcisterne': [('æcist', False)],
          'æcisternes': [('æcist', False)],
          'æd': [('æd', False)],
          'æden': [('æde', True)],
          'ædene': [('æd', False)],
          'ædenes': [('æd', False)],
          'ædens': [('æde', True)],
          'æder': [('æder', True)],
          'ædere': [('æder', False)],
          'æderen': [('æder', False)],
          'æderens': [('æder', False)],
          'æderes': [('æder', False)],
          'æderet': [('æder', False)],
          'æderets': [('æder', False)],
          'æderne': [('æder', True)],
          'ædernes': [('æder', True)],
          'æders': [('æder', False)],
          'ædes': [('æde', False)],
          'ædesten': [('ædesten', False)],
          'ædet': [('æde', True)],
          'ædets': [('æde', False)],
          'ædiater': [('ædiater', False)],
          'ædiaterne': [('ædiater', False)],
          'ædiaters': [('ædiater', False)],
          'ædier': [('ædi', False)],
          'ædiernes': [('ædi', False)],
          'ædiken': [('ædiken', False)],
          'ædikens': [('ædiken', False)],
          'ædiker': [('ædiker', False)],
          'ædikerne': [('ædiker', False)],
          'ædikernes': [('ædiker', False)],
          'ædikers': [('ædiker', False)],
          'ædis': [('ædi', False)],
          'ædlerne': [('ædler', False)],
          'ædlernes': [('ædler', False)],
          'æds': [('æd', False)],
          'ædskifterne': [('ædskifte', False)],
          'ædskifternes': [('ædskifte', False)],
          'ædskifters': [('ædskifte', False)],
          'æene': [('æ', False)],
          'æenes': [('æ', False)],
          'æer': [('æer', False)],
          'æerne': [('æer', False)],
          'æernes': [('æer', False)],
          'æfer': [('æfer', False)],
          'æferes': [('æfer', False)],
          'æferne': [('æfer', False)],
          'æfernes': [('æfer', False)],
          'æffene': [('æf', False)],
          'æffenes': [('æf', False)],
          'æffer': [('æffer', False)],
          'æfferens': [('æffer', False)],
          'æffernes': [('æffer', False)],
          'æffers': [('æffer', False)],
          'æffets': [('æf', False)],
          'æfikken': [('æfikke', False)],
          'æfikkerne': [('æfikke', False)],
          'æflisen': [('æflis', False)],
          'æflisens': [('æflis', False)],
          'æfte': [('æfte', False)],
          'æfter': [('æft', False)],
          'æfternes': [('æfte', False)],
          'æfters': [('æfte', False)],
          'æftes': [('æfte', False)],
          'æftet': [('æfte', False)],
          'æftets': [('æfte', False)],
          'æg': [('æg', False)],
          'ægbroderen': [('ægbroder', False)],
          'ægbroderens': [('ægbroder', False)],
          'ægder': [('ægd', False)],
          'ægderne': [('ægd', False)],
          'æge': [('æg', False)],
          'ægen': [('æg', False)],
          'ægene': [('æg', False)],
          'ægenes': [('æg', False)],
          'ægens': [('æge', False)],
          'æger': [('æger', False)],
          'ægere': [('æger', False)],
          'ægeren': [('æger', False)],
          'ægerens': [('æger', False)],
          'ægeres': [('æger', False)],
          'ægeret': [('æger', False)],
          'ægerets': [('æger', False)],
          'ægerne': [('æge', False)],
          'ægernes': [('æge', False)],
          'ægers': [('æge', False)],
          'æges': [('æge', False)],
          'ægeskiftet': [('ægeskift', False)],
          'ægeskiftets': [('ægeskift', False)],
          'æget': [('æg', False)],
          'ægets': [('æg', False)],
          'ægge': [('æg', True)],
          'æggen': [('æg', True)],
          'æggenes': [('æg', False)],
          'æggens': [('æg', True)],
          'ægger': [('ægge', False)],
          'æggerne': [('ægger', False)],
          'æggernes': [('ægger', False)],
          'æggers': [('ægger', False)],
          'ægges': [('æg', True)],
          'æglens': [('ægl', False)],
          'ægler': [('ægler', False)],
          'æglerne': [('ægler', False)],
          'æglernes': [('ægler', False)],
          'æglers': [('ægler', False)],
          'ægrene': [('æger', False)],
          'ægrenes': [('æger', False)],
          'ægres': [('æger', False)],
          'ægs': [('æg', False)],
          'ægte': [('ægte', False)],
          'ægten': [('ægte', False)],
          'ægtens': [('ægte', False)],
          'ægter': [('ægter', False)],
          'ægterne': [('ægter', False)],
          'ægternes': [('ægter', False)],
          'ægters': [('ægte', False)],
          'ægtes': [('ægte', False)],
          'æh': [('æh', False)],
          'æhas': [('æhase', False)],
          'æhasen': [('æhase', False)],
          'æhæs': [('æhæ', False)],
          'æhøjder': [('æhøjde', False)],
          'æhøjderne': [('æhøjde', False)],
          'æhøjdernes': [('æhøjde', False)],
          'æhøjders': [('æhøjde', False)],
          'æismen': [('æisme', False)],
          'æk': [('æk', False)],
          'ækagen': [('ækage', False)],
          'ækagens': [('ækage', False)],
          'ækalier': [('ækalier', False)],
          'ækalierne': [('ækalier', False)],
          'ækaliers': [('ækalier', False)],
          'ækarve': [('ækarve', False)],
          'ækarven': [('ækarve', False)],
          'ækarvens': [('ækarve', False)],
          'ækarver': [('ækarve', False)],
          'ækarverne': [('ækarve', False)],
          'ækarvernes': [('ækarve', False)],
          'ækarvers': [('ækarve', False)],
          'ækarves': [('ækarve', False)],
          'æken': [('æken', False)],
          'ækens': [('æken', False)],
          'æker': [('æker', False)],
          'ækere': [('æker', False)],
          'ækeren': [('æker', False)],
          'ækerens': [('æker', False)],
          'ækeres': [('æker', False)],
          'ækerne': [('æker', False)],
          'ækernes': [('æker', False)],
          'ækers': [('æker', False)],
          'æket': [('æk', False)],
          'ækets': [('æk', False)],
          'ække': [('ække', False)],
          'ækkens': [('æk', False)],
          'ækkerne': [('ækker', False)],
          'ækkernes': [('æk', False)],
          'ækkers': [('æk', False)],
          'ækkes': [('ække', False)],
          'ækket': [('æk', False)],
          'ækkets': [('æk', False)],
          'æklagen': [('æklagen', False)],
          'æklagens': [('æklagen', False)],
          'æklen': [('ækkel', False)],
          'ækler': [('ækkel', False)],
          'æklerne': [('ækkel', False)],
          'æklernes': [('ækkel', False)],
          'æklers': [('ækkel', False)],
          'æklinge': [('ækling', False)],
          'æklingen': [('ækling', False)],
          'æklingens': [('ækling', False)],
          'æklinger': [('ækling', False)],
          'æklingerne': [('ækling', False)],
          'æklingernes': [('ækling', False)],
          'æklingers': [('ækling', False)],
          'æklinges': [('ækling', False)],
          'æklister': [('ækliste', False)],
          'æklisternes': [('ækliste', False)],
          'æklisters': [('ækliste', False)],
          'æknerne': [('æken', False)],
          'ækronen': [('ækrone', False)],
          'æks': [('æk', False)],
          'æksaks': [('æksaks', False)],
          'ækslerne': [('æksel', False)],
          'ækslernes': [('æksel', False)],
          'ækslers': [('æksel', False)],
          'æksten': [('ækst', False)],
          'ækstens': [('ækst', False)],
          'ækster': [('ækst', False)],
          'æksterne': [('ækst', False)],
          'æksternes': [('ækst', False)],
          'æksters': [('ækst', False)],
          'ækvinde': [('ækvind', False)],
          'ækvinden': [('ækvind', False)],
          'ækvindens': [('ækvind', False)],
          'ækvindes': [('ækvind', False)],
          'æl': [('æl', False)],
          'ælariet': [('ælarie', False)],
          'ælariets': [('ælarie', False)],
          'ælatens': [('ælat', False)],
          'ælats': [('ælat', False)],
          'ælben': [('ælben', False)],
          'ælbens': [('ælben', False)],
          'ælde': [('ælde', False)],
          'ælden': [('ælde', False)],
          'ældene': [('æld', False)],
          'ældenes': [('ælde', False)],
          'ældens': [('ælde', False)],
          'ælder': [('ælde', False)],
          'ælders': [('ælde', False)],
          'ældes': [('ælde', False)],
          'ældet': [('ælde', False)],
          'ældets': [('ælde', False)],
          'ældre': [('ælder', False)],
          'æle': [('æl', False)],
          'ælen': [('æl', False)],
          'ælene': [('æl', False)],
          'ælenes': [('æl', False)],
          'ælens': [('æl', False)],
          'æler': [('æl', False)],
          'ælere': [('æler', False)],
          'æleren': [('æler', False)],
          'ælerens': [('æler', False)],
          'æleres': [('æler', False)],
          'ælerne': [('æl', False)],
          'ælernes': [('æl', False)],
          'ælers': [('æl', False)],
          'æles': [('æl', False)],
          'ælet': [('æle', False)],
          'ælets': [('æle', False)],
          'ælgen': [('ælg', False)],
          'ælgens': [('ælg', False)],
          'ælgerne': [('ælger', False)],
          'ælgernes': [('ælger', False)],
          'ælgers': [('ælger', False)],
          'ælingers': [('æling', False)],
          'ælke': [('ælke', False)],
          'ælken': [('ælke', False)],
          'ælkens': [('ælke', False)],
          'ælker': [('ælke', False)],
          'ælkerne': [('ælke', False)],
          'ælkes': [('ælke', False)],
          'ælle': [('ælle', False)],
          'ælleder': [('ælled', False)],
          'ællederne': [('ælled', False)],
          'ælledernes': [('ælled', False)],
          'ælleders': [('ælled', False)],
          'ællemanden': [('ællemand', False)],
          'ællemandens': [('ællemand', False)],
          'ællen': [('ælle', False)],
          'ællene': [('æl', False)],
          'ællenes': [('æl', False)],
          'ællens': [('æl', False)],
          'æller': [('ælle', False)],
          'ællerne': [('æller', False)],
          'ællernes': [('æller', False)],
          'ællers': [('ælle', False)],
          'ælles': [('ælle', False)],
          'ællet': [('æl', False)],
          'ællets': [('æl', False)],
          'ællinger': [('ælling', False)],
          'ællingerne': [('ælling', False)],
          'ællingernes': [('ælling', False)],
          'ælme': [('ælme', False)],
          'ælmen': [('ælme', False)],
          'ælmens': [('ælme', False)],
          'ælmer': [('ælm', False)],
          'ælmerne': [('ælme', False)],
          'ælmernes': [('ælme', False)],
          'ælmers': [('ælme', False)],
          'ælmes': [('ælme', False)],
          'ælpernes': [('ælper', False)],
          'ælpers': [('ælper', False)],
          'æls': [('æl', False)],
          'ælte': [('ælte', False)],
          'ælten': [('ælte', True)],
          'æltens': [('ælte', True)],
          'æltes': [('ælte', False)],
          'æltet': [('ælte', False)],
          'æltets': [('ælte', False)],
          'æløbers': [('æløber', False)],
          'æmassens': [('æmasse', False)],
          'æmasserne': [('æmasse', False)],
          'æmis': [('æmi', False)],
          'æmissen': [('æmis', False)],
          'æmissens': [('æmis', False)],
          'æmisser': [('æmis', False)],
          'æmisserne': [('æmis', False)],
          'æmissernes': [('æmis', False)],
          'æmissers': [('æmis', False)],
          'æmme': [('æmme', False)],
          'æmmelsers': [('æmmelse', False)],
          'æmmen': [('æmme', False)],
          'æmmens': [('æmme', False)],
          'æmmer': [('æmme', False)],
          'æmmerne': [('æmme', False)],
          'æmmernes': [('æmmer', False)],
          'æmmers': [('æmmer', False)],
          'æmmes': [('æmme', False)],
          'æmnerne': [('æmner', False)],
          'æmners': [('æmner', False)],
          'æmonen': [('æmon', False)],
          'æmonens': [('æmon', False)],
          'æmoner': [('æmon', False)],
          'æmonerne': [('æmon', False)],
          'æmonernes': [('æmon', False)],
          'æmoners': [('æmon', False)],
          'æmpe': [('æmpe', False)],
          'æmpen': [('æmpe', False)],
          'æmpens': [('æmpe', False)],
          'æmper': [('æmper', False)],
          'æmpernes': [('æmper', False)],
          'æmpers': [('æmper', False)],
          'æmpes': [('æmpe', False)],
          'æmænd': [('æmand', False)],
          'æmænds': [('æmand', False)],
          'æn': [('æn', False)],
          'ænader': [('ænade', False)],
          'ænde': [('ænde', False)],
          'ænden': [('ænde', False)],
          'ændens': [('ænde', False)],
          'ænder': [('and', False)],
          'ænderne': [('and', False)],
          'ændernes': [('and', False)],
          'ænders': [('and', True)],
          'ændes': [('ænde', False)],
          'ændet': [('ænde', False)],
          'ændets': [('ænde', False)],
          'ændlerne': [('ændel', False)],
          'ændlernes': [('ændel', False)],
          'ænene': [('æn', False)],
          'ænenes': [('æn', False)],
          'æners': [('æne', False)],
          'ænet': [('æn', False)],
          'ænets': [('æn', False)],
          'ænge': [('ænge', False)],
          'ængen': [('ænge', False)],
          'ængens': [('ænge', False)],
          'ænger': [('ænger', False)],
          'ængerne': [('ænger', False)],
          'ænges': [('ænge', False)],
          'ænget': [('ænge', False)],
          'ængets': [('ænge', False)],
          'ænglen': [('ængel', False)],
          'ænglerne': [('ængel', False)],
          'ænglernes': [('ængel', False)],
          'ænglers': [('ængel', False)],
          'æniker': [('æniker', False)],
          'ænikerne': [('æniker', False)],
          'ænikernes': [('æniker', False)],
          'ænikers': [('æniker', False)],
          'æningers': [('æning', False)],
          'ænke': [('ænke', False)],
          'ænken': [('ænke', False)],
          'ænkens': [('ænk', False)],
          'ænker': [('ænke', False)],
          'ænkerne': [('ænker', False)],
          'ænkernes': [('ænker', False)],
          'ænkers': [('ænker', False)],
          'ænkes': [('ænke', False)],
          'ænket': [('ænk', False)],
          'ænkets': [('ænk', False)],
          'æns': [('æn', False)],
          'ænse': [('ænse', False)],
          'ænsen': [('ænse', False)],
          'ænsens': [('ænse', False)],
          'ænser': [('ænse', False)],
          'ænserne': [('ænse', False)],
          'ænsernes': [('ænse', False)],
          'ænsers': [('ænse', False)],
          'ænses': [('ænse', False)],
          'ænter': [('ænt', False)],
          'æppe': [('æppe', False)],
          'æppen': [('æppe', False)],
          'æppens': [('æppe', False)],
          'æpper': [('æppe', False)],
          'æpperens': [('æpperens', False)],
          'æpperne': [('æppe', False)],
          'æppers': [('æppe', False)],
          'æppet': [('æp', False)],
          'æppets': [('æp', False)],
          'æps': [('æp', False)],
          'ær': [('ær', False)],
          'ærbanen': [('ærbane', False)],
          'ærbanens': [('ærbane', False)],
          'ærbaner': [('ærbane', False)],
          'ærbanerne': [('ærbane', False)],
          'ærbanernes': [('ærbane', False)],
          'ærbaners': [('ærbane', False)],
          'ærbens': [('ærben', False)],
          'ærbørn': [('ærbarn', False)],
          'ærbørnene': [('ærbarn', False)],
          'ærbørnenes': [('ærbarn', False)],
          'ærbørns': [('ærbarn', False)],
          'ærde': [('ærde', False)],
          'ærder': [('ærd', False)],
          'ærderne': [('ærde', False)],
          'ærdernes': [('ærd', False)],
          'ærders': [('ærde', False)],
          'ærdes': [('ærde', False)],
          'ærdet': [('ærde', False)],
          'ærdets': [('ærde', False)],
          'ærdien': [('ærdi', False)],
          'ærdiens': [('ærdi', False)],
          'ærdierne': [('ærdi', False)],
          'ærdiers': [('ærdi', False)],
          'ære': [('ære', True)],
          'ærelser': [('ærelse', False)],
          'ærelserne': [('ærelse', False)],
          'ærelsernes': [('ærelse', False)],
          'æren': [('ære', True), ('ær', True)],
          'ærendet': [('ærende', False)],
          'ærendets': [('ærende', False)],
          'ærene': [('ær', False)],
          'ærenes': [('ær', False)],
          'ærens': [('ære', True), ('ær', True)],
          'ærenser': [('ærens', False)],
          'ærenserne': [('ærens', False)],
          'ærensernes': [('ærens', False)],
          'ærensers': [('ærens', False)],
          'æreposen': [('ærepose', False)],
          'æreposens': [('ærepose', False)],
          'æreposer': [('ærepose', False)],
          'æreposerne': [('ærepose', False)],
          'æreposernes': [('ærepose', False)],
          'æreposers': [('ærepose', False)],
          'ærer': [('ær', True)],
          'ærerne': [('ær', False)],
          'ærernes': [('ær', False)],
          'ærers': [('ær', True)],
          'æres': [('ære', False)],
          'æresier': [('æresi', False)],
          'æresiernes': [('æresi', False)],
          'æresiers': [('æresi', False)],
          'æresten': [('æreste', False)],
          'ærestens': [('æreste', False)],
          'ærester': [('æreste', False)],
          'æresterne': [('æreste', False)],
          'æresternes': [('æreste', False)],
          'æresters': [('æreste', False)],
          'æret': [('ær', False)],
          'ærets': [('ær', False)],
          'ærge': [('ærge', False)],
          'ærgen': [('ærge', False)],
          'ærger': [('ærge', False)],
          'ærgernes': [('ærge', False)],
          'ærgers': [('ærge', False)],
          'ærges': [('ærge', False)],
          'ærget': [('ærge', False)],
          'ærgets': [('ærge', False)],
          'ærhedens': [('ærhed', False)],
          'ærien': [('ærie', False)],
          'æriens': [('ærie', False)],
          'ærier': [('ærie', False)],
          'ærierne': [('ærie', False)],
          'æriernes': [('ærie', False)],
          'æriers': [('ærie', False)],
          'æries': [('ærie', False)],
          'æringer': [('æring', False)],
          'æringerne': [('æring', False)],
          'æringernes': [('æring', False)],
          'æringers': [('æring', False)],
          'ærke': [('ærke', False)],
          'ærken': [('ærke', False)],
          'ærkens': [('ærk', False)],
          'ærker': [('ærker', False)],
          'ærkerne': [('ærke', False)],
          'ærkernes': [('ærke', False)],
          'ærkers': [('ærke', False)],
          'ærkes': [('ærke', False)],
          'ærket': [('ærke', False)],
          'ærkets': [('ærke', False)],
          'ærme': [('ærme', False)],
          'ærmen': [('ærme', False)],
          'ærmens': [('ærme', False)],
          'ærmer': [('ærme', False)],
          'ærmerne': [('ærme', True)],
          'ærmernes': [('ærme', True)],
          'ærmers': [('ærme', True)],
          'ærmes': [('ærme', False)],
          'ærmets': [('ærme', False)],
          'ærne': [('ærne', False)],
          'ærnen': [('ærne', False)],
          'ærnens': [('ærne', False)],
          'ærner': [('ærne', False)],
          'ærnerne': [('ærner', False)],
          'ærnernes': [('ærne', False)],
          'ærners': [('ærner', False)],
          'ærnes': [('ærne', False)],
          'ærpe': [('ærpe', False)],
          'ærpen': [('ærpe', False)],
          'ærpens': [('ærpe', False)],
          'ærper': [('ærpe', False)],
          'ærperne': [('ærpe', False)],
          'ærre': [('ærre', False)],
          'ærren': [('ær', False)],
          'ærrens': [('ærre', False)],
          'ærrer': [('ærre', False)],
          'ærrerne': [('ærre', False)],
          'ærrernes': [('ærre', False)],
          'ærret': [('ær', False)],
          'ærrets': [('ær', False)],
          'ærs': [('ær', False)],
          'ærsaften': [('ærsaft', False)],
          'ærsaftens': [('ærsaft', False)],
          'ærsets': [('ærs', False)],
          'ærsker': [('ærsker', False)],
          'ærskerne': [('ærsker', False)],
          'ærskers': [('ærsker', False)],
          'ærstene': [('ærsten', False)],
          'ærstens': [('ærsten', False)],
          'ærte': [('ærte', False)],
          'ærten': [('ært', True)],
          'ærtens': [('ært', True)],
          'ærter': [('ært', True)],
          'ærterne': [('ært', True)],
          'ærternes': [('ært', False)],
          'ærters': [('ært', True)],
          'ærtes': [('ærte', False)],
          'ærtoget': [('ærtog', False)],
          'ærtogets': [('ærtog', False)],
          'ærveje': [('ærvej', False)],
          'ærvejene': [('ærvej', False)],
          'ærvejenes': [('ærvej', False)],
          'ærver': [('ærve', False)],
          'ærverne': [('ærve', False)],
          'ærvernes': [('ærver', False)],
          'ærvers': [('ærver', False)],
          'ærøllens': [('ærøl', False)],
          'ærøllerne': [('ærøl', False)],
          'ærøllernes': [('ærøl', False)],
          'ærøret': [('ærør', False)],
          'ærørets': [('ærør', False)],
          'æs': [('æs', False)],
          "æs'": [('æs', False)],
          'æsaks': [('æsaks', False)],
          'æselen': [('æsel', False)],
          'æselens': [('æsel', False)],
          'æselørerne': [('æseløre', True)],
          'æselørers': [('æseløre', True)],
          'æsen': [('æsen', False)],
          'æsene': [('æs', False)],
          'æsener': [('æsen', False)],
          'æsenerne': [('æsen', False)],
          'æsenernes': [('æsen', False)],
          'æseners': [('æsen', False)],
          'æsenes': [('æs', False)],
          'æsens': [('æsen', False)],
          'æser': [('æser', False)],
          'æsere': [('æser', False)],
          'æseren': [('æser', False)],
          'æserens': [('æser', False)],
          'æseres': [('æser', False)],
          'æserne': [('æser', False)],
          'æsernes': [('æser', False)],
          'æsers': [('æse', False)],
          'æses': [('æses', False)],
          "æses'": [('æses', False)],
          'æset': [('æs', False)],
          'æsets': [('æs', False)],
          'æshoppen': [('æshoppe', False)],
          'æshoppens': [('æshoppe', False)],
          'æshopper': [('æshoppe', False)],
          'æshopperne': [('æshoppe', False)],
          'æshoppernes': [('æshoppe', False)],
          'æshoppers': [('æshoppe', False)],
          'æsidierne': [('æsidie', False)],
          'æsidiernes': [('æsidie', False)],
          'æsidiers': [('æsidie', False)],
          'æsiner': [('æsine', False)],
          'æsinerne': [('æsine', False)],
          'æsinernes': [('æsine', False)],
          'æsiners': [('æsine', False)],
          'æsingers': [('æsing', False)],
          'æsium': [('æsium', False)],
          'æsiums': [('æsium', False)],
          'æskallen': [('æskal', False)],
          'æskallens': [('æskal', False)],
          'æskaller': [('æskal', False)],
          'æskallerne': [('æskal', False)],
          'æskallernes': [('æskal', False)],
          'æskallers': [('æskal', False)],
          'æske': [('æske', False)],
          'æsken': [('æske', False)],
          'æskene': [('æsk', False)],
          'æskens': [('æske', True)],
          'æsker': [('æske', False)],
          'æskerne': [('æske', True)],
          'æskernes': [('æske', True)],
          'æskers': [('æske', False)],
          'æskes': [('æske', False)],
          'æsket': [('æsk', False)],
          'æskets': [('æsk', False)],
          'æskos': [('æsko', False)],
          'æskure': [('æskur', False)],
          'æskures': [('æskur', False)],
          'æskurs': [('æskur', False)],
          'æslens': [('æsel', False)],
          'æsler': [('æsel', False)],
          'æslinger': [('æsling', False)],
          'æslingerne': [('æsling', False)],
          'æslingernes': [('æsling', False)],
          'æslingers': [('æsling', False)],
          'æsnerne': [('æsen', False)],
          'æsoner': [('æson', False)],
          'æsonerne': [('æson', False)],
          'æsonernes': [('æson', False)],
          'æsoners': [('æson', False)],
          'æssene': [('ås', False)],
          'æssenes': [('ås', False)],
          'æsser': [('æsser', False)],
          'æsserne': [('æsser', False)],
          'æssernes': [('æs', False)],
          'æssers': [('æs', False)],
          'æsset': [('æs', False)],
          'æssets': [('æs', False)],
          'æstammen': [('æstamme', False)],
          'æstammens': [('æstamme', False)],
          'æstammer': [('æstamme', False)],
          'æstammerne': [('æstamme', False)],
          'æstammernes': [('æstamme', False)],
          'æstammers': [('æstamme', False)],
          'æste': [('æste', False)],
          'æsten': [('æst', False)],
          'æstene': [('æst', False)],
          'æstenes': [('æst', False)],
          'æstens': [('æste', False)],
          'æsterier': [('æsteri', False)],
          'æsterierne': [('æsteri', False)],
          'æsteriernes': [('æsteri', False)],
          'æsteriers': [('æsteri', False)],
          'æsteriet': [('æsteri', False)],
          'æsteriets': [('æsteri', False)],
          'æstes': [('æste', False)],
          'æstet': [('æstet', True)],
          'æstets': [('æstet', True)],
          'æstinenserne': [('æstinenser', False)],
          'æstningers': [('æstning', False)],
          'æsuren': [('æsur', False)],
          'æsurens': [('æsur', False)],
          'æsurer': [('æsur', False)],
          'æsurerne': [('æsur', False)],
          'æsurernes': [('æsur', False)],
          'æsurers': [('æsur', False)],
          'ætan': [('ætan', True)],
          'ætanet': [('ætan', True)],
          'ætanets': [('ætan', True)],
          'ætans': [('ætan', True)],
          'æten': [('æt', False)],
          'ætens': [('æt', False)],
          'æter': [('æter', True)],
          'æterne': [('æter', True)],
          'æternes': [('æter', True)],
          'æters': [('æter', True)],
          'ætningen': [('ætning', False)],
          'ætninger': [('ætning', False)],
          'ætningerne': [('ætning', False)],
          'ætningernes': [('ætning', False)],
          'ætre': [('ætter', False)],
          'ætres': [('ætter', False)],
          'ætringens': [('ætring', False)],
          'æts': [('æt', False)],
          'ætsdage': [('ætsdag', False)],
          'ætsdagene': [('ætsdag', False)],
          'ætsdagenes': [('ætsdag', False)],
          'ætsdages': [('ætsdag', False)],
          'ætte': [('ætte', False)],
          'ætten': [('æt', True)],
          'ættens': [('æt', True)],
          'ætter': [('æt', True)],
          'ætterne': [('æt', False)],
          'ætternes': [('æt', True)],
          'ætters': [('æt', True)],
          'ættes': [('ætte', False)],
          'ættings': [('ætting', False)],
          'ætylen': [('ætyl', True), ('ætylen', True)],
          'ætylens': [('ætyl', True), ('ætylen', True)],
          'æum': [('æum', False)],
          'æums': [('æum', False)],
          'æve': [('æv', False)],
          'æven': [('æv', False)],
          'ævene': [('æv', False)],
          'ævenes': [('æv', False)],
          'ævens': [('æv', False)],
          'æver': [('æver', False)],
          'æverens': [('æver', False)],
          'æveret': [('æver', False)],
          'æverets': [('æver', False)],
          'æverne': [('æver', False)],
          'ævernes': [('æver', False)],
          'ævers': [('æver', False)],
          'æverter': [('ævert', False)],
          'æverternes': [('ævert', False)],
          'æves': [('æv', False)],
          'ævet': [('æv', False)],
          'ævets': [('æv', False)],
          'ævle': [('ævel', False)],
          'ævlen': [('ævle', False)],
          'ævlene': [('ævel', False)],
          'ævlenes': [('ævel', False)],
          'ævlens': [('ævel', False)],
          'ævler': [('ævl', False)],
          'ævlerne': [('ævl', False)],
          'ævlernes': [('ævl', False)],
          'ævlers': [('ævle', False)],
          'ævles': [('ævel', False)],
          'ævner': [('ævner', False)],
          'ævnerne': [('ævne', False)],
          'ævnernes': [('ævne', False)],
          'ævners': [('ævner', False)],
          'ævnet': [('ævne', False)],
          'ævnets': [('ævne', False)],
          'ævs': [('æv', False)],
          'ér': [('ér', False)],
          'éren': [('ér', False)],
          'érens': [('ér', False)],
          'érer': [('ér', False)],
          'érerne': [('ér', False)],
          'érernes': [('ér', False)],
          'érers': [('ér', False)],
          'éret': [('ér', False)],
          'érets': [('ér', False)],
          'érs': [('ér', False)],
          'és': [('é', False)],
          'ésigten': [('ésigte', False)],
          'ésigtens': [('ésigte', False)],
          'ésigter': [('ésigte', False)],
          'ésten': [('ésten', False)],
          'éstens': [('ésten', False)],
          'éteater': [('éteater', False)],
          'évine': [('évin', False)],
          'évinen': [('évin', False)],
          'évines': [('évin', False)],
          "ø'erne": [('ø', True)],
          'øavlens': [('øavl', False)],
          'øben': [('øbe', False)],
          'øbene': [('øb', False)],
          'øbenes': [('øb', False)],
          'øbens': [('øbe', False)],
          'øber': [('øbe', False)],
          'øberiers': [('øberi', False)],
          'øberne': [('øber', False)],
          'øbernes': [('øbe', False)],
          'øbers': [('øber', False)],
          'øbet': [('øb', False)],
          'øbets': [('øb', False)],
          'øbingerne': [('øbinger', False)],
          'øbingernes': [('øbinger', False)],
          'øblens': [('øbel', False)],
          'øbler': [('øbel', False)],
          'øblet': [('øbel', False)],
          'øblets': [('øbel', False)],
          'øbo': [('øboer', True)],
          'øboen': [('øboer', True)],
          'øboens': [('øboer', True)],
          'øboer': [('øboer', True)],
          'øboerne': [('øboer', True)],
          'øboernes': [('øboer', True)],
          'øboers': [('øboer', True)],
          'øbos': [('øboer', True)],
          'øbredden': [('øbred', False)],
          'øbreddens': [('øbred', False)],
          'øbredder': [('øbred', False)],
          'øbredderne': [('øbred', False)],
          'øbreddernes': [('øbred', False)],
          'øbredders': [('øbred', False)],
          'øbs': [('øb', False)],
          'ød': [('ød', False)],
          'øddelene': [('øddele', False)],
          'ødder': [('od', False)],
          'ødderne': [('od', False)],
          'øddernes': [('od', False)],
          'ødders': [('od', False)],
          'ødelisten': [('ødeliste', False)],
          'ødelistens': [('ødeliste', False)],
          'øden': [('ød', False)],
          'ødene': [('ød', False)],
          'ødenes': [('ød', False)],
          'ødens': [('ød', False)],
          'øder': [('øde', False)],
          'ødere': [('øder', False)],
          'øderen': [('øder', False)],
          'øderens': [('øder', False)],
          'øderes': [('øder', False)],
          'øderne': [('øde', False)],
          'ødernes': [('øde', False)],
          'øders': [('øde', True)],
          'ødes': [('øde', False)],
          'ødet': [('øde', True)],
          'ødets': [('øde', True)],
          'ødfars': [('ødfars', False)],
          'ødianer': [('ødianer', False)],
          'ødianers': [('ødianer', False)],
          'ødis': [('ødis', False)],
          'ødisens': [('ødis', False)],
          'ødlen': [('øddel', False)],
          'ødler': [('øddel', False)],
          'ødlerne': [('øddel', False)],
          'ødlernes': [('øddel', False)],
          'ødlers': [('øddel', False)],
          'ødomme': [('ødom', False)],
          'ødre': [('or', False)],
          'ødrefolk': [('oderfolk', False)],
          'ødrefolks': [('oderfolk', False)],
          'ødrelande': [('oderland', False)],
          'ødrelandene': [('oderland', False)],
          'ødrelandenes': [('oderland', False)],
          'ødrelandes': [('oderland', False)],
          'ødrene': [('or', False)],
          'ødrenes': [('or', False)],
          'ødres': [('or', False)],
          'ødret': [('ødret', False)],
          'ødrets': [('ødret', False)],
          'øds': [('ød', False)],
          'ødsdage': [('ødsdag', False)],
          'ødsdagene': [('ødsdag', False)],
          'ødsdagenes': [('ødsdag', False)],
          'ødsdages': [('ødsdag', False)],
          'ødværge': [('ødværge', False)],
          'ødværges': [('ødværge', False)],
          'øe': [('øe', False)],
          'øen': [('ø', True)],
          'øene': [('ø', False)],
          'øenes': [('ø', False)],
          'øens': [('ø', True)],
          'øer': [('ø', True)],
          'øerne': [('ø', True)],
          'øernes': [('ø', True)],
          'øers': [('ø', True)],
          'øes': [('øe', False)],
          'øf': [('øf', True)],
          'øfarer': [('øfarer', False)],
          'øfarerne': [('øfarer', False)],
          'øfarernes': [('øfarer', False)],
          'øfarers': [('øfarer', False)],
          'øffen': [('øf', False)],
          'øffens': [('øf', False)],
          'øfferne': [('øf', False)],
          'øfte': [('øfte', False)],
          'øfter': [('øft', False)],
          'øftes': [('øfte', False)],
          'øg': [('øg', False)],
          'øge': [('øg', False)],
          'øgen': [('øg', False)],
          'øgene': [('øg', False)],
          'øgenes': [('øg', False)],
          'øgens': [('øg', False)],
          'øgensernes': [('øgenser', False)],
          'øger': [('øger', False)],
          'øgere': [('øger', False)],
          'øgerede': [('øgerede', False)],
          'øgeren': [('øger', False)],
          'øgerens': [('øger', False)],
          'øgeres': [('øger', False)],
          'øgerne': [('og', False)],
          'øgernes': [('og', False)],
          'øgers': [('og', False)],
          'øges': [('øg', False)],
          'øget': [('øg', False)],
          'øgets': [('øg', False)],
          'øggen': [('øgg', False)],
          'øggene': [('øgg', False)],
          'øggens': [('øgg', False)],
          'øgle': [('øgle', False)],
          'øglen': [('øgle', False)],
          'øgler': [('øgle', True)],
          'øglerne': [('øgle', True)],
          'øglernes': [('øgle', False)],
          'øglers': [('øgle', False)],
          'øgles': [('øgle', False)],
          'øglet': [('øgle', False)],
          'øglets': [('øgle', False)],
          'øgner': [('øgner', False)],
          'øgnerne': [('øgner', False)],
          'øgners': [('øgner', False)],
          'øgs': [('øg', False)],
          'øgs-': [('øgsøjemed', False)],
          'øgter': [('øgter', False)],
          'øgterne': [('øgter', False)],
          'øgternes': [('øgter', False)],
          'øhave': [('øhav', True)],
          'øhaves': [('øhav', True)],
          'øjden': [('øjde', False)],
          'øjdens': [('øjde', False)],
          'øje': [('øje', True)],
          'øjen': [('øj', False)],
          'øjene': [('øj', False)],
          'øjens': [('øj', False)],
          'øjer': [('øje', False)],
          'øjerne': [('øje', True)],
          'øjernes': [('øje', True)],
          'øjers': [('øje', True)],
          'øjes': [('øje', True)],
          'øjet': [('øje', True)],
          'øjets': [('øje', True)],
          'øjfer': [('øjfe', False)],
          'øjferne': [('øjfe', False)],
          'øjfernes': [('øjfe', False)],
          'øjfers': [('øjfe', False)],
          'øjle': [('øjle', False)],
          'øjlen': [('øjle', False)],
          'øjlens': [('øjle', False)],
          'øjler': [('øjle', False)],
          'øjlerne': [('øjl', False)],
          'øjlernes': [('øjl', False)],
          'øjlers': [('øjle', False)],
          'øjles': [('øjle', False)],
          'øjne': [('øje', True)],
          'øjnene': [('øje', True)],
          'øjnenes': [('øje', True)],
          'øjner': [('øjner', False)],
          'øjnerne': [('øjner', False)],
          'øjnernes': [('øjner', False)],
          'øjners': [('øjner', False)],
          'øjnes': [('øje', True)],
          'øjre': [('øjre', False)],
          'øjres': [('øjre', False)],
          'øjs': [('øj', False)],
          'øjser': [('øjser', False)],
          'øjsernes': [('øjser', False)],
          'øjsers': [('øjser', False)],
          'øjten': [('øjte', False)],
          'øjtens': [('øjte', False)],
          'øjters': [('øjte', False)],
          'øk': [('øk', False)],
          'øker': [('øk', False)],
          'økere': [('øker', False)],
          'økeren': [('øker', False)],
          'økerens': [('øker', False)],
          'økeres': [('øker', False)],
          'økerne': [('øker', False)],
          'økernes': [('øker', False)],
          'økers': [('øker', False)],
          'økke': [('økke', False)],
          'økken': [('økken', False)],
          'økkens': [('økken', False)],
          'økkerne': [('økke', False)],
          'økkes': [('økke', False)],
          'økket': [('øk', False)],
          'økkets': [('øk', False)],
          'øklens': [('økel', False)],
          'økler': [('økel', False)],
          'øknerne': [('øken', False)],
          'økornet': [('økorn', False)],
          'økornets': [('økorn', False)],
          'øks': [('øk', False)],
          'økse': [('økse', False)],
          'øksen': [('økse', False)],
          'øksens': [('økse', False)],
          'økser': [('økse', False)],
          'økserne': [('økse', False)],
          'øksernes': [('økse', False)],
          'øksers': [('økse', True)],
          'økses': [('økse', False)],
          'økøer': [('øko', False)],
          'økøerne': [('øko', False)],
          'økøernes': [('øko', False)],
          'økøers': [('øko', False)],
          'øl': [('øl', False)],
          'ølaks': [('ølaks', False)],
          'øle': [('øl', False)],
          'ølen': [('øl', False)],
          'ølene': [('øl', False)],
          'ølenes': [('øl', False)],
          'ølens': [('øl', False)],
          'øler': [('øler', False)],
          'ølere': [('øler', False)],
          'øleren': [('øler', False)],
          'ølerens': [('øler', False)],
          'øleres': [('øler', False)],
          'ølers': [('øler', False)],
          'øles': [('øl', False)],
          'ølet': [('øle', False)],
          'ølets': [('øl', False)],
          'ølge': [('ølge', False)],
          'ølgen': [('ølge', False)],
          'ølger': [('ølge', False)],
          'ølges': [('ølge', False)],
          'ølget': [('ølge', False)],
          'ølgets': [('ølge', False)],
          'ølingers': [('øling', False)],
          'øljen': [('ølje', False)],
          'ølle': [('ølle', False)],
          'øllen': [('øl', True)],
          'øllene': [('øl', False)],
          'øllenes': [('øl', False)],
          'øllens': [('øl', False)],
          'øller': [('øl', True)],
          'øllerne': [('øl', False)],
          'øllernes': [('øl', False)],
          'øllers': [('øl', True)],
          'ølles': [('ølle', False)],
          'øllet': [('øl', False)],
          'øllets': [('øl', False)],
          'ølliker': [('øllike', False)],
          'øllikerne': [('øllike', False)],
          'øllikernes': [('øllike', False)],
          'ølpernes': [('ølper', False)],
          'ølpers': [('ølper', False)],
          'øls': [('øl', False)],
          'ølse': [('ølse', False)],
          'ølsen': [('ølse', False)],
          'ølsens': [('ølse', False)],
          'ølser': [('ølse', False)],
          'ølserne': [('ølse', False)],
          'ølsernes': [('ølse', False)],
          'ølses': [('ølse', False)],
          'ølve': [('ølve', False)],
          'ølven': [('ølve', False)],
          'ølvens': [('ølve', False)],
          'ølver': [('ølve', False)],
          'ølverne': [('ølve', False)],
          'ølvernes': [('ølve', False)],
          'ølvers': [('ølve', False)],
          'ølves': [('ølve', False)],
          'ølæs': [('ølæs', False)],
          'øm': [('øm', False)],
          'ømer': [('ømer', False)],
          'ømere': [('ømer', False)],
          'ømeren': [('ømer', False)],
          'ømerens': [('ømer', False)],
          'ømeres': [('ømer', False)],
          'ømerne': [('ømer', False)],
          'ømernes': [('ømer', False)],
          'ømers': [('ømer', False)],
          'ømilen': [('ømil', False)],
          'ømilens': [('ømil', False)],
          'øminen': [('ømine', False)],
          'øminers': [('ømine', False)],
          'øministers': [('øminister', False)],
          'ømler': [('ømmel', False)],
          'ømme': [('ømme', False)],
          'ømmelsers': [('ømmelse', False)],
          'ømmen': [('ømme', False)],
          'ømmens': [('ømme', False)],
          'ømmernes': [('ømmer', False)],
          'ømmers': [('ømmer', False)],
          'ømmes': [('ømme', False)],
          'ømmet': [('øm', False)],
          'ømmets': [('øm', False)],
          'ømpe': [('ømpe', False)],
          'ømpen': [('ømpe', False)],
          'ømpens': [('ømpe', False)],
          'ømpes': [('ømpe', False)],
          'øms': [('øm', False)],
          'ømænd': [('ømand', False)],
          'ømændene': [('ømand', False)],
          'ømærkerne': [('ømærke', False)],
          'ømærkers': [('ømærke', False)],
          'øn': [('øn', False)],
          'ønarbejderne': [('ønarbejder', False)],
          'ønarbejdernes': [('ønarbejder', False)],
          'øndagens': [('øndag', False)],
          'ønde': [('ønde', False)],
          'ønden': [('ønde', False)],
          'øndens': [('ønde', False)],
          'ønder': [('onde', False)],
          'ønderdrenge': [('ondedreng', False)],
          'ønderdrengene': [('ondedreng', False)],
          'ønderdrengenes': [('ondedreng', False)],
          'ønderdrenges': [('ondedreng', False)],
          'øndergårde': [('ondegård', False)],
          'øndergårdene': [('ondegård', False)],
          'øndergårdenes': [('ondegård', False)],
          'øndergårdes': [('ondegård', False)],
          'ønderkarle': [('ondekarl', False)],
          'ønderkarlene': [('ondekarl', False)],
          'ønderkarlenes': [('ondekarl', False)],
          'ønderkarles': [('ondekarl', False)],
          'ønderkoner': [('ondekone', False)],
          'ønderkonerne': [('ondekone', False)],
          'ønderkonernes': [('ondekone', False)],
          'ønderkoners': [('ondekone', False)],
          'ønderne': [('onde', False)],
          'øndernes': [('onde', False)],
          'ønderpiger': [('ondepige', False)],
          'ønderpigerne': [('ondepige', False)],
          'ønderpigernes': [('ondepige', False)],
          'ønderpigers': [('ondepige', False)],
          'øndes': [('ønde', False)],
          'ønen': [('øn', False)],
          'ønene': [('øn', False)],
          'ønenes': [('øn', False)],
          'ønens': [('øn', False)],
          'øner': [('øn', False)],
          'ønerne': [('øne', False)],
          'ønernes': [('øn', False)],
          'øners': [('øne', False)],
          'ønet': [('øn', False)],
          'ønets': [('øn', False)],
          'ønge': [('ønge', False)],
          'øngen': [('ønge', False)],
          'øngens': [('ønge', False)],
          'ønger': [('ønge', False)],
          'øngerne': [('ønge', False)],
          'øngernes': [('ønge', False)],
          'ønges': [('ønge', False)],
          'øniker': [('øniker', False)],
          'ønikerne': [('øniker', False)],
          'ønikernes': [('øniker', False)],
          'ønikers': [('øniker', False)],
          'øningers': [('øning', False)],
          'ønisser': [('ønisse', False)],
          'ønissernes': [('ønisse', False)],
          'ønissers': [('ønisse', False)],
          'ønne': [('ønne', False)],
          'ønner': [('ønne', False)],
          'ønnerne': [('ønne', False)],
          'ønnernes': [('øn', False)],
          'ønners': [('ønne', False)],
          'ønnes': [('ønne', False)],
          'øns': [('øn', False)],
          "øns'": [('øne', False)],
          'ønsagen': [('ønsag', False)],
          'ønsager': [('ønsag', False)],
          'ønsagerne': [('ønsag', False)],
          'ønsats': [('ønsats', False)],
          'ønsenes': [('øne', False)],
          'ønskernes': [('ønske', True)],
          'ønskers': [('ønske', True)],
          'ønsket': [('ønske', True)],
          'ønskets': [('ønske', True)],
          'ønstres': [('ønster', False)],
          'ønter': [('ønt', False)],
          'øplanter': [('øplante', False)],
          'øplanterne': [('øplante', False)],
          'øplanternes': [('øplante', False)],
          'øplanters': [('øplante', False)],
          'ør': [('ør', False)],
          'ørder': [('ørd', False)],
          'ørdernes': [('ørd', False)],
          'øre': [('øre', True)],
          'ørelser': [('ørelse', False)],
          'ørelserne': [('ørelse', False)],
          'ørelsernes': [('ørelse', False)],
          'ørelærer': [('ørelærer', False)],
          'ørelærers': [('ørelærer', False)],
          'øren': [('øre', True)],
          'ørene': [('øre', True)],
          'ørenes': [('øre', True)],
          'ørens': [('øre', True)],
          'øreposen': [('ørepose', False)],
          'øreposens': [('ørepose', False)],
          'øreposer': [('ørepose', False)],
          'øreposerne': [('ørepose', False)],
          'øreposernes': [('ørepose', False)],
          'øreposers': [('ørepose', False)],
          'ører': [('øre', True)],
          'ørerne': [('øre', True)],
          'ørernes': [('øre', True)],
          'ørers': [('øre', True)],
          'øres': [('øre', True)],
          'øret': [('øre', True)],
          'ørets': [('øre', True)],
          'øretter': [('øret', False)],
          'ørge': [('ørge', False)],
          'ørgen': [('ørge', False)],
          'ørgens': [('ørgen', False)],
          'ørger': [('ørger', False)],
          'ørgerne': [('ørger', False)],
          'ørgernes': [('ørger', False)],
          'ørgers': [('ørger', False)],
          'ørges': [('ørge', False)],
          'ørget': [('ørge', False)],
          'ørgets': [('ørge', False)],
          'ørhaler': [('ørhale', False)],
          'ørhalernes': [('ørhale', False)],
          'ørhalers': [('ørhale', False)],
          'ørhedens': [('ørhed', False)],
          'ørianer': [('ørianer', False)],
          'ørianers': [('ørianer', False)],
          'ørigerne': [('ørige', True)],
          'ørigernes': [('ørige', True)],
          'øringer': [('øring', False)],
          'øringerne': [('øring', False)],
          'øringernes': [('øring', False)],
          'øringers': [('øring', False)],
          'øris': [('øris', False)],
          'ørisen': [('øris', False)],
          'ørke': [('ørke', False)],
          'ørken': [('ørken', False)],
          'ørkens': [('ørken', True)],
          'ørker': [('ørke', False)],
          'ørkerne': [('ørke', False)],
          'ørkernes': [('ørke', False)],
          'ørkers': [('ørke', False)],
          'ørkes': [('ørke', False)],
          'ørket': [('ørke', False)],
          'ørkets': [('ørke', False)],
          'ørkors': [('ørkors', False)],
          'ørn': [('ørn', True)],
          'ørne': [('ørn', True)],
          'ørneansigter': [('arneansigt', False)],
          'ørneansigterne': [('arneansigt', False)],
          'ørneansigternes': [('arneansigt', False)],
          'ørneansigters': [('arneansigt', False)],
          'ørnebørn': [('arnebarn', False)],
          'ørnebørnene': [('arnebarn', False)],
          'ørnebørnenes': [('arnebarn', False)],
          'ørnebørns': [('arnebarn', False)],
          'ørnefødsler': [('arnefødsel', False)],
          'ørnefødslerne': [('arnefødsel', False)],
          'ørnefødslernes': [('arnefødsel', False)],
          'ørnefødslers': [('arnefødsel', False)],
          'ørnehoveder': [('arnehoved', False)],
          'ørnehovederne': [('arnehoved', False)],
          'ørnehovedernes': [('arnehoved', False)],
          'ørnehoveders': [('arnehoved', False)],
          'ørnemord': [('arnemord', False)],
          'ørnemordene': [('arnemord', False)],
          'ørnemordenes': [('arnemord', False)],
          'ørnemordere': [('arnemorder', False)],
          'ørnemorderes': [('arnemorder', False)],
          'ørnemorderne': [('arnemorder', False)],
          'ørnemordernes': [('arnemorder', False)],
          'ørnemords': [('arnemord', False)],
          'ørnen': [('ørn', True)],
          'ørnene': [('ørn', True)],
          'ørnenes': [('ørn', True)],
          'ørnens': [('ørn', True)],
          'ørner': [('ørne', False)],
          'ørnerne': [('ørner', False)],
          'ørnernes': [('ørne', False)],
          'ørners': [('ørner', False)],
          'ørnes': [('ørn', True)],
          'ørneskeer': [('arneske', False)],
          'ørneskeerne': [('arneske', False)],
          'ørneskeernes': [('arneske', False)],
          'ørneskeers': [('arneske', False)],
          'ørnesko': [('arnesko', False)],
          'ørneskoene': [('arnesko', False)],
          'ørneskoenes': [('arnesko', False)],
          'ørneskos': [('arnesko', False)],
          'ørnestjerner': [('arnestjerne', False)],
          'ørnestjernerne': [('arnestjerne', False)],
          'ørnestjernernes': [('arnestjerne', False)],
          'ørnestjerners': [('arnestjerne', False)],
          'ørnet': [('ørne', False)],
          'ørnets': [('ørne', False)],
          'ørnlille': [('arnlille', False)],
          'ørnlilles': [('arnlille', False)],
          'ørns': [('ørn', True)],
          'ørre': [('ørre', False)],
          'ørren': [('ør', False)],
          'ørrers': [('ørrer', False)],
          'ørret': [('ør', False)],
          'ørrets': [('ør', False)],
          'ørs': [('ør', False)],
          'ørskurs': [('ørskurs', False)],
          'ørsten': [('ørste', False)],
          'ørstenes': [('ørst', False)],
          'ørstens': [('ørst', False)],
          'ørstningen': [('ørstning', False)],
          'ørternes': [('ørt', False)],
          'ørtler': [('ørtler', False)],
          'ørtlerne': [('ørtel', False)],
          'ørtlernes': [('ørtel', False)],
          'ørtlers': [('ørtel', False)],
          'ørtropperne': [('ørtropper', False)],
          'ørtroppernes': [('ørtropper', False)],
          'ørtroppers': [('ørtropper', False)],
          'ørøver': [('ørøver', False)],
          'ørøvernes': [('ørøver', False)],
          'øs': [('ø', True)],
          "øs'": [('øs', False)],
          'øsarbejders': [('øsarbejder', False)],
          'øse': [('øse', True)],
          'øsen': [('øse', True)],
          'øsene': [('øs', False)],
          'øsener': [('øsen', False)],
          'øsenerne': [('øsen', False)],
          'øsenernes': [('øsen', False)],
          'øseners': [('øsen', False)],
          'øsenes': [('øs', False)],
          'øsens': [('øse', True)],
          'øser': [('øse', True)],
          'øsere': [('øser', False)],
          'øseren': [('øser', False)],
          'øserens': [('øser', False)],
          'øseres': [('øser', False)],
          'øserier': [('øseri', False)],
          'øserierne': [('øseri', False)],
          'øseriernes': [('øseri', False)],
          'øseriers': [('øseri', False)],
          'øserne': [('øse', True)],
          'øsernes': [('øse', True)],
          'øsers': [('øse', True)],
          'øses': [('øse', True)],
          'øset': [('øs', False)],
          'øsets': [('øs', False)],
          'øsitet': [('øsitet', False)],
          'øsitets': [('øsitet', False)],
          'øsken': [('øsken', False)],
          'øskens': [('øsken', False)],
          'øskner': [('øsken', True)],
          'øsknernes': [('øsken', False)],
          'øskners': [('øsken', False)],
          'øslags': [('øslag', False)],
          'øslangen': [('øslange', False)],
          'øslangens': [('øslange', False)],
          'øsne': [('øsne', False)],
          'øsnes': [('øsne', False)],
          'øssen': [('øsse', False)],
          'øssens': [('øsse', False)],
          'øsser': [('øsse', False)],
          'øsserne': [('øsse', False)],
          'øssernes': [('øsse', False)],
          'østen': [('østen', True)],
          'østene': [('øst', False)],
          'østenes': [('øst', False)],
          'østens': [('østen', False)],
          'øster': [('øster', False)],
          'østers': [('østers', True)],
          "østers'": [('østers', True)],
          'østiene': [('østi', False)],
          'østienes': [('østi', False)],
          'østiens': [('østi', False)],
          'østis': [('østi', False)],
          'østningers': [('østning', False)],
          'østre': [('øster', False)],
          'østøvler': [('østøvle', False)],
          'østøvlernes': [('østøvle', False)],
          'øsus': [('øsus', False)],
          'øsøret': [('øsøre', False)],
          'øsørets': [('øsøre', False)],
          'øtanke': [('øtanke', False)],
          'øtanken': [('øtanke', False)],
          'øtankens': [('øtanke', False)],
          'øtanker': [('øtanke', False)],
          'øtankerne': [('øtanke', False)],
          'øtankernes': [('øtanke', False)],
          'øtankers': [('øtanke', False)],
          'øtankes': [('øtanke', False)],
          'øter': [('øter', False)],
          'øterne': [('øter', False)],
          'øternes': [('øter', False)],
          'øters': [('øter', False)],
          'øtningen': [('øtning', False)],
          'øtninger': [('øtning', False)],
          'øtningerne': [('øtning', False)],
          'øtningernes': [('øtning', False)],
          'øtransporter': [('øtransport', False)],
          'øtransporterne': [('øtransport', False)],
          'øtransporternes': [('øtransport', False)],
          'øtransporters': [('øtransport', False)],
          'øtre': [('atter', False)],
          'øtrene': [('atter', False)],
          'øtrenes': [('atter', False)],
          'øtres': [('atter', False)],
          'øtrikken': [('øtrik', False)],
          'øtrikker': [('øtrik', False)],
          'øtrikkerne': [('øtrik', False)],
          'øtrikkernes': [('øtrik', False)],
          'øtrikkers': [('øtrik', False)],
          'øtte': [('øtte', False)],
          'øtten': [('øtte', False)],
          'øttens': [('øtte', False)],
          'øtternes': [('øtte', False)],
          'øtters': [('øtte', False)],
          'øttes': [('øtte', False)],
          'øttings': [('øtting', False)],
          'øtunger': [('øtunge', False)],
          'øtungernes': [('øtunge', False)],
          'øveder': [('øved', False)],
          'øvederne': [('øved', False)],
          'øvedernes': [('øved', False)],
          'øveders': [('øved', False)],
          'øvedet': [('øved', False)],
          'øvedets': [('øved', False)],
          'øvejene': [('øvej', False)],
          'øvejens': [('øvej', False)],
          'øvejes': [('øvej', False)],
          'øvene': [('øv', False)],
          'øvenes': [('øv', False)],
          'øver': [('øver', False)],
          'øverens': [('øver', False)],
          'øveret': [('øver', False)],
          'øverets': [('øver', False)],
          'øverne': [('øver', False)],
          'øvernes': [('øver', False)],
          'øvers': [('øver', False)],
          'øvesten': [('øvesten', False)],
          'øvestens': [('øvesten', False)],
          'øvet': [('øv', False)],
          'øvets': [('øv', False)],
          'øvinde': [('øvinde', False)],
          'øvinden': [('øvinde', False)],
          'øvindens': [('øvinde', False)],
          'øvinder': [('øvinde', False)],
          'øvinderne': [('øvinde', False)],
          'øvindernes': [('øvinde', False)],
          'øvinders': [('øvinde', False)],
          'øvindes': [('øvinde', False)],
          'øvle': [('øvle', False)],
          'øvlen': [('øvle', False)],
          'øvlens': [('øvle', False)],
          'øvles': [('øvle', False)],
          'øvlet': [('øvlet', False)],
          'øvlets': [('øvlet', False)],
          'øvre': [('øvre', False)],
          'øvs': [('øv', False)],
          'øvsens': [('øvs', False)],
          'øvsers': [('øvs', False)],
          'øvstikken': [('øvstikke', False)],
          'øvstikker': [('øvstikke', False)],
          'øvstikkerne': [('øvstikke', False)],
          'øvstikkernes': [('øvstikke', False)]},
 'NOUN_ADJ': {'3.': [('3.', True), ('3', True)], 'mindre': [('lille', True)]},
 'NOUN_NOUN': {'en': [('', False)],
               'er': [('', False)],
               'fter': [('ft', False)],
               'ger': [('ger', False)],
               'k.': [('yk', False)],
               'ker': [('ke', False)],
               'men': [('me', False)],
               'mer': [('me', False)],
               'rker': [('rk', False)],
               'ter': [('te', False)],
               'ver': [('ve', False)]},
 'NOUN_VERB': {'ak': [('ikke', False)],
               'al': [('ulle', False)],
               'ar': [('ære', False)],
               'bor': [('bo', True)],
               'de': [('', False)],
               'ed': [('ide', False)],
               'eg': [('ige', False)],
               'es': [('es', False)],
               'findes': [('findes', True)],
               'indes': [('inde', False)],
               'ldes': [('ldes', False)],
               'od': [('ade', False)],
               'or': [('are', False)],
               'r': [('', False)],
               's': [('', False)],
               'ses': [('se', True)],
               'te': [('e', False)],
               'tes': [('es', False)],
               'tod': [('tå', False)],
               'ttes': [('tte', False)],
               'å': [('e', False)],
               'ødes': [('ødes', False)],
               'øg': [('yge', False)],
               'ør': [('øre', False)]},
 'NUM': {"'": [('', False)],
         "'s": [('', False)],
         'des': [('de', False)],
         'dreds': [('dred', False)],
         'ds': [('ds', False)],
         'fems': [('fem', True)],
         'gtres': [('gtres', False)],
         'jes': [('je', False)],
         'ks': [('ks', False)],
         'nds': [('nd', False)],
         'reds': [('reds', False)],
         'res': [('re', False)],
         'rs': [('rs', False)],
         's': [('', False)],
         'tes': [('te', False)],
         'tres': [('tres', True), ('tre', True)],
         'ves': [('ve', False)],
         'vfems': [('vfems', False)]},
 'NUM_ADJ': {'små': [('lille', True)]},
 'NUM_NOUN': {'er': [('', False)],
              'ers': [('', False)],
              'ger': [('ge', False)],
              'mer': [('me', False)],
              'mers': [('me', False)]},
 'NUM_VERB': {'ar': [('ære', False)], 'de': [('', False)], 'eg': [('ige', False)], 'r': [('', False)]},
 'PRON': {"'": [('d', False)],
          '.': [('nden', False)],
          'De': [('De', True)],
          'a': [('ad', False)],
          'andre': [('anden', True)],
          'andres': [('anden', True)],
          'de': [('de', True)],
          'ders': [('ders', False)],
          'dét': [('det', True)],
          'e': [('en', False)],
          'em': [('e', False)],
          'ende': [('un', False)],
          'endes': [('un', False)],
          'eres': [('e', False)],
          'ers': [('er', False)],
          'ge': [('ge', False)],
          'ig': [('u', False)],
          'ine': [('in', False)],
          'is': [('is', False)],
          'isse': [('enne', False)],
          'isses': [('enne', False)],
          'jer': [('I', True)],
          'jeres': [('I', True)],
          'le': [('en', False)],
          'les': [('en', False)],
          'm': [('n', False)],
          'me': [('me', False)],
          'mig': [('jeg', True)],
          'min': [('jeg', True)],
          'mine': [('jeg', True)],
          'mit': [('jeg', True)],
          'ne': [('ne', False)],
          'nt': [('n', False)],
          'om': [('om', False)],
          'or': [('i', False)],
          'ore': [('i', False)],
          'ores': [('i', False)],
          'ort': [('i', False)],
          'os': [('vi', True)],
          'randre': [('randre', False)],
          'randres': [('randre', False)],
          'rt': [('r', False)],
          's': [('', False)],
          'sig': [('sig', True)],
          't': [('n', False)],
          'tet': [('gen', False)],
          'tets': [('gen', False)],
          'thvert': [('nhver', False)],
          'thverts': [('nhver', False)],
          'ts': [('n', False)],
          'tte': [('nne', False)],
          'ttes': [('nne', False)],
          'vem': [('vem', False)],
          'én': [('en', True)],
          'ét': [('en', True)]},
 'PRON_ADJ': {'t': [('', False)]},
 'PRON_ADV': {'t': [('', False)]},
 'PRON_DONT_USE': {'e': [('en', False)], 't': [('n', False)]},
 'PRON_NOUN': {'en': [('', False)], 'et': [('', False)], 'ne': [('', False)]},
 'PRON_VERB': {'ad': [('ede', False)],
               'al': [('ulle', False)],
               'ap': [('ippe', False)],
               'ar': [('ære', False)],
               'ed': [('ide', False)],
               'eg': [('ige', False)],
               'es': [('es', False)],
               'gør': [('gøre', True)],
               'ir': [('ive', False)],
               'od': [('ade', False)],
               'pes': [('pe', False)],
               'r': [('', False)],
               'rtalte': [('rtælle', False)],
               'talte': [('tale', True)],
               'tes': [('es', False)],
               'tod': [('tå', False)],
               'å': [('e', False)],
               'øj': [('yve', False)],
               'ør': [('urde', False)],
               'øs': [('yse', False)]},
 'PROPN': {"'": [('', False)],
           "'s": [('', False)],
           '.ds': [('.d', False)],
           '.s': [('.', False)],
           '9s': [('9', False)],
           'Assens': [('Assens', True)],
           'Brandes': [('Brande', True)],
           'Krims': [('Krim', True)],
           'Lunds': [('Lund', True)],
           'Mars': [('Mars', True)],
           'Mols': [('Mols', True)],
           'Mors': [('Mors', True)],
           'Rica': [('Rica', False)],
           'Sunds': [('Sund', False)],
           'a': [('a', True)],
           'a.': [('a.', True)],
           'aa': [('aa', False)],
           'aas': [('aa', False)],
           'ad': [('ad', False)],
           'adas': [('adas', False)],
           'ados': [('ados', False)],
           'ads': [('ad', False)],
           'aells': [('aell', False)],
           'agens': [('agen', False)],
           'agers': [('ager', False)],
           'agnes': [('agnes', True)],
           'ags': [('ag', False)],
           'aica': [('aica', False)],
           'aks': [('ak', False)],
           'alas': [('ala', False)],
           'alias': [('alia', False)],
           'alis': [('ali', False)],
           'alls': [('alls', False)],
           'als': [('als', True)],
           'amas': [('amas', False)],
           'amos': [('amos', False)],
           'ams': [('am', False)],
           'anders': [('anders', True)],
           'angels': [('angels', True)],
           'ans': [('an', False)],
           'aps': [('ap', False)],
           'ars': [('ar', False)],
           'arts': [('arts', False)],
           'as': [('as', False)],
           'assens': [('assens', True)],
           'ats': [('at', False)],
           'aus': [('au', False)],
           'avs': [('av', False)],
           'ays': [('ay', False)],
           'b.': [('b.', True)],
           'ba': [('ba', False)],
           'bas': [('ba', False)],
           'bes': [('be', False)],
           'bings': [('bing', False)],
           'bles': [('bles', False)],
           'bones': [('bone', False)],
           'bos': [('bo', False)],
           'bras': [('bras', False)],
           'bs': [('bs', False)],
           'bys': [('by', False)],
           'c.': [('c.', True)],
           'ca': [('ca', False)],
           'cas': [('ca', False)],
           'cd': [('cd', True)],
           'ces': [('ce', False)],
           'cks': [('ck', False)],
           'colas': [('colas', False)],
           'cos': [('co', False)],
           'cus': [('cu', False)],
           'd': [('d.', False)],
           'd.': [('d.', True)],
           'da': [('da', False)],
           'dals': [('dal', False)],
           'dams': [('dams', False)],
           'das': [('da', False)],
           'dders': [('dder', False)],
           'dels': [('dels', False)],
           'des': [('de', False)],
           'dge': [('gde', False)],
           'dies': [('dies', False)],
           'dings': [('ding', False)],
           'dis': [('di', False)],
           'dons': [('dons', True)],
           'drs': [('dr', False)],
           'ds': [('ds', False)],
           'e.': [('e.', True)],
           'ea': [('ea', False)],
           'eaks': [('eaks', False)],
           'eas': [('ea', False)],
           'ed': [('ed', False)],
           'edies': [('edie', False)],
           'eds': [('ed', False)],
           'eers': [('eers', False)],
           'egas': [('egas', False)],
           'eis': [('ei', False)],
           'eiters': [('eiters', False)],
           'ejens': [('ejen', False)],
           'eks': [('ek', False)],
           'elas': [('ela', False)],
           'eles': [('eles', False)],
           'elles': [('elle', False)],
           'ells': [('ells', False)],
           'els': [('el', False)],
           'ems': [('em', False)],
           'ends': [('ends', False)],
           'ens': [('en', False)],
           'eones': [('eone', False)],
           'eops': [('eops', False)],
           'erens': [('eren', False)],
           'ernes': [('erne', False)],
           'ers': [('er', False)],
           'es': [('es', False)],
           'ets': [('et', False)],
           'eus': [('eu', False)],
           'evns': [('evns', False)],
           'evs': [('ev', False)],
           'eys': [('ey', False)],
           'f.': [('f.', True)],
           'farts': [('fart', False)],
           'fns': [('fn', True)],
           'fors': [('fors', False)],
           'fs': [('f', False)],
           'fts': [('ft', False)],
           'g.': [('g.', False)],
           'ga': [('ga', False)],
           'gals': [('gal', False)],
           'gas': [('ga', False)],
           'gens': [('gens', False)],
           'gers': [('gers', False)],
           'ges': [('ge', False)],
           'ggers': [('gger', False)],
           'gl.': [('gammel', True)],
           'gos': [('go', False)],
           'gs.': [('ongens', False)],
           'gts': [('gt', False)],
           'gunds': [('gund', False)],
           'h.': [('h.', True)],
           'hans': [('hans', True)],
           'has': [('ha', False)],
           'hders': [('hder', False)],
           'hers': [('hers', False)],
           'hias': [('hias', False)],
           'hos': [('ho', False)],
           'hr.': [('hristian', False)],
           'hs': [('hs', False)],
           'hys': [('hy', False)],
           'ia': [('ia', False)],
           'ias': [('ia', False)],
           'ica': [('ican', False)],
           'id': [('id', False)],
           'iels': [('iels', False)],
           'ies': [('ie', False)],
           'igers': [('iger', False)],
           'igs': [('ig', False)],
           'iis': [('ii', False)],
           'iks': [('ik', False)],
           'illas': [('illa', False)],
           'illes': [('ille', False)],
           'ils': [('il', False)],
           'indes': [('inde', False)],
           'ings': [('ings', False)],
           'ins': [('in', False)],
           'ions': [('ions', False)],
           'ios': [('io', False)],
           'iques': [('ique', False)],
           'is': [('is', False)],
           'isas': [('isa', False)],
           'iters': [('iter', False)],
           'its': [('it', False)],
           'j.': [('j.', True)],
           'ja': [('ja', False)],
           'jas': [('ja', False)],
           'jens': [('jens', True)],
           'jis': [('ji', False)],
           'js': [('j', False)],
           'jsens': [('jsen', False)],
           'k.': [('k.', True)],
           'ka': [('ka', False)],
           'kas': [('ka', False)],
           'kes': [('ke', False)],
           'kins': [('kins', False)],
           'kis': [('ki', False)],
           'kos': [('ko', False)],
           'ktas': [('ktas', True)],
           'ktis': [('ktis', False)],
           'l.': [('l.', True)],
           'la': [('la', False)],
           'lads': [('lads', False)],
           'lars': [('lars', True)],
           'las': [('las', True)],
           'laus': [('laus', False)],
           'ld': [('ld', False)],
           'lds': [('ld', False)],
           'les': [('le', False)],
           'lias': [('lias', False)],
           'lings': [('ling', False)],
           'lis': [('lis', True)],
           'llas': [('llas', False)],
           'lms': [('lm', False)],
           'lors': [('lors', False)],
           'los': [('los', True)],
           'ls': [('ls', False)],
           'lsens': [('lsen', False)],
           'lts': [('lt', False)],
           'lunds': [('lund', False)],
           'lus': [('lu', False)],
           'lys': [('ly', False)],
           'm.': [('m.', True)],
           'ma': [('ma', False)],
           'mas': [('ma', False)],
           'mings': [('ming', False)],
           'mos': [('mo', False)],
           'mps': [('mp', False)],
           'ms': [('ms', False)],
           'msens': [('msen', False)],
           'na': [('na', False)],
           'nadas': [('nada', False)],
           'namas': [('nama', False)],
           'nans': [('nans', False)],
           'nas': [('na', False)],
           'nd': [('nd', False)],
           'nders': [('nder', False)],
           'ndons': [('ndon', False)],
           'nds': [('nd', False)],
           'nes': [('ne', False)],
           'ngels': [('ngel', False)],
           'ngens': [('ngen', False)],
           'ngers': [('nger', False)],
           'ngs': [('ng', False)],
           'nica': [('nica', False)],
           'nils': [('nils', True)],
           'nings': [('ning', False)],
           'nks': [('nk', False)],
           'nnes': [('nnes', False)],
           'nns': [('nn', False)],
           'nos': [('no', False)],
           'nsens': [('nsen', False)],
           'ntis': [('ntis', False)],
           'nts': [('nt', False)],
           'oas': [('oa', False)],
           'od': [('od', False)],
           'ods': [('od', False)],
           'oels': [('oels', False)],
           'olas': [('ola', False)],
           'olis': [('oli', False)],
           'ols': [('ol', False)],
           'olus': [('olus', False)],
           'omas': [('omas', False)],
           'oms': [('om', False)],
           'onas': [('onas', False)],
           'ones': [('ones', False)],
           'ons': [('on', False)],
           'ops': [('op', False)],
           'ors': [('or', False)],
           'orsens': [('orsens', False)],
           'os': [('os', False)],
           'ovs': [('ov', False)],
           'p.': [('p.', True)],
           'pa': [('pa', False)],
           'pals': [('pal', False)],
           'pas': [('pa', False)],
           'pd': [('pd', False)],
           'pes': [('pe', False)],
           'phs': [('ph', False)],
           'pys': [('py', False)],
           'ques': [('ques', False)],
           'r.': [('r.', False)],
           'ra': [('ra', False)],
           'rados': [('rado', False)],
           'randes': [('randes', False)],
           'ras': [('ra', False)],
           'rcos': [('rcos', False)],
           'rd': [('rd', False)],
           'rdams': [('rdam', False)],
           'rds': [('rd', False)],
           'rens': [('rens', False)],
           'res': [('re', False)],
           'rgas': [('rgas', False)],
           'rgens': [('rgen', False)],
           'rgs': [('rg', False)],
           'rims': [('rims', False)],
           'rings': [('ring', False)],
           'rions': [('rion', False)],
           'rks': [('rk', False)],
           'rles': [('rles', False)],
           'rnes': [('rnes', False)],
           'rns': [('rn', False)],
           'ros': [('ro', False)],
           'rps': [('rp', False)],
           'rs': [('rs', False)],
           'rsens': [('rsen', False)],
           'rts': [('rt', False)],
           'rues': [('rues', False)],
           'rus': [('ru', False)],
           's': [('s', True)],
           'sas': [('sas', True)],
           'sbs': [('sb', False)],
           'ses': [('se', False)],
           'shs': [('sh', False)],
           'slos': [('slo', False)],
           'sos': [('so', False)],
           'ss': [('ss', False)],
           'ssens': [('ssen', False)],
           'stajnica': [('nstajnica', False)],
           'sters': [('ster', False)],
           'sts': [('st', False)],
           'sunds': [('sund', False)],
           't.': [('t.', False)],
           'ta': [('ta', False)],
           'tagnes': [('tagne', False)],
           'talls': [('tall', False)],
           'tals': [('tal', False)],
           'tas': [('ta', False)],
           'tes': [('te', False)],
           'ths': [('th', False)],
           'tica': [('tica', False)],
           'tis': [('ti', False)],
           'tles': [('tles', False)],
           'tos': [('to', False)],
           'ts': [('ts', False)],
           'tts': [('tt', False)],
           'tus': [('tu', False)],
           'uas': [('ua', False)],
           'ucks': [('ucks', False)],
           'ud': [('ud', False)],
           'ugs': [('ug', False)],
           'uks': [('uk', False)],
           'uls': [('ul', False)],
           'ums': [('um', False)],
           'unds': [('unds', False)],
           'uns': [('un', False)],
           'ups': [('up', False)],
           'uras': [('uras', False)],
           'urs': [('ur', False)],
           'us': [('us', False)],
           'usas': [('usa', True)],
           'v.': [('v.', True)],
           'va': [('va', False)],
           'vas': [('va', False)],
           'verly': [('rverly', False)],
           'ves': [('ve', False)],
           'vica': [('vica', False)],
           'vms': [('vm', True)],
           'vns': [('vn', False)],
           'vos': [('vo', False)],
           'vs': [('vs', True)],
           'wa': [('wa', False)],
           'wes': [('we', False)],
           'wis': [('wi', False)],
           'ws': [('ws', False)],
           'xelles': [('xelles', False)],
           'xes': [('xe', False)],
           'ya': [('ya', False)],
           'yas': [('ya', False)],
           'ybs': [('yb', False)],
           'yns': [('yn', False)],
           'yrus': [('yrus', False)],
           'ys': [('ys', False)],
           'za': [('za', False)],
           'zes': [('ze', False)],
           'ás': [('á', False)],
           'äs': [('äs', False)],
           'ågels': [('ågel', False)],
           'ås': [('å', False)],
           'æa': [('æa', False)],
           'æas': [('æa', False)],
           'æks': [('æk', False)],
           'ærs': [('ær', False)],
           'és': [('é', False)],
           'ës': [('ës', False)],
           'öd': [('öd', False)],
           'ød': [('ød', False)],
           'øds': [('ød', False)],
           'øes': [('øe', False)],
           'øms': [('øm', False)],
           'øndes': [('ønde', False)],
           'ønnes': [('ønne', False)],
           'øns': [('øn', False)],
           'ørs': [('ør', False)],
           'øs': [('ø', False)],
           'øst-': [('øst-', True), ('østeuropa', True)],
           'üters': [('üter', False)]},
 'PROPN_NOUN': {'len': [('', False)], 'ret': [('er', False)], 'rter': [('rter', False)], 'ter': [('te', False)]},
 'PROPN_VERB': {'ad': [('ede', False)],
                'al': [('ulle', False)],
                'alte': [('ælle', False)],
                'ap': [('ippe', False)],
                'ar': [('ære', False)],
                'ed': [('ide', False)],
                'er': [('e', False)],
                'od': [('å', False)],
                'r': [('re', False)],
                'tes': [('es', False)],
                'å': [('e', False)],
                'ød': [('yde', False)]},
 'PUNCT_ADJ': {'små': [('lille', True)]},
 'PUNCT_NOUN': {'en': [('', False)],
                'er': [('er', False)],
                'erne': [('', False)],
                'serne': [('ser', False)],
                'ter': [('te', False)],
                'tter': [('tter', False)]},
 'PUNCT_VERB': {'ad': [('ede', False)],
                'al': [('ulle', False)],
                'ar': [('ære', False)],
                'eg': [('ige', False)],
                'er': [('e', False)],
                'es': [('es', False)],
                'g': [('ge', False)],
                'od': [('å', False)],
                'or': [('o', False)],
                'par': [('pare', False)],
                'r': [('re', False)],
                'rtalte': [('rtælle', False)],
                's': [('se', False)],
                'talte': [('tale', True)],
                'å': [('e', False)],
                'ød': [('yde', False)]},
 'SCONJ_NOUN': {'den': [('de', False)],
                'isen': [('is', False)],
                'nden': [('nd', False)],
                'oen': [('oe', False)],
                'sen': [('se', False)],
                'usen': [('us', False)]},
 'VERB': {"'ede": [("'e", False)],
          "'edes": [("'e", False)],
          "'ende": [("'e", False)],
          "'er": [("'e", False)],
          "'es": [("'e", False)],
          "'r": [('ve', False)],
          '-ende': [('', False)],
          'S': [("S'e", False)],
          'SAND': [('sande', True)],
          'a': [('ae', False)],
          "a'": [('ave', False)],
          'ab': [('abe', True)],
          'abad': [('abede', False)],
          'abatter': [('abattere', False)],
          'abbes': [('abbe', False)],
          'abed': [('abede', False)],
          'abede': [('abe', True)],
          'abedes': [('abe', False)],
          'aber': [('abe', True)],
          'aberede': [('abere', False)],
          'aberedes': [('abere', False)],
          'aberet': [('abere', False)],
          'ablende': [('able', False)],
          'abler': [('able', False)],
          'aborer': [('aborere', False)],
          'abrede': [('abre', False)],
          'abredes': [('abre', False)],
          'abrer': [('abre', False)],
          'abuler': [('abulere', False)],
          'acer': [('acere', False)],
          'acher': [('ache', False)],
          'ad': [('ade', False)],
          'ade': [('ade', False)],
          'ades': [('ade', False)],
          'adier': [('adiere', False)],
          'adlede': [('adle', False)],
          'adrager': [('adrage', False)],
          'adredes': [('adre', False)],
          'adrer': [('adre', False)],
          'adsende': [('adse', False)],
          'adser': [('adse', False)],
          'adsås': [('adså', False)],
          'adt': [('ade', False)],
          'aduer': [('aduere', False)],
          'aede': [('ae', True)],
          'aedes': [('ae', True)],
          'aende': [('ae', False)],
          'aer': [('ae', True)],
          'aes': [('ae', True)],
          'af': [('affe', False)],
          'afer': [('afere', False)],
          'affede': [('affede', True)],
          'affedes': [('affede', True)],
          'affer': [('affe', False)],
          'afferer': [('affere', False)],
          'affes': [('affe', False)],
          'aflede': [('aflede', True)],
          'afledes': [('aflede', True)],
          'afler': [('afle', False)],
          'aflet': [('afle', False)],
          'aflokkedes': [('aflokke', True)],
          'aflokkes': [('aflokke', True)],
          'aflys': [('aflyse', True)],
          'aflås': [('aflåse', True)],
          'aflæs': [('aflæsse', True), ('aflæse', True)],
          'afrede': [('afre', False)],
          'afredes': [('afre', False)],
          'afrer': [('afre', False)],
          'afret': [('afrette', True)],
          'afryd': [('afrydde', True)],
          'aft': [('ave', False)],
          'aftedes': [('afte', False)],
          'ag': [('age', True)],
          'agde': [('ægge', False)],
          'agdes': [('ægge', False)],
          'agedes': [('age', True)],
          'agen': [('age', False)],
          'ager': [('age', True), ('agere', True)],
          'agerer': [('agere', False)],
          'ages': [('age', True)],
          'aggedes': [('agge', False)],
          'agges': [('agge', False)],
          'agier': [('agiere', False)],
          'agler': [('agle', False)],
          'agne': [('age', False)],
          'agrer': [('agre', False)],
          'agt': [('agte', True)],
          'agte': [('agte', True)],
          'agtedes': [('agte', False)],
          'agtes': [('agte', True)],
          'aher': [('ahere', False)],
          'aider': [('aide', False)],
          'ailer': [('aile', False)],
          'ailler': [('aillere', False)],
          'ain': [('aine', False)],
          'ainer': [('aine', False)],
          'ais': [('aisse', False)],
          'aiser': [('aisere', False)],
          'akater': [('akatere', False)],
          'akede': [('ake', False)],
          'akedes': [('ake', False)],
          'akeler': [('akelere', False)],
          'akende': [('akende', False)],
          'aker': [('akere', False)],
          'akkedes': [('akke', False)],
          'akkes': [('akke', False)],
          'akles': [('akle', False)],
          'akrer': [('akre', False)],
          'akser': [('akse', False)],
          'akt': [('ække', False)],
          'akte': [('ække', False)],
          'akter': [('aktere', True)],
          'aktes': [('ække', False)],
          'akuer': [('akuere', False)],
          'akuler': [('akulere', False)],
          'al': [('æle', False)],
          'alarmer': [('alarmere', True)],
          'aldedes': [('alde', False)],
          'aldende': [('alde', False)],
          'alder': [('alde', False)],
          'alede': [('ale', False)],
          'aledes': [('ale', False)],
          'aler': [('alere', False)],
          'alet': [('ale', False)],
          'algt': [('ælge', False)],
          'algte': [('ælge', False)],
          'algtes': [('ælge', False)],
          'alider': [('alidere', False)],
          'alkende': [('alke', False)],
          'alker': [('alke', False)],
          'aller': [('alle', False)],
          'alokkes': [('alokke', False)],
          'alom': [('alome', False)],
          'aloner': [('alonere', False)],
          'alopper': [('aloppere', False)],
          'alp': [('ælpe', False)],
          'alper': [('alpe', False)],
          'alser': [('alse', False)],
          'alter': [('alte', False)],
          'alterer': [('alterere', True)],
          'aluer': [('aluere', False)],
          'alvende': [('alve', False)],
          'alver': [('alve', False)],
          'alyser': [('alysere', False)],
          'alæg': [('alægge', False)],
          'am': [('amme', True)],
          'amede': [('ame', False)],
          'amedes': [('ame', False)],
          'amer': [('amere', False)],
          'ames': [('ame', False)],
          'ammedes': [('amme', False)],
          'ammer': [('amme', False)],
          'ammerer': [('ammere', False)],
          'amoter': [('amotere', False)],
          'amper': [('ampe', False)],
          'amperer': [('ampere', False)],
          'amsende': [('amse', False)],
          'an': [('ane', True)],
          'ancer': [('ance', False)],
          'ancher': [('anchere', False)],
          'ande': [('ande', False)],
          'andedes': [('ande', False)],
          'ander': [('ande', False)],
          'andledes': [('andle', False)],
          'andrer': [('andrere', False)],
          'andret': [('andre', False)],
          'andt': [('inde', False)],
          'ane': [('ane', False)],
          'aner': [('ane', True)],
          'anet': [('ane', False)],
          'ang': [('inge', False)],
          'angedes': [('ange', False)],
          'anger': [('ange', False)],
          'anges': [('ange', False)],
          'ank': [('anke', True)],
          'ankende': [('anke', False)],
          'anker': [('anke', False)],
          'annedes': [('anne', False)],
          'anner': [('anne', False)],
          'annes': [('anne', False)],
          'anser': [('anse', False)],
          'ansret': [('ansre', False)],
          'antedes': [('ante', False)],
          'anter': [('ante', False)],
          'antes': [('antes', False)],
          'aper': [('apere', False)],
          'apet': [('ape', False)],
          'aplaner': [('aplane', False)],
          'aporer': [('aporere', False)],
          'appedes': [('appe', False)],
          'appeller': [('appellere', False)],
          'apper': [('appe', False)],
          'appes': [('appe', False)],
          'apporter': [('apportere', False)],
          'apredes': [('apre', False)],
          'apres': [('apre', False)],
          'ar': [('arre', True)],
          'arberede': [('arbere', False)],
          'archer': [('archere', False)],
          'ardedes': [('arde', False)],
          'arder': [('arde', False)],
          'arede': [('are', False)],
          'aredes': [('are', False)],
          'aren': [('are', False)],
          'arende': [('are', False)],
          'arer': [('arere', False)],
          'aret': [('are', False)],
          'arger': [('arge', False)],
          'arier': [('ariere', False)],
          'ariner': [('arinere', False)],
          'ariser': [('arisere', False)],
          'arkende': [('arke', False)],
          'arker': [('arke', False)],
          'armer': [('armere', True)],
          'arne': [('are', False)],
          'arper': [('arpe', False)],
          'arrer': [('arre', False)],
          'arser': [('arse', False)],
          'arter': [('arte', True)],
          'arver': [('arve', False)],
          'as': [('ase', False)],
          'asende': [('ase', False)],
          'aser': [('ase', True)],
          'ases': [('ase', True)],
          'asigner': [('asignere', False)],
          'asker': [('aske', False)],
          'asledes': [('asle', False)],
          'aslet': [('asle', False)],
          'aspirer': [('aspirere', True)],
          'aspoler': [('aspolere', False)],
          'asser': [('asse', False)],
          'ast': [('ase', False)],
          'aste': [('ase', False)],
          'astede': [('aste', False)],
          'astedes': [('aste', False)],
          'aster': [('aste', False)],
          'asterer': [('astere', False)],
          'astes': [('ase', False)],
          'astredes': [('astre', False)],
          'astrer': [('astrere', False)],
          'at': [('ætte', False)],
          'atag': [('atage', False)],
          'ater': [('atere', False)],
          'ates': [('ate', False)],
          'atier': [('atiere', False)],
          'ativer': [('ativere', False)],
          'atover': [('atovere', False)],
          'atredes': [('atre', False)],
          'atrende': [('atre', False)],
          'atrer': [('atre', False)],
          'atrækkes': [('atrække', False)],
          'atser': [('atse', False)],
          'atte': [('ætte', False)],
          'attedes': [('atte', False)],
          'atter': [('atte', False)],
          'atterer': [('attere', False)],
          'attes': [('ætte', False)],
          'aturer': [('aturere', False)],
          'aus': [('ausse', False)],
          'av': [('ave', True)],
          'avarer': [('avarere', False)],
          'avde': [('ave', False)],
          'avegne': [('avige', False)],
          'avende': [('ave', False)],
          'aver': [('ave', True)],
          'aviger': [('avigere', False)],
          'avles': [('avle', True)],
          'avredes': [('avre', False)],
          'avrer': [('avre', False)],
          'ayedes': [('aye', False)],
          'ayet': [('aye', False)],
          'b': [('be', False)],
          'bad': [('bade', True), ('bede', True)],
          'bader': [('bade', False)],
          'badser': [('badsere', False)],
          'bagedes': [('bage', True)],
          'bager': [('bage', False)],
          'bages': [('bage', False)],
          'bagt': [('bage', False)],
          'bagte': [('bage', False)],
          'bagtes': [('bage', False)],
          'bak': [('bakke', True)],
          'baller': [('ballere', False)],
          'ban': [('bane', True)],
          'baner': [('bane', True)],
          'bang': [('bange', False)],
          'bank': [('banke', True)],
          'bap': [('bappe', True)],
          'bar': [('bære', True), ('bare', True)],
          'barder': [('bardere', True)],
          'barer': [('bare', False)],
          'bares': [('bare', True)],
          'barmer': [('barme', False)],
          'baser': [('basere', True)],
          'bast': [('baste', True)],
          'baste': [('baste', True)],
          'bastes': [('baste', True)],
          'bat': [('batte', True)],
          'batte': [('batte', True)],
          'batter': [('batte', True)],
          'battes': [('batte', True)],
          'bbede': [('bbe', False)],
          'bbedes': [('bbe', False)],
          'bbes': [('bbes', False)],
          'bed': [('bide', True), ('bede', True)],
          'bede': [('bede', True)],
          'beder': [('bede', False)],
          'bedes': [('bede', True)],
          'begav': [('begive', True), ('begave', True)],
          'bejlede': [('bejle', True)],
          'bejledes': [('bejle', True)],
          'beller': [('bellere', False)],
          'belæs': [('belæsse', True)],
          'ben': [('bene', False)],
          'bende': [('be', False)],
          'benedes': [('bene', True)],
          'bener': [('bene', False)],
          'benes': [('bene', False)],
          'ber': [('be', False)],
          'berede': [('berede', True)],
          'beredes': [('berede', True)],
          'berer': [('bere', False)],
          'beret': [('berette', True)],
          'beriger': [('berige', True)],
          'bes': [('be', False)],
          'beser': [('bese', True)],
          'beset': [('bese', True)],
          'besteg': [('bestige', True)],
          'bestiller': [('bestille', False)],
          'beså': [('bese', True), ('beså', True)],
          'besås': [('beså', True), ('bese', True)],
          'betoner': [('betone', True)],
          'bevis': [('bevise', False)],
          'bider': [('bide', True)],
          'biet': [('bie', True)],
          'bil': [('bile', True)],
          'biler': [('bile', True)],
          'biliser': [('bilisere', False)],
          'bindes': [('binde', False)],
          'bis': [('bisse', True)],
          'bispevi': [('bispevie', True), ('bispevi', True)],
          'bispeviede': [('bispevie', True), ('bispevi', True)],
          'bispeviende': [('bispevie', True), ('bispevi', True)],
          'bispevier': [('bispevi', True), ('bispevie', True)],
          'bispevies': [('bispevie', True), ('bispevi', True)],
          'bispeviet': [('bispevi', True), ('bispevie', True)],
          'bispevir': [('bispevi', True), ('bispevie', True)],
          'bispevis': [('bispevi', True), ('bispevie', True)],
          'blanker': [('blanke', False)],
          'blede': [('ble', False)],
          'bledes': [('ble', False)],
          'bleger': [('blege', False)],
          'blende': [('blende', True)],
          'blet': [('ble', False)],
          'blev': [('blive', True)],
          'blevet': [('blive', False)],
          'blevne': [('blive', False)],
          'blicer': [('blicere', False)],
          'blimer': [('blimere', False)],
          'blog': [('blogge', True)],
          'blokkedes': [('blokke', True)],
          'blokkes': [('blokke', True)],
          'blot': [('blotte', True), ('blote', True)],
          'bluedes': [('blues', True)],
          'blues': [('blues', True)],
          'blær': [('blære', True)],
          'blæs': [('blæse', False)],
          'blæst': [('blæse', False)],
          'blæste': [('blæse', False)],
          'blæstes': [('blæse', False)],
          'blød': [('bløde', False)],
          'bne': [('bne', False)],
          'bnet': [('bne', False)],
          'bo': [('bo', True)],
          'boede': [('bo', False)],
          'boedes': [('bo', True)],
          'boende': [('bo', False)],
          'bog': [('boge', True)],
          'boger': [('boge', True)],
          'boges': [('boge', True)],
          'bol': [('bole', True), ('bolle', True)],
          'boler': [('bole', True)],
          'bolerer': [('bolere', False)],
          'bom': [('bomme', True)],
          'bon': [('bone', True)],
          'boner': [('bone', True)],
          'bonner': [('bonnere', False)],
          'bor': [('bore', True), ('bo', True)],
          'borer': [('bore', False)],
          'boret': [('bore', False)],
          'borter': [('bortere', False)],
          'bortrives': [('bortrive', True)],
          'bos': [('bosse', True)],
          'bosset': [('bosse', True)],
          'br': [('bre', False)],
          'bragt': [('bringe', False)],
          'bragte': [('bringe', False)],
          'bragtes': [('bringe', False)],
          'braiser': [('braisere', True)],
          'brak': [('brakke', True)],
          'brakkes': [('brakke', True)],
          'braser': [('brase', True)],
          'brast': [('briste', True), ('brase', True)],
          'braste': [('brase', True)],
          'brastes': [('brase', True)],
          'bred': [('brede', False)],
          'brede': [('brede', True)],
          'bredes': [('brede', False)],
          'bremsende': [('bremse', True)],
          'brende': [('bre', False)],
          'brer': [('brere', False)],
          'bret': [('bre', False)],
          'briller': [('brillere', True)],
          'bringer': [('bringe', False)],
          'brod': [('brodde', True)],
          'broder': [('brodere', False)],
          'brugt': [('bruge', False)],
          'brugte': [('bruge', False)],
          'brugtes': [('bruge', True)],
          'bruner': [('brunere', True), ('brune', True)],
          'brust': [('bruse', False)],
          'bruste': [('bruse', True)],
          'brustes': [('bruse', True)],
          'bryd': [('bryde', True)],
          'brydes': [('bryde', True), ('brydes', True)],
          'bryg': [('brygge', True)],
          'bræk': [('brække', False)],
          'brækkedes': [('brække', False)],
          'brækkes': [('brække', False)],
          'brættedes': [('brætte', True)],
          'brætter': [('brætte', True)],
          'bs': [('bse', False)],
          'bsende': [('bse', False)],
          'bserver': [('bservere', False)],
          'bses': [('bse', False)],
          'bslås': [('bslå', False)],
          'bte': [('be', False)],
          'btes': [('be', False)],
          'buder': [('bude', False)],
          'buer': [('bue', True)],
          'bues': [('bue', True)],
          'buet': [('bue', False)],
          'bugt': [('bugte', True)],
          'bugte': [('bugte', True)],
          'bugtes': [('bugte', True)],
          'bukket': [('bukke', True)],
          'bul': [('bule', True)],
          'buler': [('bule', True)],
          'bundet': [('bunde', True), ('binde', True)],
          'bundt': [('bundte', True)],
          'bundte': [('bundte', True)],
          'bundtes': [('bundte', True)],
          'bunket': [('bunke', True)],
          'burer': [('bure', True)],
          'burser': [('bursere', False)],
          'buser': [('buse', True)],
          'byder': [('byde', False)],
          'byedes': [('bye', False)],
          'byet': [('bye', False)],
          'båret': [('bære', False)],
          'bås': [('båse', True)],
          'bærdes': [('bærde', False)],
          'bæres': [('bære', True)],
          'bød': [('bøde', True), ('byde', True)],
          'bøg': [('bøge', True)],
          'bøget': [('bøge', True)],
          'bøjedes': [('bøje', True)],
          'bøjes': [('bøje', True)],
          'bøjet': [('bøje', False)],
          'bør': [('burde', True)],
          'bøs': [('bøsse', True)],
          'camper': [('campere', True)],
          'can': [('canne', False)],
          'cap': [('cappe', False)],
          'cast': [('caste', False)],
          'caste': [('caste', False)],
          'castes': [('caste', True)],
          'causer': [('causere', True)],
          'ccelerer': [('ccelerere', False)],
          'cede': [('ce', False)],
          'cedes': [('ce', False)],
          'celerer': [('celere', False)],
          'celler': [('cellere', False)],
          'cende': [('ce', False)],
          'cender': [('cendere', False)],
          'censer': [('censere', False)],
          'centrer': [('centrere', True), ('centre', True)],
          'cerede': [('cere', False)],
          'ceredes': [('cere', False)],
          'cerer': [('cere', False)],
          'cerper': [('cerpere', False)],
          'certer': [('certere', False)],
          'ces': [('ce', False)],
          'cetter': [('cettere', False)],
          'charmer': [('charmere', True), ('charme', True)],
          'chatter': [('chatte', True)],
          'cher': [('chere', False)],
          'cier': [('ciere', False)],
          'ciler': [('cilere', False)],
          'ciller': [('cillere', False)],
          'ciser': [('cisere', False)],
          'ckede': [('cke', False)],
          'ckedes': [('cke', False)],
          'ckende': [('cke', False)],
          'cker': [('cke', False)],
          'ckles': [('ckle', False)],
          'committer': [('committe', True)],
          'corer': [('core', False)],
          'coret': [('core', False)],
          'croller': [('crolle', False)],
          'dagedes': [('dages', True)],
          'dager': [('dage', False)],
          'dages': [('dages', True)],
          'dal': [('dale', True)],
          'daler': [('dale', True)],
          'dan': [('danne', False)],
          'dander': [('dandere', True)],
          'dank': [('danke', False)],
          'darmer': [('darme', False)],
          'dater': [('date', True), ('datere', True)],
          'dbad': [('dbede', False)],
          'dbar': [('dbære', False)],
          'dbed': [('dbede', False)],
          'dbedes': [('dbede', False)],
          'dbor': [('dbore', False)],
          'dbrydes': [('dbryde', False)],
          'dbundet': [('dbinde', False)],
          'dbød': [('dbyde', False)],
          'ddater': [('ddatere', False)],
          'dde': [('dde', False)],
          'dder': [('ddere', False)],
          'ddes': [('dde', False)],
          'ddrager': [('ddrage', False)],
          'ddøde': [('ddø', False)],
          'ddødes': [('ddø', False)],
          'debor': [('debore', False)],
          'dede': [('de', False)],
          'dedes': [('de', False)],
          'degav': [('degive', False)],
          'dekser': [('deksere', False)],
          'del': [('dele', False)],
          'deler': [('dele', False)],
          'deller': [('dellere', False)],
          'dende': [('de', False)],
          'denser': [('densere', False)],
          'der': [('de', False)],
          'derede': [('dere', False)],
          'deredes': [('dere', False)],
          'derer': [('dere', False)],
          'derfaredes': [('derfares', False)],
          'derfares': [('derfares', False)],
          'derfaret': [('derfares', False)],
          'deser': [('dese', False)],
          'deset': [('dese', False)],
          'designer': [('designere', True), ('designe', True)],
          'destiller': [('destillere', True)],
          'deså': [('dese', False)],
          'dfandtes': [('dfinde', False)],
          'dfattedes': [('dfatte', False)],
          'dfattes': [('dfatte', False)],
          'dfiltrer': [('dfiltre', False)],
          'dfindes': [('dfinde', False)],
          'dflet': [('dflette', False)],
          'dflys': [('dfly', False)],
          'dfor': [('dfore', False)],
          'dformer': [('dforme', False)],
          'dgrader': [('dgradere', False)],
          'dgraver': [('dgravere', False)],
          'dgrunder': [('dgrunde', False)],
          'dgød': [('dgyde', False)],
          'dgør': [('dgøre', False)],
          'dhugges': [('dhugge', False)],
          'dhul': [('dhule', False)],
          'dhyl': [('dhylle', False)],
          'dier': [('die', True)],
          'diet': [('die', True)],
          'dig': [('dige', False)],
          'digedes': [('dige', False)],
          'diger': [('dige', False)],
          'diges': [('dige', False)],
          'digt': [('digte', False)],
          'digte': [('digte', False)],
          'digtes': [('digte', False)],
          'dik': [('dikke', True)],
          'dikende': [('dike', False)],
          'diker': [('dike', False)],
          'dikter': [('diktere', True)],
          'dir': [('dirre', True)],
          'diser': [('disere', False)],
          'diskende': [('diske', True)],
          'divedes': [('dive', False)],
          'diver': [('dive', False)],
          'dives': [('dive', False)],
          'djog': [('djage', False)],
          'dkende': [('dkende', False)],
          'dkerer': [('dkerere', False)],
          'dklarer': [('dklarere', False)],
          'dkrer': [('dkre', False)],
          'dkys': [('dkysse', False)],
          'dkårede': [('dkåre', False)],
          'dled': [('dlede', False)],
          'dlede': [('dlede', False)],
          'dlededes': [('dlede', False)],
          'dledes': [('dle', False)],
          'dledet': [('dlede', False)],
          'dlet': [('dle', False)],
          'dlod': [('dlade', False)],
          'dlosser': [('dlosse', False)],
          'dlyder': [('dlyde', False)],
          'dlys': [('dlyse', False)],
          'dlyst': [('dlyse', False)],
          'dlyste': [('dlyse', False)],
          'dlystes': [('dlyse', False)],
          'dlæg': [('dlægge', False)],
          'dlær': [('dlære', False)],
          'dlæs': [('dlæse', False)],
          'dlæst': [('dlæse', False)],
          'dlæste': [('dlæse', False)],
          'dlæstes': [('dlæse', False)],
          'dm': [('dme', False)],
          'dmatter': [('dmatte', False)],
          'dmede': [('dme', False)],
          'dmedes': [('dme', False)],
          'dmes': [('dme', False)],
          'dmur': [('dmure', False)],
          'dne': [('dne', False)],
          'dnet': [('dne', False)],
          'dolerer': [('dolere', False)],
          'doller': [('dollere', True)],
          'donner': [('donnere', False)],
          'dop': [('dope', True)],
          'doper': [('dope', True)],
          'doser': [('dosere', True)],
          'dosser': [('dossere', False)],
          'doucher': [('douche', True)],
          'dovne': [('dovne', True)],
          'dpasser': [('dpasse', False)],
          'dposer': [('dpose', False)],
          'dr': [('dre', False)],
          'drager': [('dragere', True), ('drage', True)],
          'drak': [('drikke', True)],
          'drakkes': [('drakke', False)],
          'drat': [('dratte', True)],
          'dred': [('drede', False)],
          'drede': [('dre', False)],
          'dredet': [('drede', False)],
          'dren': [('dre', False)],
          'drende': [('dre', False)],
          'dret': [('dre', False)],
          'drevne': [('drive', True)],
          'driller': [('drille', True)],
          'drog': [('drage', False)],
          'droner': [('dronere', False)],
          'drukket': [('drikke', False)],
          'druller': [('drulle', False)],
          'drunder': [('drunde', False)],
          'drundet': [('drinde', False)],
          'drættedes': [('drætte', False)],
          'drætter': [('drætte', False)],
          'drør': [('drøre', False)],
          'ds': [('dse', False)],
          'dses': [('dse', False)],
          'dskar': [('dskære', False)],
          'dsker': [('dske', False)],
          'dskiftedes': [('dskifte', False)],
          'dskiftes': [('dskifte', False)],
          'dskilt': [('dskille', False)],
          'dskilte': [('dskille', False)],
          'dskiltes': [('dskille', False)],
          'dskyldes': [('dskylde', False)],
          'dskyldtes': [('dskylde', False)],
          'dskød': [('dskyde', False)],
          'dslap': [('dslippe', False)],
          'dsled': [('dslide', False)],
          'dsledes': [('dsle', False)],
          'dslet': [('dslette', False)],
          'dslås': [('dslå', False)],
          'dsmed': [('dsmide', False)],
          'dspar': [('dspare', False)],
          'dspil': [('dspille', False)],
          'dst': [('de', False)],
          'dstak': [('dstikke', False)],
          'dste': [('de', False)],
          'dsteg': [('dstege', False)],
          'dstes': [('de', False)],
          'dstil': [('dstille', False)],
          'dstod': [('dstå', False)],
          'dsulter': [('dsulte', False)],
          'dsved': [('dsvede', False)],
          'dsyr': [('dsyre', False)],
          'dså': [('dså', False)],
          'dsår': [('dså', False)],
          'dsås': [('dse', False)],
          'dt': [('dte', False)],
          'dtag': [('dtage', False)],
          'dtalt': [('dtale', False)],
          'dtalte': [('dtale', False)],
          'dtaltes': [('dtale', False)],
          'dte': [('de', False)],
          'dtraf': [('dtræffe', False)],
          'dtræffes': [('dtræffe', False)],
          'dtrækkes': [('dtrække', False)],
          'dtrættedes': [('dtrætte', False)],
          'dtrættes': [('dtrætte', False)],
          'dtæres': [('dtære', False)],
          'dtør': [('dtørre', False)],
          'du': [('du', True)],
          'dubler': [('dublere', True), ('duble', True)],
          'duede': [('du', True)],
          'duedes': [('du', True)],
          'duende': [('du', True)],
          'duer': [('du', True)],
          'dukket': [('dukke', True)],
          'dunket': [('dunke', True)],
          'duppet': [('duppe', True)],
          'dur': [('du', True), ('dure', True)],
          'durer': [('dure', True)],
          'dvar': [('dvare', False)],
          'dvegne': [('dvige', False)],
          'dvende': [('dvende', False)],
          'dvies': [('dvie', False)],
          'dvis': [('dvise', False)],
          'dviser': [('dvisere', False)],
          'dvist': [('dvise', False)],
          'dviste': [('dvise', False)],
          'dvær': [('dvære', False)],
          'dy': [('dy', True)],
          'dyede': [('dy', True)],
          'dyende': [('dy', True)],
          'dyer': [('dy', True)],
          'dyr': [('dy', True)],
          'dys': [('dysse', True)],
          'dyst': [('dyste', True)],
          'dyste': [('dyste', True)],
          'dystes': [('dyste', True)],
          'dåret': [('dåre', False)],
          'dæmmes': [('dæmme', False)],
          'døb': [('døbe', True)],
          'død': [('dø', True), ('døde', True)],
          'døde': [('døde', True), ('dø', True)],
          'dødes': [('dø', True), ('døde', True)],
          'døjes': [('døje', False)],
          'døjet': [('døje', False)],
          'dør': [('dø', False)],
          'eader': [('eade', False)],
          'eager': [('eagere', False)],
          'eagte': [('eagte', False)],
          'eagtes': [('eagte', False)],
          'eak': [('eake', False)],
          'eakende': [('eake', False)],
          'eaker': [('eake', False)],
          'eal': [('eale', False)],
          'ealer': [('eale', False)],
          'eam': [('eame', False)],
          'eamer': [('eame', False)],
          'ear': [('eare', False)],
          'earcher': [('earche', False)],
          'earer': [('eare', False)],
          'eares': [('eare', False)],
          'eb': [('ebbe', True)],
          'ebar': [('ebære', False)],
          'ebatter': [('ebattere', False)],
          'ebbes': [('ebbe', True)],
          'ebede': [('ebe', False)],
          'ebedes': [('ebe', False)],
          'eben': [('ibe', False)],
          'ebet': [('ibe', False)],
          'eblende': [('eble', False)],
          'ebler': [('eble', False)],
          'ebne': [('ibe', False)],
          'ebor': [('ebo', False)],
          'ebos': [('ebo', False)],
          'ebrede': [('ebre', False)],
          'ebredes': [('ebre', False)],
          'ebrer': [('ebre', False)],
          'ebundet': [('ebinde', False)],
          'ecelerer': [('ecelerere', False)],
          'ed': [('ide', False)],
          'edater': [('edatere', False)],
          'eddedes': [('edde', False)],
          'edder': [('edde', False)],
          'ede': [('', False)],
          'eden': [('ide', False)],
          'eder': [('edere', False)],
          'edesigner': [('edesigne', False)],
          'edet': [('ide', False)],
          'edfor': [('edfare', False)],
          'edgraver': [('edgrave', False)],
          'edier': [('ediere', False)],
          'ediger': [('edigere', False)],
          'ediker': [('edikere', False)],
          'ediser': [('edise', False)],
          'edne': [('ide', False)],
          'edrager': [('edrage', False)],
          'edrak': [('edrakke', False)],
          'edredes': [('edre', False)],
          'edrer': [('edre', False)],
          'edrundet': [('edrunde', False)],
          'edsende': [('edse', False)],
          'edser': [('edse', False)],
          'edsteg': [('edstige', False)],
          'edt': [('ede', False)],
          'edte': [('edte', False)],
          'edter': [('edte', False)],
          'edtes': [('ede', False)],
          'edubler': [('eduble', False)],
          'edyr': [('edyre', False)],
          'eed': [('eede', False)],
          'eede': [('eede', False)],
          'eededes': [('eede', False)],
          'eeder': [('eede', False)],
          'eedes': [('e', False)],
          'eedet': [('eede', False)],
          'eel': [('eele', False)],
          'eeler': [('eele', False)],
          'een': [('eene', False)],
          'eende': [('e', False)],
          'eenedes': [('eene', False)],
          'eener': [('eene', False)],
          'eenes': [('eene', False)],
          'eer': [('eere', False)],
          'eerede': [('eere', False)],
          'eeredes': [('eere', False)],
          'eerer': [('eere', False)],
          'eet': [('e', False)],
          'eete': [('eete', False)],
          'eeter': [('eete', False)],
          'eetes': [('eete', False)],
          'efandtes': [('efinde', False)],
          'efattedes': [('efatte', False)],
          'efattes': [('efatte', False)],
          'efede': [('efe', False)],
          'efedes': [('efe', False)],
          'eferer': [('eferere', False)],
          'efes': [('efe', False)],
          'efiler': [('efilere', False)],
          'efindes': [('efinde', False)],
          'efiner': [('efinere', False)],
          'eflede': [('efle', False)],
          'efler': [('efle', False)],
          'eflet': [('efle', False)],
          'efor': [('efare', False)],
          'eformer': [('eformere', False)],
          'efuser': [('efusere', False)],
          'efærdedes': [('efærde', False)],
          'efærdes': [('efærde', False)],
          'eg': [('ige', False)],
          'egede': [('ige', False)],
          'egen': [('ige', False)],
          'egenerer': [('egenerere', False)],
          'eger': [('egere', False)],
          'egerer': [('egere', False)],
          'eget': [('ige', False)],
          'egler': [('egle', False)],
          'egne': [('egne', True)],
          'egner': [('egne', False)],
          'egrader': [('egradere', False)],
          'egraver': [('egrave', False)],
          'egrunder': [('egrunde', False)],
          'egt': [('ege', False)],
          'egte': [('ege', False)],
          'egtes': [('ege', False)],
          'egør': [('egøre', False)],
          'eiler': [('eile', False)],
          'ek': [('ekke', False)],
          'ekanter': [('ekantere', False)],
          'eker': [('ekere', False)],
          'ekkedes': [('ekke', False)],
          'ekkes': [('ekke', False)],
          'eklarer': [('eklarere', False)],
          'eklasser': [('eklassere', False)],
          'ekliner': [('eklinere', False)],
          'ekrigedes': [('ekrige', False)],
          'ekriges': [('ekrige', False)],
          'ekser': [('ekse', False)],
          'ekuler': [('ekulere', False)],
          'ekurrer': [('ekurrere', False)],
          'ekyler': [('ekylere', False)],
          'ekys': [('ekysse', False)],
          'el': [('elle', False)],
          'elancer': [('elance', False)],
          'elaver': [('elave', False)],
          'elbed': [('elbide', False)],
          'eldedes': [('elde', False)],
          'eldende': [('elde', False)],
          'elder': [('elde', False)],
          'elede': [('ele', False)],
          'eledes': [('ele', False)],
          'eleger': [('elegere', False)],
          'elen': [('ele', False)],
          'eler': [('elere', False)],
          'elet': [('ele', False)],
          'eletter': [('elettere', False)],
          'elever': [('elevere', True)],
          'elider': [('elidere', True)],
          'elirer': [('elirere', False)],
          'eller': [('elle', False)],
          'elod': [('elade', False)],
          'elser': [('else', False)],
          'elt': [('ele', False)],
          'elte': [('ele', False)],
          'elter': [('elte', False)],
          'eltes': [('ele', False)],
          'elys': [('elyse', False)],
          'elyst': [('elyse', False)],
          'elyste': [('elyse', False)],
          'elystes': [('elyse', False)],
          'elæg': [('elægge', False)],
          'elær': [('elære', False)],
          'elæs': [('elæse', False)],
          'elæste': [('elæse', False)],
          'elæstes': [('elæse', False)],
          'em': [('emme', True)],
          'emander': [('emande', False)],
          'emaner': [('emanere', True)],
          'emasker': [('emaskere', False)],
          'emede': [('eme', False)],
          'emedes': [('eme', False)],
          'emes': [('eme', False)],
          'emgås': [('emgå', False)],
          'emlæst': [('emlæste', False)],
          'emlæste': [('emlæste', False)],
          'emlæstes': [('emlæste', False)],
          'emmedes': [('emme', False)],
          'emmer': [('emme', False)],
          'emorer': [('emorere', False)],
          'emper': [('empe', False)],
          'emt': [('emte', False)],
          'emte': [('emte', False)],
          'emtes': [('emte', False)],
          'emuler': [('emulere', True)],
          'emur': [('emure', False)],
          'en': [('e', False)],
          'ende': [('ende', True)],
          'endedes': [('ende', False)],
          'ender': [('ende', False)],
          'endledes': [('endle', False)],
          'endte': [('ende', False)],
          'ene': [('ene', False)],
          'enedes': [('enes', True)],
          'ener': [('enere', False)],
          'enes': [('enes', True)],
          'enet': [('ene', False)],
          'enfiltrer': [('enfiltre', False)],
          'enger': [('enge', False)],
          'ennedes': [('enne', False)],
          'enner': [('enne', False)],
          'ennes': [('enne', False)],
          'enopret': [('enoprette', False)],
          'enoter': [('enotere', False)],
          'enser': [('ense', False)],
          'ent': [('ene', False)],
          'ente': [('ene', False)],
          'entedes': [('ente', False)],
          'enter': [('ente', False)],
          'entes': [('ene', False)],
          'entrer': [('entre', True), ('entrere', True)],
          'epasser': [('epasse', False)],
          'eper': [('epere', False)],
          'epiler': [('epilere', True)],
          'eppedes': [('eppe', False)],
          'epper': [('eppe', False)],
          'eppes': [('eppe', False)],
          'eprimer': [('eprimere', False)],
          'er': [('være', True)],
          'erab': [('erabe', False)],
          'erabede': [('erabe', False)],
          'erabedes': [('erabe', False)],
          'erager': [('eragere', False)],
          'ercer': [('erce', False)],
          'ered': [('erede', False)],
          'erende': [('ere', False)],
          'eret': [('ere', False)],
          'erfaredes': [('erfare', True)],
          'erfares': [('erfare', True)],
          'erfaret': [('erfare', True)],
          'erforer': [('erfore', False)],
          'erger': [('erge', False)],
          'erier': [('eriere', False)],
          'erig': [('erige', False)],
          'eriger': [('erigere', True)],
          'eril': [('erile', False)],
          'eris': [('erise', False)],
          'eriser': [('erisere', False)],
          'eriver': [('erivere', False)],
          'erlede': [('erle', False)],
          'erledes': [('erle', False)],
          'erlist': [('erliste', False)],
          'erliste': [('erliste', False)],
          'erlistes': [('erliste', False)],
          'erlystes': [('erlyse', False)],
          'erlæs': [('erlæsse', False)],
          'erner': [('erne', False)],
          'eroder': [('erodere', True)],
          'erper': [('erpe', False)],
          'errende': [('errende', False)],
          'errer': [('erre', False)],
          'erret': [('errette', False)],
          'erriver': [('errive', False)],
          'ersende': [('ersende', False)],
          'erser': [('erse', False)],
          'erstyr': [('erstyre', False)],
          'ertalte': [('ertale', False)],
          'ertaltes': [('ertale', False)],
          'erter': [('erte', False)],
          'erver': [('erve', False)],
          'erviser': [('ervise', False)],
          'erøg': [('eryge', False)],
          'erøget': [('eryge', False)],
          'erøs': [('erøse', False)],
          'erøst': [('erøse', False)],
          'erøste': [('erøse', False)],
          'erøstes': [('erøse', False)],
          'esende': [('esende', False)],
          'eser': [('esere', False)],
          'eserver': [('eservere', False)],
          'eses': [('ese', False)],
          'eset': [('ise', False)],
          'eskar': [('eskære', False)],
          'esker': [('eske', False)],
          'eskiftedes': [('eskifte', False)],
          'eskiftes': [('eskifte', False)],
          'eskorter': [('eskortere', True)],
          'eskyldes': [('eskylde', False)],
          'eskyldtes': [('eskylde', False)],
          'eskændes': [('eskænde', False)],
          'eskød': [('eskyde', False)],
          'eslås': [('eslå', False)],
          'esoner': [('esonere', False)],
          'espar': [('espare', False)],
          'espil': [('espille', False)],
          'espirer': [('espirere', False)],
          'esser': [('esse', False)],
          'estak': [('estikke', False)],
          'estede': [('este', False)],
          'estedes': [('este', False)],
          'esteg': [('estege', False)],
          'ester': [('este', False)],
          'esterer': [('estere', False)],
          'estil': [('estille', False)],
          'estimer': [('estimere', True)],
          'estod': [('estå', False)],
          'estredes': [('estre', False)],
          'estrer': [('estrere', False)],
          'estrides': [('estride', False)],
          'esulter': [('esultere', False)],
          'esår': [('eså', False)],
          'esås': [('ese', False)],
          'et': [('e', False)],
          'etag': [('etage', False)],
          'etaljer': [('etaljere', False)],
          'etalt': [('etale', False)],
          'etalte': [('etale', False)],
          'etaltes': [('etale', False)],
          'ete': [('e', False)],
          'eter': [('etere', False)],
          'etes': [('e', False)],
          'etlede': [('etle', False)],
          'etledes': [('etle', False)],
          'eto': [('etoe', False)],
          'etoede': [('etoe', False)],
          'etoende': [('etoe', False)],
          'etoet': [('etoe', False)],
          'etoner': [('etonere', False)],
          'etrækkes': [('etrække', False)],
          'etræner': [('etræne', False)],
          'ets': [('es', False)],
          'ettedes': [('ette', False)],
          'etter': [('ette', False)],
          'etterer': [('ettere', False)],
          'etør': [('etørre', False)],
          'ev': [('ive', False)],
          'evar': [('evare', False)],
          'evede': [('ive', False)],
          'even': [('ive', False)],
          'evende': [('evende', False)],
          'everer': [('everere', False)],
          'evet': [('ive', False)],
          'evider': [('evidere', False)],
          'evier': [('eviere', False)],
          'eviser': [('evise', False)],
          'evist': [('evise', False)],
          'eviste': [('evise', False)],
          'evistes': [('evise', False)],
          'evles': [('evle', False)],
          'evne': [('evne', True)],
          'evover': [('evovere', False)],
          'evredes': [('evre', False)],
          'evrer': [('evre', False)],
          'eæres': [('eære', False)],
          'f': [('fe', False)],
          'f.': [('ævnføre', False)],
          'fader': [('fade', True)],
          'fakende': [('fake', True)],
          'faker': [('fake', True)],
          'fal': [('fale', False)],
          'faler': [('fale', False)],
          'falter': [('faltere', False)],
          'falterer': [('faltere', False)],
          'fandtes': [('findes', True), ('finde', True)],
          'faner': [('fanere', False)],
          'fang': [('fange', False)],
          'far': [('fare', False)],
          'faredes': [('fare', True)],
          'farer': [('fare', True)],
          'fares': [('fare', False)],
          'faret': [('fare', True)],
          'farser': [('farsere', True)],
          'fast': [('faste', True)],
          'faste': [('faste', True)],
          'fastes': [('faste', True)],
          'fat': [('fatte', False)],
          'fatte': [('fatte', False)],
          'fattedes': [('fattes', True), ('fatte', True)],
          'fattes': [('fattes', True), ('fatte', True)],
          'fbrydes': [('fbryde', False)],
          'fbundet': [('fbinde', False)],
          'fbød': [('fbøde', False)],
          'fdrager': [('fdrage', False)],
          'fed': [('fede', True)],
          'fede': [('fede', True)],
          'fededes': [('fede', False)],
          'feder': [('fede', False)],
          'fedes': [('fede', True)],
          'fedet': [('fede', False)],
          'fedt': [('fedte', True)],
          'fedtes': [('fedte', True)],
          'fejlede': [('fejle', True)],
          'fejledes': [('fejle', False)],
          'fende': [('fe', False)],
          'fer': [('fe', False)],
          'ferede': [('fere', False)],
          'feredes': [('fere', False)],
          'ferer': [('fere', False)],
          'fes': [('fise', True)],
          'fester': [('feste', True)],
          'ffandtes': [('ffinde', False)],
          'ffattedes': [('ffatte', False)],
          'ffattes': [('ffatte', False)],
          'ffede': [('ffe', False)],
          'fferer': [('fferere', False)],
          'ffindes': [('ffinde', False)],
          'fgraver': [('fgrave', False)],
          'fgør': [('fgøre', False)],
          'fhuggedes': [('fhugge', False)],
          'fier': [('fiere', False)],
          'fikser': [('fiksere', True), ('fikse', True)],
          'filer': [('filere', True), ('file', True)],
          'filtrer': [('filtre', True), ('filtrere', True)],
          'fin': [('fine', False)],
          'findes': [('finde', True), ('findes', True)],
          'finer': [('finere', True)],
          'finger': [('fingere', True)],
          'fingerer': [('fingere', True), ('fingerere', True)],
          'fint': [('finte', True)],
          'finte': [('finte', True)],
          'fintes': [('finte', True)],
          'fir': [('fire', True)],
          'firer': [('fire', True)],
          'firmer': [('firme', True)],
          'fiser': [('fise', False)],
          'fiskende': [('fiske', True)],
          'fisker': [('fiske', True)],
          'fist': [('fiste', True), ('fise', True)],
          'fiste': [('fiste', True), ('fise', True)],
          'fistes': [('fiste', True), ('fise', True)],
          'fistrer': [('fistre', True)],
          'fkalker': [('fkalke', False)],
          'fklarer': [('fklare', False)],
          'fkorter': [('fkorte', False)],
          'flakser': [('flakse', True)],
          'flammer': [('flamme', False)],
          'flaner': [('flanere', True), ('flane', True)],
          'fled': [('flede', False)],
          'fledes': [('fle', False)],
          'fledet': [('flede', False)],
          'fler': [('flere', False)],
          'flet': [('flette', True)],
          'flever': [('flevere', False)],
          'flokkedes': [('flokkes', True), ('flokke', True)],
          'flokkes': [('flokke', True), ('flokkes', True)],
          'flopper': [('floppe', True)],
          'florer': [('florere', False)],
          'flosser': [('flosse', True)],
          'flot': [('flotte', True)],
          'flovedes': [('floves', True), ('flove', True)],
          'floves': [('floves', True), ('flove', True)],
          'fluer': [('fluere', False)],
          'flus': [('fluse', False)],
          'flyder': [('flyde', False)],
          'flys': [('fly', True)],
          'flyst': [('flyse', False)],
          'flyste': [('flyse', False)],
          'flystes': [('flyse', False)],
          'flå': [('flå', True)],
          'flås': [('flå', True)],
          'flæg': [('flægge', False)],
          'flængedes': [('flænge', True)],
          'flænges': [('flænge', True)],
          'flær': [('flære', False)],
          'flæst': [('flæse', False)],
          'flæste': [('flæse', False)],
          'flæstes': [('flæse', False)],
          'flød': [('fløde', True), ('flyde', True)],
          'fløj': [('flyve', False)],
          'fløjet': [('flyve', False)],
          'fmatter': [('fmatte', False)],
          'fnes': [('fnise', True)],
          'fniser': [('fnise', True)],
          'fnug': [('fnugge', True)],
          'fnys': [('fnyse', True)],
          'fnystes': [('fnyse', True)],
          'fnød': [('fnøde', False)],
          'fol': [('fole', True)],
          'foler': [('fole', True)],
          'for': [('fare', True), ('fore', True)],
          'forberede': [('forberede', True)],
          'foren': [('forene', False)],
          'forer': [('fore', True)],
          'foret': [('fore', False)],
          'forker': [('forke', True)],
          'former': [('forme', True), ('formere', True)],
          'fortalt': [('fortale', True), ('fortælle', True)],
          'fortalte': [('fortale', True), ('fortælle', True)],
          'fortaltes': [('fortælle', True), ('fortale', True)],
          'forvis': [('forvise', True), ('forvisse', True)],
          'fos': [('fosse', True)],
          'foser': [('fosere', False)],
          'fosset': [('fosse', True)],
          'fpasser': [('fpasse', False)],
          'fr': [('fre', False)],
          'fr.': [('ævnføre', False)],
          'franker': [('frankere', False)],
          'frapper': [('frappere', True)],
          'fraser': [('frasere', True)],
          'fred': [('frede', False)],
          'frede': [('frede', True)],
          'fredes': [('frede', False)],
          'fredet': [('frede', False)],
          'frem': [('fremme', False)],
          'fremsende': [('fremsende', True)],
          'frende': [('fre', False)],
          'frer': [('frere', False)],
          'fret': [('fre', False)],
          'frevne': [('frive', False)],
          'fris': [('fri', False)],
          'friser': [('frisere', True)],
          'frosset': [('fryse', False)],
          'frotter': [('frottere', True)],
          'frunder': [('frunde', False)],
          'frundet': [('frunde', False)],
          'fryd': [('fryde', True)],
          'frydes': [('fryde', True)],
          'frygtedes': [('frygte', True)],
          'frygtes': [('frygte', True)],
          'frys': [('fryse', False)],
          'frås': [('fråse', True)],
          'frøs': [('fryse', False)],
          'fses': [('fse', False)],
          'fskal': [('fskalle', False)],
          'fskar': [('fskære', False)],
          'fskød': [('fskyde', False)],
          'fslap': [('fslappe', False)],
          'fslås': [('fslå', False)],
          'fspil': [('fspille', False)],
          'fstak': [('fstikke', False)],
          'fstod': [('fstå', False)],
          'fsved': [('fsvide', False)],
          'fsvedet': [('fsvide', False)],
          'fsyr': [('fsyre', False)],
          'fså': [('fse', False)],
          'fsås': [('fse', False)],
          'ft': [('fte', False)],
          'ftag': [('ftage', False)],
          'ftalt': [('ftale', False)],
          'ftalte': [('ftale', False)],
          'ftaltes': [('ftale', False)],
          'fte': [('fte', False)],
          'ftes': [('fte', False)],
          'ftig': [('ftige', False)],
          'ftør': [('ftørre', False)],
          'fug': [('fuge', True)],
          'fuger': [('fuge', True)],
          'fugt': [('fugte', False)],
          'fugte': [('fugte', False)],
          'fugtes': [('fugte', False)],
          'fuldende': [('fuldende', True), ('fulde', True)],
          'fumerer': [('fumere', False)],
          'funder': [('fundere', False)],
          'funger': [('fungere', True)],
          'funket': [('funke', True)],
          'fuppet': [('fuppe', True)],
          'furer': [('fure', True)],
          'fuser': [('fuse', False)],
          'fvende': [('fvende', False)],
          'fvis': [('fvise', False)],
          'fviser': [('fvise', False)],
          'fvist': [('fvise', False)],
          'fvistes': [('fvise', False)],
          'fyg': [('fyge', True)],
          'fyldes': [('fylde', False)],
          'fyldtes': [('fylde', False)],
          'få': [('få', True)],
          'får': [('få', True)],
          'fås': [('få', True)],
          'fægt': [('fægte', False)],
          'fægte': [('fægte', False)],
          'fægtes': [('fægte', True)],
          'færdedes': [('færdes', True)],
          'færdes': [('færdes', True)],
          'fæst': [('fæste', False)],
          'fæste': [('fæste', True)],
          'fæstes': [('fæste', False)],
          'føg': [('fyge', True)],
          'føget': [('fyge', True)],
          'føj': [('føje', False)],
          'føjedes': [('føje', True)],
          'føjes': [('føje', False)],
          'føjet': [('føje', False)],
          'føl': [('føle', True)],
          'føn': [('føne', True)],
          'g': [('ge', False)],
          'gab': [('gabe', True)],
          'gaber': [('gabe', False)],
          'gad': [('gide', True)],
          'gaffede': [('gaffe', True)],
          'gaffedes': [('gaffe', True)],
          'gaflede': [('gafle', True)],
          'gafledes': [('gafle', True)],
          'gager': [('gagere', True)],
          'gal': [('gale', True)],
          'galer': [('gale', True)],
          'galp': [('galpe', True)],
          'gander': [('gandere', False)],
          'gang': [('gange', True)],
          'gantedes': [('gantes', True)],
          'garder': [('gardere', False)],
          'gas': [('gasse', True)],
          'gav': [('give', False)],
          'gaver': [('gave', False)],
          'gbundet': [('gbinde', False)],
          'gede': [('ge', False)],
          'gedes': [('ge', False)],
          'gejlede': [('gejle', False)],
          'gejledes': [('gejle', False)],
          'gelerer': [('gelere', False)],
          'gemt': [('gemme', True)],
          'gemte': [('gemme', True)],
          'gemtes': [('gemme', True)],
          'gen': [('genne', True)],
          'gende': [('ge', False)],
          'generer': [('genere', True), ('generere', True)],
          'ger': [('gere', True)],
          'gerede': [('gere', False)],
          'geredes': [('gere', False)],
          'gerer': [('gerere', True), ('gere', True)],
          'ges': [('ge', False)],
          'gestiller': [('gestille', False)],
          'getter': [('gettere', False)],
          'gevis': [('gevise', False)],
          'gger': [('gge', False)],
          'ggerer': [('ggerere', False)],
          'ggraver': [('ggravere', False)],
          'ggør': [('ggøre', False)],
          'gi': [('gi', True), ('gie', True)],
          'gider': [('gide', True)],
          'giede': [('gi', True), ('gie', True)],
          'giende': [('gi', True), ('gie', True)],
          'gier': [('gie', True), ('gi', True)],
          'gies': [('gi', True), ('gie', True)],
          'giet': [('gie', True), ('gi', True)],
          'giftes': [('gifte', False)],
          'gikkes': [('gås', False)],
          'gir': [('gire', True), ('gie', True), ('gi', True)],
          'girer': [('gire', True), ('girere', True)],
          'gis': [('gie', True), ('gi', True)],
          'giser': [('gisere', False)],
          'giver': [('give', False)],
          'gives': [('give', False)],
          'gjorde': [('gøre', False)],
          'gjordes': [('gøre', False)],
          'gkårede': [('gkåre', False)],
          'gled': [('glide', True)],
          'glede': [('gle', False)],
          'gledes': [('gle', False)],
          'gledet': [('glide', True)],
          'glet': [('gle', False)],
          'gliger': [('gligere', False)],
          'glitrer': [('glitre', True)],
          'glo': [('glo', False)],
          'glos': [('glo', True)],
          'glosser': [('glossere', True)],
          'glyst': [('glyse', False)],
          'glyste': [('glyse', False)],
          'glystes': [('glyse', False)],
          'glæder': [('glæde', True)],
          'glæg': [('glægge', False)],
          'glæs': [('glæse', False)],
          'glæst': [('glæse', False)],
          'glæste': [('glæse', False)],
          'glød': [('gløde', True)],
          'gne': [('gne', False)],
          'gner': [('gnere', False)],
          'gnet': [('gne', False)],
          'gouter': [('goutere', True)],
          'gr': [('gre', False)],
          'grader': [('grade', True), ('gradere', True)],
          'grammer': [('grammere', False)],
          'graver': [('gravere', True), ('grave', True)],
          'greb': [('gribe', False)],
          'grebet': [('gribe', False)],
          'grede': [('gre', False)],
          'greder': [('gredere', False)],
          'gredes': [('gre', False)],
          'greger': [('gregere', False)],
          'grende': [('gre', False)],
          'grer': [('grere', False)],
          'gret': [('gre', False)],
          'grib': [('gribe', False)],
          'griller': [('grille', True), ('grillere', True)],
          'grim': [('grimme', False)],
          'grint': [('grine', True)],
          'grinte': [('grine', True)],
          'grintes': [('grine', False)],
          'gris': [('grise', False)],
          'gruer': [('grue', True)],
          'grunder': [('grundere', True), ('grunde', True)],
          'grundet': [('grunde', False)],
          'græs': [('græsse', False)],
          'grøg': [('gryge', False)],
          'grøget': [('gryge', False)],
          'gser': [('gsere', False)],
          'gsledes': [('gsle', False)],
          'gslet': [('gsle', False)],
          'gstaver': [('gstavere', False)],
          'gstede': [('gste', False)],
          'gstedes': [('gste', False)],
          'gster': [('gste', False)],
          'gt': [('gte', False)],
          'gtag': [('gtage', False)],
          'gtalt': [('gtale', False)],
          'gtalte': [('gtale', False)],
          'gtaltes': [('gtale', False)],
          'gte': [('gte', False)],
          'gtig': [('gtige', False)],
          'gtredes': [('gtre', False)],
          'gtrende': [('gtre', False)],
          'gtrer': [('gtre', False)],
          'gtræner': [('gtræne', False)],
          'guder': [('gude', False)],
          'guffet': [('guffe', True)],
          'gvende': [('gvende', False)],
          'gver': [('gvere', False)],
          'gyder': [('gyde', False)],
          'gyldes': [('gylde', False)],
          'gyldtes': [('gylde', False)],
          'gyser': [('gyse', True)],
          'gå': [('gå', False)],
          'går': [('gå', False)],
          'gås': [('gå', False)],
          'gærdes': [('gærde', True)],
          'gæredes': [('gære', False)],
          'gæst': [('gæste', True)],
          'gæste': [('gæste', True)],
          'gæsterer': [('gæsterere', True)],
          'gæstes': [('gæste', True)],
          'gættes': [('gætte', True)],
          'gød': [('gøde', True), ('gyde', True)],
          'gør': [('gø', True), ('gøre', True)],
          'gøs': [('gyse', True), ('gø', True)],
          'h': [('he', False)],
          'hader': [('hade', True)],
          'hagedes': [('hage', True)],
          'hager': [('hage', False)],
          'hages': [('hage', False)],
          'hak': [('hakke', False)],
          'hal': [('hale', True)],
          'haler': [('hale', False)],
          'halt': [('halte', True)],
          'halte': [('halte', True)],
          'haltes': [('halte', True)],
          'halver': [('halvere', True)],
          'hang': [('hænge', False)],
          'hanger': [('hangere', False)],
          'har': [('have', False)],
          'harger': [('hargere', False)],
          'harmer': [('harme', False)],
          'hasser': [('hassere', False)],
          'hast': [('haste', False)],
          'haste': [('haste', True)],
          'hastes': [('haste', True)],
          'hat': [('hatte', False)],
          'hatte': [('hatte', False)],
          'hattes': [('hatte', False)],
          'hav': [('have', False)],
          'hed': [('hedde', True)],
          'hede': [('he', False)],
          'hededes': [('hede', False)],
          'heder': [('hede', False)],
          'hedes': [('he', False)],
          'hedet': [('hede', False)],
          'hegne': [('hegne', False)],
          'hel': [('hele', True)],
          'heler': [('hele', True)],
          'hende': [('he', False)],
          'hent': [('hente', False)],
          'hente': [('hente', False)],
          'hentes': [('hente', True)],
          'her': [('he', False)],
          'herede': [('here', False)],
          'heredes': [('here', False)],
          'herer': [('here', False)],
          'hersende': [('herse', True)],
          'hes': [('he', False)],
          'hetter': [('hettere', False)],
          'hig': [('hige', True)],
          'higedes': [('hige', True)],
          'higer': [('hige', True)],
          'higes': [('hige', True)],
          'hik': [('hikke', True)],
          'hikende': [('hike', True)],
          'hiker': [('hike', True)],
          'hilsende': [('hilse', True)],
          'hindret': [('hindre', False)],
          'hiner': [('hine', False)],
          'his': [('hisse', True)],
          'hiver': [('hive', True)],
          'hives': [('hive', True)],
          'hmarker': [('hmarke', False)],
          'hob': [('hobe', False)],
          'hober': [('hobe', False)],
          'hop': [('hoppe', False)],
          'horer': [('hore', True)],
          'horet': [('hore', True)],
          'horne': [('horne', False)],
          'horner': [('horne', False)],
          'host': [('hoste', True)],
          'hoste': [('hoste', True)],
          'hostes': [('hoste', True)],
          'hovne': [('hovne', True)],
          'ht': [('hte', False)],
          'htag': [('htagge', False)],
          'htes': [('hte', False)],
          'huder': [('hude', False)],
          'hudlede': [('hudle', False)],
          'hudledes': [('hudle', False)],
          'hues': [('hue', True)],
          'huet': [('hue', True)],
          'huggedes': [('hugge', True)],
          'hugges': [('hugge', True)],
          'hul': [('hulle', True), ('hule', True)],
          'huler': [('hule', True)],
          'hundsende': [('hundse', True)],
          'huser': [('husere', True), ('huse', True)],
          'hvil': [('hvile', True)],
          'hvæs': [('hvæse', True), ('hvæsse', True)],
          'hvæst': [('hvæse', True)],
          'hvæste': [('hvæse', True)],
          'hvæstes': [('hvæse', True)],
          'hydrer': [('hydrere', True)],
          'hyl': [('hyle', True), ('hylle', True)],
          'hyldes': [('hylde', True)],
          'hyler': [('hyle', True)],
          'hys': [('hysse', True)],
          'hæg': [('hæge', True)],
          'hægte': [('hægte', True)],
          'hægtes': [('hægte', True)],
          'hækledes': [('hækle', True)],
          'hækles': [('hækle', True)],
          'hæl': [('hæle', True)],
          'hældes': [('hælde', True)],
          'hæmmes': [('hæmme', True)],
          'hændes': [('hænde', False)],
          'hændtes': [('hænde', True)],
          'hængtes': [('hænge', True)],
          'hærdes': [('hærde', True)],
          'hærer': [('hærere', False)],
          'høj': [('høje', False)],
          'højes': [('høje', False)],
          'højet': [('høje', False)],
          'høst': [('høste', False)],
          'høste': [('høste', False)],
          'høstes': [('høste', True)],
          'i': [('ie', False)],
          'ianter': [('iantere', False)],
          'iar': [('iare', False)],
          'iarer': [('iare', False)],
          'iares': [('iare', False)],
          'iav': [('iave', False)],
          'ib': [('ibbe', False)],
          'ibbes': [('ibbe', False)],
          'ibede': [('ibe', False)],
          'ibedes': [('ibe', False)],
          'iben': [('ibe', False)],
          'iber': [('ibere', False)],
          'iberede': [('ibere', False)],
          'iberedes': [('ibere', False)],
          'iberet': [('ibere', False)],
          'iblende': [('ible', False)],
          'ibler': [('ible', False)],
          'ibuer': [('ibuere', False)],
          'icer': [('icere', False)],
          'id': [('ide', False)],
          'iddedes': [('idde', False)],
          'idder': [('idde', False)],
          'ide': [('ide', False)],
          'ider': [('idere', False)],
          'ides': [('ide', False)],
          'idestiller': [('idestille', False)],
          'idier': [('idiere', False)],
          'idiver': [('idivere', False)],
          'idlede': [('idle', False)],
          'idrager': [('idrage', False)],
          'idredes': [('idre', False)],
          'idrer': [('idre', False)],
          'idsende': [('idse', False)],
          'idser': [('idse', False)],
          'idt': [('ide', False)],
          'idte': [('idte', False)],
          'idter': [('idte', False)],
          'idtes': [('idte', False)],
          'iede': [('ie', False)],
          'iedes': [('ie', False)],
          'iende': [('ie', False)],
          'ienerer': [('ienere', False)],
          'ienter': [('ientere', False)],
          'ier': [('ie', False)],
          'ierede': [('iere', False)],
          'ieredes': [('iere', False)],
          'ierer': [('iere', False)],
          'ies': [('ie', False)],
          'iet': [('i', False)],
          'if': [('iffe', False)],
          'ifandtes': [('ifinde', False)],
          'ifer': [('ifere', False)],
          'ifester': [('ifestere', False)],
          'iffedes': [('iffe', False)],
          'iffer': [('iffe', False)],
          'iffes': [('iffe', False)],
          'ifindes': [('ifinde', False)],
          'iflede': [('ifle', False)],
          'ifler': [('ifle', False)],
          'iflet': [('ifle', False)],
          'iformer': [('iformere', False)],
          'iftedes': [('ifte', False)],
          'ifuger': [('ifugere', False)],
          'ig': [('igge', False)],
          'iger': [('igere', False)],
          'igerer': [('igere', False)],
          'iggedes': [('igge', False)],
          'igges': [('igge', False)],
          'igler': [('igle', False)],
          'igner': [('igne', False)],
          'igrer': [('igre', False)],
          'igtedes': [('igte', False)],
          'igør': [('igøre', False)],
          'ik': [('å', False)],
          'ikader': [('ikadere', False)],
          'ikappedes': [('ikappe', False)],
          'ikappes': [('ikappe', False)],
          'ikater': [('ikatere', False)],
          'ikede': [('ike', False)],
          'ikedes': [('ike', False)],
          'ikende': [('ikende', True)],
          'iker': [('ikere', False)],
          'ikkedes': [('ikke', False)],
          'ikkes': [('ikke', False)],
          'ikles': [('ikle', False)],
          'ikrer': [('ikre', False)],
          'ikser': [('ikse', False)],
          'ikt': [('ikte', False)],
          'ikte': [('ikte', False)],
          'ikter': [('ikte', False)],
          'iktes': [('ikte', False)],
          'ikuler': [('ikulere', False)],
          'il': [('ile', True)],
          'ilbad': [('ilbede', False)],
          'ildedes': [('ilde', False)],
          'ildende': [('ilde', False)],
          'ilder': [('ilde', False)],
          'ildne': [('ildne', False)],
          'ilede': [('ile', False)],
          'iledes': [('ile', False)],
          'ileger': [('ilegere', False)],
          'iler': [('ile', True)],
          'ilet': [('ile', False)],
          'ileter': [('iletere', False)],
          'ilkende': [('ilke', False)],
          'ilker': [('ilke', False)],
          'iller': [('ille', False)],
          'iloter': [('ilotere', False)],
          'ilret': [('ilrette', False)],
          'ilsende': [('ilsende', False)],
          'ilser': [('ilse', False)],
          'ilt': [('ilte', True)],
          'ilte': [('ilte', True)],
          'ilter': [('ilte', False)],
          'iltes': [('ilte', True)],
          'ilæg': [('ilægge', False)],
          'im': [('ime', False)],
          'imede': [('ime', False)],
          'imedes': [('ime', False)],
          'imer': [('imere', False)],
          'imider': [('imidere', False)],
          'imiler': [('imilere', False)],
          'immedes': [('imme', False)],
          'immer': [('imme', False)],
          'imper': [('impe', False)],
          'imsende': [('imse', False)],
          'imt': [('imte', False)],
          'imte': [('imte', False)],
          'imtes': [('imte', False)],
          'imuler': [('imulere', False)],
          'in': [('inne', False)],
          'inde': [('inde', False)],
          'indedes': [('inde', False)],
          'inder': [('inde', False)],
          'indhugges': [('indhugge', True)],
          'indlede': [('indlede', True)],
          'indledes': [('indlede', True)],
          'indlever': [('indleve', True), ('indlevere', True)],
          'indret': [('indrette', True)],
          'indsende': [('indsende', True)],
          'indvi': [('indvie', True), ('indvi', True)],
          'indviede': [('indvi', True), ('indvie', True)],
          'indviedes': [('indvie', True), ('indvi', True)],
          'indviende': [('indvie', True), ('indvi', True)],
          'indvier': [('indvi', True), ('indvie', True)],
          'indviet': [('indvi', True), ('indvie', True)],
          'indvir': [('indvie', True), ('indvi', True)],
          'ine': [('ine', False)],
          'iner': [('inere', False)],
          'inet': [('ine', False)],
          'ingedes': [('inge', False)],
          'inger': [('inge', False)],
          'inges': [('inge', False)],
          'inistrer': [('inistrere', False)],
          'inkende': [('inke', False)],
          'inker': [('inke', False)],
          'innedes': [('inne', False)],
          'inner': [('inne', False)],
          'innes': [('inne', False)],
          'inser': [('inse', False)],
          'int': [('ine', False)],
          'inte': [('ine', False)],
          'intedes': [('inte', False)],
          'inter': [('inte', False)],
          'intes': [('ine', False)],
          'iolerer': [('iolere', False)],
          'iper': [('ipere', False)],
          'ipet': [('ipe', False)],
          'ipetter': [('ipettere', False)],
          'ipler': [('iple', False)],
          'iplet': [('iple', False)],
          'iposter': [('ipostere', False)],
          'ippedes': [('ippe', False)],
          'ipper': [('ippe', False)],
          'ippes': [('ippe', False)],
          'ipter': [('ipte', False)],
          'ipuler': [('ipulere', False)],
          'ir': [('irre', True)],
          'irater': [('iratere', False)],
          'irede': [('ire', False)],
          'iredes': [('ire', False)],
          'irende': [('ire', False)],
          'irer': [('irere', False)],
          'iret': [('ire', False)],
          'iriger': [('irigere', False)],
          'iriser': [('irisere', True)],
          'irkende': [('irke', False)],
          'irker': [('irke', False)],
          'irper': [('irpe', False)],
          'irrer': [('irre', True)],
          'irter': [('irte', False)],
          'is': [('ise', False)],
          'isende': [('ise', False)],
          'iser': [('ise', True)],
          'ises': [('ise', False)],
          'isker': [('iske', False)],
          'islagt': [('islægge', True)],
          'isled': [('islede', False)],
          'islede': [('islede', False)],
          'isledes': [('isle', False)],
          'islet': [('isle', False)],
          'isner': [('isne', False)],
          'isoler': [('isolere', False)],
          'isoner': [('isonere', False)],
          'isser': [('isse', False)],
          'ist': [('ise', False)],
          'iste': [('ise', False)],
          'istede': [('iste', False)],
          'istedes': [('iste', False)],
          'ister': [('iste', False)],
          'isterer': [('istere', False)],
          'istes': [('ise', False)],
          'istod': [('istå', False)],
          'istredes': [('istre', False)],
          'istrer': [('istrere', False)],
          'isyr': [('isy', True)],
          'iså': [('ise', False)],
          'isås': [('ise', False)],
          'it': [('itte', False)],
          'itag': [('itage', False)],
          'iter': [('itere', False)],
          'itester': [('iteste', False)],
          'itier': [('itiere', False)],
          'itimer': [('itimere', False)],
          'itlede': [('itle', False)],
          'itledes': [('itle', False)],
          'itredes': [('itre', False)],
          'itrende': [('itre', False)],
          'itrer': [('itre', False)],
          'itræner': [('itræne', False)],
          'itser': [('itse', False)],
          'ittedes': [('itte', False)],
          'itter': [('itte', False)],
          'itterer': [('ittere', False)],
          'iumfer': [('iumfere', False)],
          'ivaler': [('ivalere', False)],
          'ivedes': [('ives', False)],
          'ivende': [('ive', False)],
          'ivider': [('ividere', False)],
          'iviser': [('ivisere', False)],
          'ivles': [('ivle', False)],
          'ivne': [('ive', False)],
          'ivredes': [('ivre', True)],
          'ivrer': [('ivre', True)],
          'iz': [('izze', False)],
          'j': [('je', False)],
          'jab': [('jabbe', True)],
          'jagedes': [('jage', False)],
          'jager': [('jage', False)],
          'jages': [('jage', False)],
          'jagt': [('jagte', False)],
          'jagtes': [('jagte', False)],
          'jaldt': [('ælde', False)],
          'jalv': [('ælve', False)],
          'jank': [('janke', False)],
          'jantes': [('jante', False)],
          'jap': [('jappe', False)],
          'jat': [('jatte', False)],
          'jatte': [('jatte', False)],
          'jattes': [('jatte', False)],
          'jav': [('jave', False)],
          'jd': [('jde', False)],
          'jde': [('jde', False)],
          'jdes': [('jde', False)],
          'jdsende': [('jdse', False)],
          'jdser': [('jdse', False)],
          'jede': [('je', False)],
          'jedes': [('je', False)],
          'jemsende': [('jemsende', False)],
          'jen': [('jene', False)],
          'jende': [('je', False)],
          'jener': [('jene', False)],
          'jenes': [('jene', False)],
          'jer': [('je', False)],
          'jerede': [('jere', False)],
          'jeredes': [('jere', False)],
          'jerer': [('jere', False)],
          'jes': [('je', False)],
          'jfede': [('jfe', False)],
          'jfedes': [('jfe', False)],
          'jfes': [('jfe', False)],
          'jkede': [('jke', False)],
          'jkedes': [('jke', False)],
          'jkende': [('jke', False)],
          'jker': [('jke', False)],
          'jled': [('jlede', False)],
          'jlede': [('jle', False)],
          'jlededes': [('jlede', False)],
          'jledes': [('jle', False)],
          'jledet': [('jlede', False)],
          'jlet': [('jle', False)],
          'jlig': [('jlige', False)],
          'jne': [('jne', False)],
          'jnet': [('jne', False)],
          'jog': [('jogge', True), ('jage', True)],
          'joker': [('joke', True)],
          'jorde': [('jorde', True)],
          'jordes': [('jorde', True)],
          'jort': [('øre', False)],
          'jottes': [('jotte', False)],
          'jr': [('jre', False)],
          'jrede': [('jre', False)],
          'jredes': [('jre', False)],
          'jrende': [('jre', False)],
          'jret': [('jre', False)],
          'js': [('jse', False)],
          'jsende': [('jse', False)],
          'jses': [('jse', False)],
          'jsledes': [('jsle', False)],
          'jslet': [('jsle', False)],
          'jst': [('jse', False)],
          'jste': [('jse', False)],
          'jstes': [('jse', False)],
          'jstredes': [('jstre', False)],
          'jt': [('jte', False)],
          'jte': [('jte', False)],
          'jtes': [('jte', False)],
          'jtrækkes': [('jtrække', False)],
          'jul': [('jule', False)],
          'juler': [('jule', False)],
          'junger': [('jungere', False)],
          'junket': [('junke', True)],
          'jus': [('jusse', False)],
          'juster': [('justere', False)],
          'jålede': [('jæle', False)],
          'jålet': [('jæle', False)],
          'jækledes': [('jækle', False)],
          'jækles': [('jækle', False)],
          'jæl': [('jæle', False)],
          'jæredes': [('jære', False)],
          'jært': [('jærte', False)],
          'jærte': [('jærte', False)],
          'jærtes': [('jærte', False)],
          'jættes': [('jætte', False)],
          'k': [('ke', False)],
          'ka': [('kulle', False)],
          "ka'": [('kulle', False)],
          'kaber': [('kabe', False)],
          'kacher': [('kachere', True)],
          'kader': [('kade', False)],
          'kaffede': [('kaffe', False)],
          'kaffedes': [('kaffe', False)],
          'kalker': [('kalkere', True), ('kalke', True)],
          'kalper': [('kalpere', False)],
          'kalt': [('kalte', False)],
          'kalte': [('kalte', False)],
          'kaltes': [('kalte', False)],
          'kan': [('kunne', True)],
          'kander': [('kandere', False)],
          'kaner': [('kanere', False)],
          'kanter': [('kante', True)],
          'kantes': [('kante', True)],
          'kap': [('kappe', True)],
          'kappedes': [('kappes', True), ('kappe', True)],
          'kappes': [('kappes', True), ('kappe', True)],
          'karter': [('kartere', True), ('karte', True)],
          'kasser': [('kassere', True)],
          'kast': [('kaste', False)],
          'kaste': [('kaste', True)],
          'kastes': [('kaste', False)],
          'kat': [('katte', False)],
          'kater': [('kate', False)],
          'katte': [('katte', False)],
          'kattes': [('katte', False)],
          'kav': [('kave', False)],
          'ked': [('kede', True)],
          'kede': [('kede', True)],
          'kededes': [('kede', False)],
          'keder': [('kede', False)],
          'kedes': [('kede', True)],
          'kedet': [('kede', True)],
          'kediger': [('kedige', False)],
          'kel': [('kele', False)],
          'keler': [('kele', False)],
          'kelerer': [('kelere', False)],
          'kende': [('kende', True)],
          'ker': [('kere', True)],
          'kerede': [('kere', False)],
          'keredes': [('kere', False)],
          'kerer': [('kere', False)],
          'kes': [('ke', False)],
          'ketter': [('kettere', False)],
          'kib': [('kibe', False)],
          'kiber': [('kibe', False)],
          'kider': [('kide', False)],
          'kik': [('kikke', False)],
          'kil': [('kile', True)],
          'kiler': [('kile', True)],
          'kilret': [('kilre', False)],
          'kim': [('kime', True)],
          'kimer': [('kime', True)],
          'kimes': [('kime', True)],
          'kiser': [('kisere', False)],
          'kitser': [('kitsere', False)],
          'kivedes': [('kives', True)],
          'kiver': [('kive', False)],
          'kives': [('kives', True)],
          'kkede': [('kke', False)],
          'kkende': [('kke', False)],
          'kker': [('kke', False)],
          'kkerer': [('kkerere', False)],
          'kko': [('kkoe', False)],
          'kkoede': [('kkoe', False)],
          'kkoende': [('kkoe', False)],
          'klang': [('klinge', False)],
          'klarer': [('klare', True), ('klarere', True)],
          'klasser': [('klasse', False)],
          'klaver': [('klavere', False)],
          'klede': [('kle', False)],
          'kledes': [('kle', False)],
          'klemt': [('klemte', True), ('klemme', True)],
          'klemte': [('klemte', True), ('klemme', True)],
          'klemtes': [('klemte', True), ('klemme', True)],
          'klet': [('kle', False)],
          'kliner': [('kline', True)],
          'klir': [('klirre', True)],
          'klog': [('kloge', True)],
          'kloger': [('kloge', True)],
          'klokkedes': [('klokke', True)],
          'klokkes': [('klokke', True)],
          'klor': [('klore', True)],
          'klorer': [('klorere', True), ('klore', True)],
          'kluder': [('kludere', False)],
          'klæder': [('klæde', False)],
          'klæg': [('klægge', False)],
          'klær': [('klære', False)],
          'kløjes': [('kløjes', True)],
          'knas': [('knase', True)],
          'kne': [('kne', False)],
          'knet': [('kne', False)],
          'knoppedes': [('knoppes', True)],
          'knoppes': [('knoppes', True)],
          'knus': [('knuse', True)],
          'knys': [('kny', True)],
          'knyst': [('knyste', True)],
          'knyste': [('knyste', True)],
          'knystes': [('knyste', True)],
          'ko': [('ko', False)],
          'kod': [('kode', False)],
          'koder': [('kode', False)],
          'koede': [('ko', False)],
          'koende': [('ko', False)],
          'koet': [('koe', False)],
          'kog': [('koge', False)],
          'koger': [('koge', False)],
          'koges': [('koge', False)],
          'kol': [('kole', False)],
          'koler': [('kole', False)],
          'koller': [('kollere', False)],
          'kom': [('komme', False)],
          'koperer': [('kopere', False)],
          'kor': [('ko', False)],
          'korder': [('kordere', False)],
          'korsende': [('korse', True)],
          'korter': [('korte', True)],
          'koser': [('kose', False)],
          'kost': [('koste', True)],
          'koste': [('koste', False)],
          'kostes': [('koste', False)],
          'kottes': [('kotte', False)],
          'kovedes': [('kove', False)],
          'kovende': [('kovende', True)],
          'kover': [('kove', False)],
          'koves': [('kove', False)],
          'kr': [('kre', False)],
          'krab': [('krabbe', True)],
          'krabede': [('krabe', False)],
          'krabedes': [('krabe', False)],
          'krak': [('krakke', True)],
          'krakkes': [('krakke', True)],
          'kranter': [('krante', False)],
          'krat': [('kratte', False)],
          'kraver': [('kravere', False)],
          'kred': [('kride', False)],
          'krede': [('kre', False)],
          'kredes': [('kre', False)],
          'kredet': [('kride', False)],
          'kreg': [('krige', False)],
          'kreget': [('krige', False)],
          'kremer': [('kremere', True)],
          'krende': [('kre', False)],
          'krer': [('krere', False)],
          'kret': [('kre', False)],
          'krevne': [('krive', False)],
          'kriber': [('kribere', False)],
          'krides': [('kride', False)],
          'krig': [('krige', False)],
          'krigedes': [('kriges', True)],
          'kriges': [('kriges', True)],
          'krom': [('krome', False)],
          'kroter': [('krote', False)],
          'kruer': [('krue', False)],
          'krukket': [('krukke', True)],
          'krumper': [('krumpe', False)],
          'krutter': [('kruttere', False)],
          'kryd': [('kryde', False)],
          'krydes': [('kryde', False)],
          'kræk': [('krække', False)],
          'krækkedes': [('krække', False)],
          'krækkes': [('krække', False)],
          'kræl': [('krælle', False)],
          'krøb': [('krybe', True)],
          'krøbet': [('krybe', True)],
          'krøl': [('krølle', True)],
          'ks': [('kse', False)],
          'ksende': [('kse', False)],
          'kses': [('kse', False)],
          'ksiler': [('ksilere', False)],
          'ksledes': [('ksle', False)],
          'kslet': [('ksle', False)],
          'kstede': [('kste', False)],
          'kstedes': [('kste', False)],
          'kster': [('kste', False)],
          'kt': [('kke', False)],
          'kte': [('ke', False)],
          'kter': [('ktere', False)],
          'ktiver': [('ktivere', False)],
          'ktriner': [('ktrinere', False)],
          'kturer': [('kturere', False)],
          'kuer': [('kue', True)],
          'kues': [('kue', False)],
          'kuet': [('kue', False)],
          'kuffet': [('kuffe', False)],
          'kukket': [('kukke', True)],
          'kul': [('kule', False)],
          'kuler': [('kule', False)],
          'kunder': [('kundere', False)],
          'kuppet': [('kuppe', True)],
          'kur': [('kurre', True), ('kure', True)],
          'kurer': [('kure', True), ('kurere', True)],
          'kurrer': [('kurre', True)],
          'kurser': [('kursere', True)],
          'kvad': [('kvæde', True)],
          'kvadrer': [('kvadrere', True)],
          'kvalt': [('kvæle', True)],
          'kvalte': [('kvæle', True)],
          'kvaltes': [('kvæle', True)],
          'kvarter': [('kvartere', False)],
          'kvatter': [('kvatte', False)],
          'kvejlede': [('kvejle', True)],
          'kvejledes': [('kvejle', True)],
          'kventer': [('kventere', False)],
          'kver': [('kvere', False)],
          'kvi': [('kvie', True)],
          'kvider': [('kvidere', False)],
          'kviede': [('kvie', True)],
          'kviedes': [('kvie', True)],
          'kviende': [('kvie', True)],
          'kvier': [('kvie', True)],
          'kvies': [('kvie', True)],
          'kviet': [('kvie', True)],
          'kvilt': [('kvilte', True)],
          'kvilte': [('kvilte', True)],
          'kviltes': [('kvilte', True)],
          'kvirer': [('kvirere', False)],
          'kvis': [('kvise', False)],
          'kviser': [('kvise', False)],
          'kvist': [('kviste', False)],
          'kviste': [('kviste', False)],
          'kvistedes': [('kviste', False)],
          'kvistes': [('kviste', False)],
          'kvitter': [('kvitte', True), ('kvittere', True)],
          'kvæd': [('kvæde', True)],
          'ky': [('ky', False)],
          'kyder': [('kyde', False)],
          'kyede': [('ky', False)],
          'kyende': [('ky', False)],
          'kyer': [('ky', False)],
          'kyes': [('ky', False)],
          'kyl': [('kyle', True)],
          'kyler': [('kyle', True)],
          'kyr': [('ky', False)],
          'kys': [('kyse', True), ('kysse', True)],
          'kyser': [('kyse', True)],
          'kårede': [('kåre', True)],
          'kåret': [('kåre', False)],
          'kæd': [('kæde', False)],
          'kæder': [('kæde', False)],
          'kæl': [('kæle', True)],
          'kæmmes': [('kæmme', False)],
          'kærer': [('kære', False)],
          'kæres': [('kære', False)],
          'kættes': [('kætte', False)],
          'kævledes': [('kævle', True), ('kævles', True)],
          'kævles': [('kævles', True), ('kævle', True)],
          'køb': [('købe', False)],
          'køl': [('køle', False)],
          'køs': [('kyse', True)],
          'l': [('le', False)],
          'lab': [('labbe', True)],
          'laber': [('labere', False)],
          'lader': [('lade', False)],
          'laffede': [('laffe', False)],
          'laffedes': [('laffe', False)],
          'lafret': [('lafre', False)],
          'lag': [('lage', False)],
          'lagedes': [('lage', False)],
          'lager': [('lage', False)],
          'lages': [('lage', False)],
          'lagt': [('lægge', False)],
          'lagte': [('lægge', False)],
          'lagtes': [('lagte', False)],
          'lak': [('lakke', True)],
          'lakser': [('laksere', False)],
          'lal': [('lalle', True)],
          'lammer': [('lamme', True)],
          'lan': [('lane', False)],
          'lancer': [('lancere', False)],
          'landrer': [('landre', False)],
          'laner': [('lane', False)],
          'lang': [('lange', True)],
          'lank': [('lanke', False)],
          'lanker': [('lankere', False)],
          'lantes': [('lante', False)],
          'lap': [('lappe', False)],
          'lar': [('lare', False)],
          'lares': [('lare', False)],
          'larmer': [('larme', True)],
          'las': [('lasse', False)],
          'laser': [('lasere', True)],
          'last': [('laste', True)],
          'laste': [('laste', False)],
          'lastes': [('laste', False)],
          'lastrer': [('lastre', False)],
          'lat': [('latte', False)],
          'latte': [('latte', False)],
          'lattes': [('latte', False)],
          'lav': [('lave', False)],
          'laver': [('lave', True), ('lavere', True)],
          'lbad': [('lbade', False)],
          'lbed': [('lbede', False)],
          'lbedes': [('lbede', False)],
          'lberede': [('lberede', False)],
          'lbundet': [('lbinde', False)],
          'lbød': [('lbyde', False)],
          'ld': [('lde', False)],
          'lde': [('lde', False)],
          'ldes': [('lde', False)],
          'ldledes': [('ldlede', False)],
          'ldne': [('lde', False)],
          'ldrager': [('ldrage', False)],
          'ldredes': [('ldre', False)],
          'ldrer': [('ldre', False)],
          'ldt': [('lde', False)],
          'ldtes': [('lde', False)],
          'leb': [('libe', False)],
          'lebrer': [('lebrere', False)],
          'led': [('lide', True), ('lede', True)],
          'lede': [('lede', True)],
          'lededes': [('ledes', True), ('lede', True)],
          'leder': [('lede', False)],
          'ledes': [('lede', True), ('ledes', True)],
          'ledet': [('lide', True), ('lede', True)],
          'lediger': [('ledige', False)],
          'ledte': [('lede', False)],
          'leg': [('lege', False)],
          'legede': [('lege', True)],
          'leger': [('lege', True), ('legere', True)],
          'leget': [('lege', True)],
          'legne': [('legne', False)],
          'lemt': [('lemme', False)],
          'lemte': [('lemme', False)],
          'lemtes': [('lemme', False)],
          'len': [('lene', False)],
          'lende': [('le', False)],
          'lenedes': [('lene', False)],
          'lener': [('lene', False)],
          'lenes': [('lene', False)],
          'lentrer': [('lentre', False)],
          'ler': [('le', False)],
          'lerede': [('lere', False)],
          'leredes': [('lere', False)],
          'lerer': [('lere', False)],
          'les': [('le', False)],
          'lester': [('lestere', False)],
          'let': [('le', True), ('lette', True)],
          'lete': [('lete', False)],
          'leter': [('lete', False)],
          'letes': [('lete', False)],
          'letter': [('lette', True)],
          'lev': [('leve', False)],
          'levede': [('leve', False)],
          'levende': [('leve', True)],
          'lever': [('levere', True), ('leve', True)],
          'leverer': [('levere', False)],
          'levet': [('leve', False)],
          'leviser': [('levisere', False)],
          'levne': [('levne', True)],
          'lfede': [('lfe', False)],
          'lfedes': [('lfe', False)],
          'lfes': [('lfe', False)],
          'lfiler': [('lfile', False)],
          'lflød': [('lflyde', False)],
          'lger': [('lge', False)],
          'lgerer': [('lgere', False)],
          'lhyl': [('lhylle', False)],
          'lib': [('libe', False)],
          'liber': [('libe', False)],
          'licer': [('lice', False)],
          'lider': [('lide', False)],
          'lier': [('liere', False)],
          'lig': [('ligge', True)],
          'ligedes': [('lige', False)],
          'liger': [('lige', False)],
          'liges': [('lige', False)],
          'ligt': [('ligte', False)],
          'ligte': [('ligte', False)],
          'ligtes': [('ligte', False)],
          'lik': [('likke', False)],
          'likende': [('like', True)],
          'liker': [('like', True)],
          'limer': [('lime', False)],
          'limes': [('lime', False)],
          'lin': [('line', False)],
          'lindes': [('linde', True)],
          'lindret': [('lindre', False)],
          'liner': [('line', False)],
          'lir': [('lire', True)],
          'lirer': [('lire', False)],
          'liser': [('lisere', False)],
          'lisser': [('lissere', False)],
          'list': [('liste', False)],
          'liste': [('liste', False)],
          'listes': [('liste', False)],
          'listrer': [('listre', False)],
          'litrer': [('litrere', True)],
          'litterer': [('litterere', False)],
          'livedes': [('live', False)],
          'liver': [('live', False)],
          'lives': [('live', False)],
          'ljer': [('ljere', False)],
          'lkede': [('lke', False)],
          'lkedes': [('lke', False)],
          'lkuler': [('lkulere', False)],
          'llaver': [('llave', False)],
          'llede': [('lle', False)],
          'lledes': [('lle', False)],
          'llen': [('lle', False)],
          'llet': [('lle', False)],
          'lleter': [('lletere', False)],
          'lletter': [('llettere', False)],
          'llider': [('llidere', False)],
          'llig': [('llige', False)],
          'llod': [('llade', False)],
          'llokkedes': [('llokke', False)],
          'llokkes': [('llokke', False)],
          'lluder': [('lludere', False)],
          'llæg': [('llægge', False)],
          'llær': [('llære', False)],
          'llæs': [('llæse', False)],
          'llæst': [('llæse', False)],
          'llæstes': [('llæse', False)],
          'lm': [('lme', False)],
          'lmede': [('lme', False)],
          'lmedes': [('lme', False)],
          'lmes': [('lme', False)],
          'lmur': [('lmure', False)],
          'lne': [('lne', False)],
          'lnet': [('lne', False)],
          'lo': [('le', False)],
          'lod': [('lodde', True), ('lade', True)],
          'loderer': [('lodere', False)],
          'loede': [('lo', False)],
          'loende': [('lo', False)],
          'log': [('logge', True)],
          'loger': [('logere', True)],
          'loges': [('loge', False)],
          'lokkedes': [('lokke', True)],
          'lokkes': [('lokke', True)],
          'lom': [('lomme', False)],
          'lomber': [('lombere', False)],
          'lomer': [('lome', False)],
          'lon': [('lone', False)],
          'loner': [('lone', False)],
          'longer': [('longere', False)],
          'lop': [('loppe', True)],
          'loperer': [('lopere', False)],
          'lopper': [('loppe', True)],
          'lor': [('lo', False)],
          'loret': [('lore', False)],
          'los': [('losse', True)],
          'loser': [('losere', False)],
          'losser': [('losse', True)],
          'losset': [('losse', False)],
          'loter': [('lote', False)],
          'lottes': [('lotte', False)],
          'lovedes': [('love', False)],
          'lover': [('love', True)],
          'loves': [('love', False)],
          'lovne': [('lovne', False)],
          'lp': [('lpe', False)],
          'lpasser': [('lpasse', False)],
          'lpet': [('lpe', False)],
          'lpredes': [('lpre', False)],
          'lpres': [('lpre', False)],
          'lr': [('lre', False)],
          'lred': [('lride', False)],
          'lrede': [('lre', False)],
          'lredes': [('lre', False)],
          'lredet': [('lride', False)],
          'lrende': [('lre', False)],
          'lret': [('lre', False)],
          'lrides': [('lride', False)],
          'lrøg': [('lryge', False)],
          'lrøget': [('lryge', False)],
          'ls': [('lse', False)],
          'lsende': [('lse', False)],
          'lses': [('lse', False)],
          'lsigner': [('lsigne', False)],
          'lskar': [('lskære', False)],
          'lsker': [('lske', False)],
          'lskød': [('lskøde', False)],
          'lslås': [('lslå', False)],
          'lspil': [('lspille', False)],
          'lst': [('lse', False)],
          'lste': [('lse', False)],
          'lsteg': [('lstege', False)],
          'lstes': [('lse', False)],
          'lstil': [('lstille', False)],
          'lstod': [('lstå', False)],
          'lstredes': [('lstre', False)],
          'lsår': [('lså', False)],
          'lt': [('lte', False)],
          'ltag': [('ltage', False)],
          'ltalt': [('ltale', False)],
          'ltalte': [('ltale', False)],
          'ltaltes': [('ltale', False)],
          'lte': [('lte', False)],
          'lterner': [('lternere', False)],
          'ltes': [('lte', False)],
          'ltiger': [('ltigere', False)],
          'ltiver': [('ltivere', False)],
          'ltredes': [('ltre', False)],
          'ltrende': [('ltre', False)],
          'ltrer': [('ltre', False)],
          'ltrækkes': [('ltrække', False)],
          'ltser': [('ltse', False)],
          'luder': [('lude', False)],
          'ludrede': [('ludre', False)],
          'ludredes': [('ludre', False)],
          'ludret': [('ludre', False)],
          'luedes': [('lue', True)],
          'luer': [('lue', True)],
          'lues': [('lue', True)],
          'luet': [('lue', True)],
          'luffet': [('luffe', False)],
          'lug': [('luge', False)],
          'luger': [('luge', False)],
          'lugt': [('lugte', False)],
          'lugte': [('lugte', False)],
          'lugtes': [('lugte', True)],
          'lukket': [('lukke', False)],
          'lukne': [('lukne', False)],
          'lukrer': [('lukrere', True)],
          'lundet': [('lunde', False)],
          'luner': [('lune', True)],
          'lunket': [('lunke', True)],
          'lurer': [('lure', False)],
          'lus': [('lusse', False)],
          'luser': [('luse', False)],
          'lvende': [('lvende', False)],
          'lver': [('lvere', False)],
          'lveriser': [('lverisere', False)],
          'ly': [('ly', False)],
          'lyder': [('lydere', True), ('lyde', True)],
          'lyede': [('ly', False)],
          'lyende': [('ly', False)],
          'lyer': [('ly', False)],
          'lyes': [('ly', False)],
          'lygtes': [('lygte', False)],
          'lykkedes': [('lykkes', True)],
          'lykkes': [('lykkes', False)],
          'lyn': [('lyne', True)],
          'lynes': [('lyne', True)],
          'lyr': [('ly', False)],
          'lys': [('lyse', True)],
          'lyser': [('lyse', False)],
          'lyst': [('lyste', True), ('lyse', True)],
          'lyste': [('lyste', True), ('lyse', True)],
          'lystes': [('lyse', True), ('lyste', True)],
          'lå': [('ligge', False)],
          'låd': [('låde', False)],
          'lår': [('lå', False)],
          'lås': [('låse', True)],
          'læbedes': [('læbe', False)],
          'læbes': [('læbe', False)],
          'læd': [('læde', False)],
          'læder': [('lædere', True)],
          'læg': [('læge', True), ('lægge', True)],
          'lægt': [('læge', True), ('lægte', True)],
          'lægte': [('læge', True), ('lægte', True)],
          'lægtes': [('læge', True), ('lægte', True)],
          'læmmes': [('læmme', False)],
          'læn': [('læne', True)],
          'lændes': [('lænde', False)],
          'læner': [('læne', True)],
          'længedes': [('længes', True)],
          'længes': [('længes', True)],
          'længtes': [('længes', True)],
          'lær': [('læ', True), ('lære', True)],
          'læredes': [('lære', False)],
          'lærer': [('lære', False)],
          'læres': [('lære', True)],
          'læs': [('læsse', True), ('læse', True)],
          'læst': [('læse', True)],
          'læste': [('læse', True)],
          'læstes': [('læse', True)],
          'løb': [('løbe', False)],
          'løbet': [('løbe', False)],
          'lød': [('lyde', False)],
          'løj': [('lyve', True), ('løje', True)],
          'løjedes': [('løje', False)],
          'løjes': [('løje', False)],
          'løjet': [('lyve', True), ('løje', True)],
          'løjne': [('lyve', False)],
          'lør': [('lø', False)],
          'løs': [('løse', False)],
          'm': [('mme', False)],
          'mader': [('made', True)],
          'magedes': [('mage', False)],
          'mager': [('mage', True)],
          'mages': [('mage', False)],
          'magt': [('magte', True)],
          'magte': [('magte', True)],
          'magtes': [('magte', True)],
          'mak': [('makke', True)],
          'mal': [('male', False)],
          'maler': [('male', False)],
          'maljer': [('maljere', False)],
          'malt': [('malte', True), ('male', True)],
          'malte': [('malte', True), ('male', True)],
          'maltes': [('malte', True), ('male', True)],
          'man': [('mane', True)],
          'mander': [('mande', True)],
          'maner': [('mane', True)],
          'manker': [('mankere', True)],
          'marker': [('markere', False)],
          'mas': [('mase', True)],
          'masker': [('maskere', True), ('maske', True)],
          'masser': [('massere', False)],
          'mast': [('mase', True)],
          'maste': [('mase', True)],
          'mastes': [('mase', True)],
          'mat': [('matte', False)],
          'matte': [('matte', False)],
          'matter': [('mattere', True)],
          'mattes': [('matte', False)],
          'mav': [('mave', True)],
          'mbar': [('mbære', False)],
          'mbed': [('mbide', False)],
          'mbede': [('mbe', False)],
          'mbedes': [('mbe', False)],
          'mber': [('mbere', False)],
          'mberede': [('mbere', False)],
          'mberedes': [('mbere', False)],
          'mberet': [('mbere', False)],
          'mblende': [('mble', False)],
          'mbler': [('mble', False)],
          'mboler': [('mbolere', False)],
          'mbor': [('mbore', False)],
          'mbrydes': [('mbryde', False)],
          'mbuler': [('mbulere', False)],
          'mbundet': [('mbinde', False)],
          'mburer': [('mburere', False)],
          'mbød': [('mbyde', False)],
          'mdater': [('mdatere', False)],
          'mdrager': [('mdrage', False)],
          'med': [('mede', False)],
          'mede': [('mede', True)],
          'mededes': [('mede', False)],
          'meder': [('mede', False)],
          'medes': [('mede', True)],
          'medet': [('mede', False)],
          'mel': [('mele', True)],
          'meler': [('mele', True)],
          'melt': [('melte', False)],
          'melte': [('melte', False)],
          'meltes': [('melte', False)],
          'men': [('mene', True)],
          'mende': [('me', False)],
          'mender': [('mendere', False)],
          'mener': [('mene', False)],
          'menerer': [('menere', False)],
          'menes': [('mene', True)],
          'menter': [('mentere', False)],
          'mer': [('me', False)],
          'merede': [('mere', False)],
          'meredes': [('mere', False)],
          'merer': [('mere', False)],
          'mes': [('messe', True)],
          'mestrer': [('mestre', False)],
          'mfattedes': [('mfatte', False)],
          'mfattes': [('mfatte', False)],
          'mfede': [('mfe', False)],
          'mfedes': [('mfe', False)],
          'mfer': [('mfere', False)],
          'mfes': [('mfe', False)],
          'mformer': [('mforme', False)],
          'mgør': [('mgøre', False)],
          'mhul': [('mhulle', False)],
          'mhyl': [('mhylle', False)],
          'mider': [('mide', False)],
          'mier': [('miere', False)],
          'migrer': [('migrere', True)],
          'mil': [('mile', False)],
          'miler': [('mile', False)],
          'milt': [('mile', False)],
          'milte': [('mile', False)],
          'miltes': [('mile', False)],
          'mimer': [('mime', True)],
          'mimes': [('mime', True)],
          'mindedes': [('mindes', True), ('minde', True)],
          'mindes': [('mindes', True), ('minde', True)],
          'mis': [('misse', False)],
          'miser': [('misere', False)],
          'miskende': [('miskende', True)],
          'misledes': [('mislede', True)],
          'mist': [('miste', True)],
          'miste': [('miste', True)],
          'mistes': [('miste', True)],
          'mitter': [('mittere', False)],
          'mlede': [('mle', False)],
          'mledes': [('mle', False)],
          'mlen': [('mle', False)],
          'mlet': [('mle', False)],
          'mlever': [('mleve', False)],
          'mlys': [('mlyse', False)],
          'mlyst': [('mlyse', False)],
          'mlyste': [('mlyse', False)],
          'mlystes': [('mlyse', False)],
          'mlæg': [('mlægge', False)],
          'mlæs': [('mlæse', False)],
          'mlæst': [('mlæse', False)],
          'mlæste': [('mlæse', False)],
          'mlæstes': [('mlæse', False)],
          'mmander': [('mmandere', False)],
          'mmede': [('mme', False)],
          'mmen': [('mme', False)],
          'mmes': [('mme', False)],
          'mmoder': [('mmodere', False)],
          'mmoderer': [('mmodere', False)],
          'mms': [("mms'e", True)],
          'mmødes': [('mmøde', False)],
          'mmødtes': [('mmøde', False)],
          'mne': [('mme', False)],
          'mner': [('mnere', False)],
          'mod': [('mode', False)],
          'moder': [('mode', False)],
          'moderer': [('moderere', True)],
          'molerer': [('molere', False)],
          'morer': [('more', True)],
          'moret': [('more', True)],
          'morsende': [('morse', True)],
          'mos': [('mose', True)],
          'moser': [('mose', True)],
          'most': [('moste', True)],
          'moste': [('moste', True)],
          'mostes': [('moste', True)],
          'mot': [('mote', False)],
          'moter': [('mote', False)],
          'mp': [('mpe', False)],
          'mperer': [('mperere', False)],
          'mpet': [('mpe', False)],
          'mpiler': [('mpilere', False)],
          'mplanter': [('mplantere', False)],
          'mpler': [('mple', False)],
          'mplet': [('mple', False)],
          'mpletter': [('mplettere', False)],
          'mporer': [('mporere', False)],
          'mposter': [('mpostere', False)],
          'mpredes': [('mpre', False)],
          'mpres': [('mpre', False)],
          'mprimer': [('mprimere', False)],
          'mr': [('mre', False)],
          'mred': [('mride', False)],
          'mrede': [('mre', False)],
          'mredes': [('mre', False)],
          'mredet': [('mride', False)],
          'mrende': [('mre', False)],
          'mret': [('mre', False)],
          'mrides': [('mride', False)],
          'mros': [('mrose', False)],
          'mrør': [('mrøre', False)],
          'ms': [('mse', False)],
          'mses': [('mse', False)],
          'msigner': [('msigne', False)],
          'mskar': [('mskære', False)],
          'mskiftedes': [('mskifte', False)],
          'mskiftes': [('mskifte', False)],
          'mskændes': [('mskænde', False)],
          'mskød': [('mskyde', False)],
          'mslås': [('mslå', False)],
          'mspil': [('mspille', False)],
          'msteg': [('mstege', False)],
          'msterer': [('mstere', False)],
          'mstil': [('mstille', False)],
          'mstod': [('mstå', False)],
          'mstredes': [('mstre', False)],
          'msyr': [('msyre', False)],
          'mså': [('mse', False)],
          'msås': [('mse', False)],
          'mt': [('mme', False)],
          'mtag': [('mtage', False)],
          'mtalt': [('mtale', False)],
          'mtalte': [('mtale', False)],
          'mtaltes': [('mtale', False)],
          'mte': [('mme', False)],
          'mtes': [('mme', False)],
          'mtrækkes': [('mtrække', False)],
          'mtykkedes': [('mtykke', False)],
          'mtykkes': [('mtykke', False)],
          'mtæres': [('mtære', False)],
          'mtør': [('mtørre', False)],
          'mudrede': [('mudre', True)],
          'mudredes': [('mudre', True)],
          'mudret': [('mudre', True)],
          'mudsende': [('mudse', False)],
          'mufler': [('muflere', False)],
          'mug': [('muge', True)],
          'muger': [('muge', True)],
          'mukket': [('mukke', True)],
          'mul': [('mule', False)],
          'muler': [('mule', False)],
          'mundet': [('munde', True)],
          'mur': [('murre', True), ('mure', True)],
          'murer': [('mure', False)],
          'muser': [('muse', True)],
          'mvis': [('mvise', False)],
          'mviser': [('mvise', False)],
          'mvist': [('mvise', False)],
          'mviste': [('mvise', False)],
          'mvistes': [('mvise', False)],
          'myg': [('myge', False)],
          'må': [('måtte', True)],
          'mår': [('må', False)],
          'mås': [('må', False)],
          'mægt': [('mægte', False)],
          'mægte': [('mægte', False)],
          'mægtes': [('mægte', True)],
          'mæl': [('mæle', True)],
          'mælt': [('mæle', False)],
          'mælte': [('mæle', True)],
          'mæltes': [('mæle', False)],
          'mættes': [('mætte', True)],
          'møbler': [('møblere', False)],
          'mødes': [('mødes', True), ('møde', True)],
          'mødtes': [('mødes', True), ('møde', True)],
          'møg': [('møge', True)],
          'møget': [('møge', False)],
          'møjes': [('møje', False)],
          'møjet': [('møje', False)],
          'møl': [('møle', False)],
          'n': [('ne', False)],
          'nagedes': [('nage', True)],
          'nager': [('nage', False)],
          'nages': [('nage', False)],
          'nak': [('nakke', False)],
          'naner': [('nanere', False)],
          'nap': [('nappe', True)],
          'nar': [('narre', True)],
          'nas': [('nasse', True)],
          'nat': [('natte', False)],
          'natte': [('natte', False)],
          'nattes': [('natte', False)],
          'nbad': [('nbade', False)],
          'nbar': [('nbare', False)],
          'nbundet': [('nbinde', False)],
          'ncentrer': [('ncentrere', False)],
          'ncer': [('ncere', False)],
          'ncher': [('nche', False)],
          'nd': [('nde', False)],
          'ndager': [('ndagere', False)],
          'nder': [('ndere', False)],
          'ndes': [('nde', False)],
          'ndhuggedes': [('ndhugge', False)],
          'ndhugges': [('ndhugges', False)],
          'ndiker': [('ndikere', False)],
          'ndlede': [('ndle', False)],
          'ndrager': [('ndrage', False)],
          'ndredes': [('ndre', False)],
          'ndrer': [('ndre', False)],
          'ndruller': [('ndrullere', False)],
          'ndsende': [('ndse', False)],
          'ndser': [('ndse', False)],
          'ndså': [('ndse', False)],
          'ndt': [('nde', False)],
          'ndter': [('ndte', False)],
          'ndtes': [('nde', False)],
          'ndøde': [('ndø', False)],
          'ndødes': [('ndø', False)],
          'neb': [('nibe', False)],
          'nede': [('ne', False)],
          'nedes': [('ne', False)],
          'neede': [('ne', False)],
          'nel': [('nele', False)],
          'nelerer': [('nelere', False)],
          'nemlæst': [('nemlæse', False)],
          'nemlæste': [('nemlæse', False)],
          'nemlæstes': [('nemlæse', False)],
          'nende': [('ne', False)],
          'nent': [('nente', False)],
          'nente': [('nente', False)],
          'nentes': [('nente', False)],
          'ner': [('ne', False)],
          'nerede': [('nere', False)],
          'neredes': [('nere', False)],
          'nerer': [('nere', False)],
          'nerrende': [('nerre', False)],
          'nerret': [('nerre', False)],
          'nes': [('ne', False)],
          'net': [('nette', True)],
          'nfandtes': [('nfinde', False)],
          'nfattedes': [('nfatte', False)],
          'nfattes': [('nfatte', False)],
          'nferer': [('nferere', False)],
          'nfiltrer': [('nfiltrere', False)],
          'nfindes': [('nfinde', False)],
          'nfirmer': [('nfirmere', False)],
          'nfisker': [('nfiskere', False)],
          'nflammer': [('nflammere', False)],
          'nformer': [('nformere', False)],
          'nfortalt': [('nfortælle', False)],
          'nfortalte': [('nfortælle', False)],
          'nfortaltes': [('nfortælle', False)],
          'ngerer': [('ngere', False)],
          'ngler': [('ngle', False)],
          'ngrer': [('ngre', False)],
          'ngruer': [('ngruere', False)],
          'ngt': [('nge', False)],
          'ngte': [('nge', False)],
          'ngtes': [('nge', False)],
          'ngør': [('ngøre', False)],
          'nhaler': [('nhalere', False)],
          'nhuser': [('nhuse', False)],
          'nib': [('nibe', False)],
          'niber': [('nibe', False)],
          'nider': [('nide', False)],
          'nig': [('nige', False)],
          'niger': [('nige', False)],
          'niges': [('nige', False)],
          'nik': [('nikke', False)],
          'niser': [('nisere', False)],
          'nistrer': [('nistre', False)],
          'niver': [('nive', True)],
          'nives': [('nive', True)],
          'njer': [('njere', False)],
          'nkede': [('nke', False)],
          'nkedes': [('nke', False)],
          'nkende': [('nkende', False)],
          'nkles': [('nkle', False)],
          'nkliner': [('nklinere', False)],
          'nkrer': [('nkre', False)],
          'nkt': [('nke', False)],
          'nktes': [('nke', False)],
          'nkuler': [('nkulere', False)],
          'nkurrer': [('nkurrere', False)],
          'nled': [('nlede', False)],
          'nlede': [('nlede', False)],
          'nlededes': [('nlede', False)],
          'nledes': [('nlede', False)],
          'nledet': [('nlede', False)],
          'nlet': [('nle', False)],
          'nlever': [('nleve', False)],
          'nlyder': [('nlyde', False)],
          'nlæg': [('nlægge', False)],
          'nlæs': [('nlæse', False)],
          'nmas': [('nmasse', False)],
          'nmasser': [('nmasse', False)],
          'nne': [('nne', False)],
          'nneler': [('nnelere', False)],
          'nnet': [('nne', False)],
          'nnoter': [('nnotere', False)],
          'no': [('no', False)],
          'noede': [('no', False)],
          'noende': [('no', False)],
          'nol': [('nole', True)],
          'noler': [('nole', True)],
          'noppedes': [('noppe', True)],
          'noppes': [('noppe', True)],
          'nopret': [('nopre', True)],
          'nor': [('no', False)],
          'norker': [('norke', False)],
          'normer': [('normere', False)],
          'nos': [('nosse', True)],
          'nosset': [('nosse', True)],
          'not': [('note', True)],
          'noter': [('note', True), ('notere', True)],
          'nottes': [('notte', False)],
          'nrevne': [('nrive', False)],
          'ns': [('nse', False)],
          'nsende': [('nse', False)],
          'nserver': [('nservere', False)],
          'nses': [('nse', False)],
          'nsier': [('nsiere', False)],
          'nsiler': [('nsilere', False)],
          'nsir': [('nsire', False)],
          'nsiver': [('nsivere', False)],
          'nskar': [('nskære', False)],
          'nsker': [('nske', False)],
          'nskød': [('nskyde', False)],
          'nsledes': [('nsle', False)],
          'nslet': [('nsle', False)],
          'nslås': [('nslå', False)],
          'nsmitter': [('nsmittere', False)],
          'nspirer': [('nspirere', False)],
          'nsret': [('nsrette', False)],
          'nstak': [('nstikke', False)],
          'nstaller': [('nstallere', False)],
          'nstede': [('nste', False)],
          'nstedes': [('nste', False)],
          'nsteg': [('nstege', False)],
          'nster': [('nste', False)],
          'nstil': [('nstille', False)],
          'nstod': [('nstå', False)],
          'nstredes': [('nstre', False)],
          'nstrenges': [('nstrenge', False)],
          'nstrer': [('nstrere', False)],
          'nsulter': [('nsultere', False)],
          'nsurer': [('nsurere', False)],
          'nsyr': [('nsy', False)],
          'nså': [('nse', False)],
          'nsås': [('nse', False)],
          'nt': [('nte', False)],
          'ntag': [('ntage', False)],
          'ntakter': [('ntakte', False)],
          'ntalt': [('ntælle', False)],
          'ntalte': [('ntælle', False)],
          'ntaltes': [('ntælle', False)],
          'nte': [('nte', False)],
          'nten': [('nte', False)],
          'nter': [('ntere', False)],
          'nterner': [('nternere', False)],
          'ntes': [('nte', False)],
          'ntester': [('nteste', False)],
          'ntier': [('ntiere', False)],
          'ntiler': [('ntilere', False)],
          'ntiliser': [('ntilisere', False)],
          'ntiver': [('ntivere', False)],
          'ntoner': [('ntonere', False)],
          'ntraf': [('ntræffe', False)],
          'ntredes': [('ntre', False)],
          'ntrende': [('ntre', False)],
          'ntrer': [('ntre', False)],
          'ntræffes': [('ntræffe', False)],
          'ntrækkes': [('ntrække', False)],
          'nturer': [('nturere', False)],
          'ntæredes': [('ntæres', False)],
          'ntæres': [('ntæres', False)],
          'ntør': [('ntørre', False)],
          'nudsende': [('nudsende', False)],
          'nuer': [('nuere', False)],
          'nues': [('nue', False)],
          'nuet': [('nue', False)],
          'nug': [('nuge', False)],
          'nuger': [('nuge', False)],
          'nuller': [('nullere', False)],
          'nummerer': [('nummerere', True)],
          'nuppet': [('nuppe', False)],
          'nur': [('nurre', False)],
          'nus': [('nusse', True)],
          'nuser': [('nuse', False)],
          'nvader': [('nvadere', False)],
          'nvende': [('nvende', False)],
          'nventer': [('nventere', False)],
          'nvis': [('nvise', False)],
          'nviser': [('nvise', False)],
          'nvist': [('nvise', False)],
          'nvistes': [('nvise', False)],
          'ny': [('ny', False)],
          'nyede': [('ny', False)],
          'nyende': [('ny', False)],
          'nyer': [('ny', False)],
          'nyes': [('ny', False)],
          'nyr': [('ny', False)],
          'nys': [('nyse', True)],
          'nyser': [('nyse', True)],
          'nyst': [('nyse', True)],
          'nyste': [('nyse', True)],
          'nystes': [('nyse', True)],
          'nzer': [('nzere', False)],
          'nå': [('nå', False)],
          'nåd': [('nåde', False)],
          'når': [('nå', False)],
          'nås': [('nå', False)],
          'nægt': [('nægte', False)],
          'nægte': [('nægte', False)],
          'nægtes': [('nægte', False)],
          'næl': [('næle', False)],
          'næredes': [('nære', True)],
          'næres': [('nære', False)],
          'næst': [('næste', True)],
          'næste': [('næste', True)],
          'næstes': [('næste', True)],
          'nød': [('nøde', True), ('nyde', True)],
          'nøjedes': [('nøjes', True)],
          'nøjes': [('nøjes', True)],
          'nøjet': [('nøje', False)],
          'nøl': [('nøle', True)],
          'nøs': [('nyse', False)],
          'o': [('oe', False)],
          'oader': [('oade', False)],
          'oat': [('oate', False)],
          'oater': [('oate', False)],
          'ob': [('obbe', False)],
          'obbes': [('obbe', False)],
          'obede': [('obe', False)],
          'obedes': [('obe', False)],
          'ober': [('obere', False)],
          'oberede': [('obere', False)],
          'oberedes': [('obere', False)],
          'oberet': [('obere', False)],
          'oblende': [('oble', False)],
          'obler': [('oble', False)],
          'obrede': [('obre', False)],
          'obredes': [('obre', False)],
          'obrer': [('obre', False)],
          'obs': [('observere', True)],
          'ocer': [('ocere', False)],
          'oddedes': [('odde', False)],
          'odder': [('odde', False)],
          'ode': [('ode', False)],
          'oder': [('odere', False)],
          'odes': [('ode', False)],
          'odier': [('odiere', False)],
          'odlede': [('odle', False)],
          'odredes': [('odre', False)],
          'odrer': [('odre', False)],
          'odsende': [('odse', False)],
          'odser': [('odse', False)],
          'odte': [('odte', False)],
          'odter': [('odte', False)],
          'odtes': [('odte', False)],
          'oede': [('oe', False)],
          'oedes': [('oe', False)],
          'oende': [('oe', False)],
          'oer': [('oe', False)],
          'oes': [('oe', False)],
          'oet': [('o', False)],
          'ofer': [('ofere', False)],
          'ofiler': [('ofilere', False)],
          'oflede': [('ofle', False)],
          'ofler': [('ofle', False)],
          'oflet': [('ofle', False)],
          'oformer': [('oformere', False)],
          'ofrede': [('ofre', True)],
          'ofredes': [('ofre', False)],
          'ofrer': [('ofre', False)],
          'og': [('age', False)],
          'ogerer': [('ogere', False)],
          'oggedes': [('ogge', False)],
          'ogges': [('ogge', False)],
          'ogler': [('ogle', False)],
          'ogrer': [('ogre', False)],
          'ogt': [('oge', False)],
          'ogte': [('oge', False)],
          'ogtedes': [('ogte', False)],
          'ogtes': [('oge', False)],
          'oigner': [('oignere', False)],
          'ointer': [('ointere', False)],
          'oiser': [('oisere', False)],
          'ojer': [('ojere', False)],
          'ok': [('okke', False)],
          'okede': [('oke', False)],
          'okedes': [('oke', False)],
          'okende': [('oke', False)],
          'oker': [('okere', False)],
          'okkedes': [('okke', False)],
          'okkes': [('okke', False)],
          'okles': [('okle', False)],
          'okser': [('okse', False)],
          'okuler': [('okulere', False)],
          'ol': [('olle', False)],
          'oldedes': [('olde', False)],
          'oldende': [('olde', False)],
          'older': [('olde', False)],
          'olede': [('ole', False)],
          'oledes': [('ole', False)],
          'oler': [('olere', False)],
          'olerer': [('olerere', False)],
          'olet': [('ole', False)],
          'olgt': [('ælge', False)],
          'olgte': [('ælge', False)],
          'olgtes': [('ælge', False)],
          'olicer': [('olicere', False)],
          'olider': [('olidere', False)],
          'olig': [('olige', False)],
          'olkende': [('olke', False)],
          'olker': [('olke', False)],
          'oller': [('olle', False)],
          'olorer': [('olorere', False)],
          'olper': [('olpe', False)],
          'olter': [('olte', False)],
          'olterer': [('oltere', False)],
          'oltser': [('oltsere', False)],
          'olyser': [('olysere', False)],
          'olæg': [('olægge', False)],
          'om': [('ome', False)],
          'omber': [('ombe', False)],
          'omede': [('ome', False)],
          'omedes': [('ome', False)],
          'omener': [('omenere', False)],
          'omer': [('omere', False)],
          'omes': [('ome', False)],
          'omgås': [('omgå', True), ('omgås', True)],
          'omlæs': [('omlæsse', True)],
          'ommedes': [('omme', False)],
          'ommer': [('omme', False)],
          'ommitter': [('ommittere', False)],
          'omplanter': [('omplante', True)],
          'omsende': [('omse', False)],
          'on': [('onne', False)],
          'ondret': [('ondre', False)],
          'one': [('one', False)],
          'oner': [('onere', False)],
          'onet': [('one', False)],
          'ongedes': [('onge', False)],
          'onger': [('onge', False)],
          'onges': [('onge', False)],
          'ongler': [('onglere', False)],
          'onner': [('onne', False)],
          'onnes': [('onne', False)],
          'onser': [('onse', False)],
          'ook': [('ooke', False)],
          'ooker': [('ooke', False)],
          'oomer': [('oome', False)],
          'oon': [('oone', False)],
          'ooner': [('oone', False)],
          'oop': [('oope', False)],
          'ooper': [('oope', False)],
          'oost': [('ooste', False)],
          'ooste': [('ooste', False)],
          'oostes': [('ooste', False)],
          'oot': [('oote', False)],
          'ooter': [('oote', False)],
          'op': [('oppe', True)],
          'oper': [('opere', False)],
          'operer': [('operere', False)],
          'opet': [('ope', False)],
          'oplys': [('oplyse', True)],
          'oppedes': [('oppe', False)],
          'opper': [('oppe', False)],
          'oppes': [('oppe', False)],
          'opredes': [('opre', False)],
          'opres': [('opre', False)],
          'opret': [('oprette', False)],
          'oprundet': [('oprunde', True), ('oprinde', True)],
          'opsende': [('opsende', True)],
          'opuler': [('opulere', False)],
          'opæg': [('opægge', True)],
          'or': [('ore', False)],
          'orak': [('orakke', False)],
          'orakkes': [('orakke', False)],
          'orberede': [('orbere', False)],
          'orberedes': [('orberede', False)],
          'ordedes': [('orde', False)],
          'order': [('orde', False)],
          'orede': [('ore', False)],
          'oredes': [('ore', False)],
          'oren': [('ærge', False)],
          'orende': [('ore', False)],
          'orer': [('orere', False)],
          'oret': [('ærge', False)],
          'orger': [('orge', False)],
          'oriser': [('orisere', False)],
          'orkende': [('orke', True)],
          'orker': [('orkere', True), ('orke', True)],
          'orlyst': [('orlyste', False)],
          'orlyste': [('orlyste', False)],
          'ormer': [('orme', False)],
          'orne': [('ærge', False)],
          'orner': [('ornere', True)],
          'orper': [('orpe', False)],
          'orret': [('orrette', False)],
          'orsende': [('orsende', False)],
          'orser': [('orse', False)],
          'ortlede': [('ortlede', False)],
          'ortledes': [('ortlede', False)],
          'ortrives': [('ortrives', False)],
          'orunder': [('orunde', False)],
          'orviser': [('orvise', False)],
          'orvær': [('orværre', False)],
          'oråd': [('oræde', False)],
          'orær': [('orære', False)],
          'orød': [('orøde', False)],
          'orødes': [('orøde', False)],
          'orøg': [('orøge', False)],
          'orøget': [('orøge', False)],
          'os': [('ose', True)],
          'osende': [('ose', True)],
          'oser': [('ose', True)],
          'oses': [('ose', False)],
          'osledes': [('osle', False)],
          'oslet': [('osle', False)],
          'osne': [('yse', False)],
          'ossen': [('yse', False)],
          'osser': [('osse', False)],
          'ost': [('ose', True), ('oste', True)],
          'oste': [('oste', True), ('ose', True)],
          'ostede': [('oste', False)],
          'ostedes': [('oste', False)],
          'oster': [('oste', False)],
          'osterer': [('ostere', False)],
          'ostes': [('ose', True), ('oste', True)],
          'ostredes': [('ostre', False)],
          'ot': [('otte', False)],
          'oteger': [('otegere', False)],
          'oter': [('otere', False)],
          'otes': [('ote', False)],
          'otester': [('otestere', False)],
          'otiver': [('otivere', False)],
          'ottedes': [('otte', False)],
          'otter': [('otte', False)],
          'otterer': [('ottere', False)],
          'oucher': [('ouchere', False)],
          'ouer': [('ouere', False)],
          'oufler': [('ouflere', False)],
          'ourser': [('oursere', False)],
          'ousser': [('oussere', False)],
          'out': [('oute', True)],
          'outer': [('oute', False)],
          'ovende': [('ove', False)],
          'over': [('overe', False)],
          'overlever': [('overlevere', True), ('overleve', True)],
          'overser': [('overse', True)],
          'overså': [('overså', True), ('overse', True)],
          'oversås': [('overså', True), ('overse', True)],
          'oviser': [('ovisere', False)],
          'ovles': [('ovle', False)],
          'ovne': [('ove', False)],
          'oyer': [('oyere', False)],
          'p': [('ppe', False)],
          'pacer': [('pace', True)],
          'pader': [('pade', False)],
          'padser': [('padsere', False)],
          'pager': [('pagere', False)],
          'pagt': [('pagte', False)],
          'pagte': [('pagte', False)],
          'pagtes': [('pagte', False)],
          'pak': [('pakke', True)],
          'pal': [('palle', True)],
          'palper': [('palpere', True)],
          'palt': [('palte', False)],
          'palte': [('palte', False)],
          'paltes': [('palte', False)],
          'pam': [('pamme', False)],
          'pander': [('pande', True)],
          'paneler': [('panele', True), ('panelere', True)],
          'paner': [('panere', True)],
          'pank': [('panke', False)],
          'pantes': [('pante', True)],
          'par': [('parre', False)],
          'parer': [('parere', True)],
          'pares': [('pare', False)],
          'parker': [('parkere', False)],
          'parter': [('partere', True)],
          'pas': [('passe', False)],
          'passer': [('passere', True), ('passe', True)],
          'pat': [('patte', True)],
          'patte': [('patte', True)],
          'pattes': [('patte', True)],
          'paus': [('pause', True)],
          'pauser': [('pausere', True), ('pause', True)],
          'pbrydes': [('pbryde', False)],
          'pbundet': [('pbinde', False)],
          'pbød': [('pbyde', False)],
          'pdagedes': [('pdage', False)],
          'pdages': [('pdage', False)],
          'pdater': [('pdatere', False)],
          'pdrager': [('pdrage', False)],
          'peb': [('pibe', False)],
          'pede': [('pe', False)],
          'pedes': [('pe', False)],
          'peedes': [('peede', False)],
          'peg': [('pege', True)],
          'pegede': [('pege', False)],
          'peger': [('pege', True)],
          'peget': [('pege', False)],
          'pejlede': [('pejle', False)],
          'pejledes': [('pejle', True)],
          'peller': [('pellere', False)],
          'pende': [('pe', False)],
          'pender': [('pendere', False)],
          'penser': [('pensere', False)],
          'per': [('pe', False)],
          'perede': [('pere', False)],
          'peredes': [('pere', False)],
          'perer': [('pere', False)],
          'perforer': [('perforere', True)],
          'perger': [('pergere', False)],
          'persende': [('perse', True)],
          'perviser': [('pervisere', False)],
          'pes': [('pe', False)],
          'pet': [('pette', True)],
          'petter': [('pette', True)],
          'pfandtes': [('pfinde', False)],
          'pfattedes': [('pfatte', False)],
          'pfattes': [('pfatte', False)],
          'pfindes': [('pfinde', False)],
          'pformer': [('pformere', False)],
          'pgrader': [('pgradere', False)],
          'pgraver': [('pgrave', False)],
          'pgør': [('pgøre', False)],
          'phed': [('phede', False)],
          'phede': [('phede', False)],
          'phedes': [('phede', False)],
          'phuggedes': [('phugge', False)],
          'phugges': [('phugge', False)],
          'pib': [('pibe', True)],
          'piber': [('pibe', True)],
          'pid': [('pidde', False)],
          'pier': [('piere', False)],
          'piftes': [('pifte', True)],
          'pik': [('pikke', True)],
          'pil': [('pille', True), ('pile', True)],
          'piler': [('pile', False)],
          'pin': [('pine', False)],
          'pindes': [('pinde', False)],
          'piner': [('pine', True)],
          'pir': [('pirre', True)],
          'pis': [('pisse', True)],
          'piser': [('pise', False)],
          'piskende': [('piske', False)],
          'pklarer': [('pklare', False)],
          'planer': [('planere', True), ('plane', True)],
          'planker': [('planke', True)],
          'planter': [('plante', False)],
          'plede': [('ple', False)],
          'pledes': [('ple', False)],
          'pler': [('plere', False)],
          'plet': [('plette', True)],
          'pletter': [('plette', True), ('plettere', True)],
          'plever': [('pleve', False)],
          'plicer': [('plicere', False)],
          'pliker': [('plikere', False)],
          'pliner': [('plinere', False)],
          'plir': [('plire', True), ('plirre', True)],
          'plod': [('plade', False)],
          'plorer': [('plorere', False)],
          'plot': [('plotte', True)],
          'plys': [('plysse', True)],
          'plyst': [('plyse', False)],
          'plyste': [('plyse', False)],
          'plystes': [('plyse', False)],
          'plæg': [('plægge', False)],
          'plær': [('plære', False)],
          'plæs': [('plæse', False)],
          'plæste': [('plæse', False)],
          'pløj': [('pløje', False)],
          'pløjet': [('pløje', False)],
          'plør': [('pløre', True)],
          'pod': [('pode', True)],
          'poder': [('pode', False)],
          'pol': [('pole', False)],
          'poler': [('polere', True)],
          'polerer': [('polere', False)],
          'ponser': [('ponsere', False)],
          'porer': [('pore', False)],
          'poret': [('pore', False)],
          'porter': [('portere', False)],
          'poser': [('posere', True), ('pose', True)],
          'post': [('poste', True)],
          'poste': [('poste', True)],
          'poster': [('postere', True), ('poste', True)],
          'postes': [('poste', True)],
          'pottes': [('potte', True)],
          'ppet': [('ppe', False)],
          'ppoler': [('ppolere', False)],
          'pr': [('pre', False)],
          'prak': [('prakke', True)],
          'prakkes': [('prakke', True)],
          'pral': [('prale', True)],
          'prang': [('prange', True)],
          'pranger': [('prange', True)],
          'praver': [('pravere', False)],
          'pred': [('prede', False)],
          'prede': [('pre', False)],
          'predes': [('prede', False)],
          'premsende': [('premse', False)],
          'prende': [('pre', False)],
          'pres': [('presse', False)],
          'presser': [('presse', False)],
          'pret': [('pre', False)],
          'prier': [('priere', False)],
          'primer': [('prime', True)],
          'pringer': [('pringe', False)],
          'pris': [('prise', False)],
          'prist': [('prise', False)],
          'priste': [('prise', False)],
          'pristes': [('prise', False)],
          'prukne': [('prække', False)],
          'pruller': [('prulle', False)],
          'prunder': [('prunde', False)],
          'prunget': [('pringe', False)],
          'pryd': [('pryde', True)],
          'prydes': [('pryde', True)],
          'præk': [('præke', True)],
          'prækkedes': [('prække', False)],
          'præl': [('prælle', False)],
          'præstevi': [('præstevi', True), ('præstevie', True)],
          'præsteviede': [('præstevi', True), ('præstevie', True)],
          'præsteviende': [('præstevi', True), ('præstevie', True)],
          'præstevier': [('præstevi', True), ('præstevie', True)],
          'præstevies': [('præstevi', True), ('præstevie', True)],
          'præsteviet': [('præstevie', True), ('præstevi', True)],
          'præstevir': [('præstevie', True), ('præstevi', True)],
          'præstevis': [('præstevie', True), ('præstevi', True)],
          'prættedes': [('prætte', False)],
          'prætter': [('prætte', False)],
          'ps': [('pse', False)],
          'psende': [('pse', False)],
          'pses': [('pse', False)],
          'pskar': [('pskære', False)],
          'pskød': [('pskyde', False)],
          'psledes': [('psle', False)],
          'pslet': [('psle', False)],
          'pslås': [('pslå', False)],
          'pspar': [('pspare', False)],
          'psteg': [('pstige', False)],
          'pstil': [('pstille', False)],
          'pstod': [('pstå', False)],
          'pstrengedes': [('pstrenge', False)],
          'pstrenges': [('pstrenge', False)],
          'psummer': [('psummere', False)],
          'pt': [('pte', False)],
          'ptag': [('ptage', False)],
          'ptalt': [('ptælle', False)],
          'ptalte': [('ptælle', False)],
          'ptaltes': [('ptælle', False)],
          'ptank': [('ptanke', False)],
          'pter': [('ptere', False)],
          'ptimer': [('ptimere', False)],
          'ptrækkes': [('ptrække', False)],
          'ptræner': [('ptræne', False)],
          'pturer': [('pturere', False)],
          'ptør': [('ptø', False)],
          'pudrede': [('pudre', True)],
          'pudredes': [('pudre', True)],
          'pudret': [('pudre', True)],
          'pudsende': [('pudse', False)],
          'puffet': [('puffe', True)],
          'pug': [('puge', True)],
          'puger': [('puge', True)],
          'pukket': [('pukke', True)],
          'pul': [('pule', True)],
          'puler': [('pule', True)],
          'pulser': [('pulsere', True), ('pulse', True)],
          'pulter': [('pultere', False)],
          'punger': [('punge', True)],
          'punget': [('punge', True)],
          'punket': [('punke', True)],
          'puppet': [('puppe', False)],
          'pur': [('purre', False)],
          'purt': [('purte', False)],
          'purte': [('purte', False)],
          'purtes': [('purte', False)],
          'pust': [('puste', True)],
          'puste': [('puste', True)],
          'pustes': [('puste', False)],
          'pvarter': [('pvarte', False)],
          'pvis': [('pvise', False)],
          'pviser': [('pvise', False)],
          'pvistes': [('pvise', False)],
          'py': [('py', False)],
          'pyede': [('py', False)],
          'pyende': [('py', False)],
          'pyer': [('py', False)],
          'pyes': [('py', False)],
          'pyntes': [('pynte', True)],
          'pyr': [('py', False)],
          'pys': [('py', False)],
          'på': [('på', False)],
          'pår': [('på', False)],
          'pås': [('på', False)],
          'pæder': [('pæde', False)],
          'pæg': [('pæge', False)],
          'pæl': [('pæle', False)],
          'pæn': [('pæne', False)],
          'pændes': [('pænde', False)],
          'pændtes': [('pænde', False)],
          'pæner': [('pæne', False)],
          'pær': [('pærre', False)],
          'pøg': [('pøge', False)],
          'pøget': [('pøge', False)],
          "r'": [('ge', False)],
          'rab': [('rabbe', False)],
          'rabede': [('rabede', False)],
          'rabedes': [('rabede', False)],
          'raber': [('rabe', False)],
          'rader': [('radere', True)],
          'raffede': [('raffe', False)],
          'raffedes': [('raffe', False)],
          'raflede': [('rafle', True)],
          'rafledes': [('rafle', True)],
          'ragedes': [('rage', False)],
          'rager': [('rage', False)],
          'rages': [('rage', False)],
          'ragt': [('ragte', False)],
          'ragte': [('ragte', False)],
          'ragtes': [('ragte', False)],
          'raiser': [('raise', False)],
          'rak': [('rakke', True)],
          'rakkes': [('rakke', True)],
          'ral': [('ralle', True)],
          'raler': [('rale', False)],
          'ralt': [('ralte', False)],
          'ralte': [('ralte', False)],
          'raltes': [('ralte', False)],
          'rammer': [('ramme', True)],
          'ran': [('rane', False)],
          'randrer': [('randre', False)],
          'raner': [('rane', True)],
          'ranger': [('rangere', True)],
          'ranker': [('ranke', True)],
          'ranter': [('rantere', False)],
          'rantes': [('rante', False)],
          'rap': [('rappe', False)],
          'rappeller': [('rappelle', True), ('rappellere', True)],
          'rapper': [('rappe', True)],
          'rarmer': [('rarme', False)],
          'raser': [('rase', True), ('rasere', True)],
          'rasser': [('rassere', False)],
          'rast': [('raste', True)],
          'raste': [('raste', True)],
          'raster': [('raste', True)],
          'rastes': [('raste', True)],
          'rat': [('rate', True)],
          'rater': [('rate', False)],
          'ratte': [('ratte', False)],
          'rattes': [('ratte', False)],
          'rav': [('rave', False)],
          'raver': [('rave', True)],
          'raviger': [('ravige', False)],
          'rbad': [('rbade', False)],
          'rber': [('rbere', False)],
          'rberedes': [('rbere', False)],
          'rberet': [('rbere', False)],
          'rbor': [('rbore', False)],
          'rbrydes': [('rbryde', False)],
          'rbundet': [('rbinde', False)],
          'rburer': [('rburere', False)],
          'rbød': [('rbyde', False)],
          'rcer': [('rcere', False)],
          'rd': [('rde', False)],
          'rdater': [('rdatere', False)],
          'rde': [('rde', False)],
          'rder': [('rdere', False)],
          'rdes': [('rde', False)],
          'rdrager': [('rdrage', False)],
          'rdredes': [('rdre', False)],
          'rdrer': [('rdre', False)],
          'rdyr': [('rdyre', False)],
          'reb': [('rebe', True)],
          'rebet': [('rebe', True)],
          'red': [('ride', True), ('redde', True), ('rede', True)],
          'rede': [('rede', True)],
          'rededes': [('rede', False)],
          'reder': [('rede', False)],
          'redes': [('rede', True)],
          'redet': [('ride', True), ('rede', True)],
          'redte': [('rede', True)],
          'reg': [('rege', False)],
          'regav': [('regive', False)],
          'regede': [('rege', False)],
          'reger': [('regere', True)],
          'reget': [('rege', False)],
          'regne': [('regne', False)],
          'rejlede': [('rejle', False)],
          'rejledes': [('rejle', False)],
          'relancer': [('relancere', True)],
          'relerer': [('relere', False)],
          'rem': [('reme', False)],
          'remer': [('reme', False)],
          'remsende': [('remse', True)],
          'ren': [('rene', False)],
          'rende': [('rende', True)],
          'renedes': [('rene', False)],
          'rener': [('rene', False)],
          'renes': [('rene', False)],
          'rent': [('rente', False)],
          'rente': [('rente', False)],
          'rentes': [('rente', False)],
          'rer': [('re', False)],
          'rerede': [('rere', False)],
          'reredes': [('rere', False)],
          'rerer': [('rere', False)],
          'res': [('re', False)],
          'reset': [('resette', True)],
          'resigner': [('resignere', True)],
          'resser': [('ressere', False)],
          'rester': [('restere', False)],
          'resterer': [('restere', True)],
          'restiller': [('restille', False)],
          'ret': [('rette', True)],
          'retlede': [('retlede', True)],
          'retledes': [('retlede', True)],
          'revis': [('revise', False)],
          'revne': [('revne', True), ('rive', True)],
          'rfattedes': [('rfatte', False)],
          'rfattes': [('rfatte', False)],
          'rfede': [('rfe', False)],
          'rfedes': [('rfe', False)],
          'rferer': [('rferere', False)],
          'rfes': [('rfe', False)],
          'rfiner': [('rfine', False)],
          'rfor': [('rfore', False)],
          'rformer': [('rforme', False)],
          'rfærdedes': [('rfærde', False)],
          'rfærdes': [('rfærde', False)],
          'rgerer': [('rgere', False)],
          'rgler': [('rgle', False)],
          'rgraver': [('rgrave', False)],
          'rgrer': [('rgre', False)],
          'rgør': [('rgøre', False)],
          'ri': [('ri', False)],
          'rib': [('ribbe', True)],
          'riber': [('ribe', False)],
          'rider': [('ride', False)],
          'rides': [('ride', True)],
          'ridt': [('ridte', False)],
          'riede': [('ri', False)],
          'riende': [('ri', False)],
          'rier': [('ri', False)],
          'ries': [('ri', False)],
          'riftes': [('rifte', False)],
          'rig': [('rigge', True)],
          'rigedes': [('rige', False)],
          'riger': [('rige', False)],
          'riges': [('rige', False)],
          'rik': [('rikke', False)],
          'ril': [('rille', True)],
          'riler': [('rile', False)],
          'riliser': [('rilisere', False)],
          'riller': [('rille', True)],
          'rilret': [('rilre', False)],
          'rim': [('rime', True)],
          'rimer': [('rime', True)],
          'rimes': [('rime', False)],
          'rin': [('rine', False)],
          'rindes': [('rinde', False)],
          'rindret': [('rindre', False)],
          'riner': [('rine', False)],
          'ringer': [('ringe', True)],
          'ringerer': [('ringere', False)],
          'rint': [('rinte', False)],
          'rinte': [('rinte', False)],
          'rintes': [('rinte', False)],
          'rir': [('ri', False)],
          'ris': [('rise', True), ('ri', True)],
          'riser': [('rise', False)],
          'riskende': [('riske', False)],
          'rislede': [('risle', True)],
          'rist': [('riste', False)],
          'riste': [('riste', False)],
          'ristes': [('riste', False)],
          'river': [('rive', True)],
          'rives': [('rive', False)],
          'rjog': [('rjage', False)],
          'rkalker': [('rkalke', False)],
          'rkede': [('rke', False)],
          'rkedes': [('rke', False)],
          'rkende': [('rkende', False)],
          'rkiver': [('rkivere', False)],
          'rklarer': [('rklare', False)],
          'rkles': [('rkle', False)],
          'rkorter': [('rkorte', False)],
          'rkuer': [('rkue', False)],
          'rkul': [('rkulle', False)],
          'rkuler': [('rkulere', False)],
          'rlaver': [('rlave', False)],
          'rled': [('rlede', False)],
          'rlede': [('rlede', False)],
          'rledes': [('rlede', False)],
          'rlet': [('rle', False)],
          'rlig': [('rlige', False)],
          'rligt': [('rlige', False)],
          'rligte': [('rlige', False)],
          'rligtes': [('rlige', False)],
          'rliser': [('rlise', False)],
          'rlist': [('rlise', False)],
          'rliste': [('rlise', False)],
          'rlistes': [('rlise', False)],
          'rlod': [('rlade', False)],
          'rlokkedes': [('rlokke', False)],
          'rlokkes': [('rlokke', False)],
          'rlyder': [('rlyde', False)],
          'rlyst': [('rlyse', False)],
          'rlyste': [('rlyse', False)],
          'rlystes': [('rlyste', False)],
          'rlæg': [('rlægge', False)],
          'rlængedes': [('rlænge', False)],
          'rlænges': [('rlænge', False)],
          'rlæs': [('rlæse', False)],
          'rlæst': [('rlæse', False)],
          'rlæste': [('rlæse', False)],
          'rlæstes': [('rlæse', False)],
          'rm': [('rme', False)],
          'rmast': [('rmaste', False)],
          'rmaste': [('rmaste', False)],
          'rmastes': [('rmaste', False)],
          'rmede': [('rme', False)],
          'rmedes': [('rme', False)],
          'rmes': [('rme', False)],
          'rmorer': [('rmorere', False)],
          'rmpres': [('rmpresse', False)],
          'rmuler': [('rmulere', False)],
          'rmå': [('rmå', False)],
          'rmøbler': [('rmøble', False)],
          'rne': [('rne', False)],
          'rner': [('rnere', False)],
          'rnet': [('rne', False)],
          'rnys': [('rny', False)],
          'rnøjedes': [('rnøje', False)],
          'rnøjes': [('rnøje', False)],
          'ro': [('ro', True)],
          'rod': [('rode', False)],
          'roder': [('rode', True)],
          'roderer': [('rodere', False)],
          'roede': [('ro', True)],
          'roedes': [('ro', False)],
          'roende': [('ro', False)],
          'rog': [('roge', False)],
          'roger': [('roge', False)],
          'roges': [('roge', False)],
          'rolerer': [('rolere', False)],
          'roller': [('rollere', False)],
          'rom': [('romme', False)],
          'romer': [('rome', False)],
          'ron': [('rone', False)],
          'roner': [('rone', False)],
          'rop': [('roppe', False)],
          'ror': [('ro', False)],
          'ros': [('rose', True), ('ro', True)],
          'roser': [('rose', True)],
          'rosset': [('rosse', False)],
          'rost': [('rose', True)],
          'roste': [('rose', False)],
          'rostes': [('rose', True)],
          'rot': [('rotte', True)],
          'roter': [('rotere', True)],
          'rotter': [('rotte', True)],
          'rottes': [('rotte', True)],
          'rovedes': [('rove', False)],
          'rover': [('rove', False)],
          'roves': [('rove', False)],
          'rp': [('rpe', False)],
          'rpasser': [('rpasse', False)],
          'rper': [('rpere', False)],
          'rpet': [('rpe', False)],
          'rporer': [('rporere', False)],
          'rpunger': [('rpungere', False)],
          'rrede': [('rre', False)],
          'rredes': [('rre', False)],
          'rrende': [('rre', False)],
          'rret': [('rre', False)],
          'rrevne': [('rrive', False)],
          'rriger': [('rrigere', False)],
          'rringer': [('rringe', False)],
          'rriver': [('rrivere', False)],
          'rroder': [('rrodere', False)],
          'rrotter': [('rrottere', False)],
          'rruger': [('rrugere', False)],
          'rræk': [('rrække', False)],
          'rrækkes': [('rrække', False)],
          'rs': [('rse', False)],
          'rsende': [('rse', False)],
          'rses': [('rse', False)],
          'rsir': [('rsire', False)],
          'rsiver': [('rsivere', False)],
          'rskal': [('rskalle', False)],
          'rskar': [('rskære', False)],
          'rsker': [('rske', False)],
          'rskos': [('rsko', False)],
          'rskyldes': [('rskylde', False)],
          'rskyldtes': [('rskylde', False)],
          'rskød': [('rskyde', False)],
          'rsledes': [('rsle', False)],
          'rslet': [('rsle', False)],
          'rslås': [('rslå', False)],
          'rspil': [('rspille', False)],
          'rspirer': [('rspire', False)],
          'rstede': [('rste', False)],
          'rstedes': [('rste', False)],
          'rsteg': [('rstige', False)],
          'rster': [('rste', False)],
          'rstil': [('rstille', False)],
          'rstod': [('rstå', False)],
          'rstyr': [('rstyrre', False)],
          'rsur': [('rsure', False)],
          'rsynes': [('rsyne', False)],
          'rsyr': [('rsy', False)],
          'rså': [('rse', False)],
          'rsår': [('rså', False)],
          'rt': [('rte', False)],
          'rtag': [('rtage', False)],
          'rtalt': [('rtale', False)],
          'rtav': [('rtie', False)],
          'rte': [('rte', False)],
          'rtes': [('rte', False)],
          'rtiliser': [('rtilisere', False)],
          'rtlede': [('rtle', False)],
          'rtledes': [('rtle', False)],
          'rtredes': [('rtre', False)],
          'rtrende': [('rtre', False)],
          'rtrer': [('rtre', False)],
          'rtræffes': [('rtræffe', False)],
          'rtrækkes': [('rtrække', False)],
          'rtræner': [('rtræne', False)],
          'rtrætter': [('rtrættere', False)],
          'rtser': [('rtse', False)],
          'rturer': [('rturere', False)],
          'rtvist': [('rtvise', False)],
          'rtviste': [('rtvise', False)],
          'rtvistes': [('rtvise', False)],
          'rtykkedes': [('rtykke', False)],
          'rtykkes': [('rtykke', False)],
          'rtæres': [('rtære', False)],
          'ruder': [('rude', False)],
          'rudlede': [('rudle', False)],
          'rudledes': [('rudle', False)],
          'rues': [('rue', False)],
          'ruet': [('rue', False)],
          'rug': [('ruge', False)],
          'ruger': [('ruge', True)],
          'rugt': [('rugte', False)],
          'rugte': [('rugte', False)],
          'rugtes': [('rugte', False)],
          'ruiser': [('ruise', False)],
          'rukken': [('række', False)],
          'rukket': [('række', False)],
          'rukne': [('rukne', False)],
          'ruller': [('rulle', True)],
          'rumper': [('rumpere', False)],
          'runder': [('runde', True), ('rundere', True)],
          'rundet': [('rinde', True), ('runde', True)],
          'rundsende': [('rundsende', True)],
          'rungen': [('ringe', False)],
          'runget': [('runge', True)],
          'runker': [('runkere', False)],
          'rupper': [('ruppere', False)],
          'ruret': [('rurette', False)],
          'ruser': [('ruse', False)],
          'rust': [('ruste', False)],
          'ruste': [('ruste', False)],
          'rustes': [('ruste', False)],
          'rutter': [('rutte', True)],
          'rvar': [('rvare', False)],
          'rvende': [('rve', False)],
          'rventer': [('rvente', False)],
          'rvir': [('rvirre', False)],
          'rvis': [('rvise', False)],
          'rvist': [('rvise', False)],
          'rviste': [('rvise', False)],
          'rvistes': [('rvise', False)],
          'rvles': [('rvle', False)],
          'rvær': [('rvære', False)],
          'ry': [('ry', False)],
          'ryd': [('rydde', True)],
          'ryder': [('ryde', False)],
          'ryede': [('ry', False)],
          'ryende': [('ry', False)],
          'ryer': [('ry', False)],
          'ryg': [('ryge', False)],
          'rygtedes': [('rygtes', True)],
          'rygtes': [('rygtes', True)],
          'ryktes': [('rykke', False)],
          'ryn': [('ryne', False)],
          'rynes': [('ryne', False)],
          'ryntes': [('rynte', False)],
          'ryr': [('ry', False)],
          'rys': [('rysse', False)],
          'ryser': [('ryse', False)],
          'ryst': [('ryste', False)],
          'ryste': [('ryste', False)],
          'rystes': [('ryste', True)],
          'rå': [('rå', False)],
          'råd': [('råde', False)],
          'rådt': [('råde', False)],
          'rådte': [('råde', False)],
          'rådtes': [('råde', False)],
          'rålede': [('råle', False)],
          'rår': [('rå', False)],
          'rås': [('rå', False)],
          'ræbedes': [('ræbe', True)],
          'ræbes': [('ræbe', False)],
          'ræd': [('ræde', False)],
          'ræddedes': [('ræddes', True)],
          'ræder': [('ræde', False)],
          'ræffedes': [('ræffes', False)],
          'ræg': [('ræge', False)],
          'ræk': [('række', True)],
          'rækkedes': [('rækkes', False)],
          'rækkes': [('række', True)],
          'ræl': [('ræle', False)],
          'rældedes': [('rældes', False)],
          'rældes': [('rældes', False)],
          'rælt': [('ræle', False)],
          'rælte': [('ræle', False)],
          'ræltes': [('ræle', False)],
          'ræmmes': [('ræmme', False)],
          'ræmt': [('ræmme', False)],
          'ræmte': [('ræmme', False)],
          'ræmtes': [('ræmme', False)],
          'ræn': [('ræne', False)],
          'rændes': [('rænde', False)],
          'rændtes': [('rænde', False)],
          'ræner': [('ræne', False)],
          'rængtes': [('rænge', False)],
          'rær': [('ræ', False)],
          'ræredes': [('rære', False)],
          'ræs': [('ræse', True)],
          'ræster': [('ræstere', False)],
          'rættes': [('rætte', False)],
          'rævledes': [('rævle', False)],
          'røb': [('røbe', True)],
          'røben': [('rybe', False)],
          'røbet': [('røbe', True)],
          'røbne': [('rybe', False)],
          'rød': [('ryde', False)],
          'rødes': [('rydes', False)],
          'røg': [('røge', True), ('ryge', True)],
          'røget': [('ryge', True), ('røge', True)],
          'røgt': [('røgte', False)],
          'røgte': [('røgte', False)],
          'røgtes': [('røgte', False)],
          'røj': [('røje', False)],
          'røjedes': [('røje', False)],
          'røjes': [('røje', False)],
          'røjet': [('røje', False)],
          'røl': [('røle', False)],
          'røn': [('røne', False)],
          'rønnedes': [('rønnes', False)],
          'rønnes': [('rønnes', False)],
          'rør': [('røre', True)],
          'røs': [('rø', False)],
          'røst': [('røste', False)],
          'røste': [('røste', False)],
          'røstes': [('røste', False)],
          'sad': [('sidde', True)],
          'saft': [('safte', True)],
          'sagde': [('sige', False)],
          'sagdes': [('sige', False)],
          'sagedes': [('sage', False)],
          'sager': [('sage', False)],
          'sages': [('sage', False)],
          'sagt': [('sige', False)],
          'sak': [('sakke', False)],
          'sakrer': [('sakrere', False)],
          'salder': [('saldere', True)],
          'salt': [('salte', False)],
          'salte': [('salte', True)],
          'saltes': [('salte', False)],
          'samsende': [('samsende', True)],
          'saner': [('sanere', False)],
          'sang': [('synge', False)],
          'sank': [('sanke', True), ('synke', True)],
          'sarmer': [('sarmere', False)],
          'sav': [('save', False)],
          'sbundet': [('sbinde', False)],
          'scer': [('scere', False)],
          'schatter': [('schattere', True)],
          'sede': [('se', False)],
          'sedes': [('se', False)],
          'seedes': [('seede', True)],
          'segne': [('segne', True)],
          'sejlede': [('sejle', True)],
          'sejledes': [('sejle', False)],
          'selerer': [('selere', False)],
          'sende': [('sende', True)],
          'senter': [('sentere', False)],
          'ser': [('se', False)],
          'sercer': [('sercere', False)],
          'serede': [('sere', False)],
          'seredes': [('sere', False)],
          'serer': [('sere', False)],
          'serter': [('sertere', False)],
          'server': [('serve', True), ('servere', True)],
          'ses': [('ses', True), ('se', True)],
          'setes': [('ses', True)],
          'sferer': [('sferere', False)],
          'sformer': [('sformere', False)],
          'sforvis': [('sforvise', False)],
          'sgør': [('sgøre', False)],
          'si': [('si', True)],
          'sid': [('sidde', True)],
          'siede': [('si', True)],
          'siende': [('si', True)],
          'sier': [('si', True)],
          'sies': [('si', True)],
          'sifler': [('siflere', False)],
          'sig': [('sige', False)],
          'siger': [('sige', False)],
          'siges': [('sige', False)],
          'signer': [('signe', True), ('signere', True)],
          'sigt': [('sigte', False)],
          'sigte': [('sigte', True)],
          'sigtes': [('sigte', False)],
          'siler': [('sile', True)],
          'sindes': [('sinde', False)],
          'sir': [('si', True)],
          'sirer': [('sire', False)],
          'sis': [('si', True)],
          'sister': [('sistere', False)],
          'sivedes': [('sive', False)],
          'siver': [('sive', True)],
          'sives': [('sive', False)],
          'skal': [('skulle', True), ('skalle', True)],
          'skalker': [('skalke', True)],
          'skan': [('skanne', False)],
          'skar': [('skarre', True), ('skære', True)],
          'sked': [('skide', True)],
          'skede': [('ske', False)],
          'skedes': [('ske', False)],
          'skende': [('ske', False)],
          'sker': [('ske', True)],
          'skiftedes': [('skiftes', True), ('skifte', True)],
          'skiftes': [('skiftes', True), ('skifte', True)],
          'skil': [('skille', True)],
          'skilt': [('skilte', True), ('skille', True)],
          'skilte': [('skilte', True), ('skille', True)],
          'skiltes': [('skilte', True), ('skille', True)],
          'skim': [('skimme', True)],
          'skivedes': [('skive', False)],
          'skives': [('skive', False)],
          'skod': [('skodde', False)],
          'skoet': [('sko', False)],
          'skorter': [('skorte', True)],
          'skos': [('skose', True), ('sko', True)],
          'skovende': [('skove', False)],
          'skrab': [('skrabe', False)],
          'skriges': [('skrige', True)],
          'skrot': [('skrotte', True), ('skrote', True)],
          'skuer': [('skue', False)],
          'skur': [('skure', True), ('skurre', True)],
          'skurer': [('skure', True)],
          'skvadrer': [('skvadre', True)],
          'skyl': [('skylle', True)],
          'skyldes': [('skyldes', True), ('skylde', True)],
          'skyldtes': [('skyldes', True), ('skylde', True)],
          'skys': [('sky', True)],
          'skårede': [('skære', False)],
          'skåret': [('skære', False)],
          'skæl': [('skælle', True)],
          'skændes': [('skændes', True), ('skænde', True)],
          'skændtes': [('skændes', True), ('skænde', True)],
          'skød': [('skøde', True), ('skyde', True)],
          'slag': [('slagge', True)],
          'slagt': [('slagte', False)],
          'slagte': [('slagte', False)],
          'slanker': [('slanke', True)],
          'slap': [('slippe', True), ('slappe', True)],
          'slaver': [('slave', True)],
          'sled': [('slide', True)],
          'slede': [('sle', False)],
          'slededes': [('slede', False)],
          'sledet': [('slede', False)],
          'slen': [('sle', False)],
          'slet': [('slette', True)],
          'slod': [('slade', False)],
          'slog': [('slå', False)],
          'sloges': [('slås', True)],
          'slugt': [('sluge', False)],
          'slugte': [('sluge', False)],
          'slugtes': [('sluge', True)],
          'slus': [('sluse', True)],
          'slå': [('slå', False)],
          'slås': [('slås', True), ('slå', True)],
          'slæder': [('slæde', True)],
          'slæg': [('slægge', False)],
          'slægt': [('slægte', False)],
          'slægte': [('slægte', True)],
          'slægtes': [('slægte', False)],
          'slængedes': [('slænge', True)],
          'slænges': [('slænge', True)],
          'slængtes': [('slænge', True)],
          'sløj': [('sløje', True)],
          'sløjet': [('sløje', True)],
          'slør': [('sløre', False)],
          'smagt': [('smage', True)],
          'smagte': [('smage', False)],
          'smagtes': [('smage', False)],
          'smak': [('smække', True)],
          'smasker': [('smaske', True)],
          'smatter': [('smatte', True)],
          'smed': [('smide', True), ('smede', True)],
          'smedes': [('smede', True)],
          'smigrer': [('smigre', False)],
          'smiskende': [('smiske', True)],
          'smitter': [('smitte', True)],
          'sms': [("sms'e", True)],
          'små': [('små', False)],
          'smøg': [('smyge', True), ('smøge', True)],
          'smøget': [('smyge', True), ('smøge', True)],
          'sne': [('sne', False)],
          'sner': [('snerre', True), ('sne', True)],
          'snet': [('sne', False)],
          'snos': [('sno', True)],
          'snot': [('snotte', True)],
          'snuer': [('snue', True)],
          'snus': [('snuse', False)],
          'snød': [('snyde', True)],
          'sod': [('sode', True)],
          'soder': [('sode', True)],
          'soet': [('soe', False)],
          'sol': [('sole', True)],
          'soler': [('sole', True)],
          'solerer': [('solere', False)],
          'son': [('sone', False)],
          'soner': [('sone', False)],
          'sonner': [('sonnere', False)],
          'sorberedes': [('sorbere', False)],
          'sorter': [('sortere', False)],
          'sover': [('sove', False)],
          'soves': [('sove', False)],
          'sp': [('spe', False)],
          'spander': [('spandere', False)],
          'spar': [('sparre', True), ('spare', True)],
          'sparer': [('spare', False)],
          'sparker': [('sparke', False)],
          'spet': [('spe', False)],
          'spil': [('spile', True), ('spille', True)],
          'spin': [('spinne', True)],
          'spir': [('spire', True)],
          'spirer': [('spire', True)],
          'spis': [('spise', False)],
          'splanter': [('splantere', False)],
          'spoler': [('spole', True), ('spolere', True)],
          'sprak': [('sprække', True)],
          'sprang': [('springe', True)],
          'sprede': [('sprede', False)],
          'spræk': [('sprække', True)],
          'sr': [('sre', False)],
          'srede': [('sre', False)],
          'sredes': [('sre', False)],
          'srende': [('sre', False)],
          'srevne': [('srive', False)],
          'ss': [('sse', False)],
          'ssende': [('sse', False)],
          'sses': [('sse', False)],
          'ssiver': [('ssivere', False)],
          'ssoner': [('ssonere', False)],
          'sstil': [('sstille', False)],
          'ssurer': [('ssurere', False)],
          'st': [('ste', False)],
          'stabler': [('stable', True)],
          'stag': [('stage', True)],
          'stak': [('stakke', True), ('stikke', True)],
          'stal': [('stalle', True)],
          'staller': [('stalle', True)],
          'stalt': [('stalte', False)],
          'stalte': [('stalte', False)],
          'staltes': [('stalte', False)],
          'stanger': [('stange', True)],
          'stank': [('stinke', True)],
          'stav': [('stave', True)],
          'staver': [('stave', True)],
          'ste': [('ste', False)],
          'stede': [('stede', True)],
          'stedes': [('stede', False)],
          'steg': [('stege', True), ('stige', True)],
          'stegne': [('stige', False)],
          'ster': [('stere', False)],
          'stes': [('ste', False)],
          'stig': [('stige', False)],
          'stil': [('stile', True), ('stille', True)],
          'stiliser': [('stilisere', True)],
          'stiller': [('stille', False)],
          'stilt': [('stille', False)],
          'stilte': [('stille', False)],
          'stiltes': [('stille', False)],
          'stimedes': [('stime', True)],
          'stimer': [('stime', True)],
          'stimes': [('stime', True)],
          'stod': [('stande', True), ('stå', True)],
          'stoppedes': [('stoppe', False)],
          'stoppes': [('stoppe', False)],
          'straf': [('straffe', False)],
          'straffes': [('straffe', False)],
          'stredes': [('strides', True)],
          'strende': [('stre', False)],
          'strengedes': [('strenges', True), ('strenge', True)],
          'strenges': [('strenges', True), ('strenge', True)],
          'strer': [('stre', False)],
          'strides': [('strides', True), ('stride', True)],
          'struer': [('struere', False)],
          'stryg': [('stryge', False)],
          'strækkes': [('strække', False)],
          'studer': [('studere', False)],
          'stykkedes': [('stykke', False)],
          'stykkes': [('stykke', False)],
          'styr': [('styre', False)],
          'stækkedes': [('stække', True)],
          'stækkes': [('stække', True)],
          'stød': [('støde', False)],
          'stør': [('større', False)],
          'sudlede': [('sudle', False)],
          'sudledes': [('sudle', False)],
          'sug': [('suge', False)],
          'suger': [('suge', False)],
          'sukket': [('sukke', True)],
          'sult': [('sulte', False)],
          'sulte': [('sulte', False)],
          'sulter': [('sulte', True)],
          'sultes': [('sulte', False)],
          'sumerer': [('sumere', False)],
          'summer': [('summe', True), ('summere', True)],
          'sundet': [('sunde', True)],
          'sundt': [('sunde', False)],
          'sunget': [('synge', False)],
          'sungne': [('synge', False)],
          'supporter': [('supporte', True), ('supportere', True)],
          'sur': [('surre', True)],
          'surer': [('sure', False)],
          'suser': [('suse', True)],
          'svar': [('svare', False)],
          'sved': [('svide', True), ('svie', True), ('svede', True)],
          'svede': [('svede', False)],
          'svedes': [('svede', True)],
          'svedet': [('svide', True), ('svie', True)],
          'svegne': [('svige', False)],
          'svi': [('svie', True)],
          'sviende': [('svie', True)],
          'svier': [('svie', True)],
          'svies': [('svie', True)],
          'svir': [('svire', True), ('svirre', True)],
          'sy': [('sy', False)],
          'syede': [('sy', False)],
          'syende': [('sy', True)],
          'syer': [('sy', True)],
          'syes': [('sy', True)],
          'syn': [('syne', False)],
          'synes': [('syne', True), ('synes', True)],
          'syr': [('sy', True), ('syre', True)],
          'sys': [('sy', False)],
          'så': [('se', True), ('så', True)],
          'sår': [('såre', True), ('så', True)],
          'såret': [('såre', True)],
          'sås': [('se', True), ('ses', True), ('så', True)],
          'sæbedes': [('sæbe', True)],
          'sæbes': [('sæbe', False)],
          'sættes': [('sætte', False)],
          'søb': [('søbe', True)],
          'søbet': [('søbe', True)],
          'søg': [('søge', False)],
          'søl': [('søle', True)],
          't': [('e', False)],
          'ta': [('tage', True)],
          "ta'": [('tage', True)],
          'taber': [('tabe', True)],
          'tabler': [('tablere', False)],
          'tacher': [('tachere', False)],
          'taffer': [('taffere', False)],
          'tag': [('tage', True), ('tagge', True)],
          'tagedes': [('tage', False)],
          'tager': [('tage', False)],
          'tages': [('tage', False)],
          'tak': [('takke', False)],
          'takser': [('taksere', True)],
          'takt': [('takte', False)],
          'takte': [('takte', False)],
          'takter': [('taktere', True)],
          'taktes': [('takte', False)],
          'tal': [('tale', False)],
          'taler': [('tale', False)],
          'taljer': [('talje', True), ('taljere', True)],
          'talt': [('tælle', True), ('tale', True)],
          'talte': [('tælle', True), ('tale', True)],
          'taltes': [('tale', True), ('tælle', True)],
          'tancer': [('tancere', False)],
          'tang': [('tange', False)],
          'tanger': [('tangere', True)],
          'tank': [('tanke', True)],
          'tap': [('tappe', True)],
          'taper': [('tape', True)],
          'tarder': [('tardere', False)],
          'taser': [('tasere', False)],
          'tast': [('taste', False)],
          'taste': [('taste', True)],
          'tastes': [('taste', True)],
          'tat': [('tatte', False)],
          'tatte': [('tatte', False)],
          'tattes': [('tatte', False)],
          'tav': [('tie', True)],
          'tcher': [('tche', False)],
          'tdater': [('tdatere', False)],
          'te': [('te', True)],
          'ted': [('tede', False)],
          'tede': [('te', False)],
          'tededes': [('tede', False)],
          'teder': [('tede', False)],
          'tedes': [('te', False)],
          'tedet': [('tede', False)],
          'tedte': [('tede', False)],
          'teede': [('te', True)],
          'teger': [('tege', False)],
          'tegne': [('tegne', True)],
          'tejlede': [('tejle', False)],
          'tejledes': [('tejle', False)],
          'telt': [('telte', True)],
          'telte': [('telte', True)],
          'teltes': [('telte', True)],
          'tem': [('temme', False)],
          'temt': [('temme', False)],
          'temte': [('temme', False)],
          'temtes': [('temme', False)],
          'ten': [('tene', False)],
          'tende': [('te', False)],
          'tender': [('tendere', False)],
          'tenedes': [('tene', False)],
          'tener': [('tene', False)],
          'tenes': [('tene', False)],
          'tenser': [('tensere', False)],
          'tenter': [('tentere', False)],
          'ter': [('te', False)],
          'terede': [('tere', False)],
          'teredes': [('tere', False)],
          'terer': [('tere', False)],
          'terlever': [('terleve', False)],
          'terner': [('terne', True)],
          'terså': [('terse', False)],
          'tersås': [('terse', False)],
          'tes': [('te', True)],
          'tester': [('teste', True), ('testere', True)],
          'tgør': [('tgøre', False)],
          'tier': [('tie', True)],
          'tiet': [('tie', True)],
          'tiftes': [('tifte', False)],
          'tig': [('tigge', True)],
          'tigedes': [('tige', False)],
          'tiger': [('tige', False)],
          'tiges': [('tige', False)],
          'tik': [('tikke', False)],
          'tiler': [('tile', False)],
          'tiliser': [('tilise', True)],
          'tilkende': [('tilkende', True)],
          'tilså': [('tilse', True), ('tilså', True)],
          'tilsås': [('tilse', True), ('tilså', True)],
          'tilt': [('tilte', True)],
          'tilte': [('tilte', True)],
          'tiltes': [('tilte', True)],
          'timedes': [('times', True), ('time', True)],
          'timer': [('time', False)],
          'times': [('time', True), ('times', True)],
          'tindret': [('tindre', True)],
          'tint': [('tinte', True)],
          'tinte': [('tinte', True)],
          'tintes': [('tinte', True)],
          'tir': [('tirre', True)],
          'tis': [('tisse', True)],
          'tiser': [('tisere', False)],
          'tiskende': [('tiske', True)],
          'titrer': [('titrere', True)],
          'tivedes': [('tive', False)],
          'tiver': [('tive', False)],
          'tives': [('tive', False)],
          'tivne': [('tivne', False)],
          'tled': [('tlede', False)],
          'tlededes': [('tlede', False)],
          'tledet': [('tlede', False)],
          'tlet': [('tle', False)],
          'tlod': [('tlodde', False)],
          'tlæg': [('tlægge', False)],
          'tne': [('tne', False)],
          'tnet': [('tne', False)],
          'to': [('to', True)],
          'toede': [('to', True)],
          'toende': [('to', True)],
          'toet': [('to', True)],
          'tol': [('tole', False)],
          'toler': [('tole', False)],
          'ton': [('tone', False)],
          'toner': [('tone', False)],
          'tonger': [('tongere', False)],
          'tonner': [('tonnere', False)],
          'top': [('toppe', False)],
          'toppedes': [('toppes', True), ('toppe', True)],
          'toppes': [('toppes', True), ('toppe', True)],
          'tor': [('to', True)],
          'torker': [('torke', False)],
          'torter': [('tortere', True)],
          'tos': [('to', True), ('tosse', True)],
          'tosset': [('tosse', True)],
          'tottedes': [('tottes', True), ('totte', True)],
          'tottes': [('totte', True), ('tottes', True)],
          'tovedes': [('tove', True)],
          'tover': [('tove', True)],
          'toves': [('tove', True)],
          'tpasser': [('tpasse', False)],
          'tr': [('tre', False)],
          'traf': [('træffe', True)],
          'traffes': [('træffes', True)],
          'trak': [('trække', False)],
          'trakkes': [('trækkes', True)],
          'traster': [('trastere', False)],
          'traver': [('trave', True)],
          'tred': [('tride', False)],
          'trede': [('tre', False)],
          'tredet': [('tride', False)],
          'treger': [('trege', False)],
          'tren': [('trine', True)],
          'trende': [('trende', True)],
          'trer': [('trere', False)],
          'tresser': [('tresse', False)],
          'tret': [('tre', False)],
          'trevne': [('trive', False)],
          'trib': [('tribe', False)],
          'tridt': [('tride', False)],
          'trier': [('triere', False)],
          'triger': [('trigere', False)],
          'triller': [('trille', True)],
          'trim': [('trimme', True)],
          'triner': [('trine', True)],
          'tringer': [('tringere', False)],
          'tris': [('trisse', True)],
          'triser': [('trisere', False)],
          'trives': [('trives', False)],
          'tros': [('tro', True)],
          'truder': [('trudere', False)],
          'truer': [('true', True)],
          'trukne': [('trække', False)],
          'tryd': [('tryde', False)],
          'trydes': [('tryde', False)],
          'tryg': [('trygge', False)],
          'trådt': [('træde', False)],
          'trådte': [('træde', False)],
          'trådtes': [('træde', False)],
          'træffes': [('træffes', True), ('træffe', True)],
          'træk': [('trække', False)],
          'trækkes': [('trækkes', True), ('trække', True)],
          'træl': [('trælle', True)],
          'træner': [('trænere', True), ('træne', True)],
          'trættedes': [('trætte', True), ('trættes', True)],
          'trætter': [('trætte', True)],
          'trættes': [('trættes', True), ('trætte', True)],
          'trøg': [('tryge', False)],
          'trøget': [('tryge', False)],
          'trør': [('trø', False)],
          'ts': [('tse', False)],
          'tsende': [('tse', False)],
          'tser': [('tsere', False)],
          'tses': [('tse', False)],
          'tskar': [('tskære', False)],
          'tslås': [('tslå', False)],
          'tspil': [('tspille', False)],
          'tstil': [('tstille', False)],
          'tså': [('tse', False)],
          'tsås': [('tse', False)],
          'ttag': [('ttage', False)],
          'tte': [('tte', False)],
          'ttes': [('tte', False)],
          'ttester': [('ttestere', False)],
          'ttevis': [('ttevise', False)],
          'ttig': [('ttige', False)],
          'ttør': [('ttørre', False)],
          'tuder': [('tude', True)],
          'tudsende': [('tudse', False)],
          'tuer': [('tuere', False)],
          'tugt': [('tugte', True)],
          'tugte': [('tugte', True)],
          'tugtes': [('tugte', True)],
          'tukne': [('tikke', False)],
          'tumerer': [('tumere', False)],
          'tundet': [('tunde', False)],
          'tuner': [('tune', True)],
          'tunget': [('tunge', True)],
          'turer': [('ture', False)],
          'tus': [('tusse', True)],
          'tvende': [('tvende', False)],
          'tvis': [('tvise', False)],
          'tviser': [('tvise', False)],
          'tvist': [('tviste', True)],
          'tviste': [('tviste', True)],
          'tvistedes': [('tviste', True), ('tvistes', True)],
          'tvistes': [('tviste', True), ('tvistes', True)],
          'tvær': [('tvære', False)],
          'ty': [('ty', True)],
          'tyder': [('tyde', True)],
          'tyede': [('ty', True)],
          'tyende': [('ty', True)],
          'tyer': [('ty', True)],
          'tyes': [('ty', True)],
          'tykkedes': [('tykkes', True)],
          'tykkes': [('tykkes', True)],
          'tyler': [('tyle', False)],
          'tyn': [('tyne', False)],
          'tynes': [('tyne', False)],
          'tyr': [('ty', True), ('tyre', True)],
          'tys': [('ty', True), ('tysse', True)],
          'tå': [('tå', False)],
          'tår': [('tå', False)],
          'tårne': [('tårne', False)],
          'tås': [('tå', False)],
          'tækkedes': [('tækkes', True), ('tække', True)],
          'tækkes': [('tækkes', True), ('tække', True)],
          'tæmmes': [('tæmme', True)],
          'tændes': [('tænde', False)],
          'tændtes': [('tænde', True)],
          'tængtes': [('tænge', False)],
          'tæredes': [('tære', True)],
          'tæres': [('tære', True)],
          'tættes': [('tætte', False)],
          'tøb': [('tøbe', False)],
          'tød': [('tyde', False)],
          'tøjedes': [('tøje', False)],
          'tøjes': [('tøje', False)],
          'tøjet': [('tøje', False)],
          'tølt': [('tølte', True)],
          'tølte': [('tølte', True)],
          'tøltes': [('tølte', True)],
          'tør': [('tø', True), ('turde', True), ('tørre', True)],
          'tøs': [('tø', True)],
          'u': [('ue', False)],
          'uancer': [('uancere', False)],
          'ub': [('ubbe', False)],
          'ubbes': [('ubbe', False)],
          'ubiler': [('ubilere', False)],
          'ublende': [('uble', False)],
          'ubler': [('uble', False)],
          'ubrede': [('ubre', False)],
          'ubredes': [('ubre', False)],
          'ubrer': [('ubre', False)],
          'ucer': [('ucere', False)],
          'ud': [('ude', False)],
          'ude': [('ude', False)],
          'uder': [('udere', False)],
          'udes': [('ude', False)],
          'udgraver': [('udgrave', True)],
          'udhuggedes': [('udhugge', True)],
          'udlede': [('udlede', True)],
          'udledes': [('udlede', True)],
          'udlever': [('udlevere', True), ('udleve', True)],
          'udlod': [('udlodde', True)],
          'udrede': [('udrede', True)],
          'udredes': [('udrede', True)],
          'udrer': [('udre', False)],
          'udret': [('udrette', True)],
          'udsende': [('udsende', True)],
          'udser': [('udse', False)],
          'udspil': [('udspile', True), ('udspille', True)],
          'udså': [('udse', True)],
          'udt': [('yde', False)],
          'udviser': [('udvise', True)],
          'uede': [('ue', False)],
          'uedes': [('ue', False)],
          'ueller': [('uellere', False)],
          'uende': [('ue', False)],
          'uer': [('ue', False)],
          'uerede': [('uere', False)],
          'ueredes': [('uere', False)],
          'uerer': [('uere', False)],
          'uet': [('u', False)],
          'uetter': [('uettere', False)],
          'uf': [('uffe', False)],
          'uffedes': [('uffe', False)],
          'uffen': [('æffe', False)],
          'uffer': [('uffe', False)],
          'uffes': [('uffe', False)],
          'uffet': [('æffe', False)],
          'uflede': [('ufle', False)],
          'ufler': [('ufle', False)],
          'uflet': [('ufle', False)],
          'ufne': [('æffe', False)],
          'uftedes': [('ufte', False)],
          'ug': [('ugge', False)],
          'uger': [('ugere', False)],
          'ugerer': [('ugere', False)],
          'uggedes': [('ugge', False)],
          'ugges': [('ugge', False)],
          'ugler': [('ugle', False)],
          'ugner': [('ugne', False)],
          'ugtedes': [('ugte', False)],
          'uider': [('uide', False)],
          'uiller': [('uillere', False)],
          'uilte': [('uilte', False)],
          'uiltes': [('uilte', False)],
          'uiser': [('uisere', False)],
          'uk': [('ukke', False)],
          'ukkedes': [('ukke', False)],
          'ukken': [('ikke', False)],
          'ukkes': [('ukke', False)],
          'ukket': [('ikke', False)],
          'ukles': [('ukle', False)],
          'ukrer': [('ukre', False)],
          'ul': [('ulle', False)],
          'uldedes': [('ulde', False)],
          'uldende': [('ulde', False)],
          'ulder': [('ulde', True)],
          'uldne': [('uldne', False)],
          'ulede': [('ule', False)],
          'uledes': [('ule', False)],
          'uler': [('ulere', False)],
          'ulet': [('ule', False)],
          'uletter': [('ulettere', False)],
          'ulger': [('ulgere', False)],
          'ulgt': [('ølge', False)],
          'ulgte': [('ølge', False)],
          'ulgtes': [('ølge', False)],
          'ulkende': [('ulke', False)],
          'ulker': [('ulke', False)],
          'uller': [('ulle', False)],
          'ulpen': [('ælpe', False)],
          'ulper': [('ulpe', False)],
          'ulpet': [('ælpe', False)],
          'ulpne': [('ælpe', False)],
          'ult': [('ule', False)],
          'ulte': [('ule', False)],
          'ulterer': [('ultere', False)],
          'ultes': [('ule', False)],
          'ulykkedes': [('ulykke', False)],
          'ulykkes': [('ulykke', False)],
          'umer': [('umere', False)],
          'umerer': [('umerere', False)],
          'umfer': [('umfe', False)],
          'ummedes': [('umme', False)],
          'ummer': [('umme', False)],
          'ummerer': [('ummere', False)],
          'umper': [('umpe', False)],
          'umperer': [('umpere', False)],
          'umsende': [('umse', False)],
          'umuler': [('umulere', False)],
          'unde': [('unde', False)],
          'undedes': [('unde', False)],
          'unden': [('inde', False)],
          'under': [('unde', False)],
          'undet': [('inde', False)],
          'undhuggedes': [('undhugges', False)],
          'undne': [('inde', False)],
          'undret': [('undre', False)],
          'undsende': [('undse', True)],
          'undt': [('unde', True)],
          'undte': [('unde', False)],
          'undtes': [('unde', True)],
          'une': [('une', False)],
          'uner': [('unere', False)],
          'unet': [('une', False)],
          'ungedes': [('unge', False)],
          'ungen': [('ynge', False)],
          'unger': [('unge', False)],
          'unges': [('unge', False)],
          'unget': [('inge', False)],
          'ungne': [('inge', False)],
          'unken': [('ynke', False)],
          'unkende': [('unke', False)],
          'unker': [('unke', False)],
          'unket': [('ynke', False)],
          'unkne': [('ynke', False)],
          'unnes': [('unne', False)],
          'unser': [('unse', False)],
          'untedes': [('unte', False)],
          'unter': [('unte', False)],
          'uper': [('upere', False)],
          'upler': [('uple', False)],
          'uplet': [('uple', False)],
          'upne': [('ippe', False)],
          'uppedes': [('uppe', False)],
          'uppen': [('ippe', False)],
          'upper': [('uppe', False)],
          'uppes': [('uppe', False)],
          'uppet': [('ippe', False)],
          'ur': [('ure', False)],
          'urager': [('uragere', False)],
          'urater': [('uratere', False)],
          'urberede': [('urbere', False)],
          'urcer': [('urce', False)],
          'urede': [('ure', False)],
          'uredes': [('ure', False)],
          'urende': [('ure', False)],
          'urer': [('urere', False)],
          'uret': [('ure', False)],
          'urgt': [('ørge', False)],
          'urgte': [('ørge', False)],
          'urgtes': [('ørge', False)],
          'urier': [('uriere', False)],
          'uriner': [('urinere', True)],
          'uriser': [('urisere', False)],
          'urmuler': [('urmule', False)],
          'uros': [('uro', True)],
          'urrer': [('urre', False)],
          'urser': [('urse', False)],
          'urt': [('øre', False)],
          'urte': [('øre', False)],
          'urter': [('urte', False)],
          'urtes': [('øre', False)],
          'urver': [('urve', False)],
          'us': [('use', False)],
          'usende': [('use', False)],
          'user': [('usere', False)],
          'uses': [('use', False)],
          'usker': [('uske', False)],
          'usledes': [('usle', False)],
          'uslet': [('usle', False)],
          'usser': [('usse', False)],
          'ust': [('use', False)],
          'uste': [('use', False)],
          'ustede': [('uste', False)],
          'ustedes': [('uste', False)],
          'uster': [('uste', False)],
          'usterer': [('ustere', False)],
          'ustes': [('use', False)],
          'ustrer': [('ustrere', False)],
          'ut': [('utte', False)],
          'uter': [('utere', False)],
          'utes': [('ute', False)],
          'utlede': [('utle', False)],
          'utledes': [('utle', False)],
          'utredes': [('utre', False)],
          'utrende': [('utre', False)],
          'utrer': [('utre', False)],
          'uttedes': [('utte', False)],
          'utter': [('utte', False)],
          'utterer': [('uttere', False)],
          'uvende': [('uve', False)],
          'v': [('ve', False)],
          'vad': [('vade', True)],
          'vader': [('vade', True)],
          'vager': [('vagere', False)],
          'val': [('vale', False)],
          'valer': [('vale', False)],
          'valp': [('valpe', False)],
          'valt': [('valte', False)],
          'valte': [('valte', True)],
          'valtes': [('valte', True)],
          'vancer': [('vancere', False)],
          'vandrer': [('vandre', False)],
          'vank': [('vanke', True)],
          'var': [('være', True), ('vare', True)],
          'varer': [('vare', False)],
          'vares': [('vare', False)],
          'varmer': [('varme', False)],
          'varter': [('varte', True)],
          'vat': [('vatte', False)],
          'vatte': [('vatte', False)],
          'vatter': [('vattere', True)],
          'vattes': [('vatte', False)],
          'vd': [('vde', False)],
          'vde': [('vde', False)],
          'vdes': [('ve', False)],
          'ved': [('vide', True)],
          'vede': [('ve', False)],
          'veder': [('vede', False)],
          'vedes': [('ve', False)],
          'vedte': [('vede', False)],
          'vegne': [('vegne', True)],
          'vejlede': [('vejlede', True)],
          'vejledes': [('vejlede', True)],
          'veller': [('vellere', False)],
          'vende': [('vende', True)],
          'venerer': [('venere', False)],
          'venser': [('vensere', False)],
          'vent': [('vente', True)],
          'vente': [('vente', True)],
          'venter': [('vente', True)],
          'ventes': [('vente', False)],
          'ver': [('ve', False)],
          'verede': [('vere', False)],
          'veredes': [('vere', False)],
          'verer': [('vere', False)],
          'verger': [('vergere', False)],
          'veriser': [('verise', False)],
          'verser': [('versere', True)],
          'verter': [('vertere', False)],
          'ves': [('ve', False)],
          'vester': [('vestere', False)],
          'vi': [('vie', True), ('vi', True)],
          'vider': [('vide', False)],
          'vidt': [('vidte', False)],
          'viede': [('vie', True), ('vi', True)],
          'viende': [('vie', True), ('vi', True)],
          'vier': [('vie', True), ('vi', True)],
          'vies': [('vie', True), ('vi', True)],
          'viet': [('vi', True), ('vie', True)],
          'viftes': [('vifte', True)],
          'vig': [('vige', False)],
          'vigedes': [('vige', False)],
          'viger': [('vige', False)],
          'viges': [('vige', False)],
          'vigt': [('vigte', False)],
          'vigte': [('vigte', False)],
          'vigtes': [('vigte', False)],
          'vik': [('vikke', False)],
          'vil': [('ville', True)],
          'viler': [('vile', False)],
          'viliser': [('vilisere', False)],
          'vilt': [('vile', False)],
          'vilte': [('vile', False)],
          'viltes': [('vile', False)],
          'vimer': [('vime', False)],
          'vimes': [('vime', False)],
          'vin': [('vine', False)],
          'vindes': [('vinde', False)],
          'vindlede': [('vindle', False)],
          'vindledes': [('vindle', False)],
          'viner': [('vine', False)],
          'vir': [('vie', True), ('virre', True), ('vi', True)],
          'virer': [('vire', False)],
          'vis': [('vise', True), ('vie', True), ('vi', True), ('visse', True)],
          'viser': [('visere', True), ('vise', True)],
          'viskende': [('viske', False)],
          'vislede': [('visle', False)],
          'vist': [('vise', True)],
          'viste': [('vise', True)],
          'vistes': [('vise', True)],
          'vklarer': [('vklare', False)],
          'vlede': [('vle', False)],
          'vledes': [('vle', False)],
          'vlet': [('vle', False)],
          'vlæg': [('vlægge', False)],
          'vne': [('vne', False)],
          'vnet': [('vne', False)],
          'vnt': [('vne', False)],
          'vnte': [('vne', False)],
          'vntes': [('vne', False)],
          'vogt': [('vogte', True)],
          'vogte': [('vogte', False)],
          'vogtes': [('vogte', False)],
          'volerer': [('volere', False)],
          'volter': [('voltere', False)],
          'vor': [('værge', False)],
          'vovedes': [('vove', True)],
          'vover': [('vove', True)],
          'voves': [('vove', True)],
          'vr': [('vre', False)],
          'vred': [('vride', True)],
          'vrede': [('vre', False)],
          'vrededes': [('vredes', True)],
          'vredes': [('vredes', True)],
          'vredet': [('vride', True)],
          'vrende': [('vre', False)],
          'vrer': [('vrere', False)],
          'vret': [('vre', False)],
          'vrides': [('vride', False)],
          'vris': [('vrisse', True)],
          'vs': [('vse', False)],
          'vsende': [('vse', False)],
          'vses': [('vse', False)],
          'vt': [('vte', False)],
          'vtes': [('vte', False)],
          'vulpet': [('vulpe', False)],
          'vungen': [('vinge', False)],
          'vuppet': [('vuppe', False)],
          'vådt': [('vådte', True)],
          'vådte': [('vådte', True)],
          'vådtes': [('vådte', True)],
          'våret': [('våre', True)],
          'vås': [('våse', True)],
          'væd': [('vædde', True), ('væde', True)],
          'væddes': [('vædde', True)],
          'væg': [('væge', False)],
          'vægte': [('vægte', True)],
          'vægtes': [('vægte', True)],
          'væl': [('væle', False)],
          'vældes': [('vælde', False)],
          'vælt': [('vælte', True)],
          'væltes': [('vælte', True)],
          'væmmedes': [('væmmes', True)],
          'vær': [('være', True)],
          'væredes': [('være', False)],
          'væres': [('være', False)],
          'vært': [('værte', False)],
          'værte': [('værte', False)],
          'værtes': [('værte', False)],
          'væst': [('væste', False)],
          'væste': [('væste', False)],
          'væstes': [('væste', False)],
          'vættes': [('vætte', False)],
          'vøb': [('vøbe', False)],
          'w': [('we', False)],
          'wede': [('we', False)],
          'wedes': [('we', False)],
          'weet': [('weete', False)],
          'wende': [('we', False)],
          'wer': [('we', False)],
          'wes': [('we', False)],
          'wiper': [('wipe', False)],
          'wist': [('wiste', False)],
          'wiste': [('wiste', False)],
          'wistes': [('wiste', False)],
          'wlede': [('wle', False)],
          'wledes': [('wle', False)],
          'wlet': [('wle', False)],
          'ws': [('wse', False)],
          'wsende': [('wse', False)],
          'wses': [('wse', False)],
          'x': [('xe', False)],
          'xede': [('xe', False)],
          'xedes': [('xe', False)],
          'xelerer': [('xelere', False)],
          'xende': [('xe', False)],
          'xer': [('xe', False)],
          'xes': [('xe', False)],
          'xiet': [('xie', False)],
          'y': [('ye', False)],
          'ybede': [('ybe', False)],
          'ybedes': [('ybe', False)],
          'yd': [('yde', False)],
          'yddedes': [('ydde', False)],
          'ydder': [('ydde', False)],
          'yde': [('yde', False)],
          'yder': [('yde', True)],
          'ydes': [('yde', False)],
          'ydredes': [('ydre', False)],
          'ydrer': [('ydre', False)],
          'ydsende': [('ydse', False)],
          'ydser': [('ydse', False)],
          'ydt': [('yde', False)],
          'yede': [('ye', False)],
          'yedes': [('y', False)],
          'yende': [('ye', False)],
          'yer': [('ye', False)],
          'yerede': [('yere', False)],
          'yeredes': [('yere', False)],
          'yerer': [('yere', False)],
          'yes': [('ye', False)],
          'yet': [('y', False)],
          'yg': [('ygge', False)],
          'yger': [('yge', False)],
          'yggedes': [('ygge', False)],
          'ygges': [('ygge', False)],
          'ygler': [('ygle', False)],
          'ygner': [('ygne', False)],
          'ygtedes': [('ygte', False)],
          'yk': [('ykke', False)],
          'ykkedes': [('ykke', False)],
          'ykkes': [('ykke', False)],
          'ykles': [('ykle', False)],
          'ykte': [('ykke', False)],
          'yktes': [('ykkes', False)],
          'yl': [('ylle', False)],
          'yldedes': [('ylde', False)],
          'yldende': [('ylde', False)],
          'ylder': [('ylde', False)],
          'yldne': [('yldne', False)],
          'ylede': [('yle', False)],
          'yledes': [('yle', False)],
          'ylet': [('yle', False)],
          'ylkende': [('ylke', False)],
          'ylker': [('ylke', False)],
          'yller': [('ylle', False)],
          'ylper': [('ylpe', False)],
          'ylter': [('ylte', False)],
          'ymper': [('ympe', False)],
          'ymt': [('ymte', True)],
          'ymte': [('ymte', True)],
          'ymtes': [('ymte', True)],
          'yn': [('ynne', False)],
          'ynde': [('ynde', False)],
          'yndedes': [('ynde', False)],
          'ynder': [('ynde', True)],
          'yndret': [('yndre', False)],
          'yndte': [('ynde', False)],
          'yne': [('yne', False)],
          'ynet': [('yne', False)],
          'yngedes': [('ynge', False)],
          'ynger': [('ynge', False)],
          'ynges': [('ynge', False)],
          'ynkende': [('ynke', False)],
          'ynker': [('ynke', True)],
          'ynnedes': [('ynne', False)],
          'ynner': [('ynne', False)],
          'ynnes': [('ynne', False)],
          'ynser': [('ynse', False)],
          'yntedes': [('ynte', False)],
          'ynter': [('ynte', False)],
          'yntes': [('ynes', False)],
          'ypet': [('ype', False)],
          'ypiser': [('ypisere', False)],
          'yppedes': [('yppe', False)],
          'ypper': [('yppe', False)],
          'yppes': [('yppe', False)],
          'yptør': [('yptørre', False)],
          'yr': [('yre', False)],
          'yrdedes': [('yrde', False)],
          'yrder': [('yrde', False)],
          'yrede': [('yre', False)],
          'yredes': [('yre', False)],
          'yrende': [('yre', False)],
          'yret': [('yre', False)],
          'yriser': [('yrisere', False)],
          'yrkende': [('yrke', False)],
          'yrker': [('yrke', False)],
          'yrner': [('yrne', False)],
          'yrrer': [('yrre', False)],
          'yrter': [('yrte', False)],
          'ys': [('yse', False)],
          'ysende': [('yse', False)],
          'yses': [('yse', False)],
          'ysledes': [('ysle', False)],
          'yslet': [('ysle', False)],
          'ysner': [('ysne', False)],
          'ysser': [('ysse', False)],
          'yst': [('yse', False)],
          'yste': [('yse', False)],
          'ystede': [('yste', False)],
          'ystedes': [('yste', False)],
          'yster': [('yste', False)],
          'ystes': [('yse', False)],
          'ystredes': [('ystre', False)],
          'yt': [('ytte', False)],
          'ytredes': [('ytre', True)],
          'ytrende': [('ytre', True)],
          'ytrer': [('ytre', True)],
          'yttedes': [('ytte', False)],
          'ytter': [('ytte', False)],
          'yvende': [('yve', False)],
          'z': [('ze', False)],
          'zag': [('zagge', False)],
          'zap': [('zappe', True)],
          'zede': [('ze', False)],
          'zedes': [('ze', False)],
          'zende': [('ze', False)],
          'zer': [('ze', False)],
          'zerede': [('zere', False)],
          'zeredes': [('zere', False)],
          'zerer': [('zere', False)],
          'zes': [('ze', False)],
          'åbede': [('åbe', False)],
          'åbedes': [('åbe', False)],
          'åbød': [('åbyde', False)],
          'åd': [('æde', False)],
          'åde': [('åde', False)],
          'ådes': [('åde', False)],
          'ådrager': [('ådrage', False)],
          'ådredes': [('ådre', True)],
          'ådrer': [('ådre', True)],
          'ådter': [('ådte', False)],
          'åedes': [('ås', False)],
          'åen': [('å', False)],
          'ående': [('å', False)],
          'ået': [('å', False)],
          'åger': [('åge', False)],
          'ågner': [('ågne', False)],
          'ågrer': [('ågre', True)],
          'åkende': [('åkende', False)],
          'ålede': [('åle', True)],
          'åledes': [('åle', False)],
          'ålen': [('æle', False)],
          'ålet': [('åle', True)],
          'ålig': [('åligge', False)],
          'ålne': [('æle', False)],
          'ålret': [('ålrette', False)],
          'ålt': [('åle', False)],
          'ålte': [('åle', False)],
          'åltes': [('åle', False)],
          'ålæg': [('ålægge', False)],
          'åmindedes': [('åminde', False)],
          'åmindes': [('åminde', False)],
          'ånde': [('ånde', False)],
          'åndedes': [('ånde', False)],
          'ånder': [('ånde', False)],
          'åndruller': [('åndrulle', False)],
          'åndter': [('åndtere', False)],
          'åne': [('åne', False)],
          'ånet': [('åne', False)],
          'ånt': [('åne', False)],
          'ånte': [('åne', False)],
          'åntes': [('åne', False)],
          'ånød': [('ånøde', False)],
          'år': [('åre', False)],
          'årede': [('åre', False)],
          'åredes': [('åre', False)],
          'åren': [('ære', False)],
          'årende': [('åre', False)],
          'året': [('åre', True)],
          'årne': [('ære', False)],
          'årner': [('årne', False)],
          'åsende': [('åse', False)],
          'åses': [('åse', False)],
          'åst': [('åse', False)],
          'åste': [('åse', False)],
          'åsteg': [('åstege', False)],
          'åstes': [('åse', False)],
          'åstod': [('åstå', False)],
          'åså': [('åse', False)],
          'åsås': [('åse', False)],
          'åt': [('åtte', False)],
          'åtag': [('åtage', False)],
          'åtalt': [('åtale', False)],
          'åtalte': [('åtale', False)],
          'åtaltes': [('åtale', False)],
          'åtraf': [('åtræffe', False)],
          'åtræffes': [('åtræffe', False)],
          'åttedes': [('åtte', False)],
          'åtter': [('åtte', False)],
          'åvis': [('åvise', False)],
          'åviser': [('åvise', False)],
          'åvistes': [('åvise', False)],
          'æbbedes': [('æbbes', False)],
          'æbede': [('æbe', False)],
          'æbedes': [('æbes', False)],
          'æbes': [('æbes', False)],
          'æd': [('æde', True)],
          'æddedes': [('ædde', False)],
          'ædder': [('ædde', False)],
          'æddes': [('æddes', False)],
          'æde': [('æde', True)],
          'æder': [('æde', True)],
          'ædes': [('æde', False)],
          'ædik': [('ædike', False)],
          'ædlede': [('ædle', False)],
          'ædredes': [('ædre', False)],
          'ædrer': [('ædre', False)],
          'ædt': [('æde', False)],
          'ædtes': [('æde', False)],
          'æedes': [('æ', False)],
          'æende': [('æ', False)],
          'æet': [('æ', False)],
          'æf': [('æffe', False)],
          'æferer': [('æferere', False)],
          'æffedes': [('æffe', False)],
          'æffer': [('æffe', False)],
          'æffes': [('æffe', False)],
          'æftedes': [('æfte', False)],
          'æg': [('ægge', False)],
          'æger': [('æge', False)],
          'æggedes': [('ægge', False)],
          'ægges': [('ægge', False)],
          'ægler': [('ægle', False)],
          'ægrer': [('ægre', False)],
          'ægt': [('ægte', True)],
          'ægte': [('ægte', True)],
          'ægtedes': [('ægte', False)],
          'ægtes': [('ægte', True)],
          'ægtevi': [('ægtevi', True), ('ægtevie', True)],
          'ægteviede': [('ægtevi', True), ('ægtevie', True)],
          'ægteviende': [('ægtevi', True), ('ægtevie', True)],
          'ægtevier': [('ægtevi', True), ('ægtevie', True)],
          'ægtevies': [('ægtevi', True), ('ægtevie', True)],
          'ægteviet': [('ægtevie', True), ('ægtevi', True)],
          'ægtevir': [('ægtevie', True), ('ægtevi', True)],
          'ægtevis': [('ægtevie', True), ('ægtevi', True)],
          'æiser': [('æisere', False)],
          'æk': [('ække', False)],
          'ækede': [('æke', False)],
          'ækedes': [('æke', False)],
          'ækende': [('æke', False)],
          'æker': [('æke', False)],
          'ækkedes': [('ække', False)],
          'ækkes': [('ække', False)],
          'ækledes': [('ækles', True)],
          'ækles': [('ækles', True)],
          'æl': [('ælle', False)],
          'ældedes': [('ælde', False)],
          'ældende': [('ælde', False)],
          'ælder': [('ælde', False)],
          'ældes': [('ælde', True)],
          'ælede': [('æle', False)],
          'æledes': [('æle', False)],
          'ælet': [('æle', False)],
          'ælkende': [('ælke', False)],
          'ælker': [('ælke', False)],
          'æller': [('ælle', False)],
          'ælper': [('ælpe', False)],
          'ælt': [('ælte', True)],
          'ælte': [('ælte', True)],
          'ælter': [('ælte', False)],
          'æltes': [('ælte', True)],
          'æluder': [('æludere', False)],
          'ælvende': [('ælve', False)],
          'ælver': [('ælve', False)],
          'æmmedes': [('æmme', False)],
          'æmmer': [('æmme', False)],
          'æmmes': [('æmmes', False)],
          'æmper': [('æmpe', False)],
          'æmt': [('æmte', False)],
          'æmte': [('æmte', False)],
          'æmtes': [('æmte', False)],
          'æn': [('ænne', False)],
          'ænde': [('ænde', False)],
          'ændedes': [('ænde', False)],
          'ænder': [('ænde', False)],
          'ændret': [('ændre', True)],
          'ændte': [('ænde', False)],
          'æne': [('æne', False)],
          'ænet': [('æne', False)],
          'ængedes': [('ænge', False)],
          'ænger': [('ænge', False)],
          'ænges': [('ænge', False)],
          'ænkende': [('ænke', False)],
          'ænker': [('ænke', False)],
          'ænnedes': [('ænne', False)],
          'ænner': [('ænne', False)],
          'ænnes': [('ænne', False)],
          'ænser': [('ænse', False)],
          'ænt': [('ænne', False)],
          'ænte': [('ænne', False)],
          'æntes': [('ænne', False)],
          'æparer': [('æparere', False)],
          'æppedes': [('æppe', False)],
          'æpper': [('æppe', False)],
          'æppes': [('æppe', False)],
          'ær': [('ære', False)],
          'ærdedes': [('ærde', False)],
          'ærder': [('ærde', False)],
          'ærede': [('ære', False)],
          'æredes': [('ære', True)],
          'ærende': [('ære', False)],
          'ærer': [('ære', True)],
          'æres': [('ære', True)],
          'ærester': [('æreste', False)],
          'æresterer': [('æresterere', False)],
          'æret': [('ære', False)],
          'ærger': [('ærge', False)],
          'ærkende': [('ærke', False)],
          'ærker': [('ærke', False)],
          'ærmer': [('ærme', False)],
          'ærner': [('ærne', False)],
          'ærper': [('ærpe', False)],
          'ærrer': [('ærre', False)],
          'ært': [('ære', False)],
          'ærte': [('ære', False)],
          'ærter': [('ærte', False)],
          'ærtes': [('ære', False)],
          'ærver': [('ærve', False)],
          'æs': [('æse', False)],
          'æsende': [('æse', False)],
          'æserver': [('æservere', False)],
          'æses': [('æse', False)],
          'æsker': [('æske', False)],
          'æsser': [('æsse', False)],
          'æstede': [('æste', False)],
          'æstedes': [('æste', False)],
          'æster': [('æste', False)],
          'æsterer': [('æstere', False)],
          'æt': [('ætte', False)],
          'ætser': [('ætse', True)],
          'ættedes': [('ætte', False)],
          'ætter': [('ætte', False)],
          'ætterer': [('ættere', False)],
          'ævdes': [('ævde', False)],
          'ævende': [('æve', False)],
          'ævledes': [('ævle', True)],
          'ævles': [('ævle', True)],
          'ævredes': [('ævre', False)],
          'ævrer': [('ævre', False)],
          'éd': [('ide', False)],
          'øbede': [('øbe', False)],
          'øbedes': [('øbe', False)],
          'øben': [('øbe', False)],
          'øblende': [('øble', False)],
          'øbler': [('øble', False)],
          'øbne': [('øbe', False)],
          'ød': [('øde', False)],
          'øde': [('øde', False)],
          'ødes': [('øde', False)],
          'ødredes': [('ødre', False)],
          'ødrer': [('ødre', False)],
          'ødslet': [('ødsle', False)],
          'ødt': [('øde', False)],
          'ødtes': [('øde', False)],
          'øedes': [('ø', False)],
          'øende': [('ø', False)],
          'øet': [('ø', False)],
          'øf': [('øffe', False)],
          'øffedes': [('øffe', False)],
          'øffer': [('øffe', False)],
          'øffes': [('øffe', False)],
          'øfiser': [('øfisere', False)],
          'øflede': [('øfle', False)],
          'øfler': [('øfle', False)],
          'øflet': [('øfle', False)],
          'øftedes': [('øfte', False)],
          'øg': [('øge', True)],
          'øgen': [('yge', False)],
          'øger': [('øge', False)],
          'øget': [('øge', True)],
          'øgler': [('øgle', False)],
          'øgne': [('yge', False)],
          'øgt': [('øge', False)],
          'øgte': [('øge', False)],
          'øgtedes': [('øgte', False)],
          'øgtes': [('øge', False)],
          'øj': [('øje', True)],
          'øjedes': [('øje', True)],
          'øjen': [('yve', False)],
          'øjes': [('øje', True)],
          'øjet': [('øje', True)],
          'øjne': [('øjne', True)],
          'øk': [('økke', False)],
          'økkedes': [('økke', False)],
          'økkes': [('økke', False)],
          'økser': [('økse', True)],
          'øl': [('ølle', False)],
          'ølede': [('øle', False)],
          'øledes': [('øle', False)],
          'ølet': [('øle', False)],
          'øller': [('ølle', False)],
          'ølt': [('øle', False)],
          'ølte': [('øle', False)],
          'ølter': [('ølte', False)],
          'øltes': [('øle', False)],
          'ølvende': [('ølve', False)],
          'ølver': [('ølve', False)],
          'ømmedes': [('ømme', True)],
          'ømmer': [('ømme', False)],
          'øn': [('ønne', False)],
          'øndret': [('øndre', False)],
          'øne': [('øne', False)],
          'ønet': [('øne', False)],
          'ønnedes': [('ønne', False)],
          'ønner': [('ønne', False)],
          'ønnes': [('ønne', False)],
          'ønser': [('ønse', False)],
          'ønstrer': [('ønstre', False)],
          'øntedes': [('ønte', False)],
          'ønter': [('ønte', False)],
          'øppedes': [('øppe', False)],
          'øpper': [('øppe', False)],
          'øppes': [('øppe', False)],
          'ør': [('øre', False)],
          'ørdedes': [('ørde', False)],
          'ørder': [('ørde', False)],
          'ørede': [('øre', False)],
          'øredes': [('øre', False)],
          'ørende': [('øre', False)],
          'øret': [('øre', False)],
          'ørger': [('ørge', False)],
          'ørkende': [('ørke', False)],
          'ørker': [('ørke', False)],
          'ørmer': [('ørme', False)],
          'ørner': [('ørne', False)],
          'ørrer': [('ørre', False)],
          'ørsteg': [('ørstege', False)],
          'ørt': [('øre', False)],
          'ørte': [('øre', False)],
          'ørtes': [('øre', False)],
          'øs': [('øse', True)],
          'øsende': [('øse', True)],
          'øses': [('øse', False)],
          'øsner': [('øsne', False)],
          'øsser': [('øsse', False)],
          'øst': [('øse', False)],
          'øste': [('øse', False)],
          'østede': [('øste', False)],
          'østedes': [('øste', False)],
          'øster': [('øste', False)],
          'østes': [('øse', False)],
          'øt': [('øtte', False)],
          'øttedes': [('øtte', False)],
          'øtter': [('øtte', False)],
          'øvende': [('øve', False)],
          'øvles': [('øvle', False)],
          'øvrende': [('øvrende', False)]},
 'VERB_ADJ': {'mindre': [('lille', True)], 'små': [('lille', True)]},
 'VERB_ADV': {'stort': [('stor', True), ('stort', True)]},
 'VERB_NOUN': {'den': [('', False)],
               'ens': [('', False)],
               'er': [('', False)],
               'erne': [('', False)],
               'ger': [('ge', False)],
               'len': [('', False)],
               'mer': [('me', False)],
               'oer': [('oe', False)],
               'rden': [('rd', False)],
               'rnes': [('', False)],
               'sterne': [('st', False)],
               't': [('', False)],
               'terne': [('te', False)],
               'ænder': [('and', False)],
               'ænderne': [('and', False)]},
 'VERB_VERB': {'r': [('', False)]},
 'X': {'.-jur.': [('idata-juris', False)],
       '.-psych.': [('idatus-psychologiae', False)],
       '.-techn.': [('entiatus-technices', False)],
       'c.-jur.': [('centiatus-juris', False)],
       'fru': [('frue', True)],
       'ou': [('ou', False)],
       'r.-scient.-pol.': [('octor-scientiarum-politicarum', False)],
       'ru': [('ru', True)],
       '×': [('x', True)]},
 '_NOUN': {'den': [('den', False)],
           'dens': [('den', False)],
           'der': [('de', False)],
           'en': [('', False)],
           'ens': [('', False)],
           'er': [('', False)],
           'erne': [('', False)],
           'ernes': [('', False)],
           'iserne': [('is', False)],
           'k.': [('ykke', False)],
           'kerne': [('ker', False)],
           'rernes': [('rer', False)],
           'serne': [('ser', False)],
           'yden': [('yd', False)]},
 '_VERB': {'ad': [('ede', False)],
           'alte': [('ælle', False)],
           'er': [('e', False)],
           'ever': [('eve', False)],
           'g': [('ge', False)],
           'i': [('ive', False)],
           'od': [('å', False)],
           's': [('se', False)],
           'ver': [('vere', False)]}}